/*
 * Accelerator_Maps methods tests
 * Testing Accelerator_Maps methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include <fcntl.h>

static gint global_result;
static gchar* global_path;
static guint global_key;
static guint global_mods;
static guint global_changed;

static const GScannerConfig scanner_struct =
{
  (
   " \t\r\n"
   )			/* cset_skip_characters */,
  (
   G_CSET_a_2_z
   "_"
   G_CSET_A_2_Z
   )			/* cset_identifier_first */,
  (
   G_CSET_a_2_z
   "_-0123456789"
   G_CSET_A_2_Z
   )			/* cset_identifier_nth */,
  ( "#\n" )		/* cpair_comment_single */,
  
  TRUE			/* case_sensitive */,
  
  TRUE			/* skip_comment_multi */,
  TRUE			/* skip_comment_single */,
  TRUE			/* scan_comment_multi */,
  TRUE			/* scan_identifier */,
  FALSE			/* scan_identifier_1char */,
  FALSE			/* scan_identifier_NULL */,
  TRUE			/* scan_symbols */,
  TRUE			/* scan_binary */,
  TRUE			/* scan_octal */,
  TRUE			/* scan_float */,
  TRUE			/* scan_hex */,
  TRUE			/* scan_hex_dollar */,
  TRUE			/* scan_string_sq */,
  TRUE			/* scan_string_dq */,
  TRUE			/* numbers_2_int */,
  FALSE			/* int_2_float */,
  FALSE			/* identifier_2_string */,
  TRUE			/* char_2_token */,
  TRUE			/* symbol_2_token */,
  FALSE			/* scope_0_fallback */,
};


void
global_foreach (gpointer data, const gchar *accel_path, guint accel_key, guint accel_mods, gboolean changed)
{
    global_result++;
    if (!strcmp (accel_path, global_path))
        if (accel_key == global_key  && accel_mods == global_mods)
        {
            global_changed = changed;
        }
}


/*
 * Name: gtk_accel_map_add_entry
 * Params: const gchar *accel_path, guint accel_key, guint accel_mods
 * Returns: void
 * Assertion: Registers a new accelerator with the global accelerator map.
 * Params Values:  const gchar *accel_path, guint accel_key, guint accel_mods
 * Expected: void  
 */
static void test_purpose_1()
{
    #define PATH "<test>/actionA"
    #define KEY GDK_A
    #define MODS GDK_SHIFT_MASK
    
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_add_entry (PATH, KEY, MODS);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
    }
    
    #undef KEY
    #undef MODS
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_add_entry
 * Params: const gchar *accel_path, guint accel_key, guint accel_mods
 * Returns: void
 * Assertion: Registers a new accelerator with the global accelerator map.
 * Params Values:  const gchar *accel_path, guint accel_key, guint accel_mods
 * Expected: void  
 */
static void test_purpose_2()
{
    #define PATH "<test>/actionB"
    #define KEY GDK_B
    #define MODS GDK_SHIFT_MASK
    
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_add_entry (PATH, KEY, MODS);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
    }
    
    #undef KEY
    #undef MODS
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_add_entry
 * Params: const gchar *accel_path, guint accel_key, guint accel_mods
 * Returns: void
 * Assertion: Registers a new accelerator with the global accelerator map.
 * Params Values:  const gchar *accel_path, guint accel_key, guint accel_mods
 * Expected: void  
 */
static void test_purpose_3()
{
    #define PATH "<test>/action1"
    #define KEY GDK_1
    #define MODS 0
    
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_add_entry (PATH, KEY, MODS);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
    }
    
    #undef KEY
    #undef MODS
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_lookup_entry
 * Params: const gchar *accel_path, GtkAccelKey *key
 * Returns: gboolean
 * Assertion: Looks up the accelerator entry for accel_path and fills in key.
 * Params Values: const gchar *accel_path, GtkAccelKey *key
 * Expected: gboolean  
 */
static void test_purpose_4()
{
    #define PATH "<test>/actionA"
    #define KEY GDK_A
    #define MODS GDK_SHIFT_MASK
    #define RESULT TRUE
    
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (RESULT)
    {
        gtk_accel_map_add_entry (PATH, KEY, MODS);
    }
    
    if (RESULT != gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns %i", RESULT);
    }
    
    #undef PATH
    #undef KEY
    #undef MODS
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_lookup_entry
 * Params: const gchar *accel_path, GtkAccelKey *key
 * Returns: gboolean
 * Assertion: Looks up the accelerator entry for accel_path and fills in key.
 * Params Values: const gchar *accel_path, GtkAccelKey *key
 * Expected: gboolean  
 */
static void test_purpose_5()
{
    #define PATH "<test>/actionC"
    #define KEY GDK_C
    #define MODS GDK_SHIFT_MASK
    #define RESULT FALSE
    
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (RESULT)
    {
        gtk_accel_map_add_entry (PATH, KEY, MODS);
    }
    
    if (RESULT != gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns %i", RESULT);
    }
    
    #undef PATH
    #undef KEY
    #undef MODS
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_lookup_entry
 * Params: const gchar *accel_path, GtkAccelKey *key
 * Returns: gboolean
 * Assertion: Looks up the accelerator entry for accel_path and fills in key.
 * Params Values: const gchar *accel_path, GtkAccelKey *key
 * Expected: gboolean  
 */
static void test_purpose_6()
{
    #define PATH "<test>/action1"
    #define KEY GDK_1
    #define MODS 0
    #define RESULT TRUE
    
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (RESULT)
    {
        gtk_accel_map_add_entry (PATH, KEY, MODS);
    }
    
    if (RESULT != gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns %i", RESULT);
    }
    
    #undef PATH
    #undef KEY
    #undef MODS
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_lookup_entry
 * Params: const gchar *accel_path, GtkAccelKey *key
 * Returns: gboolean
 * Assertion: Looks up the accelerator entry for accel_path and fills in key.
 * Params Values: const gchar *accel_path, GtkAccelKey *key
 * Expected: gboolean  
 */
static void test_purpose_7()
{
    #define PATH "<test>/action7"
    #define KEY GDK_7
    #define MODS GDK_CONTROL_MASK
    #define RESULT FALSE
    
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (RESULT)
    {
        gtk_accel_map_add_entry (PATH, KEY, MODS);
    }
    
    if (RESULT != gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns %i", RESULT);
    }
    
    #undef PATH
    #undef KEY
    #undef MODS
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_change_entry
 * Params: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Returns: gboolean
 * Assertion: Changes the accel_key and accel_mods currently associated with accel_path.
 * Params Values: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Expected: gboolean
 * 
 * Name: gtk_accel_map_change_entry
 * Params: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Returns: gboolean
 * Assertion: Successful changes are indicated by a TRUE return value.
 * Params Values: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Expected: gboolean  
 */
static void test_purpose_8()
{
    #define PATH "<test>/actionA"
    #define KEY GDK_A
    #define MODS GDK_SHIFT_MASK
    #define REPLACE TRUE
    
    GtkAccelKey key;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_add_entry (PATH, GDK_Return, 0);
    result = gtk_accel_map_change_entry (PATH, KEY, MODS, REPLACE);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    
    if (result && (key.accel_key != KEY || key.accel_mods != MODS))
    {
        TEST_FAIL ("accel entry should be replaced", NULL);
        return;
    }
    
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_change_entry
 * Params: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Returns: gboolean
 * Assertion: Changes the accel_key and accel_mods currently associated with accel_path.
 * Params Values: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Expected: gboolean
 * 
 * Name: gtk_accel_map_change_entry
 * Params: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Returns: gboolean
 * Assertion: Successful changes are indicated by a TRUE return value.
 * Params Values: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Expected: gboolean  
 */
static void test_purpose_9()
{
    #define PATH "<test>/actionC"
    #define KEY GDK_C
    #define MODS GDK_SHIFT_MASK
    #define REPLACE FALSE
    
    GtkAccelKey key;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_add_entry (PATH, GDK_Return, 0);
    result = gtk_accel_map_change_entry (PATH, KEY, MODS, REPLACE);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    
    if (result && (key.accel_key != KEY || key.accel_mods != MODS))
    {
        TEST_FAIL ("accel entry should be replaced", NULL);
        return;
    }
    
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_change_entry
 * Params: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Returns: gboolean
 * Assertion: Changes the accel_key and accel_mods currently associated with accel_path.
 * Params Values: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Expected: gboolean
 * 
 * Name: gtk_accel_map_change_entry
 * Params: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Returns: gboolean
 * Assertion: Successful changes are indicated by a TRUE return value.
 * Params Values: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Expected: gboolean  
 */
static void test_purpose_10()
{
    #define PATH "<test>/action1"
    #define KEY GDK_1
    #define MODS 0
    #define REPLACE TRUE
    
    GtkAccelKey key;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_add_entry (PATH, GDK_Return, 0);
    result = gtk_accel_map_change_entry (PATH, KEY, MODS, REPLACE);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    
    if (result && (key.accel_key != KEY || key.accel_mods != MODS))
    {
        TEST_FAIL ("accel entry should be replaced", NULL);
        return;
    }
    
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_change_entry
 * Params: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Returns: gboolean
 * Assertion: Changes the accel_key and accel_mods currently associated with accel_path.
 * Params Values: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Expected: gboolean
 * 
 * Name: gtk_accel_map_change_entry
 * Params: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Returns: gboolean
 * Assertion: Successful changes are indicated by a TRUE return value.
 * Params Values: const gchar *accel_path, guint accel_key, GdkModifierType accel_mods, gboolean replace
 * Expected: gboolean  
 */
static void test_purpose_11()
{
    #define PATH "<test>/action7"
    #define KEY GDK_7
    #define MODS GDK_CONTROL_MASK
    #define REPLACE FALSE
    
    GtkAccelKey key;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_add_entry (PATH, GDK_Return, 0);
    result = gtk_accel_map_change_entry (PATH, KEY, MODS, REPLACE);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    
    if (result && (key.accel_key != KEY || key.accel_mods != MODS))
    {
        TEST_FAIL ("accel entry should be replaced", NULL);
        return;
    }
    
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_load
 * Params: const gchar *file_name
 * Returns: void
 * Assertion: Parses a file previously saved with gtk_accel_map_save() for accelerator specifications, and propagates them accordingly.
 * Params Values: const gchar *file_name
 * Expected: void  
 */
static void test_purpose_12()
{
    #define PATH "<test>/actionA"
    #define KEY GDK_A
    #define MODS GDK_SHIFT_MASK
    #define REPLACE <%3%>
    
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    
    gtk_accel_map_save ("maps");
    gtk_accel_map_load ("maps");
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_load
 * Params: const gchar *file_name
 * Returns: void
 * Assertion: Parses a file previously saved with gtk_accel_map_save() for accelerator specifications, and propagates them accordingly.
 * Params Values: const gchar *file_name
 * Expected: void  
 */
static void test_purpose_13()
{
    #define PATH "<test>/actionC"
    #define KEY GDK_C
    #define MODS GDK_SHIFT_MASK
    #define REPLACE <%3%>
    
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    
    gtk_accel_map_save ("maps");
    gtk_accel_map_load ("maps");
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_load
 * Params: const gchar *file_name
 * Returns: void
 * Assertion: Parses a file previously saved with gtk_accel_map_save() for accelerator specifications, and propagates them accordingly.
 * Params Values: const gchar *file_name
 * Expected: void  
 */
static void test_purpose_14()
{
    #define PATH "<test>/action1"
    #define KEY GDK_1
    #define MODS 0
    #define REPLACE <%3%>
    
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    
    gtk_accel_map_save ("maps");
    gtk_accel_map_load ("maps");
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_load
 * Params: const gchar *file_name
 * Returns: void
 * Assertion: Parses a file previously saved with gtk_accel_map_save() for accelerator specifications, and propagates them accordingly.
 * Params Values: const gchar *file_name
 * Expected: void  
 */
static void test_purpose_15()
{
    #define PATH "<test>/action7"
    #define KEY GDK_7
    #define MODS GDK_CONTROL_MASK
    #define REPLACE <%3%>
    
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    
    gtk_accel_map_save ("maps");
    gtk_accel_map_load ("maps");
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_save
 * Params: const gchar *file_name
 * Returns: void
 * Assertion: Saves current accelerator specifications (accelerator path, key and modifiers) to file_name.
 * Params Values: const gchar *file_name
 * Expected: void  
 */
static void test_purpose_16()
{
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    gtk_accel_map_save ("maps");
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_load_fd
 * Params: gint fd
 * Returns: void
 * Assertion: Filedescriptor variant of gtk_accel_map_load().
 * Params Values: gint fd
 * Expected: void  
 */
static void test_purpose_17()
{
    #define PATH "<test>/actionA"
    #define KEY GDK_A
    #define MODS GDK_SHIFT_MASK
    #define REPLACE <%3%>
    
    GtkAccelKey key;
    guint file;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    gtk_accel_map_save ("maps");
    
    file = open ("maps", O_CREAT);
    if (file == -1)
    {
        TEST_FAIL ("Can't open file", NULL);
        return;
    }
    
    gtk_accel_map_save_fd (file);
    gtk_accel_map_load_fd (file);
    close (file);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_load_fd
 * Params: gint fd
 * Returns: void
 * Assertion: Filedescriptor variant of gtk_accel_map_load().
 * Params Values: gint fd
 * Expected: void  
 */
static void test_purpose_18()
{
    #define PATH "<test>/actionC"
    #define KEY GDK_C
    #define MODS GDK_SHIFT_MASK
    #define REPLACE <%3%>
    
    GtkAccelKey key;
    guint file;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    gtk_accel_map_save ("maps");
    
    file = open ("maps", O_CREAT);
    if (file == -1)
    {
        TEST_FAIL ("Can't open file", NULL);
        return;
    }
    
    gtk_accel_map_save_fd (file);
    gtk_accel_map_load_fd (file);
    close (file);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_load_fd
 * Params: gint fd
 * Returns: void
 * Assertion: Filedescriptor variant of gtk_accel_map_load().
 * Params Values: gint fd
 * Expected: void  
 */
static void test_purpose_19()
{
    #define PATH "<test>/action1"
    #define KEY GDK_1
    #define MODS 0
    #define REPLACE <%3%>
    
    GtkAccelKey key;
    guint file;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    gtk_accel_map_save ("maps");
    
    file = open ("maps", O_CREAT);
    if (file == -1)
    {
        TEST_FAIL ("Can't open file", NULL);
        return;
    }
    
    gtk_accel_map_save_fd (file);
    gtk_accel_map_load_fd (file);
    close (file);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_load_fd
 * Params: gint fd
 * Returns: void
 * Assertion: Filedescriptor variant of gtk_accel_map_load().
 * Params Values: gint fd
 * Expected: void  
 */
static void test_purpose_20()
{
    #define PATH "<test>/action7"
    #define KEY GDK_7
    #define MODS GDK_CONTROL_MASK
    #define REPLACE <%3%>
    
    GtkAccelKey key;
    guint file;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    gtk_accel_map_save ("maps");
    
    file = open ("maps", O_CREAT);
    if (file == -1)
    {
        TEST_FAIL ("Can't open file", NULL);
        return;
    }
    
    gtk_accel_map_save_fd (file);
    gtk_accel_map_load_fd (file);
    close (file);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_save_fd
 * Params: gint fd
 * Returns: void
 * Assertion: Filedescriptor variant of gtk_accel_map_save().
 * Params Values: gint fd
 * Expected: void  
 */
static void test_purpose_21()
{
    
    guint file;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    file = open ("maps", O_CREAT);
    if (file == -1)
    {
        TEST_FAIL ("Can't open file", NULL);
        return;
    }
    
    gtk_accel_map_save_fd (file);
    close (file);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_foreach 
 * Params: gpointer data, GtkAccelMapForeach foreach_func
 * Returns: void
 * Assertion: Loops over the entries in the accelerator map whose accel path doesn't match any of the filters added with gtk_accel_map_add_filter(), and execute foreach_func on each.'
 * Params Values: gpointer data, GtkAccelMapForeach foreach_func
 * Expected: void
 * 
 * Name: gtk_accel_map_foreach 
 * Params: gpointer data, GtkAccelMapForeach foreach_func
 * Returns: void
 * Assertion:  The signature of foreach_func is that of GtkAccelMapForeach, the changed parameter indicates whether this accelerator was changed during runtime (thus, would need saving during an accelerator map dump).
 * Params Values: gpointer data, GtkAccelMapForeach foreach_func
 * Expected: void  
 */
static void test_purpose_22()
{
    #define PATH "<test>/actionF"
    #define KEY GDK_F
    #define MODS 0
    #define CHANGED TRUE
    
    GtkAccelKey key;
    gboolean changed;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    global_path = PATH;
    global_key = KEY;
    global_mods = MODS;
    
    if (CHANGED)
    {
        gtk_accel_map_add_entry (PATH, KEY+1, MODS);
        gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    
    } else {
    
        gtk_accel_map_add_entry (PATH, KEY, MODS);
    }
    
    gtk_accel_map_foreach (NULL, global_foreach);
    
    if (!global_result)
    {
        TEST_FAIL ("'global_foreach' fails", NULL);
        return;
    }
    
    if (global_changed != CHANGED)
    {
        TEST_FAIL ("'changed' not equal", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef CHANGED
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_foreach 
 * Params: gpointer data, GtkAccelMapForeach foreach_func
 * Returns: void
 * Assertion: Loops over the entries in the accelerator map whose accel path doesn't match any of the filters added with gtk_accel_map_add_filter(), and execute foreach_func on each.'
 * Params Values: gpointer data, GtkAccelMapForeach foreach_func
 * Expected: void
 * 
 * Name: gtk_accel_map_foreach 
 * Params: gpointer data, GtkAccelMapForeach foreach_func
 * Returns: void
 * Assertion:  The signature of foreach_func is that of GtkAccelMapForeach, the changed parameter indicates whether this accelerator was changed during runtime (thus, would need saving during an accelerator map dump).
 * Params Values: gpointer data, GtkAccelMapForeach foreach_func
 * Expected: void  
 */
static void test_purpose_23()
{
    #define PATH "<test>/actionC"
    #define KEY GDK_C
    #define MODS GDK_SHIFT_MASK
    #define CHANGED TRUE
    
    GtkAccelKey key;
    gboolean changed;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    global_path = PATH;
    global_key = KEY;
    global_mods = MODS;
    
    if (CHANGED)
    {
        gtk_accel_map_add_entry (PATH, KEY+1, MODS);
        gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    
    } else {
    
        gtk_accel_map_add_entry (PATH, KEY, MODS);
    }
    
    gtk_accel_map_foreach (NULL, global_foreach);
    
    if (!global_result)
    {
        TEST_FAIL ("'global_foreach' fails", NULL);
        return;
    }
    
    if (global_changed != CHANGED)
    {
        TEST_FAIL ("'changed' not equal", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef CHANGED
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_foreach 
 * Params: gpointer data, GtkAccelMapForeach foreach_func
 * Returns: void
 * Assertion: Loops over the entries in the accelerator map whose accel path doesn't match any of the filters added with gtk_accel_map_add_filter(), and execute foreach_func on each.'
 * Params Values: gpointer data, GtkAccelMapForeach foreach_func
 * Expected: void
 * 
 * Name: gtk_accel_map_foreach 
 * Params: gpointer data, GtkAccelMapForeach foreach_func
 * Returns: void
 * Assertion:  The signature of foreach_func is that of GtkAccelMapForeach, the changed parameter indicates whether this accelerator was changed during runtime (thus, would need saving during an accelerator map dump).
 * Params Values: gpointer data, GtkAccelMapForeach foreach_func
 * Expected: void  
 */
static void test_purpose_24()
{
    #define PATH "<test>/action2"
    #define KEY GDK_2
    #define MODS 0
    #define CHANGED FALSE
    
    GtkAccelKey key;
    gboolean changed;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    global_path = PATH;
    global_key = KEY;
    global_mods = MODS;
    
    if (CHANGED)
    {
        gtk_accel_map_add_entry (PATH, KEY+1, MODS);
        gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    
    } else {
    
        gtk_accel_map_add_entry (PATH, KEY, MODS);
    }
    
    gtk_accel_map_foreach (NULL, global_foreach);
    
    if (!global_result)
    {
        TEST_FAIL ("'global_foreach' fails", NULL);
        return;
    }
    
    if (global_changed != CHANGED)
    {
        TEST_FAIL ("'changed' not equal", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef CHANGED
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_foreach 
 * Params: gpointer data, GtkAccelMapForeach foreach_func
 * Returns: void
 * Assertion: Loops over the entries in the accelerator map whose accel path doesn't match any of the filters added with gtk_accel_map_add_filter(), and execute foreach_func on each.'
 * Params Values: gpointer data, GtkAccelMapForeach foreach_func
 * Expected: void
 * 
 * Name: gtk_accel_map_foreach 
 * Params: gpointer data, GtkAccelMapForeach foreach_func
 * Returns: void
 * Assertion:  The signature of foreach_func is that of GtkAccelMapForeach, the changed parameter indicates whether this accelerator was changed during runtime (thus, would need saving during an accelerator map dump).
 * Params Values: gpointer data, GtkAccelMapForeach foreach_func
 * Expected: void  
 */
static void test_purpose_25()
{
    #define PATH "<test>/action8"
    #define KEY GDK_8
    #define MODS GDK_CONTROL_MASK
    #define CHANGED FALSE
    
    GtkAccelKey key;
    gboolean changed;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    global_path = PATH;
    global_key = KEY;
    global_mods = MODS;
    
    if (CHANGED)
    {
        gtk_accel_map_add_entry (PATH, KEY+1, MODS);
        gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    
    } else {
    
        gtk_accel_map_add_entry (PATH, KEY, MODS);
    }
    
    gtk_accel_map_foreach (NULL, global_foreach);
    
    if (!global_result)
    {
        TEST_FAIL ("'global_foreach' fails", NULL);
        return;
    }
    
    if (global_changed != CHANGED)
    {
        TEST_FAIL ("'changed' not equal", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef CHANGED
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_foreach_unfiltered
 * Params: gpointer data, GtkAccelMapForeach foreach_func
 * Returns: void
 * Assertion: Loops over all entries in the accelerator map, and execute foreach_func on each.
 * Params Values: gpointer data, GtkAccelMapForeach foreach_func
 * Expected: void  
 */
static void test_purpose_26()
{
    #define PATH "<test>/actionF"
    #define KEY GDK_F
    #define MODS 0
    #define CHANGED TRUE
    
    GtkAccelKey key;
    gboolean changed;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    global_path = PATH;
    global_key = KEY;
    global_mods = MODS;
    
    if (CHANGED)
    {
        gtk_accel_map_add_entry (PATH, KEY+1, MODS);
        gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    
    } else {
    
        gtk_accel_map_add_entry (PATH, KEY, MODS);
    }
    
    gtk_accel_map_foreach_unfiltered (NULL, global_foreach);
    
    if (!global_result)
    {
        TEST_FAIL ("'global_foreach' fails", NULL);
        return;
    }
    
    if (global_changed != CHANGED)
    {
        TEST_FAIL ("'changed' not equal", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef CHANGED
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_foreach_unfiltered
 * Params: gpointer data, GtkAccelMapForeach foreach_func
 * Returns: void
 * Assertion: Loops over all entries in the accelerator map, and execute foreach_func on each.
 * Params Values: gpointer data, GtkAccelMapForeach foreach_func
 * Expected: void  
 */
static void test_purpose_27()
{
    #define PATH "<test>/actionC"
    #define KEY GDK_C
    #define MODS GDK_SHIFT_MASK
    #define CHANGED TRUE
    
    GtkAccelKey key;
    gboolean changed;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    global_path = PATH;
    global_key = KEY;
    global_mods = MODS;
    
    if (CHANGED)
    {
        gtk_accel_map_add_entry (PATH, KEY+1, MODS);
        gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    
    } else {
    
        gtk_accel_map_add_entry (PATH, KEY, MODS);
    }
    
    gtk_accel_map_foreach_unfiltered (NULL, global_foreach);
    
    if (!global_result)
    {
        TEST_FAIL ("'global_foreach' fails", NULL);
        return;
    }
    
    if (global_changed != CHANGED)
    {
        TEST_FAIL ("'changed' not equal", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef CHANGED
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_foreach_unfiltered
 * Params: gpointer data, GtkAccelMapForeach foreach_func
 * Returns: void
 * Assertion: Loops over all entries in the accelerator map, and execute foreach_func on each.
 * Params Values: gpointer data, GtkAccelMapForeach foreach_func
 * Expected: void  
 */
static void test_purpose_28()
{
    #define PATH "<test>/action2"
    #define KEY GDK_2
    #define MODS 0
    #define CHANGED FALSE
    
    GtkAccelKey key;
    gboolean changed;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    global_path = PATH;
    global_key = KEY;
    global_mods = MODS;
    
    if (CHANGED)
    {
        gtk_accel_map_add_entry (PATH, KEY+1, MODS);
        gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    
    } else {
    
        gtk_accel_map_add_entry (PATH, KEY, MODS);
    }
    
    gtk_accel_map_foreach_unfiltered (NULL, global_foreach);
    
    if (!global_result)
    {
        TEST_FAIL ("'global_foreach' fails", NULL);
        return;
    }
    
    if (global_changed != CHANGED)
    {
        TEST_FAIL ("'changed' not equal", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef CHANGED
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_foreach_unfiltered
 * Params: gpointer data, GtkAccelMapForeach foreach_func
 * Returns: void
 * Assertion: Loops over all entries in the accelerator map, and execute foreach_func on each.
 * Params Values: gpointer data, GtkAccelMapForeach foreach_func
 * Expected: void  
 */
static void test_purpose_29()
{
    #define PATH "<test>/action8"
    #define KEY GDK_8
    #define MODS GDK_CONTROL_MASK
    #define CHANGED FALSE
    
    GtkAccelKey key;
    gboolean changed;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    global_path = PATH;
    global_key = KEY;
    global_mods = MODS;
    
    if (CHANGED)
    {
        gtk_accel_map_add_entry (PATH, KEY+1, MODS);
        gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    
    } else {
    
        gtk_accel_map_add_entry (PATH, KEY, MODS);
    }
    
    gtk_accel_map_foreach_unfiltered (NULL, global_foreach);
    
    if (!global_result)
    {
        TEST_FAIL ("'global_foreach' fails", NULL);
        return;
    }
    
    if (global_changed != CHANGED)
    {
        TEST_FAIL ("'changed' not equal", NULL);
        return;
    }
    #undef PATH
    #undef KEY
    #undef MODS
    #undef CHANGED
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_add_filter
 * Params: const gchar *filter_pattern
 * Returns: void
 * Assertion: Adds a filter to the global list of accel path filters.
 * Params Values: const gchar *filter_pattern
 * Expected: void
 * 
 * Name: gtk_accel_map_add_filter
 * Params: const gchar *filter_pattern
 * Returns: void
 * Assertion: Accel map entries whose accel path matches one of the filters are skipped by gtk_accel_map_foreach().
 * Params Values: const gchar *filter_pattern
 * Expected: void  
 */
static void test_purpose_30()
{
    #define FILTER "<test>/"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_add_filter (FILTER);
    
    #undef FILTER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_load_scanner
 * Params: GScanner *scanner
 * Returns: void
 * Assertion: GScanner variant of gtk_accel_map_load().
 * Params Values: GScanner *scanner
 * Expected: void  
 */
static void test_purpose_31()
{
    #define PATH "<test>/actionA"
    #define KEY GDK_A
    #define MODS GDK_SHIFT_MASK
    #define REPLACE <%3%>
    
    GtkAccelKey key;
    GScanner* scanner;
    guint file;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    gtk_accel_map_save ("maps");
    
    file = open ("maps", O_CREAT);
    if (file == -1)
    {
        TEST_FAIL ("Can't open file", NULL);
        return;
    }
    
    scanner = g_scanner_new (&scanner_struct);
    if (!scanner)
    {
        TEST_FAIL ("Can't open scanner", NULL);
        return;
    }
    g_scanner_input_file (scanner, file); 
    
    gtk_accel_map_load_scanner (scanner);
    
    close (file);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    
    g_scanner_destroy (scanner);
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_load_scanner
 * Params: GScanner *scanner
 * Returns: void
 * Assertion: GScanner variant of gtk_accel_map_load().
 * Params Values: GScanner *scanner
 * Expected: void  
 */
static void test_purpose_32()
{
    #define PATH "<test>/actionC"
    #define KEY GDK_C
    #define MODS GDK_SHIFT_MASK
    #define REPLACE <%3%>
    
    GtkAccelKey key;
    GScanner* scanner;
    guint file;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    gtk_accel_map_save ("maps");
    
    file = open ("maps", O_CREAT);
    if (file == -1)
    {
        TEST_FAIL ("Can't open file", NULL);
        return;
    }
    
    scanner = g_scanner_new (&scanner_struct);
    if (!scanner)
    {
        TEST_FAIL ("Can't open scanner", NULL);
        return;
    }
    g_scanner_input_file (scanner, file); 
    
    gtk_accel_map_load_scanner (scanner);
    
    close (file);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    
    g_scanner_destroy (scanner);
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_load_scanner
 * Params: GScanner *scanner
 * Returns: void
 * Assertion: GScanner variant of gtk_accel_map_load().
 * Params Values: GScanner *scanner
 * Expected: void  
 */
static void test_purpose_33()
{
    #define PATH "<test>/action1"
    #define KEY GDK_1
    #define MODS 0
    #define REPLACE <%3%>
    
    GtkAccelKey key;
    GScanner* scanner;
    guint file;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    gtk_accel_map_save ("maps");
    
    file = open ("maps", O_CREAT);
    if (file == -1)
    {
        TEST_FAIL ("Can't open file", NULL);
        return;
    }
    
    scanner = g_scanner_new (&scanner_struct);
    if (!scanner)
    {
        TEST_FAIL ("Can't open scanner", NULL);
        return;
    }
    g_scanner_input_file (scanner, file); 
    
    gtk_accel_map_load_scanner (scanner);
    
    close (file);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    
    g_scanner_destroy (scanner);
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_map_load_scanner
 * Params: GScanner *scanner
 * Returns: void
 * Assertion: GScanner variant of gtk_accel_map_load().
 * Params Values: GScanner *scanner
 * Expected: void  
 */
static void test_purpose_34()
{
    #define PATH "<test>/action7"
    #define KEY GDK_7
    #define MODS GDK_CONTROL_MASK
    #define REPLACE <%3%>
    
    GtkAccelKey key;
    GScanner* scanner;
    guint file;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_accel_map_change_entry (PATH, KEY, MODS, TRUE);
    gtk_accel_map_save ("maps");
    
    file = open ("maps", O_CREAT);
    if (file == -1)
    {
        TEST_FAIL ("Can't open file", NULL);
        return;
    }
    
    scanner = g_scanner_new (&scanner_struct);
    if (!scanner)
    {
        TEST_FAIL ("Can't open scanner", NULL);
        return;
    }
    g_scanner_input_file (scanner, file); 
    
    gtk_accel_map_load_scanner (scanner);
    
    close (file);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns FALSE", NULL);
        return;
    }
    
    g_scanner_destroy (scanner);
    #undef PATH
    #undef KEY
    #undef MODS
    #undef REPLACE
    
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for Accelerator_Maps ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {NULL,0}
};
