/*
 * Clipboards methods tests
 * Testing Clipboards methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

static gint global_result;
static gboolean global_text_is_same;

void 
global_get_text (GtkClipboard *clipboard, GtkSelectionData *selection_data, guint info, gpointer data)
{
    global_result++;
    gtk_selection_data_set_text (selection_data, data, -1);
}

void 
global_get (GtkClipboard *clipboard, GtkSelectionData *selection_data, guint info, gpointer data)
{
    void* p = data;
    gtk_selection_data_set (selection_data, gdk_atom_intern ("TEST_DATA", FALSE), 8, (void*)&p, sizeof (p));
    global_result++;
}

void 
global_clear (GtkClipboard *clipboard, gpointer data)
{
    global_result++;
}

void
global_receive (GtkClipboard *clipboard, GtkSelectionData *selection_data, gpointer data)
{
    global_result++;
}

void
global_text_receive (GtkClipboard *clipboard, const gchar *text, gpointer data)
{
    global_text_is_same = !strcmp (text, (const gchar*)data);
    global_result++;
}



/*
 * Name: gtk_clipboard_get
 * Params: GdkAtom selection
 * Returns: GtkClipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkAtom selection
 * Expected: GtkClipboard*  
 */
static void test_purpose_1()
{
    #define SELECTION GDK_NONE
    
    GtkClipboard* clipboard;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get
 * Params: GdkAtom selection
 * Returns: GtkClipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkAtom selection
 * Expected: GtkClipboard*  
 */
static void test_purpose_2()
{
    #define SELECTION GDK_SELECTION_PRIMARY
    
    GtkClipboard* clipboard;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_clear
 * Params: GtkClipboard *clipboard
 * Returns: void
 * Assertion: Clears the contents of the clipboard.
 * Params Values: GtkClipboard *clipboard
 * Expected: void  
 */
static void test_purpose_3()
{
    #define ATOM "TEXT"
    #define DATA "Text\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_clear (clipboard);
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    if (data)
    {
        TEST_FAIL ("clipboard contains data", NULL);
        gtk_selection_data_free (data);
    }
    
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_clear
 * Params: GtkClipboard *clipboard
 * Returns: void
 * Assertion: Clears the contents of the clipboard.
 * Params Values: GtkClipboard *clipboard
 * Expected: void  
 */
static void test_purpose_4()
{
    #define ATOM "TEXT"
    #define DATA "Text\nText\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_clear (clipboard);
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    if (data)
    {
        TEST_FAIL ("clipboard contains data", NULL);
        gtk_selection_data_free (data);
    }
    
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_clear
 * Params: GtkClipboard *clipboard
 * Returns: void
 * Assertion: Clears the contents of the clipboard.
 * Params Values: GtkClipboard *clipboard
 * Expected: void  
 */
static void test_purpose_5()
{
    #define ATOM "TEXT"
    #define DATA "Text\n\bText\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_clear (clipboard);
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    if (data)
    {
        TEST_FAIL ("clipboard contains data", NULL);
        gtk_selection_data_free (data);
    }
    
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_clear
 * Params: GtkClipboard *clipboard
 * Returns: void
 * Assertion: Clears the contents of the clipboard.
 * Params Values: GtkClipboard *clipboard
 * Expected: void  
 */
static void test_purpose_6()
{
    #define ATOM "TEXT"
    #define DATA "STRING"
    
    GtkClipboard* clipboard;
    gchar* text;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_clear (clipboard);
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    if (data)
    {
        TEST_FAIL ("clipboard contains data", NULL);
        gtk_selection_data_free (data);
    }
    
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_clear
 * Params: GtkClipboard *clipboard
 * Returns: void
 * Assertion: Clears the contents of the clipboard.
 * Params Values: GtkClipboard *clipboard
 * Expected: void  
 */
static void test_purpose_7()
{
    #define ATOM "UTF8_STRING"
    #define DATA "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkClipboard* clipboard;
    gchar* text;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_clear (clipboard);
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    if (data)
    {
        TEST_FAIL ("clipboard contains data", NULL);
        gtk_selection_data_free (data);
    }
    
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_clear
 * Params: GtkClipboard *clipboard
 * Returns: void
 * Assertion: Clears the contents of the clipboard.
 * Params Values: GtkClipboard *clipboard
 * Expected: void  
 */
static void test_purpose_8()
{
    #define ATOM "UTF8_STRING"
    #define DATA "\b\n\t\n" 
    
    GtkClipboard* clipboard;
    gchar* text;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_clear (clipboard);
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    if (data)
    {
        TEST_FAIL ("clipboard contains data", NULL);
        gtk_selection_data_free (data);
    }
    
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: Sets the contents of the clipboard to the given UTF-8 string.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void
 * 
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: GTK+ will make a copy of the text and take responsibility for responding for requests for the text, and for converting the text into the requested format.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_9()
{
    #define TEXT " "
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: Sets the contents of the clipboard to the given UTF-8 string.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void
 * 
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: GTK+ will make a copy of the text and take responsibility for responding for requests for the text, and for converting the text into the requested format.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_10()
{
    #define TEXT "Text\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: Sets the contents of the clipboard to the given UTF-8 string.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void
 * 
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: GTK+ will make a copy of the text and take responsibility for responding for requests for the text, and for converting the text into the requested format.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_11()
{
    #define TEXT "Text\nText\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: Sets the contents of the clipboard to the given UTF-8 string.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void
 * 
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: GTK+ will make a copy of the text and take responsibility for responding for requests for the text, and for converting the text into the requested format.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_12()
{
    #define TEXT "Text\n\bText\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: Sets the contents of the clipboard to the given UTF-8 string.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void
 * 
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: GTK+ will make a copy of the text and take responsibility for responding for requests for the text, and for converting the text into the requested format.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_13()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: Sets the contents of the clipboard to the given UTF-8 string.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void
 * 
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: GTK+ will make a copy of the text and take responsibility for responding for requests for the text, and for converting the text into the requested format.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_14()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: Sets the contents of the clipboard to the given UTF-8 string.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void
 * 
 * Name: gtk_clipboard_set_text 
 * Params: GtkClipboard *clipboard, const gchar *text, gint len
 * Returns: void
 * Assertion: GTK+ will make a copy of the text and take responsibility for responding for requests for the text, and for converting the text into the requested format.
 * Params Values: GtkClipboard *clipboard, const gchar *text, gint len
 * Expected: void  
 */
static void test_purpose_15()
{
    #define TEXT "\b\n\t\n" 
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_with_data
 * Params: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, gpointer user_data
 * Returns: gboolean
 * Assertion: Virtually sets the contents of the specified clipboard by providing a list of supported formats for the clipboard data and a function to call to get the actual data when it is requested.
 * Params Values: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, gpointer user_data
 * Expected: gboolean  
 */
static void test_purpose_16()
{
    #define ATOM "TEXT"
    #define DATA "Text\n"
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    gtk_clipboard_clear (clipboard);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_with_data
 * Params: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, gpointer user_data
 * Returns: gboolean
 * Assertion: Virtually sets the contents of the specified clipboard by providing a list of supported formats for the clipboard data and a function to call to get the actual data when it is requested.
 * Params Values: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, gpointer user_data
 * Expected: gboolean  
 */
static void test_purpose_17()
{
    #define ATOM "TEXT"
    #define DATA "Text\nText\n"
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    gtk_clipboard_clear (clipboard);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_with_data
 * Params: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, gpointer user_data
 * Returns: gboolean
 * Assertion: Virtually sets the contents of the specified clipboard by providing a list of supported formats for the clipboard data and a function to call to get the actual data when it is requested.
 * Params Values: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, gpointer user_data
 * Expected: gboolean  
 */
static void test_purpose_18()
{
    #define ATOM "TEXT"
    #define DATA "Text\n\bText\n"
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    gtk_clipboard_clear (clipboard);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_with_data
 * Params: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, gpointer user_data
 * Returns: gboolean
 * Assertion: Virtually sets the contents of the specified clipboard by providing a list of supported formats for the clipboard data and a function to call to get the actual data when it is requested.
 * Params Values: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, gpointer user_data
 * Expected: gboolean  
 */
static void test_purpose_19()
{
    #define ATOM "TEXT"
    #define DATA "STRING"
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    gtk_clipboard_clear (clipboard);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_with_data
 * Params: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, gpointer user_data
 * Returns: gboolean
 * Assertion: Virtually sets the contents of the specified clipboard by providing a list of supported formats for the clipboard data and a function to call to get the actual data when it is requested.
 * Params Values: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, gpointer user_data
 * Expected: gboolean  
 */
static void test_purpose_20()
{
    #define ATOM "UTF8_STRING"
    #define DATA "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    gtk_clipboard_clear (clipboard);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_with_data
 * Params: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, gpointer user_data
 * Returns: gboolean
 * Assertion: Virtually sets the contents of the specified clipboard by providing a list of supported formats for the clipboard data and a function to call to get the actual data when it is requested.
 * Params Values: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, gpointer user_data
 * Expected: gboolean  
 */
static void test_purpose_21()
{
    #define ATOM "UTF8_STRING"
    #define DATA "\b\n\t\n" 
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    gtk_clipboard_clear (clipboard);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_owner
 * Params: GtkClipboard *clipboard
 * Returns:  GObject *owner
 * Assertion: If the clipboard contents callbacks were set with gtk_clipboard_set_with_owner(), and the gtk_clipboard_set_with_data() or gtk_clipboard_clear() has not subsequently called, returns the owner set by gtk_clipboard_set_with_owner().
 * Params Values: GtkClipboard *clipboard
 * Expected:  GObject *owner  
 */
static void test_purpose_22()
{
    #define ATOM "STRING"
    #define OWNER gtk_text_buffer_new (NULL)
    
    GtkClipboard* clipboard;
    GObject* owner;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    owner = G_OBJECT (OWNER);
    if (!owner)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_owner (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, owner))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    if (owner != gtk_clipboard_get_owner (clipboard))
    {
        TEST_FAIL ("'owner' is wrong", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    if (gtk_clipboard_get_owner (clipboard))
    {
        TEST_FAIL ("'owner' should be NULL", global_result);
    }
    
    #undef ATOM
    #undef OWNER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_owner
 * Params: GtkClipboard *clipboard
 * Returns:  GObject *owner
 * Assertion: If the clipboard contents callbacks were set with gtk_clipboard_set_with_owner(), and the gtk_clipboard_set_with_data() or gtk_clipboard_clear() has not subsequently called, returns the owner set by gtk_clipboard_set_with_owner().
 * Params Values: GtkClipboard *clipboard
 * Expected:  GObject *owner  
 */
static void test_purpose_23()
{
    #define ATOM "STRING"
    #define OWNER gtk_label_new ("Label")
    
    GtkClipboard* clipboard;
    GObject* owner;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    owner = G_OBJECT (OWNER);
    if (!owner)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_owner (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, owner))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    if (owner != gtk_clipboard_get_owner (clipboard))
    {
        TEST_FAIL ("'owner' is wrong", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    if (gtk_clipboard_get_owner (clipboard))
    {
        TEST_FAIL ("'owner' should be NULL", global_result);
    }
    
    #undef ATOM
    #undef OWNER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_owner
 * Params: GtkClipboard *clipboard
 * Returns:  GObject *owner
 * Assertion: If the clipboard contents callbacks were set with gtk_clipboard_set_with_owner(), and the gtk_clipboard_set_with_data() or gtk_clipboard_clear() has not subsequently called, returns the owner set by gtk_clipboard_set_with_owner().
 * Params Values: GtkClipboard *clipboard
 * Expected:  GObject *owner  
 */
static void test_purpose_24()
{
    #define ATOM "BITMAP"
    #define OWNER gtk_image_new_from_image (NULL, NULL)
    
    GtkClipboard* clipboard;
    GObject* owner;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    owner = G_OBJECT (OWNER);
    if (!owner)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_owner (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, owner))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    if (owner != gtk_clipboard_get_owner (clipboard))
    {
        TEST_FAIL ("'owner' is wrong", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    if (gtk_clipboard_get_owner (clipboard))
    {
        TEST_FAIL ("'owner' should be NULL", global_result);
    }
    
    #undef ATOM
    #undef OWNER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_with_owner
 * Params: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, GObject *owner
 * Returns: gboolean
 * Assertion: Virtually sets the contents of the specified clipboard by providing a list of supported formats for the clipboard data and a function to call to get the actual data when it is requested.
 * Params Values: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, GObject *owner
 * Expected: gboolean  
 */
static void test_purpose_25()
{
    #define ATOM "STRING"
    #define OWNER gtk_label_new ("Label")
    
    GtkClipboard* clipboard;
    GObject* owner;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    owner = G_OBJECT (OWNER);
    if (!owner)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    if (!gtk_clipboard_set_with_owner (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, owner))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    if (owner != gtk_clipboard_get_owner (clipboard))
    {
        TEST_FAIL ("'owner' is wrong", NULL);
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    gtk_clipboard_clear (clipboard);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    
    #undef ATOM
    #undef OWNER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_with_owner
 * Params: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, GObject *owner
 * Returns: gboolean
 * Assertion: Virtually sets the contents of the specified clipboard by providing a list of supported formats for the clipboard data and a function to call to get the actual data when it is requested.
 * Params Values: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, GObject *owner
 * Expected: gboolean  
 */
static void test_purpose_26()
{
    #define ATOM "STRING"
    #define OWNER gtk_text_buffer_new (NULL)
    
    GtkClipboard* clipboard;
    GObject* owner;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    owner = G_OBJECT (OWNER);
    if (!owner)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    if (!gtk_clipboard_set_with_owner (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, owner))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    if (owner != gtk_clipboard_get_owner (clipboard))
    {
        TEST_FAIL ("'owner' is wrong", NULL);
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    gtk_clipboard_clear (clipboard);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    
    #undef ATOM
    #undef OWNER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_set_with_owner
 * Params: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, GObject *owner
 * Returns: gboolean
 * Assertion: Virtually sets the contents of the specified clipboard by providing a list of supported formats for the clipboard data and a function to call to get the actual data when it is requested.
 * Params Values: GtkClipboard *clipboard, const GtkTargetEntry *targets, guint n_targets, GtkClipboardGetFunc get_func, GtkClipboardClearFunc clear_func, GObject *owner
 * Expected: gboolean  
 */
static void test_purpose_27()
{
    #define ATOM "BITMAP"
    #define OWNER gtk_image_new_from_image (NULL, NULL)
    
    GtkClipboard* clipboard;
    GObject* owner;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    owner = G_OBJECT (OWNER);
    if (!owner)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    if (!gtk_clipboard_set_with_owner (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, owner))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    if (owner != gtk_clipboard_get_owner (clipboard))
    {
        TEST_FAIL ("'owner' is wrong", NULL);
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, TRUE));
    
    gtk_clipboard_clear (clipboard);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    
    #undef ATOM
    #undef OWNER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: Requests the contents of the clipboard as text and converts the result to UTF-8 if necessary.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*
 * 
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*  
 */
static void test_purpose_28()
{
    #define TEXT " "
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: Requests the contents of the clipboard as text and converts the result to UTF-8 if necessary.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*
 * 
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*  
 */
static void test_purpose_29()
{
    #define TEXT "Text\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: Requests the contents of the clipboard as text and converts the result to UTF-8 if necessary.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*
 * 
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*  
 */
static void test_purpose_30()
{
    #define TEXT "Text\nText\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: Requests the contents of the clipboard as text and converts the result to UTF-8 if necessary.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*
 * 
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*  
 */
static void test_purpose_31()
{
    #define TEXT "Text\n\bText\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: Requests the contents of the clipboard as text and converts the result to UTF-8 if necessary.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*
 * 
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*  
 */
static void test_purpose_32()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: Requests the contents of the clipboard as text and converts the result to UTF-8 if necessary.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*
 * 
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*  
 */
static void test_purpose_33()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: Requests the contents of the clipboard as text and converts the result to UTF-8 if necessary.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*
 * 
 * Name: gtk_clipboard_wait_for_text
 * Params: GtkClipboard *clipboard
 * Returns: gchar*
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gchar*  
 */
static void test_purpose_34()
{
    #define TEXT "\b\n\t\n" 
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    text = gtk_clipboard_wait_for_text (clipboard);
    
    if (strcmp (text, TEXT))
    {
        TEST_FAIL ("text   = '%s',\nshould be '%s'", text, TEXT);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: Test to see if there is text available to be pasted
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean
 * 
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean  
 */
static void test_purpose_35()
{
    #define TEXT " "
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    if (gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("clipboard should be empty", NULL);
    }
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    if (!gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("text has been pasted", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: Test to see if there is text available to be pasted
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean
 * 
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean  
 */
static void test_purpose_36()
{
    #define TEXT "Text\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    if (gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("clipboard should be empty", NULL);
    }
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    if (!gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("text has been pasted", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: Test to see if there is text available to be pasted
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean
 * 
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean  
 */
static void test_purpose_37()
{
    #define TEXT "Text\nText\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    if (gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("clipboard should be empty", NULL);
    }
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    if (!gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("text has been pasted", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: Test to see if there is text available to be pasted
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean
 * 
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean  
 */
static void test_purpose_38()
{
    #define TEXT "Text\n\bText\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    if (gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("clipboard should be empty", NULL);
    }
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    if (!gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("text has been pasted", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: Test to see if there is text available to be pasted
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean
 * 
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean  
 */
static void test_purpose_39()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    if (gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("clipboard should be empty", NULL);
    }
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    if (!gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("text has been pasted", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: Test to see if there is text available to be pasted
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean
 * 
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean  
 */
static void test_purpose_40()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    if (gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("clipboard should be empty", NULL);
    }
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    if (!gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("text has been pasted", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: Test to see if there is text available to be pasted
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean
 * 
 * Name: gtk_clipboard_wait_is_text_available
 * Params: GtkClipboard *clipboard
 * Returns: gboolean
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard
 * Expected: gboolean  
 */
static void test_purpose_41()
{
    #define TEXT "\b\n\t\n" 
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_clear (clipboard);
    
    if (gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("clipboard should be empty", NULL);
    }
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    if (!gtk_clipboard_wait_is_text_available (clipboard))
    {
        TEST_FAIL ("text has been pasted", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of the clipboard as text.
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the text is later received, it will be converted to UTF-8 if necessary, and callback will be called. 
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_42()
{
    #define TEXT " "
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_text_is_same = FALSE;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    gtk_clipboard_request_text (clipboard, global_text_receive, TEXT);
    
    if (!global_text_is_same)
    {
        TEST_FAIL ("texts not equal", NULL);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of the clipboard as text.
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the text is later received, it will be converted to UTF-8 if necessary, and callback will be called. 
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_43()
{
    #define TEXT "Text\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_text_is_same = FALSE;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    gtk_clipboard_request_text (clipboard, global_text_receive, TEXT);
    
    if (!global_text_is_same)
    {
        TEST_FAIL ("texts not equal", NULL);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of the clipboard as text.
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the text is later received, it will be converted to UTF-8 if necessary, and callback will be called. 
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_44()
{
    #define TEXT "Text\nText\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_text_is_same = FALSE;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    gtk_clipboard_request_text (clipboard, global_text_receive, TEXT);
    
    if (!global_text_is_same)
    {
        TEST_FAIL ("texts not equal", NULL);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of the clipboard as text.
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the text is later received, it will be converted to UTF-8 if necessary, and callback will be called. 
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_45()
{
    #define TEXT "Text\n\bText\n"
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_text_is_same = FALSE;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    gtk_clipboard_request_text (clipboard, global_text_receive, TEXT);
    
    if (!global_text_is_same)
    {
        TEST_FAIL ("texts not equal", NULL);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of the clipboard as text.
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the text is later received, it will be converted to UTF-8 if necessary, and callback will be called. 
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_46()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_text_is_same = FALSE;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    gtk_clipboard_request_text (clipboard, global_text_receive, TEXT);
    
    if (!global_text_is_same)
    {
        TEST_FAIL ("texts not equal", NULL);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of the clipboard as text.
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the text is later received, it will be converted to UTF-8 if necessary, and callback will be called. 
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_47()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_text_is_same = FALSE;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    gtk_clipboard_request_text (clipboard, global_text_receive, TEXT);
    
    if (!global_text_is_same)
    {
        TEST_FAIL ("texts not equal", NULL);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of the clipboard as text.
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_text
 * Params: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the text is later received, it will be converted to UTF-8 if necessary, and callback will be called. 
 * Params Values: GtkClipboard *clipboard, GtkClipboardTextReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_48()
{
    #define TEXT "\b\n\t\n" 
    
    GtkClipboard* clipboard;
    gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_text_is_same = FALSE;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_clipboard_set_text (clipboard, TEXT, strlen (TEXT));
    
    gtk_clipboard_request_text (clipboard, global_text_receive, TEXT);
    
    if (!global_text_is_same)
    {
        TEST_FAIL ("texts not equal", NULL);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of clipboard as the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the results of the result are later received the supplied callback will be called.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_49()
{
    #define ATOM "TEXT"
    #define DATA " "
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_request_contents (clipboard, gdk_atom_intern (ATOM, FALSE), global_receive, NULL);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of clipboard as the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the results of the result are later received the supplied callback will be called.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_50()
{
    #define ATOM "TEXT"
    #define DATA "Text\n"
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_request_contents (clipboard, gdk_atom_intern (ATOM, FALSE), global_receive, NULL);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of clipboard as the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the results of the result are later received the supplied callback will be called.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_51()
{
    #define ATOM "TEXT"
    #define DATA "Text\nText\n"
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_request_contents (clipboard, gdk_atom_intern (ATOM, FALSE), global_receive, NULL);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of clipboard as the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the results of the result are later received the supplied callback will be called.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_52()
{
    #define ATOM "STRING"
    #define DATA "Text\n\bText\n"
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_request_contents (clipboard, gdk_atom_intern (ATOM, FALSE), global_receive, NULL);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of clipboard as the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the results of the result are later received the supplied callback will be called.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_53()
{
    #define ATOM "STRING"
    #define DATA "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_request_contents (clipboard, gdk_atom_intern (ATOM, FALSE), global_receive, NULL);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of clipboard as the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the results of the result are later received the supplied callback will be called.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_54()
{
    #define ATOM "STRING"
    #define DATA "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_request_contents (clipboard, gdk_atom_intern (ATOM, FALSE), global_receive, NULL);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of clipboard as the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the results of the result are later received the supplied callback will be called.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_55()
{
    #define ATOM "UTF8_STRING"
    #define DATA "\b\n\t\n" 
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_request_contents (clipboard, gdk_atom_intern (ATOM, FALSE), global_receive, NULL);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of clipboard as the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the results of the result are later received the supplied callback will be called.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_56()
{
    #define ATOM "POINTER"
    #define DATA gtk_label_new ("Label")
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_request_contents (clipboard, gdk_atom_intern (ATOM, FALSE), global_receive, NULL);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: Requests the contents of clipboard as the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void
 * 
 * Name: gtk_clipboard_request_contents 
 * Params: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Returns: void
 * Assertion: When the results of the result are later received the supplied callback will be called.
 * Params Values: GtkClipboard *clipboard, GdkAtom target, GtkClipboardReceivedFunc callback, gpointer user_data
 * Expected: void  
 */
static void test_purpose_57()
{
    #define ATOM "POINTER"
    #define DATA gtk_text_buffer_new (NULL)
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get_text, global_clear, DATA))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    gtk_clipboard_request_contents (clipboard, gdk_atom_intern (ATOM, FALSE), global_receive, NULL);
    
    if (global_result != 2)
    {
        TEST_FAIL ("Test fails %i", global_result);
    }
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: Requests the contents of the clipboard using the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*
 * 
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*  
 */
static void test_purpose_58()
{
    #define ATOM "TEXT"
    #define DATA " "
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    gpointer init_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    init_data = DATA;
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, init_data))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, FALSE));
    
    if (!data)
    {
       TEST_FAIL ("'data' is NULL", NULL);
       return;
    }
    
    if (data->target != gdk_atom_intern (ATOM, FALSE))
    {
       TEST_FAIL ("'targets' not equal", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: Requests the contents of the clipboard using the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*
 * 
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*  
 */
static void test_purpose_59()
{
    #define ATOM "TEXT"
    #define DATA "Text\n"
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    gpointer init_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    init_data = DATA;
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, init_data))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, FALSE));
    
    if (!data)
    {
       TEST_FAIL ("'data' is NULL", NULL);
       return;
    }
    
    if (data->target != gdk_atom_intern (ATOM, FALSE))
    {
       TEST_FAIL ("'targets' not equal", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: Requests the contents of the clipboard using the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*
 * 
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*  
 */
static void test_purpose_60()
{
    #define ATOM "TEXT"
    #define DATA "Text\nText\n"
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    gpointer init_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    init_data = DATA;
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, init_data))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, FALSE));
    
    if (!data)
    {
       TEST_FAIL ("'data' is NULL", NULL);
       return;
    }
    
    if (data->target != gdk_atom_intern (ATOM, FALSE))
    {
       TEST_FAIL ("'targets' not equal", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: Requests the contents of the clipboard using the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*
 * 
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*  
 */
static void test_purpose_61()
{
    #define ATOM "STRING"
    #define DATA "Text\n\bText\n"
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    gpointer init_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    init_data = DATA;
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, init_data))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, FALSE));
    
    if (!data)
    {
       TEST_FAIL ("'data' is NULL", NULL);
       return;
    }
    
    if (data->target != gdk_atom_intern (ATOM, FALSE))
    {
       TEST_FAIL ("'targets' not equal", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: Requests the contents of the clipboard using the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*
 * 
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*  
 */
static void test_purpose_62()
{
    #define ATOM "STRING"
    #define DATA "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890\n" 
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    gpointer init_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    init_data = DATA;
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, init_data))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, FALSE));
    
    if (!data)
    {
       TEST_FAIL ("'data' is NULL", NULL);
       return;
    }
    
    if (data->target != gdk_atom_intern (ATOM, FALSE))
    {
       TEST_FAIL ("'targets' not equal", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: Requests the contents of the clipboard using the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*
 * 
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*  
 */
static void test_purpose_63()
{
    #define ATOM "STRING"
    #define DATA "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    gpointer init_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    init_data = DATA;
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, init_data))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, FALSE));
    
    if (!data)
    {
       TEST_FAIL ("'data' is NULL", NULL);
       return;
    }
    
    if (data->target != gdk_atom_intern (ATOM, FALSE))
    {
       TEST_FAIL ("'targets' not equal", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: Requests the contents of the clipboard using the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*
 * 
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*  
 */
static void test_purpose_64()
{
    #define ATOM "UTF8_STRING"
    #define DATA "\b\n\t\n" 
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    gpointer init_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    init_data = DATA;
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, init_data))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, FALSE));
    
    if (!data)
    {
       TEST_FAIL ("'data' is NULL", NULL);
       return;
    }
    
    if (data->target != gdk_atom_intern (ATOM, FALSE))
    {
       TEST_FAIL ("'targets' not equal", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: Requests the contents of the clipboard using the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*
 * 
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*  
 */
static void test_purpose_65()
{
    #define ATOM "POINTER"
    #define DATA gtk_label_new ("Label")
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    gpointer init_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    init_data = DATA;
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, init_data))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, FALSE));
    
    if (!data)
    {
       TEST_FAIL ("'data' is NULL", NULL);
       return;
    }
    
    if (data->target != gdk_atom_intern (ATOM, FALSE))
    {
       TEST_FAIL ("'targets' not equal", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: Requests the contents of the clipboard using the given target.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*
 * 
 * Name: gtk_clipboard_wait_for_contents
 * Params: GtkClipboard *clipboard, GdkAtom target
 * Returns: GtkSelectionData* 
 * Assertion: This function waits for the data to be received using the main loop, so events, timeouts, etc, may be dispatched during the wait.
 * Params Values: GtkClipboard *clipboard, GdkAtom target
 * Expected: GtkSelectionData*  
 */
static void test_purpose_66()
{
    #define ATOM "POINTER"
    #define DATA gtk_text_buffer_new (NULL)
    
    GtkClipboard* clipboard;
    static const GtkTargetEntry target[] = {ATOM, 0, 0};
    GtkSelectionData* data;
    gpointer init_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    clipboard = gtk_clipboard_get (GDK_NONE);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    init_data = DATA;
    if (!gtk_clipboard_set_with_data (clipboard, target, G_N_ELEMENTS (target), global_get, global_clear, init_data))
    {
        TEST_FAIL ("Can't set data", NULL);
        return;
    }
    
    data = gtk_clipboard_wait_for_contents (clipboard, gdk_atom_intern (ATOM, FALSE));
    
    if (!data)
    {
       TEST_FAIL ("'data' is NULL", NULL);
       return;
    }
    
    if (data->target != gdk_atom_intern (ATOM, FALSE))
    {
       TEST_FAIL ("'targets' not equal", NULL);
    }
    
    gtk_clipboard_clear (clipboard);
    
    #undef ATOM
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_display
 * Params: GtkClipboard *clipboard
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with clipboard
 * Params Values: GtkClipboard*
 * Expected: GdkDisplay*
 * 
 * Name: gtk_clipboard_get_for_display
 * Params: GdkDisplay *display, GdkAtom selection
 * Returns: Gtklipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkDisplay*, GdkAtom
 * Expected: GtkClipboard*  
 */
static void test_purpose_67()
{
    #define SELECTION GDK_SELECTION_PRIMARY
    
    GtkClipboard* clipboard;
    GtkClipboard* real_clipboard;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    display = gtk_clipboard_get_display (clipboard);
    if (!display)
    {
        TEST_FAIL ("display is NULL", NULL);
        return;
    }
    
    real_clipboard = gtk_clipboard_get_for_display (display, SELECTION);
    if (!real_clipboard)
    {
        TEST_FAIL ("real_clipboard is NULL", NULL);
        return;
    } 
    
    if (real_clipboard != clipboard)
    {
        TEST_FAIL ("real_clipboard differs from the one was set", NULL);
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_display
 * Params: GtkClipboard *clipboard
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with clipboard
 * Params Values: GtkClipboard*
 * Expected: GdkDisplay*
 * 
 * Name: gtk_clipboard_get_for_display
 * Params: GdkDisplay *display, GdkAtom selection
 * Returns: Gtklipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkDisplay*, GdkAtom
 * Expected: GtkClipboard*  
 */
static void test_purpose_68()
{
    #define SELECTION GDK_SELECTION_SECONDARY
    
    GtkClipboard* clipboard;
    GtkClipboard* real_clipboard;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    display = gtk_clipboard_get_display (clipboard);
    if (!display)
    {
        TEST_FAIL ("display is NULL", NULL);
        return;
    }
    
    real_clipboard = gtk_clipboard_get_for_display (display, SELECTION);
    if (!real_clipboard)
    {
        TEST_FAIL ("real_clipboard is NULL", NULL);
        return;
    } 
    
    if (real_clipboard != clipboard)
    {
        TEST_FAIL ("real_clipboard differs from the one was set", NULL);
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_display
 * Params: GtkClipboard *clipboard
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with clipboard
 * Params Values: GtkClipboard*
 * Expected: GdkDisplay*
 * 
 * Name: gtk_clipboard_get_for_display
 * Params: GdkDisplay *display, GdkAtom selection
 * Returns: Gtklipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkDisplay*, GdkAtom
 * Expected: GtkClipboard*  
 */
static void test_purpose_69()
{
    #define SELECTION GDK_SELECTION_CLIPBOARD
    
    GtkClipboard* clipboard;
    GtkClipboard* real_clipboard;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    display = gtk_clipboard_get_display (clipboard);
    if (!display)
    {
        TEST_FAIL ("display is NULL", NULL);
        return;
    }
    
    real_clipboard = gtk_clipboard_get_for_display (display, SELECTION);
    if (!real_clipboard)
    {
        TEST_FAIL ("real_clipboard is NULL", NULL);
        return;
    } 
    
    if (real_clipboard != clipboard)
    {
        TEST_FAIL ("real_clipboard differs from the one was set", NULL);
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_display
 * Params: GtkClipboard *clipboard
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with clipboard
 * Params Values: GtkClipboard*
 * Expected: GdkDisplay*
 * 
 * Name: gtk_clipboard_get_for_display
 * Params: GdkDisplay *display, GdkAtom selection
 * Returns: Gtklipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkDisplay*, GdkAtom
 * Expected: GtkClipboard*  
 */
static void test_purpose_70()
{
    #define SELECTION GDK_SELECTION_TYPE_ATOM
    
    GtkClipboard* clipboard;
    GtkClipboard* real_clipboard;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    display = gtk_clipboard_get_display (clipboard);
    if (!display)
    {
        TEST_FAIL ("display is NULL", NULL);
        return;
    }
    
    real_clipboard = gtk_clipboard_get_for_display (display, SELECTION);
    if (!real_clipboard)
    {
        TEST_FAIL ("real_clipboard is NULL", NULL);
        return;
    } 
    
    if (real_clipboard != clipboard)
    {
        TEST_FAIL ("real_clipboard differs from the one was set", NULL);
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_display
 * Params: GtkClipboard *clipboard
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with clipboard
 * Params Values: GtkClipboard*
 * Expected: GdkDisplay*
 * 
 * Name: gtk_clipboard_get_for_display
 * Params: GdkDisplay *display, GdkAtom selection
 * Returns: Gtklipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkDisplay*, GdkAtom
 * Expected: GtkClipboard*  
 */
static void test_purpose_71()
{
    #define SELECTION GDK_SELECTION_TYPE_BITMAP
    
    GtkClipboard* clipboard;
    GtkClipboard* real_clipboard;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    display = gtk_clipboard_get_display (clipboard);
    if (!display)
    {
        TEST_FAIL ("display is NULL", NULL);
        return;
    }
    
    real_clipboard = gtk_clipboard_get_for_display (display, SELECTION);
    if (!real_clipboard)
    {
        TEST_FAIL ("real_clipboard is NULL", NULL);
        return;
    } 
    
    if (real_clipboard != clipboard)
    {
        TEST_FAIL ("real_clipboard differs from the one was set", NULL);
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_display
 * Params: GtkClipboard *clipboard
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with clipboard
 * Params Values: GtkClipboard*
 * Expected: GdkDisplay*
 * 
 * Name: gtk_clipboard_get_for_display
 * Params: GdkDisplay *display, GdkAtom selection
 * Returns: Gtklipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkDisplay*, GdkAtom
 * Expected: GtkClipboard*  
 */
static void test_purpose_72()
{
    #define SELECTION GDK_SELECTION_TYPE_COLORMAP
    
    GtkClipboard* clipboard;
    GtkClipboard* real_clipboard;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    display = gtk_clipboard_get_display (clipboard);
    if (!display)
    {
        TEST_FAIL ("display is NULL", NULL);
        return;
    }
    
    real_clipboard = gtk_clipboard_get_for_display (display, SELECTION);
    if (!real_clipboard)
    {
        TEST_FAIL ("real_clipboard is NULL", NULL);
        return;
    } 
    
    if (real_clipboard != clipboard)
    {
        TEST_FAIL ("real_clipboard differs from the one was set", NULL);
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_display
 * Params: GtkClipboard *clipboard
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with clipboard
 * Params Values: GtkClipboard*
 * Expected: GdkDisplay*
 * 
 * Name: gtk_clipboard_get_for_display
 * Params: GdkDisplay *display, GdkAtom selection
 * Returns: Gtklipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkDisplay*, GdkAtom
 * Expected: GtkClipboard*  
 */
static void test_purpose_73()
{
    #define SELECTION GDK_SELECTION_TYPE_DRAWABLE
    
    GtkClipboard* clipboard;
    GtkClipboard* real_clipboard;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    display = gtk_clipboard_get_display (clipboard);
    if (!display)
    {
        TEST_FAIL ("display is NULL", NULL);
        return;
    }
    
    real_clipboard = gtk_clipboard_get_for_display (display, SELECTION);
    if (!real_clipboard)
    {
        TEST_FAIL ("real_clipboard is NULL", NULL);
        return;
    } 
    
    if (real_clipboard != clipboard)
    {
        TEST_FAIL ("real_clipboard differs from the one was set", NULL);
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_display
 * Params: GtkClipboard *clipboard
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with clipboard
 * Params Values: GtkClipboard*
 * Expected: GdkDisplay*
 * 
 * Name: gtk_clipboard_get_for_display
 * Params: GdkDisplay *display, GdkAtom selection
 * Returns: Gtklipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkDisplay*, GdkAtom
 * Expected: GtkClipboard*  
 */
static void test_purpose_74()
{
    #define SELECTION GDK_SELECTION_TYPE_INTEGER
    
    GtkClipboard* clipboard;
    GtkClipboard* real_clipboard;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    display = gtk_clipboard_get_display (clipboard);
    if (!display)
    {
        TEST_FAIL ("display is NULL", NULL);
        return;
    }
    
    real_clipboard = gtk_clipboard_get_for_display (display, SELECTION);
    if (!real_clipboard)
    {
        TEST_FAIL ("real_clipboard is NULL", NULL);
        return;
    } 
    
    if (real_clipboard != clipboard)
    {
        TEST_FAIL ("real_clipboard differs from the one was set", NULL);
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_display
 * Params: GtkClipboard *clipboard
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with clipboard
 * Params Values: GtkClipboard*
 * Expected: GdkDisplay*
 * 
 * Name: gtk_clipboard_get_for_display
 * Params: GdkDisplay *display, GdkAtom selection
 * Returns: Gtklipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkDisplay*, GdkAtom
 * Expected: GtkClipboard*  
 */
static void test_purpose_75()
{
    #define SELECTION GDK_SELECTION_TYPE_PIXMAP
    
    GtkClipboard* clipboard;
    GtkClipboard* real_clipboard;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    display = gtk_clipboard_get_display (clipboard);
    if (!display)
    {
        TEST_FAIL ("display is NULL", NULL);
        return;
    }
    
    real_clipboard = gtk_clipboard_get_for_display (display, SELECTION);
    if (!real_clipboard)
    {
        TEST_FAIL ("real_clipboard is NULL", NULL);
        return;
    } 
    
    if (real_clipboard != clipboard)
    {
        TEST_FAIL ("real_clipboard differs from the one was set", NULL);
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_display
 * Params: GtkClipboard *clipboard
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with clipboard
 * Params Values: GtkClipboard*
 * Expected: GdkDisplay*
 * 
 * Name: gtk_clipboard_get_for_display
 * Params: GdkDisplay *display, GdkAtom selection
 * Returns: Gtklipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkDisplay*, GdkAtom
 * Expected: GtkClipboard*  
 */
static void test_purpose_76()
{
    #define SELECTION GDK_SELECTION_TYPE_WINDOW
    
    GtkClipboard* clipboard;
    GtkClipboard* real_clipboard;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    display = gtk_clipboard_get_display (clipboard);
    if (!display)
    {
        TEST_FAIL ("display is NULL", NULL);
        return;
    }
    
    real_clipboard = gtk_clipboard_get_for_display (display, SELECTION);
    if (!real_clipboard)
    {
        TEST_FAIL ("real_clipboard is NULL", NULL);
        return;
    } 
    
    if (real_clipboard != clipboard)
    {
        TEST_FAIL ("real_clipboard differs from the one was set", NULL);
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_display
 * Params: GtkClipboard *clipboard
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with clipboard
 * Params Values: GtkClipboard*
 * Expected: GdkDisplay*
 * 
 * Name: gtk_clipboard_get_for_display
 * Params: GdkDisplay *display, GdkAtom selection
 * Returns: Gtklipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkDisplay*, GdkAtom
 * Expected: GtkClipboard*  
 */
static void test_purpose_77()
{
    #define SELECTION GDK_SELECTION_TYPE_STRING
    
    GtkClipboard* clipboard;
    GtkClipboard* real_clipboard;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    display = gtk_clipboard_get_display (clipboard);
    if (!display)
    {
        TEST_FAIL ("display is NULL", NULL);
        return;
    }
    
    real_clipboard = gtk_clipboard_get_for_display (display, SELECTION);
    if (!real_clipboard)
    {
        TEST_FAIL ("real_clipboard is NULL", NULL);
        return;
    } 
    
    if (real_clipboard != clipboard)
    {
        TEST_FAIL ("real_clipboard differs from the one was set", NULL);
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_clipboard_get_display
 * Params: GtkClipboard *clipboard
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with clipboard
 * Params Values: GtkClipboard*
 * Expected: GdkDisplay*
 * 
 * Name: gtk_clipboard_get_for_display
 * Params: GdkDisplay *display, GdkAtom selection
 * Returns: Gtklipboard*
 * Assertion: Returns the clipboard object for the given selection.
 * Params Values: GdkDisplay*, GdkAtom
 * Expected: GtkClipboard*  
 */
static void test_purpose_78()
{
    #define SELECTION GDK_NONE
    
    GtkClipboard* clipboard;
    GtkClipboard* real_clipboard;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    clipboard = gtk_clipboard_get (SELECTION);
    if (!clipboard)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    display = gtk_clipboard_get_display (clipboard);
    if (!display)
    {
        TEST_FAIL ("display is NULL", NULL);
        return;
    }
    
    real_clipboard = gtk_clipboard_get_for_display (display, SELECTION);
    if (!real_clipboard)
    {
        TEST_FAIL ("real_clipboard is NULL", NULL);
        return;
    } 
    
    if (real_clipboard != clipboard)
    {
        TEST_FAIL ("real_clipboard differs from the one was set", NULL);
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for Clipboards ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {NULL,0}
};
