/*
 * GHashTable methods tests
 * Testing GHashTable methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
static gint flag = 0;

static void
my_hash_callback (gpointer key,
                  gpointer value,
                  gpointer user_data)
{
    gint *d = value;
    *d += *(gint *)user_data;
    flag ++;
}

static guint
my_hash (gconstpointer key)
{
    return (guint) *((const gint*) key);
}

static gboolean
my_hash_equal (gconstpointer a,
               gconstpointer b)
{
    return *((const gint*) a) == *((const gint*) b);
}

static void
my_key_destroy(gpointer data)
{
    flag ++;
}

static void
my_val_destroy(gpointer data)
{
    flag ++;
}

static gboolean find_first     (gpointer key,
                                gpointer value,
                                gpointer user_data)
{
  gint *v = value;
  gint *test = user_data;
  return (*v == *test);
}


/*
 * Name: g_hash_table_insert
 * Params: GHashTable *hash_table, gpointer key, gpointer value 
 * Returns: void
 * Assertion: Inserts a new key and value into a GHashTable.
 * If the key already exists in the GHashTable its current value is replaced with the new value. If you supplied a value_destroy_func when creating the GHashTable, the old value is freed using that function. If you supplied a key_destroy_func when creating the GHashTable, the passed key is freed using that function.
 *            hash_table : a GHashTable.
 *            key : a key to insert.
 *            value : the value to associate with the key. 
 * Params Values: Key = 1, Value = 2
 * Expected: void  
 */
static void test_purpose_1()
{
    #define KEY    1
    #define VAL    2
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GHashTable *hash_table;
    gint key = KEY;
    gint val = VAL;
    gint *pvalue;
    
    hash_table = g_hash_table_new_full(my_hash, my_hash_equal, my_key_destroy, my_val_destroy);
    g_hash_table_insert(hash_table, &key, &val);
    {
        gint val1 = val + 1;
        g_hash_table_insert(hash_table, &key, &val1);
        if (flag != 2){
            TEST_FAIL("g_hash_table_insert: failed", NULL);
            g_hash_table_destroy(hash_table);
            return;
        }
        flag = 0;
        pvalue = g_hash_table_find(hash_table, find_first, &val1);
        if (!pvalue || *pvalue != val1){
            TEST_FAIL("g_hash_table_insert: failed", NULL);
            g_hash_table_destroy(hash_table);
            return;
        }
    }
    {
        gint key1 = key + 1;
        g_hash_table_insert(hash_table, &key1, &val);
        if (flag != 0){
            TEST_FAIL("g_hash_table_insert: failed", NULL);
            g_hash_table_destroy(hash_table);
            return;
        }
        flag = 0;
        pvalue = g_hash_table_find(hash_table, find_first, &val);
        if (!pvalue || *pvalue != val){
            TEST_FAIL("g_hash_table_insert: failed", NULL);
            g_hash_table_destroy(hash_table);
            return;
        }   
    }
    g_hash_table_destroy(hash_table);
    #undef KEY
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_hash_table_lookup
 * Params: GHashTable *hash_table, gconstpointer key 
 * Returns: gpointer
 * Assertion: Looks up a key in a GHashTable. Note that this function cannot distinguish between a key that is not present and one which is present and has the value NULL. If you need this distinction, use g_hash_table_lookup_extended(). 
 *            hash_table : a GHashTable.
 *            key : a key to look up.
 *            Returns : the associated value, or NULL if the key is not found.
 * Params Values: Key = 1
 * Expected: value = 1  
 */
static void test_purpose_2()
{
    #define KEY    1
    #define VAL    1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GHashTable *hash_table;
    gint array[11];
    gint i;
    gint *pval;
    gint key, val;
    
    hash_table = g_hash_table_new(my_hash, my_hash_equal);
    for (i = 0; i < 10; i++){
        array[i] = i;
        g_hash_table_insert (hash_table, &array[i], &array[i]);
    }
    array[10] = 21;
    g_hash_table_insert(hash_table, &array[10], NULL);
    key = KEY;
    val = VAL;
    pval = g_hash_table_lookup(hash_table, &key);
    if (pval == NULL){
        if (VAL != NULL){
            TEST_FAIL("g_hash_table_lookup: failed", NULL);
        }
    }
    else{
        if (*pval != val){
            TEST_FAIL("g_hash_table_lookup: failed", NULL);
        }
    }
    g_hash_table_destroy(hash_table);
    #undef KEY
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_hash_table_lookup
 * Params: GHashTable *hash_table, gconstpointer key 
 * Returns: gpointer
 * Assertion: Looks up a key in a GHashTable. Note that this function cannot distinguish between a key that is not present and one which is present and has the value NULL. If you need this distinction, use g_hash_table_lookup_extended(). 
 *            hash_table : a GHashTable.
 *            key : a key to look up.
 *            Returns : the associated value, or NULL if the key is not found.
 * Params Values: Key = 11
 * Expected: value = NULL  
 */
static void test_purpose_3()
{
    #define KEY    11
    #define VAL    NULL
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GHashTable *hash_table;
    gint array[11];
    gint i;
    gint *pval;
    gint key, val;
    
    hash_table = g_hash_table_new(my_hash, my_hash_equal);
    for (i = 0; i < 10; i++){
        array[i] = i;
        g_hash_table_insert (hash_table, &array[i], &array[i]);
    }
    array[10] = 21;
    g_hash_table_insert(hash_table, &array[10], NULL);
    key = KEY;
    val = VAL;
    pval = g_hash_table_lookup(hash_table, &key);
    if (pval == NULL){
        if (VAL != NULL){
            TEST_FAIL("g_hash_table_lookup: failed", NULL);
        }
    }
    else{
        if (*pval != val){
            TEST_FAIL("g_hash_table_lookup: failed", NULL);
        }
    }
    g_hash_table_destroy(hash_table);
    #undef KEY
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_hash_table_lookup
 * Params: GHashTable *hash_table, gconstpointer key 
 * Returns: gpointer
 * Assertion: Looks up a key in a GHashTable. Note that this function cannot distinguish between a key that is not present and one which is present and has the value NULL. If you need this distinction, use g_hash_table_lookup_extended(). 
 *            hash_table : a GHashTable.
 *            key : a key to look up.
 *            Returns : the associated value, or NULL if the key is not found.
 * Params Values: Key = 21
 * Expected: value = NULL  
 */
static void test_purpose_4()
{
    #define KEY    21
    #define VAL    NULL
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GHashTable *hash_table;
    gint array[11];
    gint i;
    gint *pval;
    gint key, val;
    
    hash_table = g_hash_table_new(my_hash, my_hash_equal);
    for (i = 0; i < 10; i++){
        array[i] = i;
        g_hash_table_insert (hash_table, &array[i], &array[i]);
    }
    array[10] = 21;
    g_hash_table_insert(hash_table, &array[10], NULL);
    key = KEY;
    val = VAL;
    pval = g_hash_table_lookup(hash_table, &key);
    if (pval == NULL){
        if (VAL != NULL){
            TEST_FAIL("g_hash_table_lookup: failed", NULL);
        }
    }
    else{
        if (*pval != val){
            TEST_FAIL("g_hash_table_lookup: failed", NULL);
        }
    }
    g_hash_table_destroy(hash_table);
    #undef KEY
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_str_hash
 * Params: gconstpointer v
 * Returns: guint
 * Assertion: Converts a string to a hash value. It can be passed to g_hash_table_new() as the hash_func parameter, when using strings as keys in a GHashTable.
 *            v : a string key.
 *            Returns : a hash value corresponding to the key. 
 * Params Values: str = "Hello, LSB"
 * Expected: value = 0x17ad3435  
 */
static void test_purpose_5()
{
    #define STR    "Hello, LSB"
    #define VAL    0x17ad3435
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strdup(STR);
    if (g_str_hash(str) != VAL){
        TEST_FAIL("g_str_hash: failed", NULL);
    }
    g_free(str);
    
    #undef STR
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_str_equal
 * Params: gconstpointer v, gconstpointer v2
 * Returns: gboolean
 * Assertion: Compares two strings and returns TRUE if they are equal. It can be passed to g_hash_table_new() as the key_equal_func parameter, when using strings as keys in a GHashTable.
 *            v : a key.
 *            v2 : a key to compare with v.
 *            Returns : TRUE if the two keys match. 
 * Params Values: str1 = "Hello, LSB", str2 = "Hello, LSB"
 * Expected: value = TRUE  
 */
static void test_purpose_6()
{
    #define STR1    "Hello, LSB"
    #define STR2    "Hello, LSB"
    #define RETB    TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str1 = g_strdup(STR1);
    gchar *str2 = g_strdup(STR2);
    if (g_str_equal(str1, str2) != RETB){
        TEST_FAIL("g_str_equal: failed", NULL);
    }
    g_free(str1);
    g_free(str2);
    
    #undef STR1
    #undef STR2
    #undef RETB
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_str_equal
 * Params: gconstpointer v, gconstpointer v2
 * Returns: gboolean
 * Assertion: Compares two strings and returns TRUE if they are equal. It can be passed to g_hash_table_new() as the key_equal_func parameter, when using strings as keys in a GHashTable.
 *            v : a key.
 *            v2 : a key to compare with v.
 *            Returns : TRUE if the two keys match. 
 * Params Values: str1 = "Hello, LSB", str2 = "Hello, lsb"
 * Expected: value = FALSE  
 */
static void test_purpose_7()
{
    #define STR1    "Hello, LSB"
    #define STR2    "Hello, lsb"
    #define RETB    FALSE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str1 = g_strdup(STR1);
    gchar *str2 = g_strdup(STR2);
    if (g_str_equal(str1, str2) != RETB){
        TEST_FAIL("g_str_equal: failed", NULL);
    }
    g_free(str1);
    g_free(str2);
    
    #undef STR1
    #undef STR2
    #undef RETB
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_int_hash
 * Params: gconstpointer v
 * Returns: guint
 * Assertion: Converts a pointer to a gint to a hash value. It can be passed to g_hash_table_new() as the hash_func parameter, when using pointers to integers values as keys in a GHashTable.
 *            v : a pointer to a gint key.
 *            Returns : a hash value corresponding to the key. 
 * Params Values: int = 1024
 * Expected: value = 0x400  
 */
static void test_purpose_8()
{
    #define INT    1024
    #define VAL    0x400
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = INT;
    if (g_int_hash(&i) != VAL){
        TEST_FAIL("g_int_hash: failed", NULL);
    }
    
    #undef INT
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_int_equal
 * Params: gconstpointer v, gconstpointer v2
 * Returns: gboolean
 * Assertion: Compares the two gint values being pointed to and returns TRUE if they are equal. It can be passed to g_hash_table_new() as the key_equal_func parameter, when using pointers to integers as keys in a GHashTable. 
 *            v : a pointer to a gint key.
 *            v2 : a pointer to a gint key to compare with v.
 *            Returns : TRUE if the two keys match. 
 * Params Values: int1 = 1024, int2 = 1024
 * Expected: value = TRUE  
 */
static void test_purpose_9()
{
    #define INT1    1024
    #define INT2    1024
    #define RETB    TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i1 = INT1;
    gint i2 = INT2;
    if (g_int_equal(&i1, &i2) != RETB){
        TEST_FAIL("g_int_equal: failed", NULL);
    }
    
    #undef INT1
    #undef INT2
    #undef RETB
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_int_equal
 * Params: gconstpointer v, gconstpointer v2
 * Returns: gboolean
 * Assertion: Compares the two gint values being pointed to and returns TRUE if they are equal. It can be passed to g_hash_table_new() as the key_equal_func parameter, when using pointers to integers as keys in a GHashTable. 
 *            v : a pointer to a gint key.
 *            v2 : a pointer to a gint key to compare with v.
 *            Returns : TRUE if the two keys match. 
 * Params Values: int1 = 1024, int2 = 1023
 * Expected: value = FALSE  
 */
static void test_purpose_10()
{
    #define INT1    1024
    #define INT2    1023
    #define RETB    FALSE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i1 = INT1;
    gint i2 = INT2;
    if (g_int_equal(&i1, &i2) != RETB){
        TEST_FAIL("g_int_equal: failed", NULL);
    }
    
    #undef INT1
    #undef INT2
    #undef RETB
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_direct_hash
 * Params: gconstpointer v
 * Returns: guint
 * Assertion: Converts a gpointer to a hash value. It can be passed to g_hash_table_new() as the hash_func parameter, when using pointers as keys in a GHashTable.
 *            v : a gpointer key.
 *            Returns : a hash value corresponding to the key. 
 * Params Values: str = "Hello, LSB"
 * Expected: guint  
 */
static void test_purpose_11()
{
    #define STR    "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strdup(STR);
    if (g_direct_hash(&str) == '\0'){
        TEST_FAIL("g_direct_hash: failed", NULL);
    }
    g_free(str);
    #undef STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_direct_equal
 * Params: gconstpointer v, gconstpointer v2
 * Returns: gboolean
 * Assertion: Compares two gpointer arguments and returns TRUE if they are equal. It can be passed to g_hash_table_new() as the key_equal_func parameter, when using pointers as keys in a GHashTable.
 *            v : a key.
 *            v2 : a key to compare with v.
 *            Returns : TRUE if the two keys match. 
 * Params Values: str = "Hello, LSB"
 * Expected: gboolean  
 */
static void test_purpose_12()
{
    #define STR    "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gchar *str = g_strdup(STR);
    gchar *str1 = g_strdup(STR);
    if (g_direct_equal(&str, &str1) != FALSE){
        TEST_FAIL("g_direct_equal: should be FALSE", NULL);
    }
    else{
        gchar **tmp = &str;
        if (g_direct_equal(&str, tmp) != TRUE){
            TEST_FAIL("g_direct_equal: should be TRUE", NULL);
        }
    }
    g_free(str);
    g_free(str1);
    #undef STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_hash_table_remove
 * Params: GHashTable *hash_table, gconstpointer key
 * Returns: gboolean
 * Assertion: Removes a key and its associated value from a GHashTable.
 * If the GHashTable was created using g_hash_table_new_full(), the key and value are freed using the supplied destroy functions, otherwise you have to make sure that any dynamically allocated values are freed yourself.
 *            hash_table : a GHashTable.
 *            key : the key to remove.
 *            Returns : TRUE if the key was found and removed from the GHashTable. 
 * Params Values: key = 1
 * Expected: value = TRUE  
 */
static void test_purpose_13()
{
    #define KEY    1
    #define VAL    TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GHashTable *hash_table;
    gint array[10];
    gint i;
    
    gint key = KEY;
    hash_table = g_hash_table_new(my_hash, my_hash_equal);
    for (i = 0; i < 10; i++){
        array[i] = i;
        g_hash_table_insert(hash_table, &array[i], &array[i]);
    }
    if (g_hash_table_remove(hash_table, &key) != VAL){
        TEST_FAIL("g_hash_table_remove: failed", NULL);
    }
    g_hash_table_destroy(hash_table);
    
    #undef KEY
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_hash_table_remove
 * Params: GHashTable *hash_table, gconstpointer key
 * Returns: gboolean
 * Assertion: Removes a key and its associated value from a GHashTable.
 * If the GHashTable was created using g_hash_table_new_full(), the key and value are freed using the supplied destroy functions, otherwise you have to make sure that any dynamically allocated values are freed yourself.
 *            hash_table : a GHashTable.
 *            key : the key to remove.
 *            Returns : TRUE if the key was found and removed from the GHashTable. 
 * Params Values: key = 11
 * Expected: value = FALSE  
 */
static void test_purpose_14()
{
    #define KEY    11
    #define VAL    FALSE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GHashTable *hash_table;
    gint array[10];
    gint i;
    
    gint key = KEY;
    hash_table = g_hash_table_new(my_hash, my_hash_equal);
    for (i = 0; i < 10; i++){
        array[i] = i;
        g_hash_table_insert(hash_table, &array[i], &array[i]);
    }
    if (g_hash_table_remove(hash_table, &key) != VAL){
        TEST_FAIL("g_hash_table_remove: failed", NULL);
    }
    g_hash_table_destroy(hash_table);
    
    #undef KEY
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_hash_table_foreach
 * Params: GHashTable *hash_table, GHFunc func, GHFunc func,
 * Returns: void
 * Assertion: Calls the given function for each of the key/value pairs in the GHashTable. The function is passed the key and value of each pair, and the given user_data parameter. The hash table may not be modified while iterating over it (you can't add/remove items). To remove all items matching a predicate, use g_hash_table_remove().
 *            hash_table : a GHashTable.
 *            func : the function to call for each key/value pair.
 *            user_data : user data to pass to the function. 
 * Params Values: user_data = 1
 * Expected: flag = 10  
 */
static void test_purpose_15()
{
    #define DATA    1
    #define FLAG    10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GHashTable *hash_table;
    gint i;
    gint array[10];
    gint user_data = DATA;
    
    hash_table = g_hash_table_new(my_hash, my_hash_equal);
    for (i = 0; i < 10; i++){
        array[i] = i;
        g_hash_table_insert(hash_table, &array[i], &array[i]);
    }
    if (flag != 0)
        flag = 0;
    g_hash_table_foreach(hash_table, my_hash_callback, &user_data);
    if (flag != FLAG){
        TEST_FAIL("g_hash_table_foreach: failed", NULL);
    }
    flag = 0;
    g_hash_table_destroy(hash_table);
    #undef DATA
    #undef FLAG
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_hash_table_size
 * Params: GHashTable *hash_table
 * Returns: guint
 * Assertion: Returns the number of elements contained in the GHashTable.
 *            hash_table : a GHashTable.
 *            Returns : the number of key/value pairs in the GHashTable.
 * Params Values: GHashTable *hash_table
 * Expected: guint  
 */
static void test_purpose_16()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GHashTable *hash_table;
    gint i;
    gint array[10];
    
    hash_table = g_hash_table_new(my_hash, my_hash_equal);
    for (i = 0; i < 10; i++){
        array[i] = i;
        g_hash_table_insert(hash_table, &array[i], &array[i]);
    }
    if (g_hash_table_size(hash_table) != 10){
        TEST_FAIL("g_hash_table_size: failed", NULL);
    }
    g_hash_table_destroy(hash_table);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_hash_table_steal
 * Params: GHashTable *hash_table, gconstpointer key
 * Returns: gboolean
 * Assertion: Removes a key and its associated value from a GHashTable without calling the key and value destroy functions. 
 *            hash_table : a GHashTable.
 *            Returns : TRUE if the key was found and removed from the GHashTable.
 * Params Values: key = 1
 * Expected: value = TRUE  
 */
static void test_purpose_17()
{
    #define KEY    1
    #define VAL    TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GHashTable *hash_table;
    gint array[10];
    gint i;
    
    gint key = KEY;
    hash_table = g_hash_table_new(my_hash, my_hash_equal);
    for (i = 0; i < 10; i++){
        array[i] = i;
        g_hash_table_insert(hash_table, &array[i], &array[i]);
    }
    if (g_hash_table_steal(hash_table, &key) != VAL){
        TEST_FAIL("g_hash_table_steal: failed", NULL);
    }
    g_hash_table_destroy(hash_table);
    #undef KEY
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_hash_table_steal
 * Params: GHashTable *hash_table, gconstpointer key
 * Returns: gboolean
 * Assertion: Removes a key and its associated value from a GHashTable without calling the key and value destroy functions. 
 *            hash_table : a GHashTable.
 *            Returns : TRUE if the key was found and removed from the GHashTable.
 * Params Values: key = 11
 * Expected: value = FALSE  
 */
static void test_purpose_18()
{
    #define KEY    11
    #define VAL    FALSE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GHashTable *hash_table;
    gint array[10];
    gint i;
    
    gint key = KEY;
    hash_table = g_hash_table_new(my_hash, my_hash_equal);
    for (i = 0; i < 10; i++){
        array[i] = i;
        g_hash_table_insert(hash_table, &array[i], &array[i]);
    }
    if (g_hash_table_steal(hash_table, &key) != VAL){
        TEST_FAIL("g_hash_table_steal: failed", NULL);
    }
    g_hash_table_destroy(hash_table);
    #undef KEY
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_hash_table_replace
 * Params: GHashTable *hash_table, gpointer key, gpointer value
 * Returns: void
 * Assertion: Inserts a new key and value into a GHashTable similar to g_hash_table_insert(). The difference is that if the key already exists in the GHashTable, it gets replaced by the new key. If you supplied a value_destroy_func when creating the GHashTable, the old value is freed using that function. If you supplied a key_destroy_func when creating the GHashTable, the old key is freed using that function.
 *            hash_table : a GHashTable.
 *            key : a key to insert.
 *            value : the value to associate with the key.
 * Params Values: key = 1, val = 11
 * Expected: void  
 */
static void test_purpose_19()
{
    #define KEY    1
    #define VAL    11
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GHashTable *hash_table;
    gint array[10];
    gint i;
    
    gint key = KEY;
    gint val = VAL;
    hash_table = g_hash_table_new(my_hash, my_hash_equal);
    for (i = 0; i < 10; i ++){
        array[i] = i;
        g_hash_table_insert(hash_table, &array[i], &array[i]);
    }
    g_hash_table_replace(hash_table, &key, &val);
    if (*(gint *)g_hash_table_lookup(hash_table, &key) != VAL){
        TEST_FAIL("g_hash_table_replace: failed", NULL);
    }
    else{
        if (g_hash_table_size(hash_table) != 10){
            TEST_FAIL("g_hash_table_replace: length failed", NULL);
        }
    }
    g_hash_table_destroy(hash_table);
    #undef KEY
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GHashTable ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {NULL,0}
};
