/*
 * GValueArray methods tests
 * Testing GValueArray methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;


/*
 * Name: g_value_array_new
 * Params: guint n_prealloced
 * Returns: GValueArray*
 * Assertion: Allocate and initialize a new GValueArray, optionally preserve space for n_prealloced elements. New arrays always contain 0 elements, regardless of the value of n_prealloced.
 *            n_prealloced :   number of values to preallocate space for
 *            Returns :   a newly allocated GValueArray with 0 values 
 * Params Values: 10
 * Expected: GValueArray*  
 */
static void test_purpose_1()
{
    #define PRELEN  10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GValueArray* val_arr = g_value_array_new(PRELEN);
    if (val_arr == NULL){
        TEST_FAIL("g_value_array_new: failed", NULL);
    }
    g_value_array_free(val_arr);
    #undef PRELEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_value_array_append
 * Params: GValueArray *value_array, const GValue *value
 * Returns: GValueArray*
 * Assertion: Insert a copy of value as last element of value_array.
 *            value_array :    GValueArray to add an element to
 *            value : GValue to copy into GValueArray
 *            Returns :   the GValueArray passed in as value_array
 * Params Values: GValueArray *value_array, const GValue *value
 * Expected: GValueArray*
 * 
 * Name: g_value_array_get_nth
 * Params: GValueArray *value_array, guint index_
 * Returns: GValue*
 * Assertion: Return a pointer to the value at index_ containd in value_array.
 *            value_array :    GValueArray to get a value from
 *            index_ :    index of the value of interest
 *            Returns :   pointer to a value at index_ in value_array
 * Params Values: GValueArray *value_array, guint index_
 * Expected: GValue*  
 */
static void test_purpose_2()
{
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GValue a = {0, };
    GValue b = {0, };
    GValueArray* val_arr = g_value_array_new(10);
    if (val_arr == NULL){
        TEST_FAIL("g_value_array_append: fail to new value array", NULL);
        return;
    }
    g_value_init(&a, G_TYPE_UINT);
    g_value_init(&b, G_TYPE_UINT64);
    val_arr = g_value_array_append(val_arr, &a);
    val_arr = g_value_array_append(val_arr, &b);
    if (val_arr->n_values != 2){
        TEST_FAIL("g_value_array_append: numbers should be 2", NULL);
    }
    else{
        if (G_VALUE_TYPE((g_value_array_get_nth(val_arr, 1))) != G_TYPE_UINT64){
             TEST_FAIL("g_value_array_append: should be append as the last element", NULL);
        }
    }
    g_value_array_free(val_arr);
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GValueArray ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {NULL,0}
};
