/*
 * GdkEvents methods tests
 * Testing GdkEvents methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;


/*
 * Name: gdk_event_new
 * Params: GdkEventType type
 * Returns: GdkEvent*
 * Assertion: Creates a new event of the given type. All fields are set to 0.
 * Params Values: a GdkEventType
 * Expected: a newly-allocated GdkEvent. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_1()
{
    #define TYPE GDK_NOTHING
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_new
 * Params: GdkEventType type
 * Returns: GdkEvent*
 * Assertion: Creates a new event of the given type. All fields are set to 0.
 * Params Values: a GdkEventType
 * Expected: a newly-allocated GdkEvent. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_2()
{
    #define TYPE GDK_DELETE
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_new
 * Params: GdkEventType type
 * Returns: GdkEvent*
 * Assertion: Creates a new event of the given type. All fields are set to 0.
 * Params Values: a GdkEventType
 * Expected: a newly-allocated GdkEvent. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_3()
{
    #define TYPE GDK_DESTROY
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_new
 * Params: GdkEventType type
 * Returns: GdkEvent*
 * Assertion: Creates a new event of the given type. All fields are set to 0.
 * Params Values: a GdkEventType
 * Expected: a newly-allocated GdkEvent. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_4()
{
    #define TYPE GDK_EXPOSE
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_new
 * Params: GdkEventType type
 * Returns: GdkEvent*
 * Assertion: Creates a new event of the given type. All fields are set to 0.
 * Params Values: a GdkEventType
 * Expected: a newly-allocated GdkEvent. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_5()
{
    #define TYPE GDK_MOTION_NOTIFY
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_new
 * Params: GdkEventType type
 * Returns: GdkEvent*
 * Assertion: Creates a new event of the given type. All fields are set to 0.
 * Params Values: a GdkEventType
 * Expected: a newly-allocated GdkEvent. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_6()
{
    #define TYPE GDK_BUTTON_PRESS
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_new
 * Params: GdkEventType type
 * Returns: GdkEvent*
 * Assertion: Creates a new event of the given type. All fields are set to 0.
 * Params Values: a GdkEventType
 * Expected: a newly-allocated GdkEvent. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_7()
{
    #define TYPE GDK_2BUTTON_PRESS
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_new
 * Params: GdkEventType type
 * Returns: GdkEvent*
 * Assertion: Creates a new event of the given type. All fields are set to 0.
 * Params Values: a GdkEventType
 * Expected: a newly-allocated GdkEvent. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_8()
{
    #define TYPE GDK_BUTTON_RELEASE
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_new
 * Params: GdkEventType type
 * Returns: GdkEvent*
 * Assertion: Creates a new event of the given type. All fields are set to 0.
 * Params Values: a GdkEventType
 * Expected: a newly-allocated GdkEvent. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_9()
{
    #define TYPE GDK_KEY_PRESS
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_new
 * Params: GdkEventType type
 * Returns: GdkEvent*
 * Assertion: Creates a new event of the given type. All fields are set to 0.
 * Params Values: a GdkEventType
 * Expected: a newly-allocated GdkEvent. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_10()
{
    #define TYPE GDK_KEY_RELEASE
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_new
 * Params: GdkEventType type
 * Returns: GdkEvent*
 * Assertion: Creates a new event of the given type. All fields are set to 0.
 * Params Values: a GdkEventType
 * Expected: a newly-allocated GdkEvent. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_11()
{
    #define TYPE GDK_DROP_START
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_new
 * Params: GdkEventType type
 * Returns: GdkEvent*
 * Assertion: Creates a new event of the given type. All fields are set to 0.
 * Params Values: a GdkEventType
 * Expected: a newly-allocated GdkEvent. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_12()
{
    #define TYPE GDK_OWNER_CHANGE
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_free
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Frees a GdkEvent, freeing or decrementing any resources associated with it. Note that this function should only be called with events returned from functions such as gdk_event_peek(), gdk_event_get(), gdk_event_get_graphics_expose() and gdk_event_copy().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_13()
{
    #define TYPE GDK_NOTHING
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_free
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Frees a GdkEvent, freeing or decrementing any resources associated with it. Note that this function should only be called with events returned from functions such as gdk_event_peek(), gdk_event_get(), gdk_event_get_graphics_expose() and gdk_event_copy().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_14()
{
    #define TYPE GDK_DELETE
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_free
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Frees a GdkEvent, freeing or decrementing any resources associated with it. Note that this function should only be called with events returned from functions such as gdk_event_peek(), gdk_event_get(), gdk_event_get_graphics_expose() and gdk_event_copy().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_15()
{
    #define TYPE GDK_DESTROY
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_free
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Frees a GdkEvent, freeing or decrementing any resources associated with it. Note that this function should only be called with events returned from functions such as gdk_event_peek(), gdk_event_get(), gdk_event_get_graphics_expose() and gdk_event_copy().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_16()
{
    #define TYPE GDK_EXPOSE
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_free
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Frees a GdkEvent, freeing or decrementing any resources associated with it. Note that this function should only be called with events returned from functions such as gdk_event_peek(), gdk_event_get(), gdk_event_get_graphics_expose() and gdk_event_copy().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_17()
{
    #define TYPE GDK_MOTION_NOTIFY
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_free
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Frees a GdkEvent, freeing or decrementing any resources associated with it. Note that this function should only be called with events returned from functions such as gdk_event_peek(), gdk_event_get(), gdk_event_get_graphics_expose() and gdk_event_copy().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_18()
{
    #define TYPE GDK_BUTTON_PRESS
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_free
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Frees a GdkEvent, freeing or decrementing any resources associated with it. Note that this function should only be called with events returned from functions such as gdk_event_peek(), gdk_event_get(), gdk_event_get_graphics_expose() and gdk_event_copy().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_19()
{
    #define TYPE GDK_2BUTTON_PRESS
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_free
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Frees a GdkEvent, freeing or decrementing any resources associated with it. Note that this function should only be called with events returned from functions such as gdk_event_peek(), gdk_event_get(), gdk_event_get_graphics_expose() and gdk_event_copy().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_20()
{
    #define TYPE GDK_BUTTON_RELEASE
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_free
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Frees a GdkEvent, freeing or decrementing any resources associated with it. Note that this function should only be called with events returned from functions such as gdk_event_peek(), gdk_event_get(), gdk_event_get_graphics_expose() and gdk_event_copy().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_21()
{
    #define TYPE GDK_KEY_PRESS
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_free
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Frees a GdkEvent, freeing or decrementing any resources associated with it. Note that this function should only be called with events returned from functions such as gdk_event_peek(), gdk_event_get(), gdk_event_get_graphics_expose() and gdk_event_copy().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_22()
{
    #define TYPE GDK_KEY_RELEASE
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_free
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Frees a GdkEvent, freeing or decrementing any resources associated with it. Note that this function should only be called with events returned from functions such as gdk_event_peek(), gdk_event_get(), gdk_event_get_graphics_expose() and gdk_event_copy().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_23()
{
    #define TYPE GDK_ENTER_NOTIFY
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_free
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Frees a GdkEvent, freeing or decrementing any resources associated with it. Note that this function should only be called with events returned from functions such as gdk_event_peek(), gdk_event_get(), gdk_event_get_graphics_expose() and gdk_event_copy().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_24()
{
    #define TYPE GDK_OWNER_CHANGE
    
    GdkEvent *event;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_screen
 * Params: GdkEvent *event
 * Returns: GdkScreen*
 * Assertion: Returns the screen for the event. The screen is typically the screen for event->any.window, but for events such as mouse events, it is the screen where the pointer was when the event occurs - that is, the screen which has the root window to which event->motion.x_root and event->motion.y_root are relative.
 * Params Values: a GdkEvent.
 * Expected: the screen for the event  
 */
static void test_purpose_25()
{
    #define TYPE GDK_BUTTON_PRESS
    
    GdkEvent *event;
    GdkScreen *screen1;
    GdkScreen *screen2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    screen1 = gdk_screen_get_default ();
    gdk_event_set_screen (event, screen1);
    
    screen2 = gdk_event_get_screen (event);
    if (screen1 != screen2)
        TEST_FAIL ("The screen for the event should be %p, not %p", screen1, screen2, NULL);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_screen
 * Params: GdkEvent *event
 * Returns: GdkScreen*
 * Assertion: Returns the screen for the event. The screen is typically the screen for event->any.window, but for events such as mouse events, it is the screen where the pointer was when the event occurs - that is, the screen which has the root window to which event->motion.x_root and event->motion.y_root are relative.
 * Params Values: a GdkEvent.
 * Expected: the screen for the event  
 */
static void test_purpose_26()
{
    #define TYPE GDK_2BUTTON_PRESS
    
    GdkEvent *event;
    GdkScreen *screen1;
    GdkScreen *screen2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    screen1 = gdk_screen_get_default ();
    gdk_event_set_screen (event, screen1);
    
    screen2 = gdk_event_get_screen (event);
    if (screen1 != screen2)
        TEST_FAIL ("The screen for the event should be %p, not %p", screen1, screen2, NULL);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_screen
 * Params: GdkEvent *event
 * Returns: GdkScreen*
 * Assertion: Returns the screen for the event. The screen is typically the screen for event->any.window, but for events such as mouse events, it is the screen where the pointer was when the event occurs - that is, the screen which has the root window to which event->motion.x_root and event->motion.y_root are relative.
 * Params Values: a GdkEvent.
 * Expected: the screen for the event  
 */
static void test_purpose_27()
{
    #define TYPE GDK_BUTTON_RELEASE
    
    GdkEvent *event;
    GdkScreen *screen1;
    GdkScreen *screen2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    screen1 = gdk_screen_get_default ();
    gdk_event_set_screen (event, screen1);
    
    screen2 = gdk_event_get_screen (event);
    if (screen1 != screen2)
        TEST_FAIL ("The screen for the event should be %p, not %p", screen1, screen2, NULL);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_screen
 * Params: GdkEvent *event
 * Returns: GdkScreen*
 * Assertion: Returns the screen for the event. The screen is typically the screen for event->any.window, but for events such as mouse events, it is the screen where the pointer was when the event occurs - that is, the screen which has the root window to which event->motion.x_root and event->motion.y_root are relative.
 * Params Values: a GdkEvent.
 * Expected: the screen for the event  
 */
static void test_purpose_28()
{
    #define TYPE GDK_KEY_PRESS
    
    GdkEvent *event;
    GdkScreen *screen1;
    GdkScreen *screen2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    screen1 = gdk_screen_get_default ();
    gdk_event_set_screen (event, screen1);
    
    screen2 = gdk_event_get_screen (event);
    if (screen1 != screen2)
        TEST_FAIL ("The screen for the event should be %p, not %p", screen1, screen2, NULL);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_screen
 * Params: GdkEvent *event
 * Returns: GdkScreen*
 * Assertion: Returns the screen for the event. The screen is typically the screen for event->any.window, but for events such as mouse events, it is the screen where the pointer was when the event occurs - that is, the screen which has the root window to which event->motion.x_root and event->motion.y_root are relative.
 * Params Values: a GdkEvent.
 * Expected: the screen for the event  
 */
static void test_purpose_29()
{
    #define TYPE GDK_KEY_RELEASE
    
    GdkEvent *event;
    GdkScreen *screen1;
    GdkScreen *screen2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    screen1 = gdk_screen_get_default ();
    gdk_event_set_screen (event, screen1);
    
    screen2 = gdk_event_get_screen (event);
    if (screen1 != screen2)
        TEST_FAIL ("The screen for the event should be %p, not %p", screen1, screen2, NULL);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_screen
 * Params: GdkEvent *event
 * Returns: GdkScreen*
 * Assertion: Returns the screen for the event. The screen is typically the screen for event->any.window, but for events such as mouse events, it is the screen where the pointer was when the event occurs - that is, the screen which has the root window to which event->motion.x_root and event->motion.y_root are relative.
 * Params Values: a GdkEvent.
 * Expected: the screen for the event  
 */
static void test_purpose_30()
{
    #define TYPE GDK_ENTER_NOTIFY
    
    GdkEvent *event;
    GdkScreen *screen1;
    GdkScreen *screen2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    screen1 = gdk_screen_get_default ();
    gdk_event_set_screen (event, screen1);
    
    screen2 = gdk_event_get_screen (event);
    if (screen1 != screen2)
        TEST_FAIL ("The screen for the event should be %p, not %p", screen1, screen2, NULL);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_put
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Appends a copy of the given event onto the front of the event queue for event->any.window's display, or the default event queue if event->any.window is NULL. See gdk_display_put_event().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_31()
{
    #define TYPE GDK_BUTTON_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_put
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Appends a copy of the given event onto the front of the event queue for event->any.window's display, or the default event queue if event->any.window is NULL. See gdk_display_put_event().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_32()
{
    #define TYPE GDK_2BUTTON_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_put
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Appends a copy of the given event onto the front of the event queue for event->any.window's display, or the default event queue if event->any.window is NULL. See gdk_display_put_event().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_33()
{
    #define TYPE GDK_BUTTON_RELEASE
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_put
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Appends a copy of the given event onto the front of the event queue for event->any.window's display, or the default event queue if event->any.window is NULL. See gdk_display_put_event().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_34()
{
    #define TYPE GDK_KEY_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_put
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Appends a copy of the given event onto the front of the event queue for event->any.window's display, or the default event queue if event->any.window is NULL. See gdk_display_put_event().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_35()
{
    #define TYPE GDK_KEY_RELEASE
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_put
 * Params: GdkEvent *event
 * Returns: void
 * Assertion: Appends a copy of the given event onto the front of the event queue for event->any.window's display, or the default event queue if event->any.window is NULL. See gdk_display_put_event().
 * Params Values: a GdkEvent.
 * Expected: void  
 */
static void test_purpose_36()
{
    #define TYPE GDK_ENTER_NOTIFY
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get
 * Params: void
 * Returns: GdkEvent*
 * Assertion: Checks all open displays for a GdkEvent to process,to be processed on, fetching events from the windowing system if necessary. See gdk_display_get_event().
 * Params Values: void
 * Expected: the next GdkEvent to be processed, or NULL if no events are pending. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_37()
{
    #define TYPE GDK_BUTTON_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event2 = gdk_event_get ();
    
    if (event2)
        TEST_FAIL ("event2 should be NULL since no events are pending", NULL);
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get
 * Params: void
 * Returns: GdkEvent*
 * Assertion: Checks all open displays for a GdkEvent to process,to be processed on, fetching events from the windowing system if necessary. See gdk_display_get_event().
 * Params Values: void
 * Expected: the next GdkEvent to be processed, or NULL if no events are pending. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_38()
{
    #define TYPE GDK_2BUTTON_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event2 = gdk_event_get ();
    
    if (event2)
        TEST_FAIL ("event2 should be NULL since no events are pending", NULL);
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get
 * Params: void
 * Returns: GdkEvent*
 * Assertion: Checks all open displays for a GdkEvent to process,to be processed on, fetching events from the windowing system if necessary. See gdk_display_get_event().
 * Params Values: void
 * Expected: the next GdkEvent to be processed, or NULL if no events are pending. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_39()
{
    #define TYPE GDK_BUTTON_RELEASE
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event2 = gdk_event_get ();
    
    if (event2)
        TEST_FAIL ("event2 should be NULL since no events are pending", NULL);
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get
 * Params: void
 * Returns: GdkEvent*
 * Assertion: Checks all open displays for a GdkEvent to process,to be processed on, fetching events from the windowing system if necessary. See gdk_display_get_event().
 * Params Values: void
 * Expected: the next GdkEvent to be processed, or NULL if no events are pending. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_40()
{
    #define TYPE GDK_KEY_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event2 = gdk_event_get ();
    
    if (event2)
        TEST_FAIL ("event2 should be NULL since no events are pending", NULL);
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get
 * Params: void
 * Returns: GdkEvent*
 * Assertion: Checks all open displays for a GdkEvent to process,to be processed on, fetching events from the windowing system if necessary. See gdk_display_get_event().
 * Params Values: void
 * Expected: the next GdkEvent to be processed, or NULL if no events are pending. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_41()
{
    #define TYPE GDK_KEY_RELEASE
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event2 = gdk_event_get ();
    
    if (event2)
        TEST_FAIL ("event2 should be NULL since no events are pending", NULL);
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get
 * Params: void
 * Returns: GdkEvent*
 * Assertion: Checks all open displays for a GdkEvent to process,to be processed on, fetching events from the windowing system if necessary. See gdk_display_get_event().
 * Params Values: void
 * Expected: the next GdkEvent to be processed, or NULL if no events are pending. The returned GdkEvent should be freed with gdk_event_free().  
 */
static void test_purpose_42()
{
    #define TYPE GDK_ENTER_NOTIFY
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event2 = gdk_event_get ();
    
    if (event2)
        TEST_FAIL ("event2 should be NULL since no events are pending", NULL);
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_peek
 * Params: void
 * Returns: GdkEvent*
 * Assertion: If there is an event waiting in the event queue of some open display, returns a copy of it. See gdk_display_peek_event().
 * Params Values: void
 * Expected: If there is an event waiting in the event queue of some open display, returns a copy of it. See gdk_display_peek_event().  
 */
static void test_purpose_43()
{
    #define TYPE GDK_BUTTON_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event2 = gdk_event_peek ();
    
    if (event2)
        TEST_FAIL ("event2 should be NULL since no events are pending", NULL);
    
    gdk_event_put (event);
    
    event2 = gdk_event_peek ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    event2 = gdk_event_get ();	/* cleanup the event queue for the following tests */
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_peek
 * Params: void
 * Returns: GdkEvent*
 * Assertion: If there is an event waiting in the event queue of some open display, returns a copy of it. See gdk_display_peek_event().
 * Params Values: void
 * Expected: If there is an event waiting in the event queue of some open display, returns a copy of it. See gdk_display_peek_event().  
 */
static void test_purpose_44()
{
    #define TYPE GDK_2BUTTON_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event2 = gdk_event_peek ();
    
    if (event2)
        TEST_FAIL ("event2 should be NULL since no events are pending", NULL);
    
    gdk_event_put (event);
    
    event2 = gdk_event_peek ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    event2 = gdk_event_get ();	/* cleanup the event queue for the following tests */
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_peek
 * Params: void
 * Returns: GdkEvent*
 * Assertion: If there is an event waiting in the event queue of some open display, returns a copy of it. See gdk_display_peek_event().
 * Params Values: void
 * Expected: If there is an event waiting in the event queue of some open display, returns a copy of it. See gdk_display_peek_event().  
 */
static void test_purpose_45()
{
    #define TYPE GDK_BUTTON_RELEASE
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event2 = gdk_event_peek ();
    
    if (event2)
        TEST_FAIL ("event2 should be NULL since no events are pending", NULL);
    
    gdk_event_put (event);
    
    event2 = gdk_event_peek ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    event2 = gdk_event_get ();	/* cleanup the event queue for the following tests */
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_peek
 * Params: void
 * Returns: GdkEvent*
 * Assertion: If there is an event waiting in the event queue of some open display, returns a copy of it. See gdk_display_peek_event().
 * Params Values: void
 * Expected: If there is an event waiting in the event queue of some open display, returns a copy of it. See gdk_display_peek_event().  
 */
static void test_purpose_46()
{
    #define TYPE GDK_KEY_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event2 = gdk_event_peek ();
    
    if (event2)
        TEST_FAIL ("event2 should be NULL since no events are pending", NULL);
    
    gdk_event_put (event);
    
    event2 = gdk_event_peek ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    event2 = gdk_event_get ();	/* cleanup the event queue for the following tests */
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_peek
 * Params: void
 * Returns: GdkEvent*
 * Assertion: If there is an event waiting in the event queue of some open display, returns a copy of it. See gdk_display_peek_event().
 * Params Values: void
 * Expected: If there is an event waiting in the event queue of some open display, returns a copy of it. See gdk_display_peek_event().  
 */
static void test_purpose_47()
{
    #define TYPE GDK_KEY_RELEASE
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event2 = gdk_event_peek ();
    
    if (event2)
        TEST_FAIL ("event2 should be NULL since no events are pending", NULL);
    
    gdk_event_put (event);
    
    event2 = gdk_event_peek ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    event2 = gdk_event_get ();	/* cleanup the event queue for the following tests */
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_peek
 * Params: void
 * Returns: GdkEvent*
 * Assertion: If there is an event waiting in the event queue of some open display, returns a copy of it. See gdk_display_peek_event().
 * Params Values: void
 * Expected: If there is an event waiting in the event queue of some open display, returns a copy of it. See gdk_display_peek_event().  
 */
static void test_purpose_48()
{
    #define TYPE GDK_ENTER_NOTIFY
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event2 = gdk_event_peek ();
    
    if (event2)
        TEST_FAIL ("event2 should be NULL since no events are pending", NULL);
    
    gdk_event_put (event);
    
    event2 = gdk_event_peek ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    event2 = gdk_event_get ();	/* cleanup the event queue for the following tests */
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_events_pending
 * Params: void
 * Returns: gboolean
 * Assertion: Checks if any events are ready to be processed for any display.
 * Params Values: void
 * Expected: TRUE if any events are pending.  
 */
static void test_purpose_49()
{
    #define TYPE GDK_BUTTON_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_events_pending ())
        TEST_FAIL ("There should be no pending events", NULL);
    
    gdk_event_put (event);
    
    if (!gdk_events_pending ())
        TEST_FAIL ("event queue should contain pending events", NULL);
    
    event2 = gdk_event_get ();	/* cleanup the event queue for the following tests */
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_events_pending
 * Params: void
 * Returns: gboolean
 * Assertion: Checks if any events are ready to be processed for any display.
 * Params Values: void
 * Expected: TRUE if any events are pending.  
 */
static void test_purpose_50()
{
    #define TYPE GDK_2BUTTON_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_events_pending ())
        TEST_FAIL ("There should be no pending events", NULL);
    
    gdk_event_put (event);
    
    if (!gdk_events_pending ())
        TEST_FAIL ("event queue should contain pending events", NULL);
    
    event2 = gdk_event_get ();	/* cleanup the event queue for the following tests */
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_events_pending
 * Params: void
 * Returns: gboolean
 * Assertion: Checks if any events are ready to be processed for any display.
 * Params Values: void
 * Expected: TRUE if any events are pending.  
 */
static void test_purpose_51()
{
    #define TYPE GDK_BUTTON_RELEASE
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_events_pending ())
        TEST_FAIL ("There should be no pending events", NULL);
    
    gdk_event_put (event);
    
    if (!gdk_events_pending ())
        TEST_FAIL ("event queue should contain pending events", NULL);
    
    event2 = gdk_event_get ();	/* cleanup the event queue for the following tests */
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_events_pending
 * Params: void
 * Returns: gboolean
 * Assertion: Checks if any events are ready to be processed for any display.
 * Params Values: void
 * Expected: TRUE if any events are pending.  
 */
static void test_purpose_52()
{
    #define TYPE GDK_KEY_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_events_pending ())
        TEST_FAIL ("There should be no pending events", NULL);
    
    gdk_event_put (event);
    
    if (!gdk_events_pending ())
        TEST_FAIL ("event queue should contain pending events", NULL);
    
    event2 = gdk_event_get ();	/* cleanup the event queue for the following tests */
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_events_pending
 * Params: void
 * Returns: gboolean
 * Assertion: Checks if any events are ready to be processed for any display.
 * Params Values: void
 * Expected: TRUE if any events are pending.  
 */
static void test_purpose_53()
{
    #define TYPE GDK_KEY_RELEASE
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_events_pending ())
        TEST_FAIL ("There should be no pending events", NULL);
    
    gdk_event_put (event);
    
    if (!gdk_events_pending ())
        TEST_FAIL ("event queue should contain pending events", NULL);
    
    event2 = gdk_event_get ();	/* cleanup the event queue for the following tests */
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_events_pending
 * Params: void
 * Returns: gboolean
 * Assertion: Checks if any events are ready to be processed for any display.
 * Params Values: void
 * Expected: TRUE if any events are pending.  
 */
static void test_purpose_54()
{
    #define TYPE GDK_ENTER_NOTIFY
    
    GdkEvent *event;
    GdkEvent *event2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_events_pending ())
        TEST_FAIL ("There should be no pending events", NULL);
    
    gdk_event_put (event);
    
    if (!gdk_events_pending ())
        TEST_FAIL ("event queue should contain pending events", NULL);
    
    event2 = gdk_event_get ();	/* cleanup the event queue for the following tests */
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_time
 * Params: GdkEvent *event
 * Returns: guint32
 * Assertion: Returns the time stamp from event, if there is one; otherwise returns GDK_CURRENT_TIME. If event is NULL, returns GDK_CURRENT_TIME.
 * Params Values: a GdkEvent
 * Expected: time stamp field from event  
 */
static void test_purpose_55()
{
    #define TYPE GDK_BUTTON_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    time_t event_time;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_time (NULL) != GDK_CURRENT_TIME)
        TEST_FAIL ("If event is NULL, gdk_event_get_time should return GDK_CURRENT_TIME", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event_time = time (NULL);
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.time = event_time;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.time = event_time;
            break;
        case GDK_SCROLL:
            event->scroll.time = event_time;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.time = event_time;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.time = event_time;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.time = event_time;
            break;
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
            event->selection.time = event_time;
            break;
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
            event->proximity.time = event_time;
            break;
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            event->dnd.time = event_time;
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no time field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    switch (event2->type)
    {
        case GDK_MOTION_NOTIFY:
    
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
    
        case GDK_SCROLL:
    
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
    
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
    
        case GDK_PROPERTY_NOTIFY:
    
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
    
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
    
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            if (gdk_event_get_time (event2) != event_time)
                TEST_FAIL ("Event time should be %u", event_time, NULL);
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            if (gdk_event_get_time (event2) != GDK_CURRENT_TIME)
                TEST_FAIL ("Event time should be GDK_CURRENT_TIME", NULL);
            break;
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_time
 * Params: GdkEvent *event
 * Returns: guint32
 * Assertion: Returns the time stamp from event, if there is one; otherwise returns GDK_CURRENT_TIME. If event is NULL, returns GDK_CURRENT_TIME.
 * Params Values: a GdkEvent
 * Expected: time stamp field from event  
 */
static void test_purpose_56()
{
    #define TYPE GDK_2BUTTON_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    time_t event_time;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_time (NULL) != GDK_CURRENT_TIME)
        TEST_FAIL ("If event is NULL, gdk_event_get_time should return GDK_CURRENT_TIME", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event_time = time (NULL);
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.time = event_time;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.time = event_time;
            break;
        case GDK_SCROLL:
            event->scroll.time = event_time;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.time = event_time;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.time = event_time;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.time = event_time;
            break;
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
            event->selection.time = event_time;
            break;
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
            event->proximity.time = event_time;
            break;
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            event->dnd.time = event_time;
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no time field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    switch (event2->type)
    {
        case GDK_MOTION_NOTIFY:
    
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
    
        case GDK_SCROLL:
    
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
    
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
    
        case GDK_PROPERTY_NOTIFY:
    
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
    
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
    
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            if (gdk_event_get_time (event2) != event_time)
                TEST_FAIL ("Event time should be %u", event_time, NULL);
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            if (gdk_event_get_time (event2) != GDK_CURRENT_TIME)
                TEST_FAIL ("Event time should be GDK_CURRENT_TIME", NULL);
            break;
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_time
 * Params: GdkEvent *event
 * Returns: guint32
 * Assertion: Returns the time stamp from event, if there is one; otherwise returns GDK_CURRENT_TIME. If event is NULL, returns GDK_CURRENT_TIME.
 * Params Values: a GdkEvent
 * Expected: time stamp field from event  
 */
static void test_purpose_57()
{
    #define TYPE GDK_BUTTON_RELEASE
    
    GdkEvent *event;
    GdkEvent *event2;
    time_t event_time;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_time (NULL) != GDK_CURRENT_TIME)
        TEST_FAIL ("If event is NULL, gdk_event_get_time should return GDK_CURRENT_TIME", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event_time = time (NULL);
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.time = event_time;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.time = event_time;
            break;
        case GDK_SCROLL:
            event->scroll.time = event_time;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.time = event_time;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.time = event_time;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.time = event_time;
            break;
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
            event->selection.time = event_time;
            break;
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
            event->proximity.time = event_time;
            break;
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            event->dnd.time = event_time;
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no time field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    switch (event2->type)
    {
        case GDK_MOTION_NOTIFY:
    
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
    
        case GDK_SCROLL:
    
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
    
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
    
        case GDK_PROPERTY_NOTIFY:
    
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
    
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
    
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            if (gdk_event_get_time (event2) != event_time)
                TEST_FAIL ("Event time should be %u", event_time, NULL);
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            if (gdk_event_get_time (event2) != GDK_CURRENT_TIME)
                TEST_FAIL ("Event time should be GDK_CURRENT_TIME", NULL);
            break;
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_time
 * Params: GdkEvent *event
 * Returns: guint32
 * Assertion: Returns the time stamp from event, if there is one; otherwise returns GDK_CURRENT_TIME. If event is NULL, returns GDK_CURRENT_TIME.
 * Params Values: a GdkEvent
 * Expected: time stamp field from event  
 */
static void test_purpose_58()
{
    #define TYPE GDK_KEY_PRESS
    
    GdkEvent *event;
    GdkEvent *event2;
    time_t event_time;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_time (NULL) != GDK_CURRENT_TIME)
        TEST_FAIL ("If event is NULL, gdk_event_get_time should return GDK_CURRENT_TIME", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event_time = time (NULL);
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.time = event_time;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.time = event_time;
            break;
        case GDK_SCROLL:
            event->scroll.time = event_time;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.time = event_time;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.time = event_time;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.time = event_time;
            break;
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
            event->selection.time = event_time;
            break;
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
            event->proximity.time = event_time;
            break;
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            event->dnd.time = event_time;
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no time field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    switch (event2->type)
    {
        case GDK_MOTION_NOTIFY:
    
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
    
        case GDK_SCROLL:
    
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
    
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
    
        case GDK_PROPERTY_NOTIFY:
    
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
    
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
    
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            if (gdk_event_get_time (event2) != event_time)
                TEST_FAIL ("Event time should be %u", event_time, NULL);
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            if (gdk_event_get_time (event2) != GDK_CURRENT_TIME)
                TEST_FAIL ("Event time should be GDK_CURRENT_TIME", NULL);
            break;
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_time
 * Params: GdkEvent *event
 * Returns: guint32
 * Assertion: Returns the time stamp from event, if there is one; otherwise returns GDK_CURRENT_TIME. If event is NULL, returns GDK_CURRENT_TIME.
 * Params Values: a GdkEvent
 * Expected: time stamp field from event  
 */
static void test_purpose_59()
{
    #define TYPE GDK_KEY_RELEASE
    
    GdkEvent *event;
    GdkEvent *event2;
    time_t event_time;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_time (NULL) != GDK_CURRENT_TIME)
        TEST_FAIL ("If event is NULL, gdk_event_get_time should return GDK_CURRENT_TIME", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event_time = time (NULL);
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.time = event_time;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.time = event_time;
            break;
        case GDK_SCROLL:
            event->scroll.time = event_time;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.time = event_time;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.time = event_time;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.time = event_time;
            break;
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
            event->selection.time = event_time;
            break;
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
            event->proximity.time = event_time;
            break;
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            event->dnd.time = event_time;
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no time field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    switch (event2->type)
    {
        case GDK_MOTION_NOTIFY:
    
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
    
        case GDK_SCROLL:
    
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
    
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
    
        case GDK_PROPERTY_NOTIFY:
    
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
    
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
    
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            if (gdk_event_get_time (event2) != event_time)
                TEST_FAIL ("Event time should be %u", event_time, NULL);
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            if (gdk_event_get_time (event2) != GDK_CURRENT_TIME)
                TEST_FAIL ("Event time should be GDK_CURRENT_TIME", NULL);
            break;
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_time
 * Params: GdkEvent *event
 * Returns: guint32
 * Assertion: Returns the time stamp from event, if there is one; otherwise returns GDK_CURRENT_TIME. If event is NULL, returns GDK_CURRENT_TIME.
 * Params Values: a GdkEvent
 * Expected: time stamp field from event  
 */
static void test_purpose_60()
{
    #define TYPE GDK_ENTER_NOTIFY
    
    GdkEvent *event;
    GdkEvent *event2;
    time_t event_time;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_time (NULL) != GDK_CURRENT_TIME)
        TEST_FAIL ("If event is NULL, gdk_event_get_time should return GDK_CURRENT_TIME", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event_time = time (NULL);
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.time = event_time;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.time = event_time;
            break;
        case GDK_SCROLL:
            event->scroll.time = event_time;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.time = event_time;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.time = event_time;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.time = event_time;
            break;
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
            event->selection.time = event_time;
            break;
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
            event->proximity.time = event_time;
            break;
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            event->dnd.time = event_time;
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no time field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    switch (event2->type)
    {
        case GDK_MOTION_NOTIFY:
    
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
    
        case GDK_SCROLL:
    
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
    
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
    
        case GDK_PROPERTY_NOTIFY:
    
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
    
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
    
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            if (gdk_event_get_time (event2) != event_time)
                TEST_FAIL ("Event time should be %u", event_time, NULL);
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            if (gdk_event_get_time (event2) != GDK_CURRENT_TIME)
                TEST_FAIL ("Event time should be GDK_CURRENT_TIME", NULL);
            break;
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_time
 * Params: GdkEvent *event
 * Returns: guint32
 * Assertion: Returns the time stamp from event, if there is one; otherwise returns GDK_CURRENT_TIME. If event is NULL, returns GDK_CURRENT_TIME.
 * Params Values: a GdkEvent
 * Expected: time stamp field from event  
 */
static void test_purpose_61()
{
    #define TYPE GDK_FOCUS_CHANGE
    
    GdkEvent *event;
    GdkEvent *event2;
    time_t event_time;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_time (NULL) != GDK_CURRENT_TIME)
        TEST_FAIL ("If event is NULL, gdk_event_get_time should return GDK_CURRENT_TIME", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event_time = time (NULL);
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.time = event_time;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.time = event_time;
            break;
        case GDK_SCROLL:
            event->scroll.time = event_time;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.time = event_time;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.time = event_time;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.time = event_time;
            break;
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
            event->selection.time = event_time;
            break;
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
            event->proximity.time = event_time;
            break;
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            event->dnd.time = event_time;
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no time field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    switch (event2->type)
    {
        case GDK_MOTION_NOTIFY:
    
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
    
        case GDK_SCROLL:
    
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
    
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
    
        case GDK_PROPERTY_NOTIFY:
    
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
    
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
    
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            if (gdk_event_get_time (event2) != event_time)
                TEST_FAIL ("Event time should be %u", event_time, NULL);
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            if (gdk_event_get_time (event2) != GDK_CURRENT_TIME)
                TEST_FAIL ("Event time should be GDK_CURRENT_TIME", NULL);
            break;
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_time
 * Params: GdkEvent *event
 * Returns: guint32
 * Assertion: Returns the time stamp from event, if there is one; otherwise returns GDK_CURRENT_TIME. If event is NULL, returns GDK_CURRENT_TIME.
 * Params Values: a GdkEvent
 * Expected: time stamp field from event  
 */
static void test_purpose_62()
{
    #define TYPE GDK_DELETE
    
    GdkEvent *event;
    GdkEvent *event2;
    time_t event_time;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_time (NULL) != GDK_CURRENT_TIME)
        TEST_FAIL ("If event is NULL, gdk_event_get_time should return GDK_CURRENT_TIME", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    event_time = time (NULL);
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.time = event_time;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.time = event_time;
            break;
        case GDK_SCROLL:
            event->scroll.time = event_time;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.time = event_time;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.time = event_time;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.time = event_time;
            break;
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
            event->selection.time = event_time;
            break;
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
            event->proximity.time = event_time;
            break;
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            event->dnd.time = event_time;
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no time field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    switch (event2->type)
    {
        case GDK_MOTION_NOTIFY:
    
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
    
        case GDK_SCROLL:
    
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
    
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
    
        case GDK_PROPERTY_NOTIFY:
    
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
    
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
    
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
            if (gdk_event_get_time (event2) != event_time)
                TEST_FAIL ("Event time should be %u", event_time, NULL);
            break;
        case GDK_CLIENT_EVENT:
        case GDK_VISIBILITY_NOTIFY:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            if (gdk_event_get_time (event2) != GDK_CURRENT_TIME)
                TEST_FAIL ("Event time should be GDK_CURRENT_TIME", NULL);
            break;
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_state
 * Params: GdkEvent *event, GdkModifierType *state
 * Returns: gboolean
 * Assertion: If the event contains a "state" field, puts that field in state. Otherwise stores an empty state (0). Returns TRUE if there was a state field in the event. event may be NULL, in which case it's treated as if the event had no state field.
 * Params Values: a GdkEvent, return location for state
 * Expected: TRUE if there was a state field in the event  
 */
static void test_purpose_63()
{
    #define TYPE GDK_BUTTON_PRESS
    #define MODIFIER GDK_BUTTON1_MASK | GDK_SHIFT_MASK
    #define HAS_STATE TRUE
    
    GdkEvent *event;
    GdkEvent *event2;
    GdkModifierType state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_state (NULL, &state) != FALSE)
        TEST_FAIL ("If event is NULL, gdk_event_get_state should return FALSE", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.state = MODIFIER;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.state = MODIFIER;
            break;
        case GDK_SCROLL:
            event->scroll.state = MODIFIER;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.state = MODIFIER;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.state = MODIFIER;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.state = MODIFIER;
            break;
        case GDK_VISIBILITY_NOTIFY:
        case GDK_CLIENT_EVENT:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no state field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_state (event2, &state) != HAS_STATE)
        TEST_FAIL ("gdk_event_get_state should return %d for event %d", HAS_STATE, TYPE, NULL);
    
    if (HAS_STATE) {
        if (state != (MODIFIER))
            TEST_FAIL ("state should be %d, not %d", MODIFIER, state, NULL);
    } else {
        if (state != 0)
            TEST_FAIL ("state should be 0, not %d", state, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef MODIFIER
    #undef HAS_STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_state
 * Params: GdkEvent *event, GdkModifierType *state
 * Returns: gboolean
 * Assertion: If the event contains a "state" field, puts that field in state. Otherwise stores an empty state (0). Returns TRUE if there was a state field in the event. event may be NULL, in which case it's treated as if the event had no state field.
 * Params Values: a GdkEvent, return location for state
 * Expected: TRUE if there was a state field in the event  
 */
static void test_purpose_64()
{
    #define TYPE GDK_2BUTTON_PRESS
    #define MODIFIER GDK_BUTTON1_MASK | GDK_BUTTON2_MASK | GDK_CONTROL_MASK
    #define HAS_STATE TRUE
    
    GdkEvent *event;
    GdkEvent *event2;
    GdkModifierType state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_state (NULL, &state) != FALSE)
        TEST_FAIL ("If event is NULL, gdk_event_get_state should return FALSE", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.state = MODIFIER;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.state = MODIFIER;
            break;
        case GDK_SCROLL:
            event->scroll.state = MODIFIER;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.state = MODIFIER;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.state = MODIFIER;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.state = MODIFIER;
            break;
        case GDK_VISIBILITY_NOTIFY:
        case GDK_CLIENT_EVENT:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no state field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_state (event2, &state) != HAS_STATE)
        TEST_FAIL ("gdk_event_get_state should return %d for event %d", HAS_STATE, TYPE, NULL);
    
    if (HAS_STATE) {
        if (state != (MODIFIER))
            TEST_FAIL ("state should be %d, not %d", MODIFIER, state, NULL);
    } else {
        if (state != 0)
            TEST_FAIL ("state should be 0, not %d", state, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef MODIFIER
    #undef HAS_STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_state
 * Params: GdkEvent *event, GdkModifierType *state
 * Returns: gboolean
 * Assertion: If the event contains a "state" field, puts that field in state. Otherwise stores an empty state (0). Returns TRUE if there was a state field in the event. event may be NULL, in which case it's treated as if the event had no state field.
 * Params Values: a GdkEvent, return location for state
 * Expected: TRUE if there was a state field in the event  
 */
static void test_purpose_65()
{
    #define TYPE GDK_BUTTON_RELEASE
    #define MODIFIER GDK_BUTTON3_MASK
    #define HAS_STATE TRUE
    
    GdkEvent *event;
    GdkEvent *event2;
    GdkModifierType state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_state (NULL, &state) != FALSE)
        TEST_FAIL ("If event is NULL, gdk_event_get_state should return FALSE", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.state = MODIFIER;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.state = MODIFIER;
            break;
        case GDK_SCROLL:
            event->scroll.state = MODIFIER;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.state = MODIFIER;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.state = MODIFIER;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.state = MODIFIER;
            break;
        case GDK_VISIBILITY_NOTIFY:
        case GDK_CLIENT_EVENT:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no state field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_state (event2, &state) != HAS_STATE)
        TEST_FAIL ("gdk_event_get_state should return %d for event %d", HAS_STATE, TYPE, NULL);
    
    if (HAS_STATE) {
        if (state != (MODIFIER))
            TEST_FAIL ("state should be %d, not %d", MODIFIER, state, NULL);
    } else {
        if (state != 0)
            TEST_FAIL ("state should be 0, not %d", state, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef MODIFIER
    #undef HAS_STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_state
 * Params: GdkEvent *event, GdkModifierType *state
 * Returns: gboolean
 * Assertion: If the event contains a "state" field, puts that field in state. Otherwise stores an empty state (0). Returns TRUE if there was a state field in the event. event may be NULL, in which case it's treated as if the event had no state field.
 * Params Values: a GdkEvent, return location for state
 * Expected: TRUE if there was a state field in the event  
 */
static void test_purpose_66()
{
    #define TYPE GDK_KEY_PRESS
    #define MODIFIER GDK_SHIFT_MASK | GDK_CONTROL_MASK
    #define HAS_STATE TRUE
    
    GdkEvent *event;
    GdkEvent *event2;
    GdkModifierType state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_state (NULL, &state) != FALSE)
        TEST_FAIL ("If event is NULL, gdk_event_get_state should return FALSE", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.state = MODIFIER;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.state = MODIFIER;
            break;
        case GDK_SCROLL:
            event->scroll.state = MODIFIER;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.state = MODIFIER;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.state = MODIFIER;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.state = MODIFIER;
            break;
        case GDK_VISIBILITY_NOTIFY:
        case GDK_CLIENT_EVENT:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no state field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_state (event2, &state) != HAS_STATE)
        TEST_FAIL ("gdk_event_get_state should return %d for event %d", HAS_STATE, TYPE, NULL);
    
    if (HAS_STATE) {
        if (state != (MODIFIER))
            TEST_FAIL ("state should be %d, not %d", MODIFIER, state, NULL);
    } else {
        if (state != 0)
            TEST_FAIL ("state should be 0, not %d", state, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef MODIFIER
    #undef HAS_STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_state
 * Params: GdkEvent *event, GdkModifierType *state
 * Returns: gboolean
 * Assertion: If the event contains a "state" field, puts that field in state. Otherwise stores an empty state (0). Returns TRUE if there was a state field in the event. event may be NULL, in which case it's treated as if the event had no state field.
 * Params Values: a GdkEvent, return location for state
 * Expected: TRUE if there was a state field in the event  
 */
static void test_purpose_67()
{
    #define TYPE GDK_KEY_RELEASE
    #define MODIFIER GDK_MOD1_MASK | GDK_MOD2_MASK | GDK_LOCK_MASK
    #define HAS_STATE TRUE
    
    GdkEvent *event;
    GdkEvent *event2;
    GdkModifierType state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_state (NULL, &state) != FALSE)
        TEST_FAIL ("If event is NULL, gdk_event_get_state should return FALSE", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.state = MODIFIER;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.state = MODIFIER;
            break;
        case GDK_SCROLL:
            event->scroll.state = MODIFIER;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.state = MODIFIER;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.state = MODIFIER;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.state = MODIFIER;
            break;
        case GDK_VISIBILITY_NOTIFY:
        case GDK_CLIENT_EVENT:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no state field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_state (event2, &state) != HAS_STATE)
        TEST_FAIL ("gdk_event_get_state should return %d for event %d", HAS_STATE, TYPE, NULL);
    
    if (HAS_STATE) {
        if (state != (MODIFIER))
            TEST_FAIL ("state should be %d, not %d", MODIFIER, state, NULL);
    } else {
        if (state != 0)
            TEST_FAIL ("state should be 0, not %d", state, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef MODIFIER
    #undef HAS_STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_state
 * Params: GdkEvent *event, GdkModifierType *state
 * Returns: gboolean
 * Assertion: If the event contains a "state" field, puts that field in state. Otherwise stores an empty state (0). Returns TRUE if there was a state field in the event. event may be NULL, in which case it's treated as if the event had no state field.
 * Params Values: a GdkEvent, return location for state
 * Expected: TRUE if there was a state field in the event  
 */
static void test_purpose_68()
{
    #define TYPE GDK_ENTER_NOTIFY
    #define MODIFIER GDK_CONTROL_MASK | GDK_MOD1_MASK
    #define HAS_STATE TRUE
    
    GdkEvent *event;
    GdkEvent *event2;
    GdkModifierType state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_state (NULL, &state) != FALSE)
        TEST_FAIL ("If event is NULL, gdk_event_get_state should return FALSE", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.state = MODIFIER;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.state = MODIFIER;
            break;
        case GDK_SCROLL:
            event->scroll.state = MODIFIER;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.state = MODIFIER;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.state = MODIFIER;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.state = MODIFIER;
            break;
        case GDK_VISIBILITY_NOTIFY:
        case GDK_CLIENT_EVENT:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no state field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_state (event2, &state) != HAS_STATE)
        TEST_FAIL ("gdk_event_get_state should return %d for event %d", HAS_STATE, TYPE, NULL);
    
    if (HAS_STATE) {
        if (state != (MODIFIER))
            TEST_FAIL ("state should be %d, not %d", MODIFIER, state, NULL);
    } else {
        if (state != 0)
            TEST_FAIL ("state should be 0, not %d", state, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef MODIFIER
    #undef HAS_STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_state
 * Params: GdkEvent *event, GdkModifierType *state
 * Returns: gboolean
 * Assertion: If the event contains a "state" field, puts that field in state. Otherwise stores an empty state (0). Returns TRUE if there was a state field in the event. event may be NULL, in which case it's treated as if the event had no state field.
 * Params Values: a GdkEvent, return location for state
 * Expected: TRUE if there was a state field in the event  
 */
static void test_purpose_69()
{
    #define TYPE GDK_FOCUS_CHANGE
    #define MODIFIER 0
    #define HAS_STATE FALSE
    
    GdkEvent *event;
    GdkEvent *event2;
    GdkModifierType state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_state (NULL, &state) != FALSE)
        TEST_FAIL ("If event is NULL, gdk_event_get_state should return FALSE", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.state = MODIFIER;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.state = MODIFIER;
            break;
        case GDK_SCROLL:
            event->scroll.state = MODIFIER;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.state = MODIFIER;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.state = MODIFIER;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.state = MODIFIER;
            break;
        case GDK_VISIBILITY_NOTIFY:
        case GDK_CLIENT_EVENT:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no state field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_state (event2, &state) != HAS_STATE)
        TEST_FAIL ("gdk_event_get_state should return %d for event %d", HAS_STATE, TYPE, NULL);
    
    if (HAS_STATE) {
        if (state != (MODIFIER))
            TEST_FAIL ("state should be %d, not %d", MODIFIER, state, NULL);
    } else {
        if (state != 0)
            TEST_FAIL ("state should be 0, not %d", state, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef MODIFIER
    #undef HAS_STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_state
 * Params: GdkEvent *event, GdkModifierType *state
 * Returns: gboolean
 * Assertion: If the event contains a "state" field, puts that field in state. Otherwise stores an empty state (0). Returns TRUE if there was a state field in the event. event may be NULL, in which case it's treated as if the event had no state field.
 * Params Values: a GdkEvent, return location for state
 * Expected: TRUE if there was a state field in the event  
 */
static void test_purpose_70()
{
    #define TYPE GDK_DELETE
    #define MODIFIER 0
    #define HAS_STATE FALSE
    
    GdkEvent *event;
    GdkEvent *event2;
    GdkModifierType state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (gdk_event_get_state (NULL, &state) != FALSE)
        TEST_FAIL ("If event is NULL, gdk_event_get_state should return FALSE", NULL);
    
    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            event->motion.state = MODIFIER;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_2BUTTON_PRESS:
        case GDK_3BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            event->button.state = MODIFIER;
            break;
        case GDK_SCROLL:
            event->scroll.state = MODIFIER;
            break;
        case GDK_KEY_PRESS:
        case GDK_KEY_RELEASE:
            event->key.state = MODIFIER;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            event->crossing.state = MODIFIER;
            break;
        case GDK_PROPERTY_NOTIFY:
            event->property.state = MODIFIER;
            break;
        case GDK_VISIBILITY_NOTIFY:
        case GDK_CLIENT_EVENT:
        case GDK_NO_EXPOSE:
        case GDK_CONFIGURE:
        case GDK_FOCUS_CHANGE:
        case GDK_SELECTION_CLEAR:
        case GDK_SELECTION_REQUEST:
        case GDK_SELECTION_NOTIFY:
        case GDK_PROXIMITY_IN:
        case GDK_PROXIMITY_OUT:
        case GDK_DRAG_ENTER:
        case GDK_DRAG_LEAVE:
        case GDK_DRAG_MOTION:
        case GDK_DRAG_STATUS:
        case GDK_DROP_START:
        case GDK_DROP_FINISHED:
        case GDK_NOTHING:
        case GDK_DELETE:
        case GDK_DESTROY:
        case GDK_EXPOSE:
        case GDK_MAP:
        case GDK_UNMAP:
        case GDK_WINDOW_STATE:
        case GDK_SETTING:
        case GDK_OWNER_CHANGE:
            /* no state field */
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_state (event2, &state) != HAS_STATE)
        TEST_FAIL ("gdk_event_get_state should return %d for event %d", HAS_STATE, TYPE, NULL);
    
    if (HAS_STATE) {
        if (state != (MODIFIER))
            TEST_FAIL ("state should be %d, not %d", MODIFIER, state, NULL);
    } else {
        if (state != 0)
            TEST_FAIL ("state should be 0, not %d", state, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef MODIFIER
    #undef HAS_STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_axis
 * Params: GdkEvent *event, GdkAxisUse axis_use, gdouble *value
 * Returns: gboolean
 * Assertion: Extract the axis value for a particular axis use from an event structure.
 * Params Values: a GdkEvent, the axis use to look for, location to store the value found
 * Expected: TRUE if the specified axis was found, otherwise FALSE  
 */
static void test_purpose_71()
{
    #define TYPE GDK_BUTTON_PRESS
    #define AXIS GDK_AXIS_X
    #define VALUE 123
    #define HAS_AXIS TRUE
    
    GdkEvent *event;
    GdkEvent *event2;
    gdouble value;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->motion.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->motion.y = VALUE;
            break;
        case GDK_SCROLL:
            if (AXIS == GDK_AXIS_X)
                event->scroll.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->scroll.y = VALUE;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            if (AXIS == GDK_AXIS_X)
                event->button.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->button.y = VALUE;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->crossing.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->crossing.y = VALUE;
            break;
    
        default:
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_axis (event2, AXIS, &value) != HAS_AXIS)
        TEST_FAIL ("gdk_event_get_axis should return %d for event %d", HAS_AXIS, TYPE, NULL);
    
    if (HAS_AXIS) {
        if (value != VALUE)
            TEST_FAIL ("axis value should be %d, not %d", VALUE, value, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef AXIS
    #undef VALUE
    #undef HAS_AXIS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_axis
 * Params: GdkEvent *event, GdkAxisUse axis_use, gdouble *value
 * Returns: gboolean
 * Assertion: Extract the axis value for a particular axis use from an event structure.
 * Params Values: a GdkEvent, the axis use to look for, location to store the value found
 * Expected: TRUE if the specified axis was found, otherwise FALSE  
 */
static void test_purpose_72()
{
    #define TYPE GDK_BUTTON_PRESS
    #define AXIS GDK_AXIS_Y
    #define VALUE 456
    #define HAS_AXIS TRUE
    
    GdkEvent *event;
    GdkEvent *event2;
    gdouble value;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->motion.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->motion.y = VALUE;
            break;
        case GDK_SCROLL:
            if (AXIS == GDK_AXIS_X)
                event->scroll.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->scroll.y = VALUE;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            if (AXIS == GDK_AXIS_X)
                event->button.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->button.y = VALUE;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->crossing.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->crossing.y = VALUE;
            break;
    
        default:
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_axis (event2, AXIS, &value) != HAS_AXIS)
        TEST_FAIL ("gdk_event_get_axis should return %d for event %d", HAS_AXIS, TYPE, NULL);
    
    if (HAS_AXIS) {
        if (value != VALUE)
            TEST_FAIL ("axis value should be %d, not %d", VALUE, value, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef AXIS
    #undef VALUE
    #undef HAS_AXIS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_axis
 * Params: GdkEvent *event, GdkAxisUse axis_use, gdouble *value
 * Returns: gboolean
 * Assertion: Extract the axis value for a particular axis use from an event structure.
 * Params Values: a GdkEvent, the axis use to look for, location to store the value found
 * Expected: TRUE if the specified axis was found, otherwise FALSE  
 */
static void test_purpose_73()
{
    #define TYPE GDK_BUTTON_RELEASE
    #define AXIS GDK_AXIS_X
    #define VALUE 1000
    #define HAS_AXIS TRUE
    
    GdkEvent *event;
    GdkEvent *event2;
    gdouble value;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->motion.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->motion.y = VALUE;
            break;
        case GDK_SCROLL:
            if (AXIS == GDK_AXIS_X)
                event->scroll.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->scroll.y = VALUE;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            if (AXIS == GDK_AXIS_X)
                event->button.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->button.y = VALUE;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->crossing.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->crossing.y = VALUE;
            break;
    
        default:
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_axis (event2, AXIS, &value) != HAS_AXIS)
        TEST_FAIL ("gdk_event_get_axis should return %d for event %d", HAS_AXIS, TYPE, NULL);
    
    if (HAS_AXIS) {
        if (value != VALUE)
            TEST_FAIL ("axis value should be %d, not %d", VALUE, value, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef AXIS
    #undef VALUE
    #undef HAS_AXIS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_axis
 * Params: GdkEvent *event, GdkAxisUse axis_use, gdouble *value
 * Returns: gboolean
 * Assertion: Extract the axis value for a particular axis use from an event structure.
 * Params Values: a GdkEvent, the axis use to look for, location to store the value found
 * Expected: TRUE if the specified axis was found, otherwise FALSE  
 */
static void test_purpose_74()
{
    #define TYPE GDK_BUTTON_RELEASE
    #define AXIS GDK_AXIS_Y
    #define VALUE 10000
    #define HAS_AXIS TRUE
    
    GdkEvent *event;
    GdkEvent *event2;
    gdouble value;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->motion.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->motion.y = VALUE;
            break;
        case GDK_SCROLL:
            if (AXIS == GDK_AXIS_X)
                event->scroll.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->scroll.y = VALUE;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            if (AXIS == GDK_AXIS_X)
                event->button.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->button.y = VALUE;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->crossing.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->crossing.y = VALUE;
            break;
    
        default:
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_axis (event2, AXIS, &value) != HAS_AXIS)
        TEST_FAIL ("gdk_event_get_axis should return %d for event %d", HAS_AXIS, TYPE, NULL);
    
    if (HAS_AXIS) {
        if (value != VALUE)
            TEST_FAIL ("axis value should be %d, not %d", VALUE, value, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef AXIS
    #undef VALUE
    #undef HAS_AXIS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_axis
 * Params: GdkEvent *event, GdkAxisUse axis_use, gdouble *value
 * Returns: gboolean
 * Assertion: Extract the axis value for a particular axis use from an event structure.
 * Params Values: a GdkEvent, the axis use to look for, location to store the value found
 * Expected: TRUE if the specified axis was found, otherwise FALSE  
 */
static void test_purpose_75()
{
    #define TYPE GDK_ENTER_NOTIFY
    #define AXIS GDK_AXIS_X
    #define VALUE 10000
    #define HAS_AXIS TRUE
    
    GdkEvent *event;
    GdkEvent *event2;
    gdouble value;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->motion.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->motion.y = VALUE;
            break;
        case GDK_SCROLL:
            if (AXIS == GDK_AXIS_X)
                event->scroll.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->scroll.y = VALUE;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            if (AXIS == GDK_AXIS_X)
                event->button.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->button.y = VALUE;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->crossing.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->crossing.y = VALUE;
            break;
    
        default:
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_axis (event2, AXIS, &value) != HAS_AXIS)
        TEST_FAIL ("gdk_event_get_axis should return %d for event %d", HAS_AXIS, TYPE, NULL);
    
    if (HAS_AXIS) {
        if (value != VALUE)
            TEST_FAIL ("axis value should be %d, not %d", VALUE, value, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef AXIS
    #undef VALUE
    #undef HAS_AXIS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_axis
 * Params: GdkEvent *event, GdkAxisUse axis_use, gdouble *value
 * Returns: gboolean
 * Assertion: Extract the axis value for a particular axis use from an event structure.
 * Params Values: a GdkEvent, the axis use to look for, location to store the value found
 * Expected: TRUE if the specified axis was found, otherwise FALSE  
 */
static void test_purpose_76()
{
    #define TYPE GDK_LEAVE_NOTIFY
    #define AXIS GDK_AXIS_Y
    #define VALUE 10000
    #define HAS_AXIS TRUE
    
    GdkEvent *event;
    GdkEvent *event2;
    gdouble value;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->motion.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->motion.y = VALUE;
            break;
        case GDK_SCROLL:
            if (AXIS == GDK_AXIS_X)
                event->scroll.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->scroll.y = VALUE;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            if (AXIS == GDK_AXIS_X)
                event->button.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->button.y = VALUE;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->crossing.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->crossing.y = VALUE;
            break;
    
        default:
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_axis (event2, AXIS, &value) != HAS_AXIS)
        TEST_FAIL ("gdk_event_get_axis should return %d for event %d", HAS_AXIS, TYPE, NULL);
    
    if (HAS_AXIS) {
        if (value != VALUE)
            TEST_FAIL ("axis value should be %d, not %d", VALUE, value, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef AXIS
    #undef VALUE
    #undef HAS_AXIS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_axis
 * Params: GdkEvent *event, GdkAxisUse axis_use, gdouble *value
 * Returns: gboolean
 * Assertion: Extract the axis value for a particular axis use from an event structure.
 * Params Values: a GdkEvent, the axis use to look for, location to store the value found
 * Expected: TRUE if the specified axis was found, otherwise FALSE  
 */
static void test_purpose_77()
{
    #define TYPE GDK_KEY_PRESS
    #define AXIS GDK_AXIS_X
    #define VALUE 10000
    #define HAS_AXIS FALSE
    
    GdkEvent *event;
    GdkEvent *event2;
    gdouble value;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->motion.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->motion.y = VALUE;
            break;
        case GDK_SCROLL:
            if (AXIS == GDK_AXIS_X)
                event->scroll.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->scroll.y = VALUE;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            if (AXIS == GDK_AXIS_X)
                event->button.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->button.y = VALUE;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->crossing.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->crossing.y = VALUE;
            break;
    
        default:
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_axis (event2, AXIS, &value) != HAS_AXIS)
        TEST_FAIL ("gdk_event_get_axis should return %d for event %d", HAS_AXIS, TYPE, NULL);
    
    if (HAS_AXIS) {
        if (value != VALUE)
            TEST_FAIL ("axis value should be %d, not %d", VALUE, value, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef AXIS
    #undef VALUE
    #undef HAS_AXIS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_event_get_axis
 * Params: GdkEvent *event, GdkAxisUse axis_use, gdouble *value
 * Returns: gboolean
 * Assertion: Extract the axis value for a particular axis use from an event structure.
 * Params Values: a GdkEvent, the axis use to look for, location to store the value found
 * Expected: TRUE if the specified axis was found, otherwise FALSE  
 */
static void test_purpose_78()
{
    #define TYPE GDK_KEY_RELEASE
    #define AXIS GDK_AXIS_Y
    #define VALUE 10000
    #define HAS_AXIS FALSE
    
    GdkEvent *event;
    GdkEvent *event2;
    gdouble value;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    event = gdk_event_new (TYPE);
    
    if (!event)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (event->type != TYPE)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    switch (event->type)
    {
        case GDK_MOTION_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->motion.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->motion.y = VALUE;
            break;
        case GDK_SCROLL:
            if (AXIS == GDK_AXIS_X)
                event->scroll.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->scroll.y = VALUE;
            break;
        case GDK_BUTTON_PRESS:
        case GDK_BUTTON_RELEASE:
            if (AXIS == GDK_AXIS_X)
                event->button.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->button.y = VALUE;
            break;
        case GDK_ENTER_NOTIFY:
        case GDK_LEAVE_NOTIFY:
            if (AXIS == GDK_AXIS_X)
                event->crossing.x = VALUE;
            else if (AXIS == GDK_AXIS_Y)
                event->crossing.y = VALUE;
            break;
    
        default:
            break;
    }
    
    gdk_event_put (event);
    
    event2 = gdk_event_get ();
    
    if (!event2)
        TEST_FAIL ("Did not get the event recently put on the event queue", NULL);
    
    if (gdk_event_get_axis (event2, AXIS, &value) != HAS_AXIS)
        TEST_FAIL ("gdk_event_get_axis should return %d for event %d", HAS_AXIS, TYPE, NULL);
    
    if (HAS_AXIS) {
        if (value != VALUE)
            TEST_FAIL ("axis value should be %d, not %d", VALUE, value, NULL);
    }
    
    gdk_event_free (event2);
    
    gdk_event_free (event);
    
    #undef TYPE
    #undef AXIS
    #undef VALUE
    #undef HAS_AXIS
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkEvents ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {NULL,0}
};
