/*
 * GdkGraphContext methods tests
 * Testing GdkGraphContext methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
static GdkWindow *create_new_gdk_window()
{
    GdkWindowAttr parent_attributes = {"Lsb_Test", 0, 1, 2, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    return gdk_window_new(NULL, &parent_attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
}

/*
 * Name: gdk_gc_new
 * Params: GdkDrawable *drawable
 * Returns: GdkGC*
 * Assertion: Create a new graphics context with default values.
 *            drawable : a GdkDrawable. The created GC must always be used with drawables of the same depth as this one.  
 *            Returns : the new graphics context.  
 * Params Values: GdkDrawable *drawable
 * Expected: GdkGC*  
 */
static void test_purpose_1()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    if (!GDK_IS_GC(gdk_gc)){
        TEST_FAIL("gdk_gc_new: it's not a GDK_TYPE_GC", NULL);
    }
    g_object_unref(gdk_gc);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_gc_new_with_values
 * Params: GdkDrawable *drawable, GdkGCValues *values, GdkGCValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Create a new GC with the given initial values.
 *            drawable : a GdkDrawable. The created GC must always be used with drawables of the same depth as this one.  
 *            values : a structure containing initial values for the GC.  
 *            values_mask : a bit mask indicating which fields in values are set.  
 *            Returns : the new graphics context.
 * Params Values: GdkDrawable *drawable, GdkGCValues *values, GdkGCValuesMask values_mask
 * Expected: GdkDrawable *drawable, GdkGCValues *values, GdkGCValuesMask values_mask  
 */
static void test_purpose_2()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkGCValues gc_value;
    gc_value.fill = GDK_SOLID;
    GdkGC* gdk_gc = gdk_gc_new_with_values(gdk_window, &gc_value, GDK_GC_FILL);
    if (!GDK_IS_GC(gdk_gc)){
        TEST_FAIL("gdk_gc_new_with_values: it's not a GDK_TYPE_GC", NULL);
    }
    g_object_unref(gdk_gc);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_gc_copy
 * Params: GdkGC *dst_gc, GdkGC *src_gc
 * Returns: void
 * Assertion: Copy the set of values from one graphics context onto another graphics context.
 *            dst_gc : the destination graphics context.  
 *            src_gc : the source graphics context.
 * Params Values: GdkGC *dst_gc, GdkGC *src_gc
 * Expected: void  
 */
static void test_purpose_3()
{
    GdkGCValues gc_value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkGC *gc_src = NULL, *gc_dst = NULL;
    GdkWindow *gdk_window = create_new_gdk_window();
    gc_value.fill = GDK_SOLID;
    gc_src = gdk_gc_new_with_values(gdk_window, &gc_value, GDK_GC_FILL);
    if (!GDK_IS_GC(gc_src)){
        TEST_FAIL("gdk_gc_copy: it's not a GDK_TYPE_GC", NULL);
    }
    else{
        gc_dst = gdk_gc_new(gdk_window);
        gdk_gc_copy(gc_dst, gc_src);
        if (!GDK_IS_GC(gc_dst)){
            TEST_FAIL("gdk_gc_copy: gc_dst is not a GDK_TYPE_GC", NULL);
        }
        else{
            GdkGCValues gc_dst_value;
            gdk_gc_get_values(gc_dst, &gc_dst_value);
            if (gc_dst_value.fill != GDK_SOLID){
                TEST_FAIL("gdk_gc_copy: copy failed", NULL);
            }
        }
    }
    g_object_unref(gc_src);
    g_object_unref(gc_dst);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_gc_set_function
 * Params: GdkGC *gc, GdkFunction function
 * Returns: void
 * Assertion: Determines how the current pixel values and the pixel values being drawn are combined to produce the final pixel values.
 *            gc : a GdkGC.  
 *            function : the GdkFunction to use
 * Params Values: GdkGC *gc, GdkFunction function
 * Expected: void  
 */
static void test_purpose_4()
{
    GdkGCValues gc_value;
    GdkColor gdk_color = {0, 128, 128, 128};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkGC *gc = NULL;
    GdkWindow *gdk_window = create_new_gdk_window();
    gc = gdk_gc_new(gdk_window);
    gdk_gc_set_function(gc, GDK_XOR);
    gdk_gc_set_foreground(gc, &gdk_color);
    gdk_gc_set_clip_origin(gc, 10, 10);
    gdk_gc_set_fill(gc, GDK_SOLID);
    gdk_gc_set_ts_origin(gc, 100, 100);
    gdk_gc_set_exposures(gc, TRUE);
    gdk_gc_get_values(gc, &gc_value);
    if (gc_value.function != GDK_XOR)
        TEST_FAIL("gdk_gc_set_function: should be GDK_XOR", NULL);
    /*
    if ((gc_value.clip_x_origin != 10) || (gc_value.clip_y_origin != 10))
        TEST_FAIL("gdk_gc_set_clip_origin: should be 10, 10", NULL);
    */
    if (gc_value.fill != GDK_SOLID)
        TEST_FAIL("gdk_gc_set_fill: should be GDK_SOLID", NULL);
    /*
    if ((gc_value.ts_x_origin != 100) || (gc_value.ts_y_origin != 100))
        TEST_FAIL("gdk_gc_set_ts_origin: should be 100, 100", NULL);
    */
    if (gc_value.graphics_exposures != TRUE)
        TEST_FAIL("gdk_gc_set_exposures: should be TRUE", NULL);
    
    g_object_unref(gc);
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkGraphContext ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {NULL,0}
};
