/*
 * GdkKeyValues methods tests
 * Testing GdkKeyValues methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gdk_keyval_name
 * Params: gint
 * Return: gchar *
 * Assertion: Converts a key value into a symbolic name. The names are the same as those in the <gdk/gdkkeysyms.h> header file but without the leading "GDK_". 
 * Expect: a string containing the name of the key, or NULL if keyval is not a valid key. The string should not be modified.  
 */
static void test_purpose_1()
{
    #define KEY		      0xFFFFFF
    #define NAME		      "VoidSymbol"
    gchar * name = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_keyval_name(KEY);
    if(NAME == NULL){
    	if(name != NULL){
    		TEST_FAIL("gdk_keyval: an NULL is expected, but it is not NULL!",NULL);
    		return;
    	}
    }else{
    	if(strcmp(name,NAME) != 0){
    		TEST_FAIL("gdk_keyval: return string doesnt match expected string!",NULL);
    		return;
    	}
    };
    #undef KEY
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_name
 * Params: gint
 * Return: gchar *
 * Assertion: Converts a key value into a symbolic name. The names are the same as those in the <gdk/gdkkeysyms.h> header file but without the leading "GDK_". 
 * Expect: a string containing the name of the key, or NULL if keyval is not a valid key. The string should not be modified.  
 */
static void test_purpose_2()
{
    #define KEY		      0xff08
    #define NAME		      "BackSpace"
    gchar * name = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_keyval_name(KEY);
    if(NAME == NULL){
    	if(name != NULL){
    		TEST_FAIL("gdk_keyval: an NULL is expected, but it is not NULL!",NULL);
    		return;
    	}
    }else{
    	if(strcmp(name,NAME) != 0){
    		TEST_FAIL("gdk_keyval: return string doesnt match expected string!",NULL);
    		return;
    	}
    };
    #undef KEY
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_name
 * Params: gint
 * Return: gchar *
 * Assertion: Converts a key value into a symbolic name. The names are the same as those in the <gdk/gdkkeysyms.h> header file but without the leading "GDK_". 
 * Expect: a string containing the name of the key, or NULL if keyval is not a valid key. The string should not be modified.  
 */
static void test_purpose_3()
{
    #define KEY		      0xFD1E
    #define NAME		      "3270_Enter"
    gchar * name = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_keyval_name(KEY);
    if(NAME == NULL){
    	if(name != NULL){
    		TEST_FAIL("gdk_keyval: an NULL is expected, but it is not NULL!",NULL);
    		return;
    	}
    }else{
    	if(strcmp(name,NAME) != 0){
    		TEST_FAIL("gdk_keyval: return string doesnt match expected string!",NULL);
    		return;
    	}
    };
    #undef KEY
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_name
 * Params: gint
 * Return: gchar *
 * Assertion: Converts a key value into a symbolic name. The names are the same as those in the <gdk/gdkkeysyms.h> header file but without the leading "GDK_". 
 * Expect: a string containing the name of the key, or NULL if keyval is not a valid key. The string should not be modified.  
 */
static void test_purpose_4()
{
    #define KEY		      0x020
    #define NAME		      "space"
    gchar * name = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_keyval_name(KEY);
    if(NAME == NULL){
    	if(name != NULL){
    		TEST_FAIL("gdk_keyval: an NULL is expected, but it is not NULL!",NULL);
    		return;
    	}
    }else{
    	if(strcmp(name,NAME) != 0){
    		TEST_FAIL("gdk_keyval: return string doesnt match expected string!",NULL);
    		return;
    	}
    };
    #undef KEY
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_name
 * Params: gint
 * Return: gchar *
 * Assertion: Converts a key value into a symbolic name. The names are the same as those in the <gdk/gdkkeysyms.h> header file but without the leading "GDK_". 
 * Expect: a string containing the name of the key, or NULL if keyval is not a valid key. The string should not be modified.  
 */
static void test_purpose_5()
{
    #define KEY		      0x030
    #define NAME		      "0"
    gchar * name = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_keyval_name(KEY);
    if(NAME == NULL){
    	if(name != NULL){
    		TEST_FAIL("gdk_keyval: an NULL is expected, but it is not NULL!",NULL);
    		return;
    	}
    }else{
    	if(strcmp(name,NAME) != 0){
    		TEST_FAIL("gdk_keyval: return string doesnt match expected string!",NULL);
    		return;
    	}
    };
    #undef KEY
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_name
 * Params: gint
 * Return: gchar *
 * Assertion: Converts a key value into a symbolic name. The names are the same as those in the <gdk/gdkkeysyms.h> header file but without the leading "GDK_". 
 * Expect: a string containing the name of the key, or NULL if keyval is not a valid key. The string should not be modified.  
 */
static void test_purpose_6()
{
    #define KEY		      0xedb
    #define NAME		      "Hangul_J_Rieul"
    gchar * name = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_keyval_name(KEY);
    if(NAME == NULL){
    	if(name != NULL){
    		TEST_FAIL("gdk_keyval: an NULL is expected, but it is not NULL!",NULL);
    		return;
    	}
    }else{
    	if(strcmp(name,NAME) != 0){
    		TEST_FAIL("gdk_keyval: return string doesnt match expected string!",NULL);
    		return;
    	}
    };
    #undef KEY
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_name
 * Params: gint
 * Return: gchar *
 * Assertion: Converts a key value into a symbolic name. The names are the same as those in the <gdk/gdkkeysyms.h> header file but without the leading "GDK_". 
 * Expect: a string containing the name of the key, or NULL if keyval is not a valid key. The string should not be modified.  
 */
static void test_purpose_7()
{
    #define KEY		      0x1000
    #define NAME		      NULL
    gchar * name = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_keyval_name(KEY);
    if(NAME == NULL){
    	if(name != NULL){
    		TEST_FAIL("gdk_keyval: an NULL is expected, but it is not NULL!",NULL);
    		return;
    	}
    }else{
    	if(strcmp(name,NAME) != 0){
    		TEST_FAIL("gdk_keyval: return string doesnt match expected string!",NULL);
    		return;
    	}
    };
    #undef KEY
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_from_name
 * Parmas: const gchar *
 * Return: guint
 * Assertion: Converts a key name to a key value.
 * Expected: the corresponding key value, or GDK_VoidSymbol if the key name is not a valid key.  
 */
static void test_purpose_8()
{
    #define NAME 			      "VoidSymbol"
    #define EXPECTED		      0xFFFFFF
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_from_name(NAME);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_from_name: doesnt match expected!",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_from_name
 * Parmas: const gchar *
 * Return: guint
 * Assertion: Converts a key name to a key value.
 * Expected: the corresponding key value, or GDK_VoidSymbol if the key name is not a valid key.  
 */
static void test_purpose_9()
{
    #define NAME 			      "BackSpace"
    #define EXPECTED		      0xff08
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_from_name(NAME);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_from_name: doesnt match expected!",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_from_name
 * Parmas: const gchar *
 * Return: guint
 * Assertion: Converts a key name to a key value.
 * Expected: the corresponding key value, or GDK_VoidSymbol if the key name is not a valid key.  
 */
static void test_purpose_10()
{
    #define NAME 			      "3270_Enter"
    #define EXPECTED		      0xFD1E
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_from_name(NAME);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_from_name: doesnt match expected!",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_from_name
 * Parmas: const gchar *
 * Return: guint
 * Assertion: Converts a key name to a key value.
 * Expected: the corresponding key value, or GDK_VoidSymbol if the key name is not a valid key.  
 */
static void test_purpose_11()
{
    #define NAME 			      "space"
    #define EXPECTED		      0x020
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_from_name(NAME);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_from_name: doesnt match expected!",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_from_name
 * Parmas: const gchar *
 * Return: guint
 * Assertion: Converts a key name to a key value.
 * Expected: the corresponding key value, or GDK_VoidSymbol if the key name is not a valid key.  
 */
static void test_purpose_12()
{
    #define NAME 			      "0"
    #define EXPECTED		      0x030
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_from_name(NAME);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_from_name: doesnt match expected!",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_from_name
 * Parmas: const gchar *
 * Return: guint
 * Assertion: Converts a key name to a key value.
 * Expected: the corresponding key value, or GDK_VoidSymbol if the key name is not a valid key.  
 */
static void test_purpose_13()
{
    #define NAME 			      "Hangul_J_Rieul"
    #define EXPECTED		      0xedb
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_from_name(NAME);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_from_name: doesnt match expected!",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_from_name
 * Parmas: const gchar *
 * Return: guint
 * Assertion: Converts a key name to a key value.
 * Expected: the corresponding key value, or GDK_VoidSymbol if the key name is not a valid key.  
 */
static void test_purpose_14()
{
    #define NAME 			      "no_such_name"
    #define EXPECTED		      0
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_from_name(NAME);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_from_name: doesnt match expected!",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_lower
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to lower case, if applicable.
 * Expected: the lower case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_15()
{
    #define KEY			     'A'
    #define EXPECTED		     'a'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_lower(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_lower
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to lower case, if applicable.
 * Expected: the lower case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_16()
{
    #define KEY			     'H'
    #define EXPECTED		     'h'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_lower(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_lower
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to lower case, if applicable.
 * Expected: the lower case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_17()
{
    #define KEY			     'Z'
    #define EXPECTED		     'z'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_lower(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_lower
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to lower case, if applicable.
 * Expected: the lower case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_18()
{
    #define KEY			     'Y'
    #define EXPECTED		     'y'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_lower(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_lower
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to lower case, if applicable.
 * Expected: the lower case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_19()
{
    #define KEY			     'O'
    #define EXPECTED		     'o'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_lower(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_lower
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to lower case, if applicable.
 * Expected: the lower case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_20()
{
    #define KEY			     'N'
    #define EXPECTED		     'n'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_lower(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_lower
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to lower case, if applicable.
 * Expected: the lower case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_21()
{
    #define KEY			     'G'
    #define EXPECTED		     'g'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_lower(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_lower
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to lower case, if applicable.
 * Expected: the lower case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_22()
{
    #define KEY			     'L'
    #define EXPECTED		     'l'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_lower(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_lower
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to lower case, if applicable.
 * Expected: the lower case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_23()
{
    #define KEY			     'I'
    #define EXPECTED		     'i'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_lower(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_lower
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to lower case, if applicable.
 * Expected: the lower case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_24()
{
    #define KEY			     'M'
    #define EXPECTED		     'm'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_lower(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_upper
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to upper case, if applicable.
 * Expected: the upper case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_25()
{
    #define KEY			     'a'
    #define EXPECTED		     'A'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_upper(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_upper
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to upper case, if applicable.
 * Expected: the upper case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_26()
{
    #define KEY			     'h'
    #define EXPECTED		     'H'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_upper(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_upper
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to upper case, if applicable.
 * Expected: the upper case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_27()
{
    #define KEY			     'z'
    #define EXPECTED		     'Z'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_upper(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_upper
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to upper case, if applicable.
 * Expected: the upper case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_28()
{
    #define KEY			     'y'
    #define EXPECTED		     'Y'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_upper(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_upper
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to upper case, if applicable.
 * Expected: the upper case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_29()
{
    #define KEY			     'o'
    #define EXPECTED		     'O'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_upper(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_upper
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to upper case, if applicable.
 * Expected: the upper case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_30()
{
    #define KEY			     'n'
    #define EXPECTED		     'N'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_upper(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_upper
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to upper case, if applicable.
 * Expected: the upper case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_31()
{
    #define KEY			     'g'
    #define EXPECTED		     'G'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_upper(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_upper
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to upper case, if applicable.
 * Expected: the upper case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_32()
{
    #define KEY			     'l'
    #define EXPECTED		     'L'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_upper(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_upper
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to upper case, if applicable.
 * Expected: the upper case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_33()
{
    #define KEY			     'i'
    #define EXPECTED		     'I'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_upper(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_upper
 * Params: guint
 * Return: guint
 * Assertion: Converts a key value to upper case, if applicable.
 * Expected: the upper case form of keyval, or keyval itself if it is already in lower case or it is not subject to case conversion.  
 */
static void test_purpose_34()
{
    #define KEY			     'm'
    #define EXPECTED		     'M'
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_upper(KEY);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_lower: not the expected value!",NULL);
    	return;
    }
    #undef KEY
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_unicode
 * Params: guint
 * Return: guint32
 * Assertion: Convert from a GDK key symbol to the corresponding ISO10646 (Unicode) character.
 * Expected: the corresponding unicode character, or 0 if there is no corresponding character.  
 */
static void test_purpose_35()
{
    #define KEYVAL			     0x01a1
    #define EXPECTED		     0x0104
    guint32 ret = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_unicode(KEYVAL);
    if(!g_unichar_validate(ret)){
    	TEST_FAIL("gdk_keyval_to_unicode: is not a unicode!",NULL);
    	return;
    }
    
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_unicode: doesnt match expected!",NULL);
    	return;
    }
    
    #undef KEYVAL
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_unicode
 * Params: guint
 * Return: guint32
 * Assertion: Convert from a GDK key symbol to the corresponding ISO10646 (Unicode) character.
 * Expected: the corresponding unicode character, or 0 if there is no corresponding character.  
 */
static void test_purpose_36()
{
    #define KEYVAL			     0xFFBD
    #define EXPECTED		     '='
    guint32 ret = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_unicode(KEYVAL);
    if(!g_unichar_validate(ret)){
    	TEST_FAIL("gdk_keyval_to_unicode: is not a unicode!",NULL);
    	return;
    }
    
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_unicode: doesnt match expected!",NULL);
    	return;
    }
    
    #undef KEYVAL
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_unicode
 * Params: guint
 * Return: guint32
 * Assertion: Convert from a GDK key symbol to the corresponding ISO10646 (Unicode) character.
 * Expected: the corresponding unicode character, or 0 if there is no corresponding character.  
 */
static void test_purpose_37()
{
    #define KEYVAL			     0xFFB0
    #define EXPECTED		     '0'
    guint32 ret = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_unicode(KEYVAL);
    if(!g_unichar_validate(ret)){
    	TEST_FAIL("gdk_keyval_to_unicode: is not a unicode!",NULL);
    	return;
    }
    
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_unicode: doesnt match expected!",NULL);
    	return;
    }
    
    #undef KEYVAL
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_unicode
 * Params: guint
 * Return: guint32
 * Assertion: Convert from a GDK key symbol to the corresponding ISO10646 (Unicode) character.
 * Expected: the corresponding unicode character, or 0 if there is no corresponding character.  
 */
static void test_purpose_38()
{
    #define KEYVAL			     'a'
    #define EXPECTED		     'a'
    guint32 ret = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_unicode(KEYVAL);
    if(!g_unichar_validate(ret)){
    	TEST_FAIL("gdk_keyval_to_unicode: is not a unicode!",NULL);
    	return;
    }
    
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_unicode: doesnt match expected!",NULL);
    	return;
    }
    
    #undef KEYVAL
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_unicode
 * Params: guint
 * Return: guint32
 * Assertion: Convert from a GDK key symbol to the corresponding ISO10646 (Unicode) character.
 * Expected: the corresponding unicode character, or 0 if there is no corresponding character.  
 */
static void test_purpose_39()
{
    #define KEYVAL			     0x0020
    #define EXPECTED		     0x0020
    guint32 ret = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_unicode(KEYVAL);
    if(!g_unichar_validate(ret)){
    	TEST_FAIL("gdk_keyval_to_unicode: is not a unicode!",NULL);
    	return;
    }
    
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_unicode: doesnt match expected!",NULL);
    	return;
    }
    
    #undef KEYVAL
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_unicode
 * Params: guint
 * Return: guint32
 * Assertion: Convert from a GDK key symbol to the corresponding ISO10646 (Unicode) character.
 * Expected: the corresponding unicode character, or 0 if there is no corresponding character.  
 */
static void test_purpose_40()
{
    #define KEYVAL			     0xff
    #define EXPECTED		     0xff
    guint32 ret = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_unicode(KEYVAL);
    if(!g_unichar_validate(ret)){
    	TEST_FAIL("gdk_keyval_to_unicode: is not a unicode!",NULL);
    	return;
    }
    
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_unicode: doesnt match expected!",NULL);
    	return;
    }
    
    #undef KEYVAL
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keyval_to_unicode
 * Params: guint
 * Return: guint32
 * Assertion: Convert from a GDK key symbol to the corresponding ISO10646 (Unicode) character.
 * Expected: the corresponding unicode character, or 0 if there is no corresponding character.  
 */
static void test_purpose_41()
{
    #define KEYVAL			     0x11111111
    #define EXPECTED		     0x0
    guint32 ret = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_keyval_to_unicode(KEYVAL);
    if(!g_unichar_validate(ret)){
    	TEST_FAIL("gdk_keyval_to_unicode: is not a unicode!",NULL);
    	return;
    }
    
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_keyval_to_unicode: doesnt match expected!",NULL);
    	return;
    }
    
    #undef KEYVAL
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_unicode_to_keyval
 * Params: guint32
 * Return: guint
 * Assertion: Convert from a ISO10646 character to a key symbol.
 * Expected: the corresponding GDK key symbol, if one exists. or, if there is no corresponding symbol, wc | 0x01000000   
 */
static void test_purpose_42()
{
    #define UNICODE			    0x0020
    #define EXPECTED	0x0020
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_unicode_to_keyval(UNICODE);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_unicode_to_keyval: doesnt match expected!",NULL);
    	return;
    }
    
    #undef UNICODE
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_unicode_to_keyval
 * Params: guint32
 * Return: guint
 * Assertion: Convert from a ISO10646 character to a key symbol.
 * Expected: the corresponding GDK key symbol, if one exists. or, if there is no corresponding symbol, wc | 0x01000000   
 */
static void test_purpose_43()
{
    #define UNICODE			    0x00ff
    #define EXPECTED	0x00ff
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_unicode_to_keyval(UNICODE);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_unicode_to_keyval: doesnt match expected!",NULL);
    	return;
    }
    
    #undef UNICODE
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_unicode_to_keyval
 * Params: guint32
 * Return: guint
 * Assertion: Convert from a ISO10646 character to a key symbol.
 * Expected: the corresponding GDK key symbol, if one exists. or, if there is no corresponding symbol, wc | 0x01000000   
 */
static void test_purpose_44()
{
    #define UNICODE		0x318e
    #define EXPECTED		    0x0ef7
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_unicode_to_keyval(UNICODE);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_unicode_to_keyval: doesnt match expected!",NULL);
    	return;
    }
    
    #undef UNICODE
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_unicode_to_keyval
 * Params: guint32
 * Return: guint
 * Assertion: Convert from a ISO10646 character to a key symbol.
 * Expected: the corresponding GDK key symbol, if one exists. or, if there is no corresponding symbol, wc | 0x01000000   
 */
static void test_purpose_45()
{
    #define UNICODE		0x3186
    #define EXPECTED		    0x0ef5
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_unicode_to_keyval(UNICODE);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_unicode_to_keyval: doesnt match expected!",NULL);
    	return;
    }
    
    #undef UNICODE
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_unicode_to_keyval
 * Params: guint32
 * Return: guint
 * Assertion: Convert from a ISO10646 character to a key symbol.
 * Expected: the corresponding GDK key symbol, if one exists. or, if there is no corresponding symbol, wc | 0x01000000   
 */
static void test_purpose_46()
{
    #define UNICODE		0x0100
    #define EXPECTED		    0x03c0
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_unicode_to_keyval(UNICODE);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_unicode_to_keyval: doesnt match expected!",NULL);
    	return;
    }
    
    #undef UNICODE
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_unicode_to_keyval
 * Params: guint32
 * Return: guint
 * Assertion: Convert from a ISO10646 character to a key symbol.
 * Expected: the corresponding GDK key symbol, if one exists. or, if there is no corresponding symbol, wc | 0x01000000   
 */
static void test_purpose_47()
{
    #define UNICODE		0x00abcdef
    #define EXPECTED		    (0x00abcdef|0x01000000)
    guint ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_unicode_to_keyval(UNICODE);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_unicode_to_keyval: doesnt match expected!",NULL);
    	return;
    }
    
    #undef UNICODE
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_keymap_get_defualt
 * Params: void
 * Return: GdkKeymap*
 * Assertion: Returns the GdkKeymap attached to the default display.
 * Expected: the GdkKeymap attached to the default display.   
 */
static void test_purpose_48()
{
    GdkKeymap * keymap = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    keymap = gdk_keymap_get_default();
    if(keymap == NULL){
    	TEST_FAIL("gdk_keymap_get_default: keymap is NULL",NULL);
    	return;
    }
    if(GDK_IS_KEYMAP(keymap) != TRUE){
    	TEST_FAIL("gdk_keymap_get_default: keymap is not a GdkKeymap object!",NULL);
    	return;
    }
    
    if(keymap)
    	g_object_unref(keymap);
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkKeyValues ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {NULL,0}
};
