/*
 * GdkRGB methods tests
 * Testing GdkRGB methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gdk_rgb_cmap_new
 * Params: guint32 *colors, gint n_colors
 * Returns: GdkRgbCmap*
 * Assertion: Creates a new GdkRgbCmap structure. The cmap maps color indexes to RGB colors. If n_colors is less than 256, then images containing color values greater than or equal to n_colors will produce undefined results, including possibly segfaults.
 *            colors : The colors, represented as 0xRRGGBB integer values.
 *            n_colors :   The number of colors in the cmap.
 *            Returns :    The newly created GdkRgbCmap
 * Params Values: guint32 *colors, gint n_colors
 * Expected: GdkRgbCmap*  
 */
static void test_purpose_1()
{
    GdkRgbCmap* gdk_cmap;
    guint color = 0x101010;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gdk_cmap = gdk_rgb_cmap_new(&color, 256);
    if (gdk_cmap->colors[0] != 0x101010)
        TEST_FAIL("gdk_rgb_cmap_new: failed", NULL);
    gdk_rgb_cmap_free(gdk_cmap);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_rgb_find_color
 * Params: GdkColormap *colormap, GdkColor *color
 * Returns: void
 * Assertion: colormap should be the colormap for the graphics context and drawable you're using to draw. If you're drawing to a GtkWidget, call gtk_widget_get_colormap().
 *            color should have its red, green, and blue fields initialized; gdk_rgb_find_color() will fill in the pixel field with the best matching pixel from a color cube. The color is then ready to be used for drawing, e.g. you can call gdk_gc_set_foreground() which expects pixel to be initialized.
 *            In many cases, you can avoid this whole issue by calling gdk_gc_set_rgb_fg_color() or gdk_gc_set_rgb_bg_color(), which do not expect pixel to be initialized in advance. If you use those functions, there's no need for gdk_rgb_find_color().
 *            colormap :    a GdkColormap
 *            color :  a GdkColor
 * Params Values: guint32 *colors, gint n_colors
 * Expected: void  
 */
static void test_purpose_2()
{
    GdkColormap* gdk_cmap;
    GdkVisual *pvisual;
    GdkColor color;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pvisual = gdk_visual_get_system();
    gdk_cmap = gdk_colormap_new(pvisual, TRUE);
    color.red = 0xff;
    color.green = 0x00;
    color.blue = 0x00;
    gdk_rgb_find_color(gdk_cmap, &color);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_rgb_get_visual
 * Params: void
 * Returns: GdkVisual*
 * Assertion: Gets a "preferred visual" chosen by GdkRGB for rendering image data on the default screen. In previous versions of GDK, this was the only visual GdkRGB could use for rendering. In current versions, it's simply the visual GdkRGB would have chosen as the optimal one in those previous versions. GdkRGB can now render to drawables with any visual.
 *            Returns :    The GdkVisual chosen by GdkRGB.
 * Params Values: void
 * Expected: GdkVisual*  
 */
static void test_purpose_3()
{
    GdkVisual *pvisual;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pvisual = gdk_rgb_get_visual();
    if (pvisual == NULL)
        TEST_FAIL("gdk_rgb_get_visual: failed", NULL);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_rgb_get_colormap
 * Params: void
 * Returns: GdkColormap*
 * Assertion: Get the preferred colormap for rendering image data. Not a very useful function; historically, GDK could only render RGB image data to one colormap and visual, but in the current version it can render to any colormap and visual. So there's no need to call this function.
 *            Returns :    the preferred colormap
 * Params Values: void
 * Expected: GdkColormap*  
 */
static void test_purpose_4()
{
    GdkColormap* gdk_cmap;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gdk_cmap = gdk_rgb_get_colormap();
    if (gdk_cmap == NULL)
        TEST_FAIL("gdk_rgb_get_colormap: failed", NULL);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_draw_rgb_image
 * Params: GdkDrawable *drawable, GdkGC *gc, gint x, gint y, gint width, gint height, GdkRgbDither dith, guchar *rgb_buf, gint rowstride
 * Returns: void
 * Assertion: Draws an RGB image in the drawable. This is the core GdkRGB function, and likely the only one you will need to use.
 *            The rowstride parameter allows for lines to be aligned more flexibly. For example, lines may be allocated to begin on 32-bit boundaries, even if the width of the rectangle is odd. Rowstride is also useful when drawing a subrectangle of a larger image in memory. Finally, to replicate the same line a number of times, the trick of setting rowstride to 0 is allowed.
 *            In general, for 0 <= i < width and 0 <= j < height, the pixel (x + i, y + j) is colored with red value rgb_buf[j * rowstride + i * 3], green value rgb_buf[j * rowstride + i * 3 + 1], and blue value rgb_buf[j * rowstride + i * 3 + 2].
 *            drawable :	The GdkDrawable to draw in (usually a GdkWindow).
 *            gc :	The graphics context (all GDK drawing operations require one; its contents are ignored).
 *            x :	The x coordinate of the top-left corner in the drawable.
 *            y :	The y coordinate of the top-left corner in the drawable.
 *            width :	The width of the rectangle to be drawn.
 *            height :	The height of the rectangle to be drawn.
 *            dith :	A GdkRgbDither value, selecting the desired dither mode.
 *            rgb_buf :	The pixel data, represented as packed 24-bit data.
 *            rowstride :	The number of bytes from the start of one row in rgb_buf to the start of the next.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, gint x, gint y, gint width, gint height, GdkRgbDither dith, guchar *rgb_buf, gint rowstride
 * Expected: void
 * 
 * Name: gdk_draw_rgb_32_image
 * Params: GdkDrawable *drawable, GdkGC *gc, gint x, gint y, gint width, gint height, GdkRgbDither dith, guchar *rgb_buf, gint rowstride
 * Returns: void
 * Assertion: Draws a padded RGB image in the drawable. The image is stored as one pixel per 32-bit word. It is laid out as a red byte, a green byte, a blue byte, and a padding byte.
 *            It's unlikely that this function will give significant performance gains in practice. In my experience, the performance gain from having pixels aligned to 32-bit boundaries is cancelled out by the increased memory bandwidth.
 *            drawable :	The GdkDrawable to draw in (usually a GdkWindow).
 *            gc :	The graphics context.
 *            x :	The x coordinate of the top-left corner in the drawable.
 *            y :	The y coordinate of the top-left corner in the drawable.
 *            width :	The width of the rectangle to be drawn.
 *            height :	The height of the rectangle to be drawn.
 *            dith :	A GdkRgbDither value, selecting the desired dither mode.
 *            buf :	The pixel data, represented as padded 32-bit data.
 *            rowstride :	The number of bytes from the start of one row in buf to the start of the next.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, gint x, gint y, gint width, gint height, GdkRgbDither dith, guchar *rgb_buf, gint rowstride
 * Expected: void
 * 
 * Name: gdk_draw_gray_image
 * Params: GdkDrawable *drawable, GdkGC *gc, gint x, gint y, gint width, gint height, GdkRgbDither dith, guchar *rgb_buf, gint rowstride
 * Returns: void
 * Assertion: Draws a grayscale image in the drawable.
 *            drawable :	The GdkDrawable to draw in (usually a GdkWindow).
 *            gc :	The graphics context.
 *            x :	The x coordinate of the top-left corner in the drawable.
 *            y :	The y coordinate of the top-left corner in the drawable.
 *            width :	The width of the rectangle to be drawn.
 *            height :	The height of the rectangle to be drawn.
 *            dith :	A GdkRgbDither value, selecting the desired dither mode.
 *            buf :	The pixel data, represented as 8-bit gray values.
 *            rowstride :	The number of bytes from the start of one row in buf to the start of the next.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, gint x, gint y, gint width, gint height, GdkRgbDither dith, guchar *rgb_buf, gint rowstride
 * Expected: void  
 */
static void test_purpose_5()
{
    guchar rgb_buf[1024];
    gint width = 100;
    gint height = 100;
    gint rowstride = 3;
    GdkWindow *gdk_window;
    GdkGC* gdk_gc;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    for (i = 0; i < 1000; ++i){
        rgb_buf[i] = i % 256;
        i ++;
        rgb_buf[i] = i % 255;
        i ++;
        rgb_buf[i] = i % 254;
    }
    GdkWindowAttr parent_attributes = {"Lsb_Test", 0, 1, 2, 800, 600, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    gdk_window = gdk_window_new(NULL, &parent_attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    gdk_gc = gdk_gc_new(gdk_window);
    gdk_window_show(gdk_window);
    gdk_draw_rgb_image(gdk_window, gdk_gc, 0, 0, width, height, GDK_RGB_DITHER_NONE, rgb_buf, rowstride);
    for (i = 0; i < 1024; ++i)
        rgb_buf[i] = ~rgb_buf[i];
    gdk_draw_rgb_32_image(gdk_window, gdk_gc, 0, 0, width, height, GDK_RGB_DITHER_NONE, rgb_buf, rowstride);
    gdk_draw_gray_image(gdk_window, gdk_gc, 0, 0, width, height, GDK_RGB_DITHER_NONE, rgb_buf, rowstride);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_draw_indexed_image
 * Params: GdkDrawable *drawable, GdkGC *gc, gint x, gint y, gint width, gint height, GdkRgbDither dith, guchar *buf, gint rowstride, GdkRgbCmap *cmap
 * Returns: void
 * Assertion: Draws an indexed image in the drawable, using a GdkRgbCmap to assign actual colors to the color indices.
 *            drawable :	The GdkDrawable to draw in (usually a GdkWindow).
 *            gc :	The graphics context.
 *            x :	The x coordinate of the top-left corner in the drawable.
 *            y :	The y coordinate of the top-left corner in the drawable.
 *            width :	The width of the rectangle to be drawn.
 *            height :	The height of the rectangle to be drawn.
 *            dith :	A GdkRgbDither value, selecting the desired dither mode.
 *            buf :	The pixel data, represented as 8-bit color indices.
 *            rowstride :	The number of bytes from the start of one row in buf to the start of the next.
 *            cmap :	The GdkRgbCmap used to assign colors to the color indices.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, gint x, gint y, gint width, gint height, GdkRgbDither dith, guchar *buf, gint rowstride, GdkRgbCmap *cmap
 * Expected: void  
 */
static void test_purpose_6()
{
    guchar buf[1024];
    gint width = 100;
    gint height = 100;
    gint rowstride = 3;
    guint colors[256];
    GdkWindow *gdk_window;
    GdkGC* gdk_gc;
    GdkRgbCmap* gdk_cmap;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    for (i = 0; i < 256; ++i){
        buf[i] = i;
        colors[i] = i;
    }
    gdk_cmap = gdk_rgb_cmap_new(colors, 256);
    GdkWindowAttr parent_attributes = {"Lsb_Test", 0, 1, 2, 800, 600, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    gdk_window = gdk_window_new(NULL, &parent_attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    gdk_gc = gdk_gc_new(gdk_window);
    gdk_window_show(gdk_window);
    gdk_draw_indexed_image(gdk_window, gdk_gc, 0, 0, width, height, GDK_RGB_DITHER_NONE, buf, rowstride, gdk_cmap);
    gdk_rgb_cmap_free(gdk_cmap);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkRGB ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {NULL,0}
};
