/*
 * GtkCalendar methods tests
 * Testing GtkCalendar methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_calendar_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new calendar, with the current date being selected. 
 * Params Values: void
 * Expected: GtkWidget*  
 */
static void test_purpose_1()
{
    GtkWidget *widget;
    guint year;
    guint sys_year;
    guint month;
    guint day;
    time_t rawtime;
    struct tm *timeinfo;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_calendar_get_date (GTK_CALENDAR (widget), &year, &month, &day);
    time (&rawtime);
    timeinfo = localtime (&rawtime);
    sys_year = timeinfo->tm_year + 1900;
    if (year != sys_year)
    {
        TEST_FAIL ("Default year = %i, should be %i", year, sys_year);
    }
    
    if (month != timeinfo->tm_mon)
    {
        TEST_FAIL ("Default month = %i, should be %i", month, timeinfo->tm_mon);
    }
    
    if (day != timeinfo->tm_mday)
    {
        TEST_FAIL ("Default day = %i, should be %i", day, timeinfo->tm_mday);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_get_date
 * Params: GtkCalendar* calendar, guint *year, guint *month, guint *day
 * Returns: void
 * Assertion: Obtains the selected date from a GtkCalendar.
 * Params Values: newly created GtkCalendar*, *year, *month, *day
 * Expected: void, year = 0, month = 0, day = 0 
 * 
 * Name: gtk_calendar_select_month
 * Params: GtkCalendar* calendar, guint month, guint year
 * Returns: gboolean
 * Assertion: Shifts the calendar to a different month.
 * Params Values: newly created GtkCalendar*, 0, 0
 * Expected: ?
 * 
 * Name: gtk_calendar_select_day
 * Params: GtkCalendar* calendar, guint day
 * Returns: gboolean
 * Assertion: Selects a day from the current month.
 * Params Values: newly created GtkCalendar*, 0
 * Expected: ?  
 */
static void test_purpose_2()
{
    #define YEAR 0
    #define MONTH 0
    #define DAY 0
    
    GtkWidget *widget;
    guint year;
    guint month;
    guint day;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_calendar_select_month (GTK_CALENDAR (widget), MONTH, YEAR);
    gtk_calendar_select_day (GTK_CALENDAR (widget), DAY);
    
    gtk_calendar_get_date (GTK_CALENDAR (widget), &year, &month, &day);
    
    if (year != (guint)YEAR)
    {
        TEST_FAIL("GtkCalendar year = %u, should be %u", year, YEAR);
    }
    
    if (month != (guint)MONTH)
    {
        TEST_FAIL("GtkCalendar month = %u, should be %u", month, MONTH);
    }
    
    if (day != (guint)DAY)
    {
        TEST_FAIL("GtkCalendar day = %u, should be %u", day, DAY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef YEAR 
    #undef MONTH 
    #undef DAY 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_get_date
 * Params: GtkCalendar* calendar, guint *year, guint *month, guint *day
 * Returns: void
 * Assertion: Obtains the selected date from a GtkCalendar.
 * Params Values: newly created GtkCalendar*, *year, *month, *day
 * Expected: void, year = G_MAXUINT, month = 11, day = 31 
 * 
 * Name: gtk_calendar_select_month
 * Params: GtkCalendar* calendar, guint month, guint year
 * Returns: gboolean
 * Assertion: Shifts the calendar to a different month.
 * Params Values: newly created GtkCalendar*, 11, G_MAXUINT
 * Expected: ?
 * 
 * Name: gtk_calendar_select_day
 * Params: GtkCalendar* calendar, guint day
 * Returns: gboolean
 * Assertion: Selects a day from the current month.
 * Params Values: newly created GtkCalendar*, 31
 * Expected: ?  
 */
static void test_purpose_3()
{
    #define YEAR G_MAXUINT
    #define MONTH 11
    #define DAY 31
    
    GtkWidget *widget;
    guint year;
    guint month;
    guint day;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_calendar_select_month (GTK_CALENDAR (widget), MONTH, YEAR);
    gtk_calendar_select_day (GTK_CALENDAR (widget), DAY);
    
    gtk_calendar_get_date (GTK_CALENDAR (widget), &year, &month, &day);
    
    if (year != (guint)YEAR)
    {
        TEST_FAIL("GtkCalendar year = %u, should be %u", year, YEAR);
    }
    
    if (month != (guint)MONTH)
    {
        TEST_FAIL("GtkCalendar month = %u, should be %u", month, MONTH);
    }
    
    if (day != (guint)DAY)
    {
        TEST_FAIL("GtkCalendar day = %u, should be %u", day, DAY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef YEAR 
    #undef MONTH 
    #undef DAY 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_get_date
 * Params: GtkCalendar* calendar, guint *year, guint *month, guint *day
 * Returns: void
 * Assertion: Obtains the selected date from a GtkCalendar.
 * Params Values: newly created GtkCalendar*, *year, *month, *day
 * Expected: void, year = 10, month = 7, day = 27 
 * 
 * Name: gtk_calendar_select_month
 * Params: GtkCalendar* calendar, guint month, guint year
 * Returns: gboolean
 * Assertion: Shifts the calendar to a different month.
 * Params Values: newly created GtkCalendar*, 7, 10
 * Expected: ?
 * 
 * Name: gtk_calendar_select_day
 * Params: GtkCalendar* calendar, guint day
 * Returns: gboolean
 * Assertion: Selects a day from the current month.
 * Params Values: newly created GtkCalendar*, 27
 * Expected: ?  
 */
static void test_purpose_4()
{
    #define YEAR 10
    #define MONTH 7
    #define DAY 27
    
    GtkWidget *widget;
    guint year;
    guint month;
    guint day;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_calendar_select_month (GTK_CALENDAR (widget), MONTH, YEAR);
    gtk_calendar_select_day (GTK_CALENDAR (widget), DAY);
    
    gtk_calendar_get_date (GTK_CALENDAR (widget), &year, &month, &day);
    
    if (year != (guint)YEAR)
    {
        TEST_FAIL("GtkCalendar year = %u, should be %u", year, YEAR);
    }
    
    if (month != (guint)MONTH)
    {
        TEST_FAIL("GtkCalendar month = %u, should be %u", month, MONTH);
    }
    
    if (day != (guint)DAY)
    {
        TEST_FAIL("GtkCalendar day = %u, should be %u", day, DAY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef YEAR 
    #undef MONTH 
    #undef DAY 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_get_date
 * Params: GtkCalendar* calendar, guint *year, guint *month, guint *day
 * Returns: void
 * Assertion: Obtains the selected date from a GtkCalendar.
 * Params Values: newly created GtkCalendar*, *year, *month, *day
 * Expected: void, year = 5, month = 1, day = 30 
 * 
 * Name: gtk_calendar_select_month
 * Params: GtkCalendar* calendar, guint month, guint year
 * Returns: gboolean
 * Assertion: Shifts the calendar to a different month.
 * Params Values: newly created GtkCalendar*, 1, 5
 * Expected: ?
 * 
 * Name: gtk_calendar_select_day
 * Params: GtkCalendar* calendar, guint day
 * Returns: gboolean
 * Assertion: Selects a day from the current month.
 * Params Values: newly created GtkCalendar*, 30
 * Expected: ?  
 */
static void test_purpose_5()
{
    #define YEAR 5
    #define MONTH 1
    #define DAY 30
    
    GtkWidget *widget;
    guint year;
    guint month;
    guint day;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_calendar_select_month (GTK_CALENDAR (widget), MONTH, YEAR);
    gtk_calendar_select_day (GTK_CALENDAR (widget), DAY);
    
    gtk_calendar_get_date (GTK_CALENDAR (widget), &year, &month, &day);
    
    if (year != (guint)YEAR)
    {
        TEST_FAIL("GtkCalendar year = %u, should be %u", year, YEAR);
    }
    
    if (month != (guint)MONTH)
    {
        TEST_FAIL("GtkCalendar month = %u, should be %u", month, MONTH);
    }
    
    if (day != (guint)DAY)
    {
        TEST_FAIL("GtkCalendar day = %u, should be %u", day, DAY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef YEAR 
    #undef MONTH 
    #undef DAY 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_get_date
 * Params: GtkCalendar* calendar, guint *year, guint *month, guint *day
 * Returns: void
 * Assertion: Obtains the selected date from a GtkCalendar.
 * Params Values: newly created GtkCalendar*, *year, *month, *day
 * Expected: void, year = 777, month = 2, day = 31 
 * 
 * Name: gtk_calendar_select_month
 * Params: GtkCalendar* calendar, guint month, guint year
 * Returns: gboolean
 * Assertion: Shifts the calendar to a different month.
 * Params Values: newly created GtkCalendar*, 2, 777
 * Expected: ?
 * 
 * Name: gtk_calendar_select_day
 * Params: GtkCalendar* calendar, guint day
 * Returns: gboolean
 * Assertion: Selects a day from the current month.
 * Params Values: newly created GtkCalendar*, 31
 * Expected: ?  
 */
static void test_purpose_6()
{
    #define YEAR 777
    #define MONTH 2
    #define DAY 31
    
    GtkWidget *widget;
    guint year;
    guint month;
    guint day;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_calendar_select_month (GTK_CALENDAR (widget), MONTH, YEAR);
    gtk_calendar_select_day (GTK_CALENDAR (widget), DAY);
    
    gtk_calendar_get_date (GTK_CALENDAR (widget), &year, &month, &day);
    
    if (year != (guint)YEAR)
    {
        TEST_FAIL("GtkCalendar year = %u, should be %u", year, YEAR);
    }
    
    if (month != (guint)MONTH)
    {
        TEST_FAIL("GtkCalendar month = %u, should be %u", month, MONTH);
    }
    
    if (day != (guint)DAY)
    {
        TEST_FAIL("GtkCalendar day = %u, should be %u", day, DAY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef YEAR 
    #undef MONTH 
    #undef DAY 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_display_options
 * Params: GtkCalendar *calendar, GtkCalendarDisplayOptions flags
 * Returns: void
 * Assertion: Sets display options (whether to display the heading and the month headings).
 * Params Values: a newly created GtkCalendar*, GTK_CALENDAR_SHOW_HEADING
 * Expected: void  
 */
static void test_purpose_7()
{
    #define OPTIONS GTK_CALENDAR_SHOW_HEADING
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef OPTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_display_options
 * Params: GtkCalendar *calendar, GtkCalendarDisplayOptions flags
 * Returns: void
 * Assertion: Sets display options (whether to display the heading and the month headings).
 * Params Values: a newly created GtkCalendar*, GTK_CALENDAR_SHOW_DAY_NAMES
 * Expected: void  
 */
static void test_purpose_8()
{
    #define OPTIONS GTK_CALENDAR_SHOW_DAY_NAMES
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef OPTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_display_options
 * Params: GtkCalendar *calendar, GtkCalendarDisplayOptions flags
 * Returns: void
 * Assertion: Sets display options (whether to display the heading and the month headings).
 * Params Values: a newly created GtkCalendar*, GTK_CALENDAR_NO_MONTH_CHANGE
 * Expected: void  
 */
static void test_purpose_9()
{
    #define OPTIONS GTK_CALENDAR_NO_MONTH_CHANGE
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef OPTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_display_options
 * Params: GtkCalendar *calendar, GtkCalendarDisplayOptions flags
 * Returns: void
 * Assertion: Sets display options (whether to display the heading and the month headings).
 * Params Values: a newly created GtkCalendar*, GTK_CALENDAR_SHOW_WEEK_NUMBERS
 * Expected: void  
 */
static void test_purpose_10()
{
    #define OPTIONS GTK_CALENDAR_SHOW_WEEK_NUMBERS
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef OPTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_display_options
 * Params: GtkCalendar *calendar, GtkCalendarDisplayOptions flags
 * Returns: void
 * Assertion: Sets display options (whether to display the heading and the month headings).
 * Params Values: a newly created GtkCalendar*, GTK_CALENDAR_WEEK_START_MONDAY
 * Expected: void  
 */
static void test_purpose_11()
{
    #define OPTIONS GTK_CALENDAR_WEEK_START_MONDAY
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef OPTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_display_options
 * Params: GtkCalendar *calendar, GtkCalendarDisplayOptions flags
 * Returns: void
 * Assertion: Sets display options (whether to display the heading and the month headings).
 * Params Values: a newly created GtkCalendar*, GTK_CALENDAR_SHOW_HEADING | GTK_CALENDAR_WEEK_START_MONDAY
 * Expected: void  
 */
static void test_purpose_12()
{
    #define OPTIONS GTK_CALENDAR_SHOW_HEADING | GTK_CALENDAR_WEEK_START_MONDAY
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef OPTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_display_options
 * Params: GtkCalendar *calendar, GtkCalendarDisplayOptions flags
 * Returns: void
 * Assertion: Sets display options (whether to display the heading and the month headings).
 * Params Values: a newly created GtkCalendar*, GTK_CALENDAR_SHOW_DAY_NAMES | GTK_CALENDAR_NO_MONTH_CHANGE
 * Expected: void  
 */
static void test_purpose_13()
{
    #define OPTIONS GTK_CALENDAR_SHOW_DAY_NAMES | GTK_CALENDAR_NO_MONTH_CHANGE
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef OPTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_display_options
 * Params: GtkCalendar *calendar, GtkCalendarDisplayOptions flags
 * Returns: void
 * Assertion: Sets display options (whether to display the heading and the month headings).
 * Params Values: a newly created GtkCalendar*, GTK_CALENDAR_SHOW_WEEK_NUMBERS | GTK_CALENDAR_SHOW_DAY_NAMES
 * Expected: void  
 */
static void test_purpose_14()
{
    #define OPTIONS GTK_CALENDAR_SHOW_WEEK_NUMBERS | GTK_CALENDAR_SHOW_DAY_NAMES
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef OPTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_display_options
 * Params: GtkCalendar *calendar, GtkCalendarDisplayOptions flags
 * Returns: void
 * Assertion: Sets display options (whether to display the heading and the month headings).
 * Params Values: a newly created GtkCalendar*, GTK_CALENDAR_SHOW_HEADING | GTK_CALENDAR_NO_MONTH_CHANGE | GTK_CALENDAR_WEEK_START_MONDAY
 * Expected: void  
 */
static void test_purpose_15()
{
    #define OPTIONS GTK_CALENDAR_SHOW_HEADING | GTK_CALENDAR_NO_MONTH_CHANGE | GTK_CALENDAR_WEEK_START_MONDAY
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef OPTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_calendar_display_options
 * Params: GtkCalendar *calendar, GtkCalendarDisplayOptions flags
 * Returns: void
 * Assertion: Sets display options (whether to display the heading and the month headings).
 * Params Values: a newly created GtkCalendar*, GTK_CALENDAR_SHOW_HEADING | GTK_CALENDAR_NO_MONTH_CHANGE | GTK_CALENDAR_WEEK_START_MONDAY | GTK_CALENDAR_SHOW_DAY_NAMES | GTK_CALENDAR_SHOW_WEEK_NUMBERS
 * Expected: void  
 */
static void test_purpose_16()
{
    #define OPTIONS GTK_CALENDAR_SHOW_HEADING | GTK_CALENDAR_NO_MONTH_CHANGE | GTK_CALENDAR_WEEK_START_MONDAY | GTK_CALENDAR_SHOW_DAY_NAMES | GTK_CALENDAR_SHOW_WEEK_NUMBERS
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_calendar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_CALENDAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef OPTIONS
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkCalendar ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {NULL,0}
};
