/*
 * GtkCheckMenuItem methods tests
 * Testing GtkCheckMenuItem methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gint global_counter;

void global_toggled_signal (GtkCheckMenuItem *checkmenuitem,gpointer user_data)
{
    global_counter++;
}

/*
 * Name: gtk_check_menu_item_new
 * Params: void
 * Returns: GtkCheckMenuItem*
 * Assertion: Creates a new GtkCheckMenuItem.
 * Params Values: void
 * Expected: GtkCheckMenuItem*  
 */
static void test_purpose_1()
{
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkCheckMenuItem*
 * Assertion: Creates a new GtkCheckMenuItem with a label.
 * Params Values: const gchar *label
 * Expected: GtkCheckMenuItem*  
 */
static void test_purpose_2()
{
    #define LABEL "Text"
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkCheckMenuItem*
 * Assertion: Creates a new GtkCheckMenuItem with a label.
 * Params Values: const gchar *label
 * Expected: GtkCheckMenuItem*  
 */
static void test_purpose_3()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkCheckMenuItem*
 * Assertion: Creates a new GtkCheckMenuItem with a label.
 * Params Values: const gchar *label
 * Expected: GtkCheckMenuItem*  
 */
static void test_purpose_4()
{
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkCheckMenuItem*
 * Assertion: Creates a new GtkCheckMenuItem with a label.
 * Params Values: const gchar *label
 * Expected: GtkCheckMenuItem*  
 */
static void test_purpose_5()
{
    #define LABEL "\b\n\t"
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkCheckMenuItem*
 * Assertion: Creates a new GtkCheckMenuItem with a label.
 * Params Values: const gchar *label
 * Expected: GtkCheckMenuItem*  
 */
static void test_purpose_6()
{
    #define LABEL " "
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkCheckMenuItem*
 * Assertion: Creates a new GtkCheckMenuItem with a label.
 * Params Values: const gchar *label
 * Expected: GtkCheckMenuItem*  
 */
static void test_purpose_7()
{
    #define LABEL ""
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_label (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_set_active
 * Params: GtkCheckMenuItem*, gboolean is_active
 * Returns: void
 * Assertion: Sets the active state of the menu item's check box.'
 * Params Values: GtkCheckMenuItem*, FALSE
 * Expected: void  
 */
static void test_purpose_8()
{
    #define  ACTIVE FALSE
    gboolean active;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM (widget), ACTIVE);
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != ACTIVE) 
    {
        TEST_FAIL("active is %d, should be %d", active, ACTIVE);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ACTIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_set_active
 * Params: GtkCheckMenuItem*, gboolean is_active
 * Returns: void
 * Assertion: Sets the active state of the menu item's check box.'
 * Params Values: GtkCheckMenuItem*, TRUE
 * Expected: void  
 */
static void test_purpose_9()
{
    #define  ACTIVE TRUE
    gboolean active;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM (widget), ACTIVE);
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != ACTIVE) 
    {
        TEST_FAIL("active is %d, should be %d", active, ACTIVE);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ACTIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_get_active
 * Params: GtkCheckMenuItem*
 * Returns: gboolean
 * Assertion: Returns whether the check menu item is active.
 * Params Values: GtkCheckMenuItem*
 * Expected: FALSE  
 */
static void test_purpose_10()
{
    #define  ACTIVE FALSE
    gboolean active;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "active", ACTIVE, NULL);
    active = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM (widget));
    if (active != ACTIVE) 
    {
        TEST_FAIL("active is %d, should be %d", active, ACTIVE);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ACTIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_get_active
 * Params: GtkCheckMenuItem*
 * Returns: gboolean
 * Assertion: Returns whether the check menu item is active.
 * Params Values: GtkCheckMenuItem*
 * Expected: TRUE  
 */
static void test_purpose_11()
{
    #define  ACTIVE TRUE
    gboolean active;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "active", ACTIVE, NULL);
    active = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM (widget));
    if (active != ACTIVE) 
    {
        TEST_FAIL("active is %d, should be %d", active, ACTIVE);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ACTIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_set_inconsistent
 * Params: GtkCheckMenuItem*, gboolean is_inconsistent
 * Returns: void
 * Assertion: If the user has selected a range of elements (such as some text or spreadsheet cells) that are affected by a boolean setting, and the current values in that range are inconsistent, you may want to display the check in an "in between" state.
 * Params Values: GtkCheckMenuItem*, FALSE
 * Expected: void  
 */
static void test_purpose_12()
{
    #define  INCONSISTENT FALSE
    
    gboolean inconsistent;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_check_menu_item_set_inconsistent(GTK_CHECK_MENU_ITEM (widget), INCONSISTENT);
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != INCONSISTENT) 
    {
        TEST_FAIL("inconsistent = %i %i", inconsistent, INCONSISTENT);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef INCONSISTENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_set_inconsistent
 * Params: GtkCheckMenuItem*, gboolean is_inconsistent
 * Returns: void
 * Assertion: If the user has selected a range of elements (such as some text or spreadsheet cells) that are affected by a boolean setting, and the current values in that range are inconsistent, you may want to display the check in an "in between" state.
 * Params Values: GtkCheckMenuItem*, TRUE
 * Expected: void  
 */
static void test_purpose_13()
{
    #define  INCONSISTENT TRUE
    
    gboolean inconsistent;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_check_menu_item_set_inconsistent(GTK_CHECK_MENU_ITEM (widget), INCONSISTENT);
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != INCONSISTENT) 
    {
        TEST_FAIL("inconsistent = %i %i", inconsistent, INCONSISTENT);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef INCONSISTENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_get_inconsistent
 * Params: GtkCheckMenuItem* 
 * Returns: gboolean
 * Assertion: Retrieves the value set by gtk_check_menu_item_set_inconsistent().
 * Params Values: GtkCheckMenuItem*
 * Expected: FALSE  
 */
static void test_purpose_14()
{
    #define  INCONSISTENT FALSE
    
    gboolean inconsistent;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    inconsistent = INCONSISTENT;
    g_object_set(GTK_OBJECT(widget), "inconsistent", inconsistent, NULL);
    inconsistent = gtk_check_menu_item_get_inconsistent(GTK_CHECK_MENU_ITEM (widget));
    if (inconsistent != INCONSISTENT) 
    {
        TEST_FAIL("inconsistent = %i %i", inconsistent, INCONSISTENT);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef INCONSISTENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_get_inconsistent
 * Params: GtkCheckMenuItem* 
 * Returns: gboolean
 * Assertion: Retrieves the value set by gtk_check_menu_item_set_inconsistent().
 * Params Values: GtkCheckMenuItem*
 * Expected: TRUE  
 */
static void test_purpose_15()
{
    #define  INCONSISTENT TRUE
    
    gboolean inconsistent;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    inconsistent = INCONSISTENT;
    g_object_set(GTK_OBJECT(widget), "inconsistent", inconsistent, NULL);
    inconsistent = gtk_check_menu_item_get_inconsistent(GTK_CHECK_MENU_ITEM (widget));
    if (inconsistent != INCONSISTENT) 
    {
        TEST_FAIL("inconsistent = %i %i", inconsistent, INCONSISTENT);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef INCONSISTENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_toggled 
 * Params: GtkCheckMenuItem* check_menu_item
 * Returns: void
 * Assertion: Emits the GtkCheckMenuItem::toggled signal.
 * Params Values: GtkCheckMenuItem* check_menu_item
 * Expected: void  
 */
static void test_purpose_16()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_check_menu_item_new ();
    
    g_signal_connect (G_OBJECT (widget), "toggled", 
                        GTK_SIGNAL_FUNC (global_toggled_signal), NULL);
    
    gtk_check_menu_item_toggled (GTK_CHECK_MENU_ITEM (widget));
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkToggled widget should emit 'toggled' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckMenuItem containing a label.
 * Params Values: ""
 * Expected: GtkWidget*  
 */
static void test_purpose_17()
{
    #define LABEL ""
    #define CORRECT_LABEL ""
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckMenuItem containing a label.
 * Params Values: " "
 * Expected: GtkWidget*  
 */
static void test_purpose_18()
{
    #define LABEL " "
    #define CORRECT_LABEL " "
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckMenuItem containing a label.
 * Params Values: "   "
 * Expected: GtkWidget*  
 */
static void test_purpose_19()
{
    #define LABEL "   "
    #define CORRECT_LABEL "   "
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckMenuItem containing a label.
 * Params Values: "Label String"
 * Expected: GtkWidget*  
 */
static void test_purpose_20()
{
    #define LABEL "Label String"
    #define CORRECT_LABEL "Label String"
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckMenuItem containing a label.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkWidget*  
 */
static void test_purpose_21()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define CORRECT_LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckMenuItem containing a label.
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkWidget*  
 */
static void test_purpose_22()
{
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    #define CORRECT_LABEL "!@#$%^&*()+|~=\";:'?<>`/"
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckMenuItem containing a label.
 * Params Values: "_a_b"
 * Expected: GtkWidget*  
 */
static void test_purpose_23()
{
    #define LABEL "_a_b"
    #define CORRECT_LABEL "ab"
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckMenuItem containing a label.
 * Params Values: "\n\t\""
 * Expected: GtkWidget*  
 */
static void test_purpose_24()
{
    #define LABEL "\n\t\""
    #define CORRECT_LABEL "\n\t\""
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckMenuItem containing a label.
 * Params Values: "_\n\t\""
 * Expected: GtkWidget*  
 */
static void test_purpose_25()
{
    #define LABEL "_\n\t\""
    #define CORRECT_LABEL "\n\t\""
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckMenuItem containing a label.
 * Params Values: "\b"
 * Expected: GtkWidget*  
 */
static void test_purpose_26()
{
    #define LABEL "\b"
    #define CORRECT_LABEL "\b"
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkCheckMenuItem containing a label.
 * Params Values: "_\b"
 * Expected: GtkWidget*  
 */
static void test_purpose_27()
{
    #define LABEL "_\b"
    #define CORRECT_LABEL "\b"
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "_File"
 * Expected: GtkWidget*  
 */
static void test_purpose_28()
{
    #define LABEL "_File"
    #define CORRECT_KEYVAL 'f'
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "_file"
 * Expected: GtkWidget*  
 */
static void test_purpose_29()
{
    #define LABEL "_file"
    #define CORRECT_KEYVAL 'f'
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "_@ile"
 * Expected: GtkWidget*  
 */
static void test_purpose_30()
{
    #define LABEL "_@ile"
    #define CORRECT_KEYVAL '@'
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "_#ile"
 * Expected: GtkWidget*  
 */
static void test_purpose_31()
{
    #define LABEL "_#ile"
    #define CORRECT_KEYVAL '#'
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "_/ile"
 * Expected: GtkWidget*  
 */
static void test_purpose_32()
{
    #define LABEL "_/ile"
    #define CORRECT_KEYVAL '/'
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "_\\le"
 * Expected: GtkWidget*  
 */
static void test_purpose_33()
{
    #define LABEL "_\\le"
    #define CORRECT_KEYVAL '\\'
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "_ le"
 * Expected: GtkWidget*  
 */
static void test_purpose_34()
{
    #define LABEL "_ le"
    #define CORRECT_KEYVAL ' '
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "_fi_le"
 * Expected: GtkWidget*  
 */
static void test_purpose_35()
{
    #define LABEL "_fi_le"
    #define CORRECT_KEYVAL 'f'
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "__le"
 * Expected: GtkWidget*  
 */
static void test_purpose_36()
{
    #define LABEL "__le"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "___le"
 * Expected: GtkWidget*  
 */
static void test_purpose_37()
{
    #define LABEL "___le"
    #define CORRECT_KEYVAL 'l'
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "____le"
 * Expected: GtkWidget*  
 */
static void test_purpose_38()
{
    #define LABEL "____le"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "_____le"
 * Expected: GtkWidget*  
 */
static void test_purpose_39()
{
    #define LABEL "_____le"
    #define CORRECT_KEYVAL 'l'
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "__"
 * Expected: GtkWidget*  
 */
static void test_purpose_40()
{
    #define LABEL "__"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "_\0"
 * Expected: GtkWidget*  
 */
static void test_purpose_41()
{
    #define LABEL "_\0"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_check_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "Fil\0_e"
 * Expected: GtkWidget*  
 */
static void test_purpose_42()
{
    #define LABEL "Fil\0_e"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gboolean active;
    gboolean inconsistent;
    
    GtkWidget *widget;
    GtkWidget *child;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_check_menu_item_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_CHECK_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkCheckMenuItem ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {NULL,0}
};
