/*
 * GtkFixed methods tests
 * Testing GtkFixed methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_fixed_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkFixed.
 * Params Values: void
 * Expected: GtkFixed*  
 */
static void test_purpose_1()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_fixed_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_FIXED (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_fixed_put
 * Params: GtkFixed *fixed,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Adds a widget to a GtkFixed container at the given position.
 * Params Values: a newly created GtkFixed*, gtk_button_new (),1,1
 * Expected: void  
 */
static void test_purpose_2()
{
    #define WIDGET gtk_button_new ()
    #define X 1
    #define Y 1
    
    GtkWidget *fixed;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    fixed =  gtk_fixed_new ();
    
    widget = WIDGET;
    
    gtk_fixed_put (GTK_FIXED (fixed), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (fixed));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (fixed), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (fixed != parent)
    {
        TEST_FAIL ("Widget is not added to GtkFixed container",NULL);
    }
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (fixed);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (fixed));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_fixed_put
 * Params: GtkFixed *fixed,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Adds a widget to a GtkFixed container at the given position.
 * Params Values: a newly created GtkFixed*, gtk_button_new (),0,0
 * Expected: void  
 */
static void test_purpose_3()
{
    #define WIDGET gtk_button_new ()
    #define X 0
    #define Y 0
    
    GtkWidget *fixed;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    fixed =  gtk_fixed_new ();
    
    widget = WIDGET;
    
    gtk_fixed_put (GTK_FIXED (fixed), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (fixed));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (fixed), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (fixed != parent)
    {
        TEST_FAIL ("Widget is not added to GtkFixed container",NULL);
    }
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (fixed);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (fixed));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_fixed_put
 * Params: GtkFixed *fixed,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Adds a widget to a GtkFixed container at the given position.
 * Params Values: a newly created GtkFixed*, gtk_button_new (),1,100
 * Expected: void  
 */
static void test_purpose_4()
{
    #define WIDGET gtk_button_new ()
    #define X 1
    #define Y 100
    
    GtkWidget *fixed;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    fixed =  gtk_fixed_new ();
    
    widget = WIDGET;
    
    gtk_fixed_put (GTK_FIXED (fixed), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (fixed));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (fixed), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (fixed != parent)
    {
        TEST_FAIL ("Widget is not added to GtkFixed container",NULL);
    }
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (fixed);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (fixed));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_fixed_put
 * Params: GtkFixed *fixed,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Adds a widget to a GtkFixed container at the given position.
 * Params Values: a newly created GtkFixed*, gtk_button_new (),1,10000
 * Expected: void  
 */
static void test_purpose_5()
{
    #define WIDGET gtk_button_new ()
    #define X 1
    #define Y 10000
    
    GtkWidget *fixed;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    fixed =  gtk_fixed_new ();
    
    widget = WIDGET;
    
    gtk_fixed_put (GTK_FIXED (fixed), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (fixed));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (fixed), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (fixed != parent)
    {
        TEST_FAIL ("Widget is not added to GtkFixed container",NULL);
    }
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (fixed);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (fixed));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_fixed_move
 * Params: GtkFixed *fixed,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Moves a child of a GtkFixed container to the given position.
 * Params Values: a newly created GtkFixed*,gtk_button_new (),1,1
 * Expected: void  
 */
static void test_purpose_6()
{
    #define WIDGET gtk_button_new ()
    #define X 1
    #define Y 1
    
    GtkWidget *fixed;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    fixed =  gtk_fixed_new ();
    
    widget = WIDGET;
    
    gtk_fixed_put (GTK_FIXED (fixed), widget, 1,1);
    
    gtk_fixed_move (GTK_FIXED (fixed), widget, X,Y);
    children = gtk_container_get_children (GTK_CONTAINER (fixed));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (fixed), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (fixed != parent)
    {
        TEST_FAIL ("Widget is not added to GtkFixed container",NULL);
    }
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (fixed);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (fixed));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_fixed_move
 * Params: GtkFixed *fixed,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Moves a child of a GtkFixed container to the given position.
 * Params Values: a newly created GtkFixed*,gtk_button_new (),0,0
 * Expected: void  
 */
static void test_purpose_7()
{
    #define WIDGET gtk_button_new ()
    #define X 0
    #define Y 0
    
    GtkWidget *fixed;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    fixed =  gtk_fixed_new ();
    
    widget = WIDGET;
    
    gtk_fixed_put (GTK_FIXED (fixed), widget, 1,1);
    
    gtk_fixed_move (GTK_FIXED (fixed), widget, X,Y);
    children = gtk_container_get_children (GTK_CONTAINER (fixed));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (fixed), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (fixed != parent)
    {
        TEST_FAIL ("Widget is not added to GtkFixed container",NULL);
    }
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (fixed);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (fixed));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_fixed_move
 * Params: GtkFixed *fixed,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Moves a child of a GtkFixed container to the given position.
 * Params Values: a newly created GtkFixed*,gtk_button_new (),1,100
 * Expected: void  
 */
static void test_purpose_8()
{
    #define WIDGET gtk_button_new ()
    #define X 1
    #define Y 100
    
    GtkWidget *fixed;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    fixed =  gtk_fixed_new ();
    
    widget = WIDGET;
    
    gtk_fixed_put (GTK_FIXED (fixed), widget, 1,1);
    
    gtk_fixed_move (GTK_FIXED (fixed), widget, X,Y);
    children = gtk_container_get_children (GTK_CONTAINER (fixed));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (fixed), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (fixed != parent)
    {
        TEST_FAIL ("Widget is not added to GtkFixed container",NULL);
    }
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (fixed);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (fixed));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_fixed_move
 * Params: GtkFixed *fixed,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Moves a child of a GtkFixed container to the given position.
 * Params Values: a newly created GtkFixed*,gtk_button_new (),1,10000
 * Expected: void  
 */
static void test_purpose_9()
{
    #define WIDGET gtk_button_new ()
    #define X 1
    #define Y 10000
    
    GtkWidget *fixed;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    fixed =  gtk_fixed_new ();
    
    widget = WIDGET;
    
    gtk_fixed_put (GTK_FIXED (fixed), widget, 1,1);
    
    gtk_fixed_move (GTK_FIXED (fixed), widget, X,Y);
    children = gtk_container_get_children (GTK_CONTAINER (fixed));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (fixed), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (fixed != parent)
    {
        TEST_FAIL ("Widget is not added to GtkFixed container",NULL);
    }
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (fixed);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (fixed));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_fixed_set_has_window
 * Params: GtkFixed *fixed, gboolean has_window
 * Returns: void
 * Assertion: Sets whether a GtkFixed widget is created with a separate GdkWindow for widget->window or not.
 * Params Values: a newly created GtkFixed*, TRUE
 * Expected: void
 * 
 * Name: gtk_fixed_get_has_window
 * Params: GtkFixed *fixed
 * Returns: gboolean
 * Assertion: Gets whether the GtkFixed has it's own GdkWindow.'
 * Params Values: a newly created GtkFixed*
 * Expected: TRUE  
 */
static void test_purpose_10()
{
    #define HAS_WINDOW TRUE
    
    GtkWidget *widget;
    GtkWidget *window;
    gboolean real_has_window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_fixed_new ();
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_FIXED (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_fixed_set_has_window (GTK_FIXED (widget), HAS_WINDOW);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    real_has_window = gtk_fixed_get_has_window (GTK_FIXED (widget));
    if (real_has_window != HAS_WINDOW)
    {
        TEST_FAIL ("real_has_window = %d, should be %d", 
                   real_has_window, HAS_WINDOW);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HAS_WINDOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_fixed_set_has_window
 * Params: GtkFixed *fixed, gboolean has_window
 * Returns: void
 * Assertion: Sets whether a GtkFixed widget is created with a separate GdkWindow for widget->window or not.
 * Params Values: a newly created GtkFixed*, FALSE
 * Expected: void
 * 
 * Name: gtk_fixed_get_has_window
 * Params: GtkFixed *fixed
 * Returns: gboolean
 * Assertion: Gets whether the GtkFixed has it's own GdkWindow.'
 * Params Values: a newly created GtkFixed*
 * Expected: FALSE  
 */
static void test_purpose_11()
{
    #define HAS_WINDOW FALSE
    
    GtkWidget *widget;
    GtkWidget *window;
    gboolean real_has_window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_fixed_new ();
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_FIXED (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_fixed_set_has_window (GTK_FIXED (widget), HAS_WINDOW);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    real_has_window = gtk_fixed_get_has_window (GTK_FIXED (widget));
    if (real_has_window != HAS_WINDOW)
    {
        TEST_FAIL ("real_has_window = %d, should be %d", 
                   real_has_window, HAS_WINDOW);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HAS_WINDOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_fixed_set_has_window
 * Params: GtkFixed *fixed, gboolean has_window
 * Returns: void
 * Assertion: (By default, it will be created with no separate GdkWindow).
 * Params Values: N/A
 * Expected: void  
 */
static void test_purpose_12()
{
    GtkWidget *widget;
    GtkWidget *window;
    gboolean real_has_window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_fixed_new ();
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_FIXED (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    real_has_window = gtk_fixed_get_has_window (GTK_FIXED (widget));
    if (real_has_window != FALSE)
    {
        TEST_FAIL ("real_has_window = %d, the default value is %d", 
                   real_has_window, FALSE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkFixed ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {NULL,0}
};
