/*
 * GtkHScale methods tests
 * Testing GtkHScale methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include <float.h>

/*
 * Name: gtk_hscale_new
 * Params: GtkAdjustment *adjustment
 * Returns: GtkHScale*
 * Assertion: Creates a new GtkHScale.
 * Params Values: NULL
 * Expected: GtkHScale* with adjustment = NULL  
 */
static void test_purpose_1()
{
    #define ADJUSTMENT NULL
    
    GtkWidget *widget;
    GtkObject *adjustment;
    GtkObject *real_adjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = ADJUSTMENT;
    
    if (adjustment)
    {
        widget = gtk_hscale_new (GTK_ADJUSTMENT (adjustment));
    } else {
        widget = gtk_hscale_new (NULL);
    }
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_HSCALE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    
    if (adjustment)
    {
        if (((GtkAdjustment*)adjustment)->lower 
            != ((GtkAdjustment*)real_adjustment)->lower)
        {
            TEST_FAIL ("adjustment->lower = %d, real_adjustment->lower = %d",
                       ((GtkAdjustment*)adjustment)->lower, 
                       ((GtkAdjustment*)real_adjustment)->lower);
        }
        if (((GtkAdjustment*)adjustment)->upper 
            != ((GtkAdjustment*)real_adjustment)->upper)
        {
            TEST_FAIL ("adjustment->upper = %d, real_adjustment->upper = %d",
                       ((GtkAdjustment*)adjustment)->upper, 
                       ((GtkAdjustment*)real_adjustment)->upper);
        }
        if (((GtkAdjustment*)adjustment)->value
            != ((GtkAdjustment*)real_adjustment)->value)
        {
            TEST_FAIL ("adjustment->value = %d, real_adjustment->value = %d",
                       ((GtkAdjustment*)adjustment)->value, 
                       ((GtkAdjustment*)real_adjustment)->value);
        }
        if (((GtkAdjustment*)adjustment)->step_increment
            != ((GtkAdjustment*)real_adjustment)->step_increment)
        {
            TEST_FAIL ("adjustment->step_increment = %d, real_adjustment->step_increment = %d",
                       ((GtkAdjustment*)adjustment)->step_increment, 
                       ((GtkAdjustment*)real_adjustment)->step_increment);
        }
        if (((GtkAdjustment*)adjustment)->page_increment
            != ((GtkAdjustment*)real_adjustment)->page_increment)
        {
            TEST_FAIL ("adjustment->page_increment = %d, real_adjustment->page_increment = %d",
                       ((GtkAdjustment*)adjustment)->page_increment, 
                       ((GtkAdjustment*)real_adjustment)->page_increment);
        }
        if (((GtkAdjustment*)adjustment)->page_size
            != ((GtkAdjustment*)real_adjustment)->page_size)
        {
            TEST_FAIL ("adjustment->page_size = %d, real_adjustment->page_size = %d",
                       ((GtkAdjustment*)adjustment)->page_size, 
                       ((GtkAdjustment*)real_adjustment)->page_size);
        }
    } else {
        if (((GtkAdjustment*)real_adjustment)->lower)
        {
            TEST_FAIL ("real_adjustment->lower = %d, should be 0", ((GtkAdjustment*)real_adjustment)->lower);
        }
        if (((GtkAdjustment*)real_adjustment)->upper)
        {
            TEST_FAIL ("real_adjustment->upper = %d, should be 0", ((GtkAdjustment*)real_adjustment)->upper);
        }
        if (((GtkAdjustment*)real_adjustment)->value)
        {
            TEST_FAIL ("real_adjustment->value = %d, should be 0", ((GtkAdjustment*)real_adjustment)->value);
        }
        if (((GtkAdjustment*)real_adjustment)->step_increment)
        {
            TEST_FAIL ("real_adjustment->step_increment = %d, should be 0", ((GtkAdjustment*)real_adjustment)->step_increment);
        }
        if (((GtkAdjustment*)real_adjustment)->page_increment)
        {
            TEST_FAIL ("real_adjustment->page_increment = %d, should be 0", ((GtkAdjustment*)real_adjustment)->page_increment);
        }
        if (((GtkAdjustment*)real_adjustment)->page_size)
        {
            TEST_FAIL ("real_adjustment->page_size = %d, should be 0", ((GtkAdjustment*)real_adjustment)->page_size);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_hscale_new
 * Params: GtkAdjustment *adjustment
 * Returns: GtkHScale*
 * Assertion: Creates a new GtkHScale.
 * Params Values: gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
 * Expected: GtkHScale* with adjustment = gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)  
 */
static void test_purpose_2()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    
    GtkWidget *widget;
    GtkObject *adjustment;
    GtkObject *real_adjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = ADJUSTMENT;
    
    if (adjustment)
    {
        widget = gtk_hscale_new (GTK_ADJUSTMENT (adjustment));
    } else {
        widget = gtk_hscale_new (NULL);
    }
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_HSCALE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    
    if (adjustment)
    {
        if (((GtkAdjustment*)adjustment)->lower 
            != ((GtkAdjustment*)real_adjustment)->lower)
        {
            TEST_FAIL ("adjustment->lower = %d, real_adjustment->lower = %d",
                       ((GtkAdjustment*)adjustment)->lower, 
                       ((GtkAdjustment*)real_adjustment)->lower);
        }
        if (((GtkAdjustment*)adjustment)->upper 
            != ((GtkAdjustment*)real_adjustment)->upper)
        {
            TEST_FAIL ("adjustment->upper = %d, real_adjustment->upper = %d",
                       ((GtkAdjustment*)adjustment)->upper, 
                       ((GtkAdjustment*)real_adjustment)->upper);
        }
        if (((GtkAdjustment*)adjustment)->value
            != ((GtkAdjustment*)real_adjustment)->value)
        {
            TEST_FAIL ("adjustment->value = %d, real_adjustment->value = %d",
                       ((GtkAdjustment*)adjustment)->value, 
                       ((GtkAdjustment*)real_adjustment)->value);
        }
        if (((GtkAdjustment*)adjustment)->step_increment
            != ((GtkAdjustment*)real_adjustment)->step_increment)
        {
            TEST_FAIL ("adjustment->step_increment = %d, real_adjustment->step_increment = %d",
                       ((GtkAdjustment*)adjustment)->step_increment, 
                       ((GtkAdjustment*)real_adjustment)->step_increment);
        }
        if (((GtkAdjustment*)adjustment)->page_increment
            != ((GtkAdjustment*)real_adjustment)->page_increment)
        {
            TEST_FAIL ("adjustment->page_increment = %d, real_adjustment->page_increment = %d",
                       ((GtkAdjustment*)adjustment)->page_increment, 
                       ((GtkAdjustment*)real_adjustment)->page_increment);
        }
        if (((GtkAdjustment*)adjustment)->page_size
            != ((GtkAdjustment*)real_adjustment)->page_size)
        {
            TEST_FAIL ("adjustment->page_size = %d, real_adjustment->page_size = %d",
                       ((GtkAdjustment*)adjustment)->page_size, 
                       ((GtkAdjustment*)real_adjustment)->page_size);
        }
    } else {
        if (((GtkAdjustment*)real_adjustment)->lower)
        {
            TEST_FAIL ("real_adjustment->lower = %d, should be 0", ((GtkAdjustment*)real_adjustment)->lower);
        }
        if (((GtkAdjustment*)real_adjustment)->upper)
        {
            TEST_FAIL ("real_adjustment->upper = %d, should be 0", ((GtkAdjustment*)real_adjustment)->upper);
        }
        if (((GtkAdjustment*)real_adjustment)->value)
        {
            TEST_FAIL ("real_adjustment->value = %d, should be 0", ((GtkAdjustment*)real_adjustment)->value);
        }
        if (((GtkAdjustment*)real_adjustment)->step_increment)
        {
            TEST_FAIL ("real_adjustment->step_increment = %d, should be 0", ((GtkAdjustment*)real_adjustment)->step_increment);
        }
        if (((GtkAdjustment*)real_adjustment)->page_increment)
        {
            TEST_FAIL ("real_adjustment->page_increment = %d, should be 0", ((GtkAdjustment*)real_adjustment)->page_increment);
        }
        if (((GtkAdjustment*)real_adjustment)->page_size)
        {
            TEST_FAIL ("real_adjustment->page_size = %d, should be 0", ((GtkAdjustment*)real_adjustment)->page_size);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_hscale_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns:GtkHScale*
 * Assertion: Creates a new horizontal scale widget that lets the user input a number between min and max (including min and max) with the increment step.
 * Params Values: 0.0, 1.0, 1.0
 * Expected: GtkHScale*  
 */
static void test_purpose_3()
{
    #define MINIMUM 0.0
    #define MAXIMUM 1.0
    #define STEP 1.0
    
    GtkWidget *widget;
    GtkObject *real_adjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_hscale_new_with_range (MINIMUM, MAXIMUM, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_HSCALE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    
    if (real_adjustment)
    {
        if (((GtkAdjustment*)real_adjustment)->lower != MINIMUM)
        {
            TEST_FAIL ("real_adjustment->lower = %d, MINIMUM = %d",
                       ((GtkAdjustment*)real_adjustment)->lower, MINIMUM);
        }
        if (((GtkAdjustment*)real_adjustment)-> upper!= MAXIMUM)
        {
            TEST_FAIL ("real_adjustment->upper = %d, MAXIMUM = %d",
                       ((GtkAdjustment*)real_adjustment)->upper, MAXIMUM);
        }
        if (((GtkAdjustment*)real_adjustment)->step_increment != STEP)
        {
            TEST_FAIL ("real_adjustment->step_increment = %d, STEP = %d",
                       ((GtkAdjustment*)real_adjustment)->step_increment, STEP);
        } 
    } else {
        TEST_FAIL ("GtkHScale was created without adjustment", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MINIMUM
    #undef MAXIMUM
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_hscale_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns:GtkHScale*
 * Assertion: Creates a new horizontal scale widget that lets the user input a number between min and max (including min and max) with the increment step.
 * Params Values: 0.0, 100.0, 100.0
 * Expected: GtkHScale*  
 */
static void test_purpose_4()
{
    #define MINIMUM 0.0
    #define MAXIMUM 100.0
    #define STEP 100.0
    
    GtkWidget *widget;
    GtkObject *real_adjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_hscale_new_with_range (MINIMUM, MAXIMUM, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_HSCALE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    
    if (real_adjustment)
    {
        if (((GtkAdjustment*)real_adjustment)->lower != MINIMUM)
        {
            TEST_FAIL ("real_adjustment->lower = %d, MINIMUM = %d",
                       ((GtkAdjustment*)real_adjustment)->lower, MINIMUM);
        }
        if (((GtkAdjustment*)real_adjustment)-> upper!= MAXIMUM)
        {
            TEST_FAIL ("real_adjustment->upper = %d, MAXIMUM = %d",
                       ((GtkAdjustment*)real_adjustment)->upper, MAXIMUM);
        }
        if (((GtkAdjustment*)real_adjustment)->step_increment != STEP)
        {
            TEST_FAIL ("real_adjustment->step_increment = %d, STEP = %d",
                       ((GtkAdjustment*)real_adjustment)->step_increment, STEP);
        } 
    } else {
        TEST_FAIL ("GtkHScale was created without adjustment", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MINIMUM
    #undef MAXIMUM
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_hscale_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns:GtkHScale*
 * Assertion: Creates a new horizontal scale widget that lets the user input a number between min and max (including min and max) with the increment step.
 * Params Values: 0, 100, 50.49
 * Expected: GtkHScale*  
 */
static void test_purpose_5()
{
    #define MINIMUM 0
    #define MAXIMUM 100
    #define STEP 50.49
    
    GtkWidget *widget;
    GtkObject *real_adjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_hscale_new_with_range (MINIMUM, MAXIMUM, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_HSCALE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    
    if (real_adjustment)
    {
        if (((GtkAdjustment*)real_adjustment)->lower != MINIMUM)
        {
            TEST_FAIL ("real_adjustment->lower = %d, MINIMUM = %d",
                       ((GtkAdjustment*)real_adjustment)->lower, MINIMUM);
        }
        if (((GtkAdjustment*)real_adjustment)-> upper!= MAXIMUM)
        {
            TEST_FAIL ("real_adjustment->upper = %d, MAXIMUM = %d",
                       ((GtkAdjustment*)real_adjustment)->upper, MAXIMUM);
        }
        if (((GtkAdjustment*)real_adjustment)->step_increment != STEP)
        {
            TEST_FAIL ("real_adjustment->step_increment = %d, STEP = %d",
                       ((GtkAdjustment*)real_adjustment)->step_increment, STEP);
        } 
    } else {
        TEST_FAIL ("GtkHScale was created without adjustment", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MINIMUM
    #undef MAXIMUM
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_hscale_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns:GtkHScale*
 * Assertion: Creates a new horizontal scale widget that lets the user input a number between min and max (including min and max) with the increment step.
 * Params Values: 0, G_MAXDOUBLE, G_MAXDOUBLE / 2
 * Expected: GtkHScale*  
 */
static void test_purpose_6()
{
    #define MINIMUM 0
    #define MAXIMUM G_MAXDOUBLE
    #define STEP G_MAXDOUBLE / 2
    
    GtkWidget *widget;
    GtkObject *real_adjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_hscale_new_with_range (MINIMUM, MAXIMUM, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_HSCALE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    
    if (real_adjustment)
    {
        if (((GtkAdjustment*)real_adjustment)->lower != MINIMUM)
        {
            TEST_FAIL ("real_adjustment->lower = %d, MINIMUM = %d",
                       ((GtkAdjustment*)real_adjustment)->lower, MINIMUM);
        }
        if (((GtkAdjustment*)real_adjustment)-> upper!= MAXIMUM)
        {
            TEST_FAIL ("real_adjustment->upper = %d, MAXIMUM = %d",
                       ((GtkAdjustment*)real_adjustment)->upper, MAXIMUM);
        }
        if (((GtkAdjustment*)real_adjustment)->step_increment != STEP)
        {
            TEST_FAIL ("real_adjustment->step_increment = %d, STEP = %d",
                       ((GtkAdjustment*)real_adjustment)->step_increment, STEP);
        } 
    } else {
        TEST_FAIL ("GtkHScale was created without adjustment", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MINIMUM
    #undef MAXIMUM
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkHScale ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {NULL,0}
};
