/*
 * GtkImage methods tests
 * Testing GtkImage methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_image_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new empty GtkImage widget.
 * Params Values: void
 * Expected: GtkWidget*  
 */
static void test_purpose_1()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = gtk_image_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_file
 * Params: const gchar *filename
 * Returns: GtkImage*
 * Assertion: Creates a new GtkImage displaying the file filename.
 * Params Values: "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
 * Expected: GtkImage* with type <%1%>
 * 
 * Name: gtk_image_new_from_file
 * Params: const gchar *filename
 * Returns: GtkImage*
 * Assertion: This function never returns NULL, it always returns a valid GtkImage widget.
 * Params Values: "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
 * Expected: GtkImage* with type <%1%>  
 */
static void test_purpose_2()
{
    #define IMAGE_FILE_NAME  "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    
    GtkWidget *widget;
    gchar *filename = calloc (1, 1024);
    gchar *tet_root = calloc (1, 1024); 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    filename = strcat (filename, tet_root);
    filename = strcat (filename, IMAGE_FILE_NAME);
    
    widget = gtk_image_new_from_file (filename);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IMAGE_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_file
 * Params: const gchar *filename
 * Returns: GtkImage*
 * Assertion: Creates a new GtkImage displaying the file filename.
 * Params Values: "Text"
 * Expected: GtkImage* with type <%1%>
 * 
 * Name: gtk_image_new_from_file
 * Params: const gchar *filename
 * Returns: GtkImage*
 * Assertion: This function never returns NULL, it always returns a valid GtkImage widget.
 * Params Values: "Text"
 * Expected: GtkImage* with type <%1%>  
 */
static void test_purpose_3()
{
    #define IMAGE_FILE_NAME  "Text"
    
    GtkWidget *widget;
    gchar *filename = calloc (1, 1024);
    gchar *tet_root = calloc (1, 1024); 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    filename = strcat (filename, tet_root);
    filename = strcat (filename, IMAGE_FILE_NAME);
    
    widget = gtk_image_new_from_file (filename);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IMAGE_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_icon_set
 * Params: GtkIconSet *icon_set, GtkIconSize size
 * Returns: GtkImage* 
 * Assertion: Creates a GtkImage displaying an icon set.
 * Params Values: gtk_icon_set_new (), GTK_ICON_SIZE_MENU
 * Expected: GtkImage* with type GTK_IMAGE_ICON_SET  
 */
static void test_purpose_4()
{
    #define ICON_SET gtk_icon_set_new ()
    #define SIZE  GTK_ICON_SIZE_MENU
    #define GTK_IMAGE_TYPE_CORRECT GTK_IMAGE_ICON_SET
    
    GtkWidget *widget;
    GtkIconSet* iconset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    iconset = ICON_SET;
    
    widget = gtk_image_new_from_icon_set (iconset, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_TYPE_CORRECT)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_TYPE_CORRECT); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ICON_SET
    #undef SIZE
    #undef GTK_IMAGE_TYPE_CORRECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_icon_set
 * Params: GtkIconSet *icon_set, GtkIconSize size
 * Returns: GtkImage* 
 * Assertion: Creates a GtkImage displaying an icon set.
 * Params Values: gtk_icon_set_new (), GTK_ICON_SIZE_SMALL_TOOLBAR 
 * Expected: GtkImage* with type GTK_IMAGE_ICON_SET  
 */
static void test_purpose_5()
{
    #define ICON_SET gtk_icon_set_new ()
    #define SIZE  GTK_ICON_SIZE_SMALL_TOOLBAR 
    #define GTK_IMAGE_TYPE_CORRECT GTK_IMAGE_ICON_SET
    
    GtkWidget *widget;
    GtkIconSet* iconset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    iconset = ICON_SET;
    
    widget = gtk_image_new_from_icon_set (iconset, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_TYPE_CORRECT)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_TYPE_CORRECT); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ICON_SET
    #undef SIZE
    #undef GTK_IMAGE_TYPE_CORRECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_icon_set
 * Params: GtkIconSet *icon_set, GtkIconSize size
 * Returns: GtkImage* 
 * Assertion: Creates a GtkImage displaying an icon set.
 * Params Values: gtk_icon_set_new (), GTK_ICON_SIZE_LARGE_TOOLBAR
 * Expected: GtkImage* with type GTK_IMAGE_ICON_SET  
 */
static void test_purpose_6()
{
    #define ICON_SET gtk_icon_set_new ()
    #define SIZE  GTK_ICON_SIZE_LARGE_TOOLBAR
    #define GTK_IMAGE_TYPE_CORRECT GTK_IMAGE_ICON_SET
    
    GtkWidget *widget;
    GtkIconSet* iconset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    iconset = ICON_SET;
    
    widget = gtk_image_new_from_icon_set (iconset, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_TYPE_CORRECT)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_TYPE_CORRECT); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ICON_SET
    #undef SIZE
    #undef GTK_IMAGE_TYPE_CORRECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_icon_set
 * Params: GtkIconSet *icon_set, GtkIconSize size
 * Returns: GtkImage* 
 * Assertion: Creates a GtkImage displaying an icon set.
 * Params Values: gtk_icon_set_new (), GTK_ICON_SIZE_BUTTON
 * Expected: GtkImage* with type GTK_IMAGE_ICON_SET  
 */
static void test_purpose_7()
{
    #define ICON_SET gtk_icon_set_new ()
    #define SIZE  GTK_ICON_SIZE_BUTTON
    #define GTK_IMAGE_TYPE_CORRECT GTK_IMAGE_ICON_SET
    
    GtkWidget *widget;
    GtkIconSet* iconset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    iconset = ICON_SET;
    
    widget = gtk_image_new_from_icon_set (iconset, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_TYPE_CORRECT)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_TYPE_CORRECT); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ICON_SET
    #undef SIZE
    #undef GTK_IMAGE_TYPE_CORRECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_icon_set
 * Params: GtkIconSet *icon_set, GtkIconSize size
 * Returns: GtkImage* 
 * Assertion: Creates a GtkImage displaying an icon set.
 * Params Values: gtk_icon_set_new (), GTK_ICON_SIZE_DIALOG
 * Expected: GtkImage* with type GTK_IMAGE_ICON_SET  
 */
static void test_purpose_8()
{
    #define ICON_SET gtk_icon_set_new ()
    #define SIZE  GTK_ICON_SIZE_DIALOG
    #define GTK_IMAGE_TYPE_CORRECT GTK_IMAGE_ICON_SET
    
    GtkWidget *widget;
    GtkIconSet* iconset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    iconset = ICON_SET;
    
    widget = gtk_image_new_from_icon_set (iconset, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_TYPE_CORRECT)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_TYPE_CORRECT); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ICON_SET
    #undef SIZE
    #undef GTK_IMAGE_TYPE_CORRECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_icon_set
 * Params: GtkIconSet *icon_set, GtkIconSize size
 * Returns: GtkImage* 
 * Assertion: Creates a GtkImage displaying an icon set.
 * Params Values: gtk_icon_set_new (), GTK_ICON_SIZE_DND
 * Expected: GtkImage* with type GTK_IMAGE_ICON_SET  
 */
static void test_purpose_9()
{
    #define ICON_SET gtk_icon_set_new ()
    #define SIZE  GTK_ICON_SIZE_DND
    #define GTK_IMAGE_TYPE_CORRECT GTK_IMAGE_ICON_SET
    
    GtkWidget *widget;
    GtkIconSet* iconset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    iconset = ICON_SET;
    
    widget = gtk_image_new_from_icon_set (iconset, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_TYPE_CORRECT)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_TYPE_CORRECT); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ICON_SET
    #undef SIZE
    #undef GTK_IMAGE_TYPE_CORRECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_image
 * Params: GdkImage *image, GdkBitmap *mask
 * Returns: GtkImage* 
 * Assertion: Creates a GtkImage widget displaying a image with a mask.
 * Params Values: gdk_image_new (GDK_IMAGE_FASTEST,  gdk_visual_get_best(), 1, 1), NULL
 * Expected: GtkImage* with type GTK_IMAGE_IMAGE  
 */
static void test_purpose_10()
{
    #define GDK_IMG gdk_image_new (GDK_IMAGE_FASTEST,  gdk_visual_get_best(), 1, 1)
    #define GDK_BITMAP NULL
    #define GTK_IMAGE_TYPE_CORRECT GTK_IMAGE_IMAGE
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_new_from_image (GDK_IMG, GDK_BITMAP);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_TYPE_CORRECT)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_TYPE_CORRECT); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef GDK_IMG
    #undef GDK_BITMAP
    #undef GTK_IMAGE_TYPE_CORRECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_pixbuf
 * Params: GdkPixbuf *pixbuf
 * Returns: GtkImage* 
 * Assertion: Creates a new GtkImage displaying pixbuf.
 * Params Values: "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
 * Expected: GtkImage* with type GTK_IMAGE_PIXBUF  
 */
static void test_purpose_11()
{
    #define IMAGE_FILE_NAME "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    #define GTK_IMAGE_TYPE_CORRECT GTK_IMAGE_PIXBUF
    
    GtkWidget *widget;
    GtkWidget *image;
    GdkPixbuf *pixbuf;
    gchar *filename = calloc (1, 1024);
    gchar *tet_root = calloc (1, 1024); 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (IMAGE_FILE_NAME)
    {
        tet_root = getenv ("TET_ROOT");
        filename = strcat (filename, tet_root);
        filename = strcat (filename, IMAGE_FILE_NAME);
        image = gtk_image_new_from_file (filename);
        pixbuf = gtk_image_get_pixbuf (GTK_IMAGE (image));
    } else {
        pixbuf = NULL;
    }
    
    widget = gtk_image_new_from_pixbuf (pixbuf);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_TYPE_CORRECT)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_TYPE_CORRECT); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IMAGE_FILE_NAME
    #undef GTK_IMAGE_TYPE_CORRECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_pixbuf
 * Params: GdkPixbuf *pixbuf
 * Returns: GtkImage* 
 * Assertion: Creates a new GtkImage displaying pixbuf.
 * Params Values: NULL
 * Expected: GtkImage* with type GTK_IMAGE_EMPTY  
 */
static void test_purpose_12()
{
    #define IMAGE_FILE_NAME NULL
    #define GTK_IMAGE_TYPE_CORRECT GTK_IMAGE_EMPTY
    
    GtkWidget *widget;
    GtkWidget *image;
    GdkPixbuf *pixbuf;
    gchar *filename = calloc (1, 1024);
    gchar *tet_root = calloc (1, 1024); 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (IMAGE_FILE_NAME)
    {
        tet_root = getenv ("TET_ROOT");
        filename = strcat (filename, tet_root);
        filename = strcat (filename, IMAGE_FILE_NAME);
        image = gtk_image_new_from_file (filename);
        pixbuf = gtk_image_get_pixbuf (GTK_IMAGE (image));
    } else {
        pixbuf = NULL;
    }
    
    widget = gtk_image_new_from_pixbuf (pixbuf);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_TYPE_CORRECT)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_TYPE_CORRECT); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IMAGE_FILE_NAME
    #undef GTK_IMAGE_TYPE_CORRECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_animation
 * Params: GdkPixbufAnimation *animation
 * Returns: GtkWidget*
 * Assertion: Creates a GtkImage displaying the given animation. 
 * Params Values: "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
 * Expected: GtkImage*  
 */
static void test_purpose_13()
{
    #define FILENAME "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    
    GtkWidget *widget;
    GdkPixbufAnimation* animation;
    GError **error = NULL;
    gchar *filename = calloc (1, 1024);
    gchar *tet_root = calloc (1, 1024); 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    filename = strcat (filename, tet_root);
    filename = strcat (filename, FILENAME);
    
    animation = gdk_pixbuf_animation_new_from_file (filename, error);
    
    widget = gtk_image_new_from_animation (animation);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_ANIMATION)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_ANIMATION); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FILENAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_image_get_pixbuf 
 * Params: GtkImage *image
 * Returns: GdkPixbuf*
 * Assertion: Gets the GdkPixbuf being displayed by the GtkImage.
 * Params Values: a newly created GtkImage
 * Expected: GdkPixbuf*
 * 
 * Name: gtk_image_set_from_pixbuf  
 * Params: GtkImage *image, GdkPixbuf *pixbuf
 * Returns: void
 * Assertion: See gtk_image_new_from_pixbuf() for details.
 * Params Values: a newly created GtkImage, GdkPixbuf*
 * Expected: void  
 */
static void test_purpose_14()
{
    #define PIXBUF NULL
    
    GtkWidget* widget;
    GdkPixbuf* pixbuf;
    GdkPixbuf* real_pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_new_from_pixmap (gdk_pixmap_new (NULL, 1, 1, 1),NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    real_pixbuf = PIXBUF;
    gtk_image_set_from_pixbuf (GTK_IMAGE (widget), real_pixbuf);
    
    pixbuf = gtk_image_get_pixbuf (GTK_IMAGE (widget));
    if(pixbuf != real_pixbuf)
    {
        TEST_FAIL ("pixbuf = '%p', should be '%p'",pixbuf,real_pixbuf);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PIXBUF
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_set_from_file
 * Params: GtkImage *image,const gchar *filename
 * Returns: void
 * Assertion: See gtk_image_new_from_file() for details.
 * Params Values: "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
 * Expected: void  
 */
static void test_purpose_15()
{
    #define IMAGE_FILE_NAME  "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    
    GtkWidget *widget;
    gchar *filename = calloc (1, 1024);
    gchar *tet_root = calloc (1, 1024); 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    filename = strcat (filename, tet_root);
    filename = strcat (filename, IMAGE_FILE_NAME);
    
    widget = gtk_image_new_from_image ( gdk_image_new (GDK_IMAGE_FASTEST,  gdk_visual_get_best(), 1, 1), NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_image_set_from_file (GTK_IMAGE (widget), filename);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IMAGE_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_set_from_file
 * Params: GtkImage *image,const gchar *filename
 * Returns: void
 * Assertion: See gtk_image_new_from_file() for details.
 * Params Values: "Text"
 * Expected: void  
 */
static void test_purpose_16()
{
    #define IMAGE_FILE_NAME  "Text"
    
    GtkWidget *widget;
    gchar *filename = calloc (1, 1024);
    gchar *tet_root = calloc (1, 1024); 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    filename = strcat (filename, tet_root);
    filename = strcat (filename, IMAGE_FILE_NAME);
    
    widget = gtk_image_new_from_image ( gdk_image_new (GDK_IMAGE_FASTEST,  gdk_visual_get_best(), 1, 1), NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_image_set_from_file (GTK_IMAGE (widget), filename);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IMAGE_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_image_get_icon_set
 * Params: GtkImage *image, GtkIconSet **icon_set, GtkIconSize *size
 * Returns: void
 * Assertion:Gets the icon set and size being displayed by the GtkImage.
 * Params Values: a newly created GtkWindow of type GTK_ICON_SIZE_MENU, <%1%>
 * Expected: void
 * 
 * Name:  gtk_image_set_from_icon_set
 * Params: GtkImage *image, GtkIconSet *icon_set, GtkIconSize size
 * Returns: void
 * Assertion: See gtk_image_new_from_icon_set() for details.
 * Params Values: a newly created GtkWindow of type GTK_ICON_SIZE_MENU
 * Expected: void  
 */
static void test_purpose_17()
{
    #define SIZE  GTK_ICON_SIZE_MENU
    
    GtkWidget *widget;
    GtkIconSet *icon_set;
    GtkIconSet *real_icon_set;
    GtkIconSize size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    icon_set = gtk_icon_set_new ();
    widget = gtk_image_new_from_icon_set (icon_set, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if ( gtk_image_get_storage_type (GTK_IMAGE (widget))!= GTK_IMAGE_ICON_SET &&
         gtk_image_get_storage_type (GTK_IMAGE (widget))!= GTK_IMAGE_EMPTY)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_image_set_from_icon_set (GTK_IMAGE (widget),icon_set,SIZE);
    
    gtk_image_get_icon_set (GTK_IMAGE (widget),&real_icon_set,&size);
    if(icon_set != real_icon_set)
    {
        TEST_FAIL ("icon_set = '%s', should be '%s'", icon_set,real_icon_set);
    }
    if(size != SIZE)
    {
        TEST_FAIL ("size = '%s', should be '%s'", &size, SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SIZE  
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_image_get_icon_set
 * Params: GtkImage *image, GtkIconSet **icon_set, GtkIconSize *size
 * Returns: void
 * Assertion:Gets the icon set and size being displayed by the GtkImage.
 * Params Values: a newly created GtkWindow of type GTK_ICON_SIZE_SMALL_TOOLBAR, <%1%>
 * Expected: void
 * 
 * Name:  gtk_image_set_from_icon_set
 * Params: GtkImage *image, GtkIconSet *icon_set, GtkIconSize size
 * Returns: void
 * Assertion: See gtk_image_new_from_icon_set() for details.
 * Params Values: a newly created GtkWindow of type GTK_ICON_SIZE_SMALL_TOOLBAR
 * Expected: void  
 */
static void test_purpose_18()
{
    #define SIZE  GTK_ICON_SIZE_SMALL_TOOLBAR
    
    GtkWidget *widget;
    GtkIconSet *icon_set;
    GtkIconSet *real_icon_set;
    GtkIconSize size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    icon_set = gtk_icon_set_new ();
    widget = gtk_image_new_from_icon_set (icon_set, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if ( gtk_image_get_storage_type (GTK_IMAGE (widget))!= GTK_IMAGE_ICON_SET &&
         gtk_image_get_storage_type (GTK_IMAGE (widget))!= GTK_IMAGE_EMPTY)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_image_set_from_icon_set (GTK_IMAGE (widget),icon_set,SIZE);
    
    gtk_image_get_icon_set (GTK_IMAGE (widget),&real_icon_set,&size);
    if(icon_set != real_icon_set)
    {
        TEST_FAIL ("icon_set = '%s', should be '%s'", icon_set,real_icon_set);
    }
    if(size != SIZE)
    {
        TEST_FAIL ("size = '%s', should be '%s'", &size, SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SIZE  
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_image_get_icon_set
 * Params: GtkImage *image, GtkIconSet **icon_set, GtkIconSize *size
 * Returns: void
 * Assertion:Gets the icon set and size being displayed by the GtkImage.
 * Params Values: a newly created GtkWindow of type GTK_ICON_SIZE_LARGE_TOOLBAR, <%1%>
 * Expected: void
 * 
 * Name:  gtk_image_set_from_icon_set
 * Params: GtkImage *image, GtkIconSet *icon_set, GtkIconSize size
 * Returns: void
 * Assertion: See gtk_image_new_from_icon_set() for details.
 * Params Values: a newly created GtkWindow of type GTK_ICON_SIZE_LARGE_TOOLBAR
 * Expected: void  
 */
static void test_purpose_19()
{
    #define SIZE  GTK_ICON_SIZE_LARGE_TOOLBAR
    
    GtkWidget *widget;
    GtkIconSet *icon_set;
    GtkIconSet *real_icon_set;
    GtkIconSize size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    icon_set = gtk_icon_set_new ();
    widget = gtk_image_new_from_icon_set (icon_set, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if ( gtk_image_get_storage_type (GTK_IMAGE (widget))!= GTK_IMAGE_ICON_SET &&
         gtk_image_get_storage_type (GTK_IMAGE (widget))!= GTK_IMAGE_EMPTY)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_image_set_from_icon_set (GTK_IMAGE (widget),icon_set,SIZE);
    
    gtk_image_get_icon_set (GTK_IMAGE (widget),&real_icon_set,&size);
    if(icon_set != real_icon_set)
    {
        TEST_FAIL ("icon_set = '%s', should be '%s'", icon_set,real_icon_set);
    }
    if(size != SIZE)
    {
        TEST_FAIL ("size = '%s', should be '%s'", &size, SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SIZE  
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_image_get_icon_set
 * Params: GtkImage *image, GtkIconSet **icon_set, GtkIconSize *size
 * Returns: void
 * Assertion:Gets the icon set and size being displayed by the GtkImage.
 * Params Values: a newly created GtkWindow of type GTK_ICON_SIZE_BUTTON, <%1%>
 * Expected: void
 * 
 * Name:  gtk_image_set_from_icon_set
 * Params: GtkImage *image, GtkIconSet *icon_set, GtkIconSize size
 * Returns: void
 * Assertion: See gtk_image_new_from_icon_set() for details.
 * Params Values: a newly created GtkWindow of type GTK_ICON_SIZE_BUTTON
 * Expected: void  
 */
static void test_purpose_20()
{
    #define SIZE  GTK_ICON_SIZE_BUTTON
    
    GtkWidget *widget;
    GtkIconSet *icon_set;
    GtkIconSet *real_icon_set;
    GtkIconSize size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    icon_set = gtk_icon_set_new ();
    widget = gtk_image_new_from_icon_set (icon_set, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if ( gtk_image_get_storage_type (GTK_IMAGE (widget))!= GTK_IMAGE_ICON_SET &&
         gtk_image_get_storage_type (GTK_IMAGE (widget))!= GTK_IMAGE_EMPTY)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_image_set_from_icon_set (GTK_IMAGE (widget),icon_set,SIZE);
    
    gtk_image_get_icon_set (GTK_IMAGE (widget),&real_icon_set,&size);
    if(icon_set != real_icon_set)
    {
        TEST_FAIL ("icon_set = '%s', should be '%s'", icon_set,real_icon_set);
    }
    if(size != SIZE)
    {
        TEST_FAIL ("size = '%s', should be '%s'", &size, SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SIZE  
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_image_get_icon_set
 * Params: GtkImage *image, GtkIconSet **icon_set, GtkIconSize *size
 * Returns: void
 * Assertion:Gets the icon set and size being displayed by the GtkImage.
 * Params Values: a newly created GtkWindow of type GTK_ICON_SIZE_DIALOG, <%1%>
 * Expected: void
 * 
 * Name:  gtk_image_set_from_icon_set
 * Params: GtkImage *image, GtkIconSet *icon_set, GtkIconSize size
 * Returns: void
 * Assertion: See gtk_image_new_from_icon_set() for details.
 * Params Values: a newly created GtkWindow of type GTK_ICON_SIZE_DIALOG
 * Expected: void  
 */
static void test_purpose_21()
{
    #define SIZE  GTK_ICON_SIZE_DIALOG
    
    GtkWidget *widget;
    GtkIconSet *icon_set;
    GtkIconSet *real_icon_set;
    GtkIconSize size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    icon_set = gtk_icon_set_new ();
    widget = gtk_image_new_from_icon_set (icon_set, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if ( gtk_image_get_storage_type (GTK_IMAGE (widget))!= GTK_IMAGE_ICON_SET &&
         gtk_image_get_storage_type (GTK_IMAGE (widget))!= GTK_IMAGE_EMPTY)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_image_set_from_icon_set (GTK_IMAGE (widget),icon_set,SIZE);
    
    gtk_image_get_icon_set (GTK_IMAGE (widget),&real_icon_set,&size);
    if(icon_set != real_icon_set)
    {
        TEST_FAIL ("icon_set = '%s', should be '%s'", icon_set,real_icon_set);
    }
    if(size != SIZE)
    {
        TEST_FAIL ("size = '%s', should be '%s'", &size, SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SIZE  
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_image_get_icon_set
 * Params: GtkImage *image, GtkIconSet **icon_set, GtkIconSize *size
 * Returns: void
 * Assertion:Gets the icon set and size being displayed by the GtkImage.
 * Params Values: a newly created GtkWindow of type GTK_ICON_SIZE_DND, <%1%>
 * Expected: void
 * 
 * Name:  gtk_image_set_from_icon_set
 * Params: GtkImage *image, GtkIconSet *icon_set, GtkIconSize size
 * Returns: void
 * Assertion: See gtk_image_new_from_icon_set() for details.
 * Params Values: a newly created GtkWindow of type GTK_ICON_SIZE_DND
 * Expected: void  
 */
static void test_purpose_22()
{
    #define SIZE  GTK_ICON_SIZE_DND
    
    GtkWidget *widget;
    GtkIconSet *icon_set;
    GtkIconSet *real_icon_set;
    GtkIconSize size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    icon_set = gtk_icon_set_new ();
    widget = gtk_image_new_from_icon_set (icon_set, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if ( gtk_image_get_storage_type (GTK_IMAGE (widget))!= GTK_IMAGE_ICON_SET &&
         gtk_image_get_storage_type (GTK_IMAGE (widget))!= GTK_IMAGE_EMPTY)
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_image_set_from_icon_set (GTK_IMAGE (widget),icon_set,SIZE);
    
    gtk_image_get_icon_set (GTK_IMAGE (widget),&real_icon_set,&size);
    if(icon_set != real_icon_set)
    {
        TEST_FAIL ("icon_set = '%s', should be '%s'", icon_set,real_icon_set);
    }
    if(size != SIZE)
    {
        TEST_FAIL ("size = '%s', should be '%s'", &size, SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SIZE  
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_image_get_image
 * Params: GtkImage *image, GdkImage **gdk_image, GdkBitmap **mask
 * Returns: void
 * Assertion: Gets the GdkImage and mask being displayed by the GtkImage.
 * Params Values: a newly created GtkImage, GdkImage**, GdkBitmap**
 * Expected: void
 * 
 * Name:  gtk_image_set_from_image
 * Params: GtkImage *image, GdkImage *gdk_image, GdkBitmap *mask
 * Returns: void
 * Assertion: See gtk_image_new_from_image() for details.
 * Params Values: a newly created GtkImage, GdkImage*, GdkBitmap*
 * Expected: void  
 */
static void test_purpose_23()
{
    #define GDK_IMG gdk_image_new (GDK_IMAGE_FASTEST,  gdk_visual_get_best(), 1, 1)
    #define GDK_BITMAP NULL
    
    GtkWidget* widget;
    GdkImage* gdk_image;
    GdkBitmap* bitmap;
    GdkImage* img;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_new_from_image (GDK_IMG, GDK_BITMAP);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    img = GDK_IMG;
    gtk_image_set_from_image(GTK_IMAGE (widget), img, GDK_BITMAP); 
    
    gtk_image_get_image(GTK_IMAGE (widget), &gdk_image, &bitmap); 
    if(gdk_image != img)
    {
        TEST_FAIL ("GdkImage is not correct", NULL); 
    }
    if(bitmap != GDK_BITMAP)
    {
        TEST_FAIL ("GdkBitmap is not correct", NULL); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef GDK_IMG 
    #undef GDK_BITMAP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_get_storage_type
 * Params: GtkImage *image
 * Returns: GtkImageType
 * Assertion: Gets the type of representation being used by the GtkImage to store image data.
 * Params Values: a newly created GtkImage*
 * Expected: GtkImageType  
 */
static void test_purpose_24()
{
    GtkWidget *widget;
    GtkImageType image_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = gtk_image_new_from_image ( gdk_image_new (GDK_IMAGE_FASTEST,  gdk_visual_get_best(), 1, 1), NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    image_type = gtk_image_get_storage_type (GTK_IMAGE (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_get_storage_type
 * Params: GtkImage *image
 * Returns: GtkImageType
 * Assertion: If the GtkImage has no image data, the return value will be GTK_IMAGE_EMPTY.
 * Params Values: a newly created GtkImage*
 * Expected: GtkImageType  
 */
static void test_purpose_25()
{
    GtkWidget *widget;
    GtkImageType image_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = gtk_image_new_from_image ( NULL, NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    image_type = gtk_image_get_storage_type (GTK_IMAGE (widget));
    if (image_type != GTK_IMAGE_EMPTY)
    {
        TEST_FAIL ("Type of image is '%s', should be GTK_IMAGE_EMPTY",image_type,NULL);
    } 
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_get_animation 
 * Params: GtkImage *image
 * Returns: GdkPixbufAnimation*
 * Assertion: Gets the GdkPixbufAnimation being displayed by the GtkImage.
 * Params Values: a newly created GtkImage*
 * Expected: GdkPixbufAnimation*
 * 
 * Name: gtk_image_set_from_animation 
 * Params: GtkImage *image, GdkPixbufAnimation *animation
 * Returns: GdkPixbufAnimation*
 * Assertion: Causes the GtkImage to display the given animation (or display nothing, if you set the animation to NULL).
 * Params Values: a newly created GtkImage*
 * Expected: GdkPixbufAnimation*  
 */
static void test_purpose_26()
{
    #define FILENAME "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    
    GtkWidget *widget;
    GtkImageType image_type;
    GdkPixbufAnimation* animation;
    GError **error = NULL;
    gchar *filename = calloc (1, 1024);
    gchar *tet_root = calloc (1, 1024); 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    filename = strcat (filename, tet_root);
    filename = strcat (filename, FILENAME);
    
    animation = gdk_pixbuf_animation_new_from_file (filename, error);
    
    widget = gtk_image_new_from_image (NULL, NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    image_type = gtk_image_get_storage_type (GTK_IMAGE (widget));
    if ((image_type != GTK_IMAGE_EMPTY) && (image_type != GTK_IMAGE_ANIMATION))
    {
        TEST_FAIL ("Type of image is '%s', should be GTK_IMAGE_EMPTY or GTK_IMAGE_ANIMATION",image_type,NULL);
    } 
    gtk_image_set_from_animation (GTK_IMAGE (widget), animation);
    gtk_image_get_animation(GTK_IMAGE (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_get_stock
 * Params: GtkImage *image,gchar **stock_id,GtkIconSize *size
 * Returns: void
 * Assertion: Gets the stock icon name and size being displayed by the GtkImage. 
 * Params Values: a newly created GtkImage*
 * Expected: void
 * 
 * Name: gtk_image_set_from_stock
 * Params: GtkImage *image,const gchar *stock_id,GtkIconSize *size
 * Returns: void
 * Assertion: See gtk_image_new_from_stock() for details.
 * Params Values: a newly created GtkImage*
 * Expected: void  
 */
static void test_purpose_27()
{
    #define STOCK_ID GTK_STOCK_OPEN
    #define SIZE GTK_ICON_SIZE_MENU
    
    GtkWidget *widget;
    GtkImageType image_type;
    gchar* stock;
    GtkIconSize size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = gtk_image_new_from_image ( NULL, NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    image_type = gtk_image_get_storage_type (GTK_IMAGE (widget));
    if ( (image_type != GTK_IMAGE_EMPTY) && (image_type != GTK_IMAGE_STOCK))
    {
        TEST_FAIL ("Type of image is '%s', should be GTK_IMAGE_EMPTY or GTK_IMAGE_STOCK",image_type,NULL);
    } 
    
    gtk_image_set_from_stock (GTK_IMAGE (widget),STOCK_ID,SIZE);
    
    gtk_image_get_stock (GTK_IMAGE (widget),&stock,&size);
    
    if (strcmp (STOCK_ID,stock))
    {
        TEST_FAIL ("Stock is %s, should be %s",stock,STOCK_ID);
    }
    if (size != SIZE)
    {
        TEST_FAIL ("Size is %s, should be %s",size,SIZE);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STOCK_ID
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_get_stock
 * Params: GtkImage *image,gchar **stock_id,GtkIconSize *size
 * Returns: void
 * Assertion: Gets the stock icon name and size being displayed by the GtkImage. 
 * Params Values: a newly created GtkImage*
 * Expected: void
 * 
 * Name: gtk_image_set_from_stock
 * Params: GtkImage *image,const gchar *stock_id,GtkIconSize *size
 * Returns: void
 * Assertion: See gtk_image_new_from_stock() for details.
 * Params Values: a newly created GtkImage*
 * Expected: void  
 */
static void test_purpose_28()
{
    #define STOCK_ID GTK_STOCK_QUIT
    #define SIZE GTK_ICON_SIZE_SMALL_TOOLBAR
    
    GtkWidget *widget;
    GtkImageType image_type;
    gchar* stock;
    GtkIconSize size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = gtk_image_new_from_image ( NULL, NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    image_type = gtk_image_get_storage_type (GTK_IMAGE (widget));
    if ( (image_type != GTK_IMAGE_EMPTY) && (image_type != GTK_IMAGE_STOCK))
    {
        TEST_FAIL ("Type of image is '%s', should be GTK_IMAGE_EMPTY or GTK_IMAGE_STOCK",image_type,NULL);
    } 
    
    gtk_image_set_from_stock (GTK_IMAGE (widget),STOCK_ID,SIZE);
    
    gtk_image_get_stock (GTK_IMAGE (widget),&stock,&size);
    
    if (strcmp (STOCK_ID,stock))
    {
        TEST_FAIL ("Stock is %s, should be %s",stock,STOCK_ID);
    }
    if (size != SIZE)
    {
        TEST_FAIL ("Size is %s, should be %s",size,SIZE);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STOCK_ID
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_get_stock
 * Params: GtkImage *image,gchar **stock_id,GtkIconSize *size
 * Returns: void
 * Assertion: Gets the stock icon name and size being displayed by the GtkImage. 
 * Params Values: a newly created GtkImage*
 * Expected: void
 * 
 * Name: gtk_image_set_from_stock
 * Params: GtkImage *image,const gchar *stock_id,GtkIconSize *size
 * Returns: void
 * Assertion: See gtk_image_new_from_stock() for details.
 * Params Values: a newly created GtkImage*
 * Expected: void  
 */
static void test_purpose_29()
{
    #define STOCK_ID GTK_STOCK_QUIT
    #define SIZE GTK_ICON_SIZE_LARGE_TOOLBAR
    
    GtkWidget *widget;
    GtkImageType image_type;
    gchar* stock;
    GtkIconSize size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = gtk_image_new_from_image ( NULL, NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    image_type = gtk_image_get_storage_type (GTK_IMAGE (widget));
    if ( (image_type != GTK_IMAGE_EMPTY) && (image_type != GTK_IMAGE_STOCK))
    {
        TEST_FAIL ("Type of image is '%s', should be GTK_IMAGE_EMPTY or GTK_IMAGE_STOCK",image_type,NULL);
    } 
    
    gtk_image_set_from_stock (GTK_IMAGE (widget),STOCK_ID,SIZE);
    
    gtk_image_get_stock (GTK_IMAGE (widget),&stock,&size);
    
    if (strcmp (STOCK_ID,stock))
    {
        TEST_FAIL ("Stock is %s, should be %s",stock,STOCK_ID);
    }
    if (size != SIZE)
    {
        TEST_FAIL ("Size is %s, should be %s",size,SIZE);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STOCK_ID
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_get_stock
 * Params: GtkImage *image,gchar **stock_id,GtkIconSize *size
 * Returns: void
 * Assertion: Gets the stock icon name and size being displayed by the GtkImage. 
 * Params Values: a newly created GtkImage*
 * Expected: void
 * 
 * Name: gtk_image_set_from_stock
 * Params: GtkImage *image,const gchar *stock_id,GtkIconSize *size
 * Returns: void
 * Assertion: See gtk_image_new_from_stock() for details.
 * Params Values: a newly created GtkImage*
 * Expected: void  
 */
static void test_purpose_30()
{
    #define STOCK_ID GTK_STOCK_QUIT
    #define SIZE GTK_ICON_SIZE_BUTTON
    
    GtkWidget *widget;
    GtkImageType image_type;
    gchar* stock;
    GtkIconSize size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = gtk_image_new_from_image ( NULL, NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    image_type = gtk_image_get_storage_type (GTK_IMAGE (widget));
    if ( (image_type != GTK_IMAGE_EMPTY) && (image_type != GTK_IMAGE_STOCK))
    {
        TEST_FAIL ("Type of image is '%s', should be GTK_IMAGE_EMPTY or GTK_IMAGE_STOCK",image_type,NULL);
    } 
    
    gtk_image_set_from_stock (GTK_IMAGE (widget),STOCK_ID,SIZE);
    
    gtk_image_get_stock (GTK_IMAGE (widget),&stock,&size);
    
    if (strcmp (STOCK_ID,stock))
    {
        TEST_FAIL ("Stock is %s, should be %s",stock,STOCK_ID);
    }
    if (size != SIZE)
    {
        TEST_FAIL ("Size is %s, should be %s",size,SIZE);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STOCK_ID
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_get_stock
 * Params: GtkImage *image,gchar **stock_id,GtkIconSize *size
 * Returns: void
 * Assertion: Gets the stock icon name and size being displayed by the GtkImage. 
 * Params Values: a newly created GtkImage*
 * Expected: void
 * 
 * Name: gtk_image_set_from_stock
 * Params: GtkImage *image,const gchar *stock_id,GtkIconSize *size
 * Returns: void
 * Assertion: See gtk_image_new_from_stock() for details.
 * Params Values: a newly created GtkImage*
 * Expected: void  
 */
static void test_purpose_31()
{
    #define STOCK_ID GTK_STOCK_QUIT
    #define SIZE GTK_ICON_SIZE_DND
    
    GtkWidget *widget;
    GtkImageType image_type;
    gchar* stock;
    GtkIconSize size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = gtk_image_new_from_image ( NULL, NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    image_type = gtk_image_get_storage_type (GTK_IMAGE (widget));
    if ( (image_type != GTK_IMAGE_EMPTY) && (image_type != GTK_IMAGE_STOCK))
    {
        TEST_FAIL ("Type of image is '%s', should be GTK_IMAGE_EMPTY or GTK_IMAGE_STOCK",image_type,NULL);
    } 
    
    gtk_image_set_from_stock (GTK_IMAGE (widget),STOCK_ID,SIZE);
    
    gtk_image_get_stock (GTK_IMAGE (widget),&stock,&size);
    
    if (strcmp (STOCK_ID,stock))
    {
        TEST_FAIL ("Stock is %s, should be %s",stock,STOCK_ID);
    }
    if (size != SIZE)
    {
        TEST_FAIL ("Size is %s, should be %s",size,SIZE);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STOCK_ID
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_get_stock
 * Params: GtkImage *image,gchar **stock_id,GtkIconSize *size
 * Returns: void
 * Assertion: Gets the stock icon name and size being displayed by the GtkImage. 
 * Params Values: a newly created GtkImage*
 * Expected: void
 * 
 * Name: gtk_image_set_from_stock
 * Params: GtkImage *image,const gchar *stock_id,GtkIconSize *size
 * Returns: void
 * Assertion: See gtk_image_new_from_stock() for details.
 * Params Values: a newly created GtkImage*
 * Expected: void  
 */
static void test_purpose_32()
{
    #define STOCK_ID GTK_STOCK_QUIT
    #define SIZE GTK_ICON_SIZE_DIALOG
    
    GtkWidget *widget;
    GtkImageType image_type;
    gchar* stock;
    GtkIconSize size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = gtk_image_new_from_image ( NULL, NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    image_type = gtk_image_get_storage_type (GTK_IMAGE (widget));
    if ( (image_type != GTK_IMAGE_EMPTY) && (image_type != GTK_IMAGE_STOCK))
    {
        TEST_FAIL ("Type of image is '%s', should be GTK_IMAGE_EMPTY or GTK_IMAGE_STOCK",image_type,NULL);
    } 
    
    gtk_image_set_from_stock (GTK_IMAGE (widget),STOCK_ID,SIZE);
    
    gtk_image_get_stock (GTK_IMAGE (widget),&stock,&size);
    
    if (strcmp (STOCK_ID,stock))
    {
        TEST_FAIL ("Stock is %s, should be %s",stock,STOCK_ID);
    }
    if (size != SIZE)
    {
        TEST_FAIL ("Size is %s, should be %s",size,SIZE);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget); 
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STOCK_ID
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_get_pixmap
 * Params: GtkImage *image,GdkPixmap **pixmap,GdkBitmap **mask
 * Returns: void
 * Assertion: Gets the pixmap and mask being displayed by the GtkImage. 
 * Params Values: a newly created GtkImage*
 * Expected: void
 * 
 * Name: gtk_image_set_from_pixmap
 * Params: GtkImage *image,
 * Returns: void
 * Assertion: See gtk_image_new_from_pixmap() for details.
 * Params Values: a newly created GtkImage*
 * Expected: void  
 */
static void test_purpose_33()
{
    #define PIXMAP NULL
    #define MASK NULL
    
    GtkWidget *widget;
    GtkWidget *window;
    GtkImageType image_type;
    GdkPixmap* pixmap;
    GdkPixmap* real_pixmap;
    GdkBitmap* bitmap;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_new_from_image (NULL, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    gdk_window_resize (window->window, 50, 50);
    
    image_type = gtk_image_get_storage_type (GTK_IMAGE (widget));
    if ( (image_type != GTK_IMAGE_EMPTY) && (image_type != GTK_IMAGE_PIXMAP))
    {
        TEST_FAIL ("Type of image is '%s', should be GTK_IMAGE_EMPTY or GTK_IMAGE_PIXMAP",image_type,NULL);
    } 
    
    real_pixmap = PIXMAP;
    
    gtk_image_set_from_pixmap (GTK_IMAGE (widget), real_pixmap, MASK);
    
    gtk_image_get_pixmap (GTK_IMAGE (widget), &pixmap, &bitmap);
    
    if (pixmap != real_pixmap)
    {
        TEST_FAIL ("pixmap is not correct",NULL);
    }
    if (bitmap != MASK)
    {
        TEST_FAIL ("bitmap is not correct",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (window);
    /******* -------------  *******/  
    
    gtk_widget_destroy (window);
    
    #undef PIXMAP
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_get_pixmap
 * Params: GtkImage *image,GdkPixmap **pixmap,GdkBitmap **mask
 * Returns: void
 * Assertion: Gets the pixmap and mask being displayed by the GtkImage. 
 * Params Values: a newly created GtkImage*
 * Expected: void
 * 
 * Name: gtk_image_set_from_pixmap
 * Params: GtkImage *image,
 * Returns: void
 * Assertion: See gtk_image_new_from_pixmap() for details.
 * Params Values: a newly created GtkImage*
 * Expected: void  
 */
static void test_purpose_34()
{
    #define PIXMAP gdk_pixmap_new (window->window, 10, 10, -1)
    #define MASK NULL
    
    GtkWidget *widget;
    GtkWidget *window;
    GtkImageType image_type;
    GdkPixmap* pixmap;
    GdkPixmap* real_pixmap;
    GdkBitmap* bitmap;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_new_from_image (NULL, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    gdk_window_resize (window->window, 50, 50);
    
    image_type = gtk_image_get_storage_type (GTK_IMAGE (widget));
    if ( (image_type != GTK_IMAGE_EMPTY) && (image_type != GTK_IMAGE_PIXMAP))
    {
        TEST_FAIL ("Type of image is '%s', should be GTK_IMAGE_EMPTY or GTK_IMAGE_PIXMAP",image_type,NULL);
    } 
    
    real_pixmap = PIXMAP;
    
    gtk_image_set_from_pixmap (GTK_IMAGE (widget), real_pixmap, MASK);
    
    gtk_image_get_pixmap (GTK_IMAGE (widget), &pixmap, &bitmap);
    
    if (pixmap != real_pixmap)
    {
        TEST_FAIL ("pixmap is not correct",NULL);
    }
    if (bitmap != MASK)
    {
        TEST_FAIL ("bitmap is not correct",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (window);
    /******* -------------  *******/  
    
    gtk_widget_destroy (window);
    
    #undef PIXMAP
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_pixmap
 * Params: GdkPixmap *pixmap, GdkBitmap *mask
 * Returns: GtkImage* 
 * Assertion: Creates a GtkImage widget displaying pixmap with a mask.
 * Params Values: gdk_pixmap_new (window->window, 10, 10, -1), NULL
 * Expected: GtkImage* with type GTK_IMAGE_PIXMAP  
 */
static void test_purpose_35()
{
    #define PIXMAP gdk_pixmap_new (window->window, 10, 10, -1)
    #define MASK NULL
    #define GTK_IMAGE_TYPE_CORRECT GTK_IMAGE_PIXMAP
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_show_all (window);
    gdk_window_resize (window->window, 50, 50);
    
    widget = gtk_image_new_from_pixmap (PIXMAP, MASK);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_TYPE_CORRECT)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_TYPE_CORRECT); 
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (window);
    /******* -------------  *******/  
    
    gtk_widget_destroy (window);
    
    #undef PIXMAP
    #undef MASK
    #undef GTK_IMAGE_TYPE_CORRECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_stock
 * Params: const gchar *stock_id, GtkIconSize size
 * Returns: GtkImage* 
 * Assertion: Creates a GtkImage displaying a stock icon.
 * Params Values: GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU
 * Expected: GtkImage* with type GTK_IMAGE_STOCK  
 */
static void test_purpose_36()
{
    #define STOCK_ID GTK_STOCK_OPEN
    #define SIZE GTK_ICON_SIZE_MENU
    #define GTK_IMAGE_TYPE_CORRECT GTK_IMAGE_STOCK
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_new_from_stock (STOCK_ID, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_TYPE_CORRECT)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_TYPE_CORRECT); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STOCK_ID
    #undef SIZE
    #undef GTK_IMAGE_TYPE_CORRECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_new_from_stock
 * Params: const gchar *stock_id, GtkIconSize size
 * Returns: GtkImage* 
 * Assertion: Creates a GtkImage displaying a stock icon.
 * Params Values: GTK_STOCK_QUIT, GTK_ICON_SIZE_SMALL_TOOLBAR
 * Expected: GtkImage* with type GTK_IMAGE_STOCK  
 */
static void test_purpose_37()
{
    #define STOCK_ID GTK_STOCK_QUIT
    #define SIZE GTK_ICON_SIZE_SMALL_TOOLBAR
    #define GTK_IMAGE_TYPE_CORRECT GTK_IMAGE_STOCK
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_new_from_stock (STOCK_ID, SIZE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_image_get_storage_type (GTK_IMAGE (widget)) 
        != GTK_IMAGE_TYPE_CORRECT)
    {
        TEST_FAIL ("storage_type = %d, should be %d", 
                   gtk_image_get_storage_type (GTK_IMAGE (widget)),
                   GTK_IMAGE_TYPE_CORRECT); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STOCK_ID
    #undef SIZE
    #undef GTK_IMAGE_TYPE_CORRECT
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkImage ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {NULL,0}
};
