/*
 * GtkInvisible methods tests
 * Testing GtkInvisible methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name:   gtk_invisible_new
 * Params: void
 * Returns: GtkInvisible* 
 * Assertion: Creates a new GtkInvisible.
 * Params Values: void
 * Expected: GtkInvisible*  
 */
static void test_purpose_1()
{
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_invisible_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_new_for_screen
 * Params: GdkScreen *screen
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkInvisible object for a specified screen.
 * Params Values: gdk_screen_get_default ()
 * Expected: GtkInvisible*  
 */
static void test_purpose_2()
{
    #define SCREEN gdk_screen_get_default ()
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    widget = gtk_invisible_new_for_screen (screen);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_new_for_screen
 * Params: GdkScreen *screen
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkInvisible object for a specified screen.
 * Params Values: gtk_widget_get_screen (gtk_button_new ())
 * Expected: GtkInvisible*  
 */
static void test_purpose_3()
{
    #define SCREEN gtk_widget_get_screen (gtk_button_new ())
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    widget = gtk_invisible_new_for_screen (screen);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_new_for_screen
 * Params: GdkScreen *screen
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkInvisible object for a specified screen.
 * Params Values: gtk_widget_get_screen (gtk_button_new_with_label ("button"))
 * Expected: GtkInvisible*  
 */
static void test_purpose_4()
{
    #define SCREEN gtk_widget_get_screen (gtk_button_new_with_label ("button"))
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    widget = gtk_invisible_new_for_screen (screen);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_new_for_screen
 * Params: GdkScreen *screen
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkInvisible object for a specified screen.
 * Params Values: gtk_widget_get_screen (gtk_window_new (GTK_WINDOW_TOPLEVEL))
 * Expected: GtkInvisible*  
 */
static void test_purpose_5()
{
    #define SCREEN gtk_widget_get_screen (gtk_window_new (GTK_WINDOW_TOPLEVEL))
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    widget = gtk_invisible_new_for_screen (screen);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_new_for_screen
 * Params: GdkScreen *screen
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkInvisible object for a specified screen.
 * Params Values: gtk_widget_get_screen (gtk_calendar_new ())
 * Expected: GtkInvisible*  
 */
static void test_purpose_6()
{
    #define SCREEN gtk_widget_get_screen (gtk_calendar_new ())
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    widget = gtk_invisible_new_for_screen (screen);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_new_for_screen
 * Params: GdkScreen *screen
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkInvisible object for a specified screen.
 * Params Values: gtk_widget_get_screen (gtk_text_view_new ())
 * Expected: GtkInvisible*  
 */
static void test_purpose_7()
{
    #define SCREEN gtk_widget_get_screen (gtk_text_view_new ())
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    widget = gtk_invisible_new_for_screen (screen);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_set_screen
 * Params: GtkInvisible *invisible, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the GtkInvisible object will be displayed.
 * Params Values: GtkInvisible*, gdk_screen_get_default ()
 * Expected: void  
 */
static void test_purpose_8()
{
    #define SCREEN_INIT gdk_screen_get_default ()
    #define SCREEN gdk_screen_get_default ()
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    if (SCREEN_INIT)
    {
        widget = gtk_invisible_new_for_screen (SCREEN_INIT);
    } else {
        widget = gtk_invisible_new ();
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_invisible_set_screen (GTK_INVISIBLE (widget), screen);
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN_INIT
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_set_screen
 * Params: GtkInvisible *invisible, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the GtkInvisible object will be displayed.
 * Params Values: GtkInvisible*, gtk_widget_get_screen (gtk_button_new ())
 * Expected: void  
 */
static void test_purpose_9()
{
    #define SCREEN_INIT gdk_screen_get_default ()
    #define SCREEN gtk_widget_get_screen (gtk_button_new ())
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    if (SCREEN_INIT)
    {
        widget = gtk_invisible_new_for_screen (SCREEN_INIT);
    } else {
        widget = gtk_invisible_new ();
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_invisible_set_screen (GTK_INVISIBLE (widget), screen);
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN_INIT
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_set_screen
 * Params: GtkInvisible *invisible, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the GtkInvisible object will be displayed.
 * Params Values: GtkInvisible*, gtk_widget_get_screen (gtk_button_new_with_label ("button"))
 * Expected: void  
 */
static void test_purpose_10()
{
    #define SCREEN_INIT NULL
    #define SCREEN gtk_widget_get_screen (gtk_button_new_with_label ("button"))
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    if (SCREEN_INIT)
    {
        widget = gtk_invisible_new_for_screen (SCREEN_INIT);
    } else {
        widget = gtk_invisible_new ();
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_invisible_set_screen (GTK_INVISIBLE (widget), screen);
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN_INIT
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_set_screen
 * Params: GtkInvisible *invisible, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the GtkInvisible object will be displayed.
 * Params Values: GtkInvisible*, gtk_widget_get_screen (gtk_window_new (GTK_WINDOW_TOPLEVEL))
 * Expected: void  
 */
static void test_purpose_11()
{
    #define SCREEN_INIT gtk_widget_get_screen (gtk_calendar_new ())
    #define SCREEN gtk_widget_get_screen (gtk_window_new (GTK_WINDOW_TOPLEVEL))
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    if (SCREEN_INIT)
    {
        widget = gtk_invisible_new_for_screen (SCREEN_INIT);
    } else {
        widget = gtk_invisible_new ();
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_invisible_set_screen (GTK_INVISIBLE (widget), screen);
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN_INIT
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_set_screen
 * Params: GtkInvisible *invisible, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the GtkInvisible object will be displayed.
 * Params Values: GtkInvisible*, gtk_widget_get_screen (gtk_calendar_new ())
 * Expected: void  
 */
static void test_purpose_12()
{
    #define SCREEN_INIT gtk_widget_get_screen (gtk_button_new ())
    #define SCREEN gtk_widget_get_screen (gtk_calendar_new ())
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    if (SCREEN_INIT)
    {
        widget = gtk_invisible_new_for_screen (SCREEN_INIT);
    } else {
        widget = gtk_invisible_new ();
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_invisible_set_screen (GTK_INVISIBLE (widget), screen);
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN_INIT
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_set_screen
 * Params: GtkInvisible *invisible, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the GtkInvisible object will be displayed.
 * Params Values: GtkInvisible*, gtk_widget_get_screen (gtk_text_view_new ())
 * Expected: void  
 */
static void test_purpose_13()
{
    #define SCREEN_INIT gtk_widget_get_screen (gtk_text_view_new ())
    #define SCREEN gtk_widget_get_screen (gtk_text_view_new ())
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    if (SCREEN_INIT)
    {
        widget = gtk_invisible_new_for_screen (SCREEN_INIT);
    } else {
        widget = gtk_invisible_new ();
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_invisible_set_screen (GTK_INVISIBLE (widget), screen);
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN_INIT
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_set_screen
 * Params: GtkInvisible *invisible, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the GtkInvisible object will be displayed.
 * Params Values: GtkInvisible*, gdk_screen_get_default ()
 * Expected: void  
 */
static void test_purpose_14()
{
    #define SCREEN_INIT NULL
    #define SCREEN gdk_screen_get_default ()
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    if (SCREEN_INIT)
    {
        widget = gtk_invisible_new_for_screen (SCREEN_INIT);
    } else {
        widget = gtk_invisible_new ();
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_invisible_set_screen (GTK_INVISIBLE (widget), screen);
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN_INIT
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_set_screen
 * Params: GtkInvisible *invisible, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the GtkInvisible object will be displayed.
 * Params Values: GtkInvisible*, gtk_widget_get_screen (gtk_button_new ())
 * Expected: void  
 */
static void test_purpose_15()
{
    #define SCREEN_INIT gtk_widget_get_screen (gtk_button_new_with_label ("button"))
    #define SCREEN gtk_widget_get_screen (gtk_button_new ())
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    if (SCREEN_INIT)
    {
        widget = gtk_invisible_new_for_screen (SCREEN_INIT);
    } else {
        widget = gtk_invisible_new ();
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_invisible_set_screen (GTK_INVISIBLE (widget), screen);
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN_INIT
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_set_screen
 * Params: GtkInvisible *invisible, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the GtkInvisible object will be displayed.
 * Params Values: GtkInvisible*, gtk_widget_get_screen (gtk_button_new_with_label ("button"))
 * Expected: void  
 */
static void test_purpose_16()
{
    #define SCREEN_INIT gtk_widget_get_screen (gtk_button_new ())
    #define SCREEN gtk_widget_get_screen (gtk_button_new_with_label ("button"))
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    if (SCREEN_INIT)
    {
        widget = gtk_invisible_new_for_screen (SCREEN_INIT);
    } else {
        widget = gtk_invisible_new ();
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_invisible_set_screen (GTK_INVISIBLE (widget), screen);
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN_INIT
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_set_screen
 * Params: GtkInvisible *invisible, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the GtkInvisible object will be displayed.
 * Params Values: GtkInvisible*, gtk_widget_get_screen (gtk_window_new (GTK_WINDOW_TOPLEVEL))
 * Expected: void  
 */
static void test_purpose_17()
{
    #define SCREEN_INIT gtk_widget_get_screen (gtk_window_new (GTK_WINDOW_TOPLEVEL))
    #define SCREEN gtk_widget_get_screen (gtk_window_new (GTK_WINDOW_TOPLEVEL))
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    if (SCREEN_INIT)
    {
        widget = gtk_invisible_new_for_screen (SCREEN_INIT);
    } else {
        widget = gtk_invisible_new ();
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_invisible_set_screen (GTK_INVISIBLE (widget), screen);
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN_INIT
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_set_screen
 * Params: GtkInvisible *invisible, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the GtkInvisible object will be displayed.
 * Params Values: GtkInvisible*, gtk_widget_get_screen (gtk_calendar_new ())
 * Expected: void  
 */
static void test_purpose_18()
{
    #define SCREEN_INIT NULL
    #define SCREEN gtk_widget_get_screen (gtk_calendar_new ())
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    if (SCREEN_INIT)
    {
        widget = gtk_invisible_new_for_screen (SCREEN_INIT);
    } else {
        widget = gtk_invisible_new ();
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_invisible_set_screen (GTK_INVISIBLE (widget), screen);
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN_INIT
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_invisible_set_screen
 * Params: GtkInvisible *invisible, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the GtkInvisible object will be displayed.
 * Params Values: GtkInvisible*, gtk_widget_get_screen (gtk_text_view_new ())
 * Expected: void  
 */
static void test_purpose_19()
{
    #define SCREEN_INIT NULL
    #define SCREEN gtk_widget_get_screen (gtk_text_view_new ())
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    screen = SCREEN;
    
    if (SCREEN_INIT)
    {
        widget = gtk_invisible_new_for_screen (SCREEN_INIT);
    } else {
        widget = gtk_invisible_new ();
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_INVISIBLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_invisible_set_screen (GTK_INVISIBLE (widget), screen);
    
    real_screen = gtk_widget_get_screen (widget);
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen is not the one a widget was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef SCREEN_INIT
    #undef SCREEN
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkInvisible ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {NULL,0}
};
