/*
 * GtkPlug methods tests
 * Testing GtkPlug methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_plug_new
 * Params: GdkNativeWindow socket_id
 * Returns: GtkWidget*
 * Assertion: Creates a new plug widget inside the GtkSocket identified by socket_id.
 * Params Values: GdkNativeWindow socket_id
 * Expected:  GtkWidget*  
 */
static void test_purpose_1()
{
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new (gtk_socket_get_id (GTK_SOCKET (socket)));
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_new_for_display
 * Params: GdkDisplay *display, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Create a new plug widget inside the GtkSocket identified by socket_id.
 * Params Values: GtkPlug *plug, gdk_display_get_default (), GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_2()
{
    #define DISPLAY gdk_display_get_default ()
    
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    GdkDisplay* display;
    GdkDisplay* real_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    display = DISPLAY;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new_for_display (display, 
                                       gtk_socket_get_id (GTK_SOCKET (socket)));
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_display = gtk_widget_get_display (widget);
    if (real_display != display)
    {
        TEST_FAIL ("real_display is not the one the plug was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    #undef DISPLAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_new_for_display
 * Params: GdkDisplay *display, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Create a new plug widget inside the GtkSocket identified by socket_id.
 * Params Values: GtkPlug *plug, gtk_widget_get_display (gtk_button_new ()), GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_3()
{
    #define DISPLAY gtk_widget_get_display (gtk_button_new ())
    
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    GdkDisplay* display;
    GdkDisplay* real_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    display = DISPLAY;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new_for_display (display, 
                                       gtk_socket_get_id (GTK_SOCKET (socket)));
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_display = gtk_widget_get_display (widget);
    if (real_display != display)
    {
        TEST_FAIL ("real_display is not the one the plug was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    #undef DISPLAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_new_for_display
 * Params: GdkDisplay *display, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Create a new plug widget inside the GtkSocket identified by socket_id.
 * Params Values: GtkPlug *plug, gtk_widget_get_display (gtk_button_new_with_label ("button")), GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_4()
{
    #define DISPLAY gtk_widget_get_display (gtk_button_new_with_label ("button"))
    
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    GdkDisplay* display;
    GdkDisplay* real_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    display = DISPLAY;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new_for_display (display, 
                                       gtk_socket_get_id (GTK_SOCKET (socket)));
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_display = gtk_widget_get_display (widget);
    if (real_display != display)
    {
        TEST_FAIL ("real_display is not the one the plug was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    #undef DISPLAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_new_for_display
 * Params: GdkDisplay *display, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Create a new plug widget inside the GtkSocket identified by socket_id.
 * Params Values: GtkPlug *plug, gtk_widget_get_display (gtk_window_new (GTK_WINDOW_TOPLEVEL)), GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_5()
{
    #define DISPLAY gtk_widget_get_display (gtk_window_new (GTK_WINDOW_TOPLEVEL))
    
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    GdkDisplay* display;
    GdkDisplay* real_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    display = DISPLAY;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new_for_display (display, 
                                       gtk_socket_get_id (GTK_SOCKET (socket)));
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_display = gtk_widget_get_display (widget);
    if (real_display != display)
    {
        TEST_FAIL ("real_display is not the one the plug was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    #undef DISPLAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_new_for_display
 * Params: GdkDisplay *display, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Create a new plug widget inside the GtkSocket identified by socket_id.
 * Params Values: GtkPlug *plug, gtk_widget_get_display (gtk_calendar_new ()), GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_6()
{
    #define DISPLAY gtk_widget_get_display (gtk_calendar_new ())
    
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    GdkDisplay* display;
    GdkDisplay* real_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    display = DISPLAY;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new_for_display (display, 
                                       gtk_socket_get_id (GTK_SOCKET (socket)));
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_display = gtk_widget_get_display (widget);
    if (real_display != display)
    {
        TEST_FAIL ("real_display is not the one the plug was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    #undef DISPLAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_new_for_display
 * Params: GdkDisplay *display, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Create a new plug widget inside the GtkSocket identified by socket_id.
 * Params Values: GtkPlug *plug, gtk_widget_get_display (gtk_text_view_new ()), GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_7()
{
    #define DISPLAY gtk_widget_get_display (gtk_text_view_new ())
    
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    GdkDisplay* display;
    GdkDisplay* real_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    display = DISPLAY;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new_for_display (display, 
                                       gtk_socket_get_id (GTK_SOCKET (socket)));
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_display = gtk_widget_get_display (widget);
    if (real_display != display)
    {
        TEST_FAIL ("real_display is not the one the plug was created for", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    #undef DISPLAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_get_id
 * Params: GtkSocket *socket
 * Returns: GdkNativeWindow
 * Assertion: Gets the window ID of a GtkPlug widget, which can then be used to embed this window inside another window, for instance with gtk_socket_add_id().
 * Params Values: GtkSocket *socket, GdkNativeWindow id
 * Expected: GdkNativeWindow  
 */
static void test_purpose_8()
{
    GtkWidget* window;
    GtkWidget* widget;
    GtkWidget* plug;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    widget = gtk_socket_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    plug = gtk_plug_new (gtk_socket_get_id (GTK_SOCKET (widget)));
    if (!plug)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    
    if (gtk_plug_get_id (GTK_PLUG (plug)) == 0)
    {
        TEST_FAIL ("Plug is wrong", NULL);
    }
    
    gtk_widget_destroy (plug);
    gtk_widget_destroy (window);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_construct
 * Params: GtkPlug *plug, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Finish the initialization of plug for a given GtkSocket identified by socket_id.
 * Params Values: GtkPlug *plug, GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_9()
{
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new ( (GdkNativeWindow) 0);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_plug_construct (GTK_PLUG (widget), gtk_socket_get_id (GTK_SOCKET (socket)));
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_construct_for_display
 * Params: GtkPlug *plug, GdkDisplay *display, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Finish the initialization of plug for a given GtkSocket identified by socket_id which is currently displayed on display.
 * Params Values: GtkPlug *plug, gdk_display_get_default (), GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_10()
{
    #define DISPLAY gdk_display_get_default ()
    
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    GdkDisplay* display;
    GdkDisplay* real_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    display = DISPLAY;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new_for_display (display, 
                                       (GdkNativeWindow) 0);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_plug_construct_for_display (GTK_PLUG (widget), display, gtk_socket_get_id (GTK_SOCKET (socket)));
    
    real_display = gtk_widget_get_display (widget);
    if (real_display != display)
    {
        TEST_FAIL ("real_display is not the one the plug was constructed for", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    #undef DISPLAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_construct_for_display
 * Params: GtkPlug *plug, GdkDisplay *display, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Finish the initialization of plug for a given GtkSocket identified by socket_id which is currently displayed on display.
 * Params Values: GtkPlug *plug, gtk_widget_get_display (gtk_button_new ()), GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_11()
{
    #define DISPLAY gtk_widget_get_display (gtk_button_new ())
    
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    GdkDisplay* display;
    GdkDisplay* real_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    display = DISPLAY;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new_for_display (display, 
                                       (GdkNativeWindow) 0);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_plug_construct_for_display (GTK_PLUG (widget), display, gtk_socket_get_id (GTK_SOCKET (socket)));
    
    real_display = gtk_widget_get_display (widget);
    if (real_display != display)
    {
        TEST_FAIL ("real_display is not the one the plug was constructed for", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    #undef DISPLAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_construct_for_display
 * Params: GtkPlug *plug, GdkDisplay *display, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Finish the initialization of plug for a given GtkSocket identified by socket_id which is currently displayed on display.
 * Params Values: GtkPlug *plug, gtk_widget_get_display (gtk_button_new_with_label ("button")), GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_12()
{
    #define DISPLAY gtk_widget_get_display (gtk_button_new_with_label ("button"))
    
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    GdkDisplay* display;
    GdkDisplay* real_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    display = DISPLAY;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new_for_display (display, 
                                       (GdkNativeWindow) 0);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_plug_construct_for_display (GTK_PLUG (widget), display, gtk_socket_get_id (GTK_SOCKET (socket)));
    
    real_display = gtk_widget_get_display (widget);
    if (real_display != display)
    {
        TEST_FAIL ("real_display is not the one the plug was constructed for", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    #undef DISPLAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_construct_for_display
 * Params: GtkPlug *plug, GdkDisplay *display, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Finish the initialization of plug for a given GtkSocket identified by socket_id which is currently displayed on display.
 * Params Values: GtkPlug *plug, gtk_widget_get_display (gtk_window_new (GTK_WINDOW_TOPLEVEL)), GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_13()
{
    #define DISPLAY gtk_widget_get_display (gtk_window_new (GTK_WINDOW_TOPLEVEL))
    
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    GdkDisplay* display;
    GdkDisplay* real_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    display = DISPLAY;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new_for_display (display, 
                                       (GdkNativeWindow) 0);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_plug_construct_for_display (GTK_PLUG (widget), display, gtk_socket_get_id (GTK_SOCKET (socket)));
    
    real_display = gtk_widget_get_display (widget);
    if (real_display != display)
    {
        TEST_FAIL ("real_display is not the one the plug was constructed for", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    #undef DISPLAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_construct_for_display
 * Params: GtkPlug *plug, GdkDisplay *display, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Finish the initialization of plug for a given GtkSocket identified by socket_id which is currently displayed on display.
 * Params Values: GtkPlug *plug, gtk_widget_get_display (gtk_calendar_new ()), GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_14()
{
    #define DISPLAY gtk_widget_get_display (gtk_calendar_new ())
    
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    GdkDisplay* display;
    GdkDisplay* real_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    display = DISPLAY;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new_for_display (display, 
                                       (GdkNativeWindow) 0);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_plug_construct_for_display (GTK_PLUG (widget), display, gtk_socket_get_id (GTK_SOCKET (socket)));
    
    real_display = gtk_widget_get_display (widget);
    if (real_display != display)
    {
        TEST_FAIL ("real_display is not the one the plug was constructed for", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    #undef DISPLAY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_plug_construct_for_display
 * Params: GtkPlug *plug, GdkDisplay *display, GdkNativeWindow socket_id
 * Returns: void
 * Assertion: Finish the initialization of plug for a given GtkSocket identified by socket_id which is currently displayed on display.
 * Params Values: GtkPlug *plug, gtk_widget_get_display (gtk_text_view_new ()), GdkNativeWindow socket_id
 * Expected:  void  
 */
static void test_purpose_15()
{
    #define DISPLAY gtk_widget_get_display (gtk_text_view_new ())
    
    GtkWidget* window;
    GtkWidget* socket;
    GtkWidget* widget;
    GdkDisplay* display;
    GdkDisplay* real_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    display = DISPLAY;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    socket = gtk_socket_new ();
    if (!socket)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (window), socket);
    gtk_widget_show_all (window);
    
    widget = gtk_plug_new_for_display (display, 
                                       (GdkNativeWindow) 0);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PLUG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_plug_construct_for_display (GTK_PLUG (widget), display, gtk_socket_get_id (GTK_SOCKET (socket)));
    
    real_display = gtk_widget_get_display (widget);
    if (real_display != display)
    {
        TEST_FAIL ("real_display is not the one the plug was constructed for", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (window);
    
    #undef DISPLAY
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkPlug ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {NULL,0}
};
