/*
 * GtkRadioMenuItem methods tests
 * Testing GtkRadioMenuItem methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_radio_menu_item_new
 * Params: GSList *group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioMenuItem.
 * Params Values: CSList*
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_1()
{
    #define    GROUP NULL
    
    GSList *group;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new (group);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new
 * Params: GSList *group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioMenuItem.
 * Params Values: CSList*
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_2()
{
    #define    GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    
    GSList *group;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new (group);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem whose child is a simple GtkLabel. 
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "Text"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_3()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "Text"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_label (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem whose child is a simple GtkLabel. 
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_4()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_label (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem whose child is a simple GtkLabel. 
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_5()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_label (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem whose child is a simple GtkLabel. 
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "\b\n\t"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_6()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "\b\n\t"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_label (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem whose child is a simple GtkLabel. 
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), " "
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_7()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL " "
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_label (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem whose child is a simple GtkLabel. 
 * Params Values: NULL, "Text"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_8()
{
    #define GROUP NULL
    #define LABEL "Text"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_label (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem whose child is a simple GtkLabel. 
 * Params Values: NULL, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_9()
{
    #define GROUP NULL
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_label (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem whose child is a simple GtkLabel. 
 * Params Values: NULL, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_10()
{
    #define GROUP NULL
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_label (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem whose child is a simple GtkLabel. 
 * Params Values: NULL, "\b\n\t"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_11()
{
    #define GROUP NULL
    #define LABEL "\b\n\t"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_label (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem containing a label.
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "Text"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_12()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "Text"
    #define CORRECT_LABEL "Text"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_mnemonic (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", 
                       real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef CORRECT_LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem containing a label.
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "Tex_t"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_13()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "Tex_t"
    #define CORRECT_LABEL "Text"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_mnemonic (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", 
                       real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef CORRECT_LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem containing a label.
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_14()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define CORRECT_LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_mnemonic (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", 
                       real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef CORRECT_LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem containing a label.
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "ab_cdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_15()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "ab_cdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define CORRECT_LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_mnemonic (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", 
                       real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef CORRECT_LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem containing a label.
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "!@#$%^&*()__+|~=\";:'?<>`/"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_16()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "!@#$%^&*()__+|~=\";:'?<>`/"
    #define CORRECT_LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_mnemonic (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", 
                       real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef CORRECT_LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem containing a label.
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "\b\n\t"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_17()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "\b\n\t"
    #define CORRECT_LABEL "\b\n\t"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_mnemonic (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", 
                       real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef CORRECT_LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem containing a label.
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "\b_\n\t"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_18()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "\b_\n\t"
    #define CORRECT_LABEL "\b\n\t"
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_mnemonic (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", 
                       real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef CORRECT_LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem containing a label.
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), " "
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_19()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL " "
    #define CORRECT_LABEL " "
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_mnemonic (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", 
                       real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef CORRECT_LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: Creates a new GtkRadioMenuItem containing a label.
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "_ "
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_20()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "_ "
    #define CORRECT_LABEL " "
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* real_label = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_mnemonic (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", 
                       real_label, CORRECT_LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef CORRECT_LABEL
    #undef GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "Te_xt"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_21()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "Te_xt"
    #define KEY GDK_x
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_mnemonic (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef CORRECT_LABEL
    #undef KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "_Text"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_22()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "_Text"
    #define KEY GDK_t
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_mnemonic (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef CORRECT_LABEL
    #undef KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_menu_item_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkRadioMenuItem*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item"))), "T_ext"
 * Expected: GtkRadioMenuItem*  
 */
static void test_purpose_23()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define LABEL "T_ext"
    #define KEY GDK_e
    
    GSList *group;
    GtkWidget *widget;
    GtkWidget* child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_menu_item_new_with_mnemonic (group, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef CORRECT_LABEL
    #undef KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_radio_menu_item_get_group
 * Params: GtkRadioMenuItem *radio_menu_item
 * Returns: GSList*
 * Assertion: Returns the group to which the radio menu item belongs, as a GList of GtkRadioMenuItem.
 * Params Values: a newly created GtkRadioMenuItem
 * Expected: GSList*
 * 
 * Name:   gtk_radio_menu_item_set_group
 * Params: GtkRadioMenuItem *radio_menu_item, GSList *group
 * Returns: void
 * Assertion: Sets the group of a radio menu item, or changes it.
 * Params Values: a newly created GtkRadioMenuItem, GSList*
 * Expected: void
 *   
 */
static void test_purpose_24()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define ELEM_NUM 1
    #define NEW_GRP_ELEM_NUM 1
    
    GtkWidget* widget[ELEM_NUM];
    GtkWidget* wdg1;
    GtkWidget* wdg2;
    GSList* grp1;
    GSList* grp2;
    GSList* group_value;
    gint i;
    gint group_length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    wdg1 = gtk_radio_menu_item_new (NULL);
    wdg2 = gtk_radio_menu_item_new (NULL);
    
    grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1));
    grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg2));
    
    for (i = 0; i < ELEM_NUM; i++)
    {
        widget[i] = gtk_radio_menu_item_new (grp1);
    
        if (!widget[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL); 
            return;
        } 
    
        if (!GTK_IS_RADIO_MENU_ITEM (widget[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL); 
            return;
        }
    
        grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    /* change group for a few elements */
    for (i = 0; i < NEW_GRP_ELEM_NUM; i++)
    {
        gtk_radio_menu_item_set_group (GTK_RADIO_MENU_ITEM (widget[i]), grp2);
        grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    for (i = 1; i < NEW_GRP_ELEM_NUM; i++)
    {
        group_value = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
        if (group_value != grp2)
        {
            TEST_FAIL ("changed group: group of widget[%i] is wrong", i);
        }
    }
    
    group_length = g_slist_length (gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1)));
    if (group_length != ELEM_NUM - NEW_GRP_ELEM_NUM + 1)
    {
        TEST_FAIL ("changed group: old group_length = %d, should be %d", group_length, ELEM_NUM - NEW_GRP_ELEM_NUM + 1);
    } 
    
    /******* VISUALISATION *******/
    {
        gint i;
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        for (i = 0; i < ELEM_NUM; i++)
        {
            gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget[i]);
        }
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget[0]));
    
    #undef ELEM_NUM
    #undef NEW_GRP_ELEM_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_radio_menu_item_get_group
 * Params: GtkRadioMenuItem *radio_menu_item
 * Returns: GSList*
 * Assertion: Returns the group to which the radio menu item belongs, as a GList of GtkRadioMenuItem.
 * Params Values: a newly created GtkRadioMenuItem
 * Expected: GSList*
 * 
 * Name:   gtk_radio_menu_item_set_group
 * Params: GtkRadioMenuItem *radio_menu_item, GSList *group
 * Returns: void
 * Assertion: Sets the group of a radio menu item, or changes it.
 * Params Values: a newly created GtkRadioMenuItem, GSList*
 * Expected: void
 *   
 */
static void test_purpose_25()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define ELEM_NUM 10
    #define NEW_GRP_ELEM_NUM 1
    
    GtkWidget* widget[ELEM_NUM];
    GtkWidget* wdg1;
    GtkWidget* wdg2;
    GSList* grp1;
    GSList* grp2;
    GSList* group_value;
    gint i;
    gint group_length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    wdg1 = gtk_radio_menu_item_new (NULL);
    wdg2 = gtk_radio_menu_item_new (NULL);
    
    grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1));
    grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg2));
    
    for (i = 0; i < ELEM_NUM; i++)
    {
        widget[i] = gtk_radio_menu_item_new (grp1);
    
        if (!widget[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL); 
            return;
        } 
    
        if (!GTK_IS_RADIO_MENU_ITEM (widget[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL); 
            return;
        }
    
        grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    /* change group for a few elements */
    for (i = 0; i < NEW_GRP_ELEM_NUM; i++)
    {
        gtk_radio_menu_item_set_group (GTK_RADIO_MENU_ITEM (widget[i]), grp2);
        grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    for (i = 1; i < NEW_GRP_ELEM_NUM; i++)
    {
        group_value = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
        if (group_value != grp2)
        {
            TEST_FAIL ("changed group: group of widget[%i] is wrong", i);
        }
    }
    
    group_length = g_slist_length (gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1)));
    if (group_length != ELEM_NUM - NEW_GRP_ELEM_NUM + 1)
    {
        TEST_FAIL ("changed group: old group_length = %d, should be %d", group_length, ELEM_NUM - NEW_GRP_ELEM_NUM + 1);
    } 
    
    /******* VISUALISATION *******/
    {
        gint i;
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        for (i = 0; i < ELEM_NUM; i++)
        {
            gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget[i]);
        }
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget[0]));
    
    #undef ELEM_NUM
    #undef NEW_GRP_ELEM_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_radio_menu_item_get_group
 * Params: GtkRadioMenuItem *radio_menu_item
 * Returns: GSList*
 * Assertion: Returns the group to which the radio menu item belongs, as a GList of GtkRadioMenuItem.
 * Params Values: a newly created GtkRadioMenuItem
 * Expected: GSList*
 * 
 * Name:   gtk_radio_menu_item_set_group
 * Params: GtkRadioMenuItem *radio_menu_item, GSList *group
 * Returns: void
 * Assertion: Sets the group of a radio menu item, or changes it.
 * Params Values: a newly created GtkRadioMenuItem, GSList*
 * Expected: void
 *   
 */
static void test_purpose_26()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define ELEM_NUM 10
    #define NEW_GRP_ELEM_NUM 2
    
    GtkWidget* widget[ELEM_NUM];
    GtkWidget* wdg1;
    GtkWidget* wdg2;
    GSList* grp1;
    GSList* grp2;
    GSList* group_value;
    gint i;
    gint group_length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    wdg1 = gtk_radio_menu_item_new (NULL);
    wdg2 = gtk_radio_menu_item_new (NULL);
    
    grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1));
    grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg2));
    
    for (i = 0; i < ELEM_NUM; i++)
    {
        widget[i] = gtk_radio_menu_item_new (grp1);
    
        if (!widget[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL); 
            return;
        } 
    
        if (!GTK_IS_RADIO_MENU_ITEM (widget[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL); 
            return;
        }
    
        grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    /* change group for a few elements */
    for (i = 0; i < NEW_GRP_ELEM_NUM; i++)
    {
        gtk_radio_menu_item_set_group (GTK_RADIO_MENU_ITEM (widget[i]), grp2);
        grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    for (i = 1; i < NEW_GRP_ELEM_NUM; i++)
    {
        group_value = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
        if (group_value != grp2)
        {
            TEST_FAIL ("changed group: group of widget[%i] is wrong", i);
        }
    }
    
    group_length = g_slist_length (gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1)));
    if (group_length != ELEM_NUM - NEW_GRP_ELEM_NUM + 1)
    {
        TEST_FAIL ("changed group: old group_length = %d, should be %d", group_length, ELEM_NUM - NEW_GRP_ELEM_NUM + 1);
    } 
    
    /******* VISUALISATION *******/
    {
        gint i;
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        for (i = 0; i < ELEM_NUM; i++)
        {
            gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget[i]);
        }
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget[0]));
    
    #undef ELEM_NUM
    #undef NEW_GRP_ELEM_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_radio_menu_item_get_group
 * Params: GtkRadioMenuItem *radio_menu_item
 * Returns: GSList*
 * Assertion: Returns the group to which the radio menu item belongs, as a GList of GtkRadioMenuItem.
 * Params Values: a newly created GtkRadioMenuItem
 * Expected: GSList*
 * 
 * Name:   gtk_radio_menu_item_set_group
 * Params: GtkRadioMenuItem *radio_menu_item, GSList *group
 * Returns: void
 * Assertion: Sets the group of a radio menu item, or changes it.
 * Params Values: a newly created GtkRadioMenuItem, GSList*
 * Expected: void
 *   
 */
static void test_purpose_27()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define ELEM_NUM 10
    #define NEW_GRP_ELEM_NUM 10
    
    GtkWidget* widget[ELEM_NUM];
    GtkWidget* wdg1;
    GtkWidget* wdg2;
    GSList* grp1;
    GSList* grp2;
    GSList* group_value;
    gint i;
    gint group_length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    wdg1 = gtk_radio_menu_item_new (NULL);
    wdg2 = gtk_radio_menu_item_new (NULL);
    
    grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1));
    grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg2));
    
    for (i = 0; i < ELEM_NUM; i++)
    {
        widget[i] = gtk_radio_menu_item_new (grp1);
    
        if (!widget[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL); 
            return;
        } 
    
        if (!GTK_IS_RADIO_MENU_ITEM (widget[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL); 
            return;
        }
    
        grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    /* change group for a few elements */
    for (i = 0; i < NEW_GRP_ELEM_NUM; i++)
    {
        gtk_radio_menu_item_set_group (GTK_RADIO_MENU_ITEM (widget[i]), grp2);
        grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    for (i = 1; i < NEW_GRP_ELEM_NUM; i++)
    {
        group_value = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
        if (group_value != grp2)
        {
            TEST_FAIL ("changed group: group of widget[%i] is wrong", i);
        }
    }
    
    group_length = g_slist_length (gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1)));
    if (group_length != ELEM_NUM - NEW_GRP_ELEM_NUM + 1)
    {
        TEST_FAIL ("changed group: old group_length = %d, should be %d", group_length, ELEM_NUM - NEW_GRP_ELEM_NUM + 1);
    } 
    
    /******* VISUALISATION *******/
    {
        gint i;
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        for (i = 0; i < ELEM_NUM; i++)
        {
            gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget[i]);
        }
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget[0]));
    
    #undef ELEM_NUM
    #undef NEW_GRP_ELEM_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_radio_menu_item_get_group
 * Params: GtkRadioMenuItem *radio_menu_item
 * Returns: GSList*
 * Assertion: Returns the group to which the radio menu item belongs, as a GList of GtkRadioMenuItem.
 * Params Values: a newly created GtkRadioMenuItem
 * Expected: GSList*
 * 
 * Name:   gtk_radio_menu_item_set_group
 * Params: GtkRadioMenuItem *radio_menu_item, GSList *group
 * Returns: void
 * Assertion: Sets the group of a radio menu item, or changes it.
 * Params Values: a newly created GtkRadioMenuItem, GSList*
 * Expected: void
 *   
 */
static void test_purpose_28()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define ELEM_NUM 100
    #define NEW_GRP_ELEM_NUM 1
    
    GtkWidget* widget[ELEM_NUM];
    GtkWidget* wdg1;
    GtkWidget* wdg2;
    GSList* grp1;
    GSList* grp2;
    GSList* group_value;
    gint i;
    gint group_length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    wdg1 = gtk_radio_menu_item_new (NULL);
    wdg2 = gtk_radio_menu_item_new (NULL);
    
    grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1));
    grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg2));
    
    for (i = 0; i < ELEM_NUM; i++)
    {
        widget[i] = gtk_radio_menu_item_new (grp1);
    
        if (!widget[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL); 
            return;
        } 
    
        if (!GTK_IS_RADIO_MENU_ITEM (widget[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL); 
            return;
        }
    
        grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    /* change group for a few elements */
    for (i = 0; i < NEW_GRP_ELEM_NUM; i++)
    {
        gtk_radio_menu_item_set_group (GTK_RADIO_MENU_ITEM (widget[i]), grp2);
        grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    for (i = 1; i < NEW_GRP_ELEM_NUM; i++)
    {
        group_value = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
        if (group_value != grp2)
        {
            TEST_FAIL ("changed group: group of widget[%i] is wrong", i);
        }
    }
    
    group_length = g_slist_length (gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1)));
    if (group_length != ELEM_NUM - NEW_GRP_ELEM_NUM + 1)
    {
        TEST_FAIL ("changed group: old group_length = %d, should be %d", group_length, ELEM_NUM - NEW_GRP_ELEM_NUM + 1);
    } 
    
    /******* VISUALISATION *******/
    {
        gint i;
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        for (i = 0; i < ELEM_NUM; i++)
        {
            gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget[i]);
        }
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget[0]));
    
    #undef ELEM_NUM
    #undef NEW_GRP_ELEM_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_radio_menu_item_get_group
 * Params: GtkRadioMenuItem *radio_menu_item
 * Returns: GSList*
 * Assertion: Returns the group to which the radio menu item belongs, as a GList of GtkRadioMenuItem.
 * Params Values: a newly created GtkRadioMenuItem
 * Expected: GSList*
 * 
 * Name:   gtk_radio_menu_item_set_group
 * Params: GtkRadioMenuItem *radio_menu_item, GSList *group
 * Returns: void
 * Assertion: Sets the group of a radio menu item, or changes it.
 * Params Values: a newly created GtkRadioMenuItem, GSList*
 * Expected: void
 *   
 */
static void test_purpose_29()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define ELEM_NUM 100
    #define NEW_GRP_ELEM_NUM 26
    
    GtkWidget* widget[ELEM_NUM];
    GtkWidget* wdg1;
    GtkWidget* wdg2;
    GSList* grp1;
    GSList* grp2;
    GSList* group_value;
    gint i;
    gint group_length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    wdg1 = gtk_radio_menu_item_new (NULL);
    wdg2 = gtk_radio_menu_item_new (NULL);
    
    grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1));
    grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg2));
    
    for (i = 0; i < ELEM_NUM; i++)
    {
        widget[i] = gtk_radio_menu_item_new (grp1);
    
        if (!widget[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL); 
            return;
        } 
    
        if (!GTK_IS_RADIO_MENU_ITEM (widget[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL); 
            return;
        }
    
        grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    /* change group for a few elements */
    for (i = 0; i < NEW_GRP_ELEM_NUM; i++)
    {
        gtk_radio_menu_item_set_group (GTK_RADIO_MENU_ITEM (widget[i]), grp2);
        grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    for (i = 1; i < NEW_GRP_ELEM_NUM; i++)
    {
        group_value = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
        if (group_value != grp2)
        {
            TEST_FAIL ("changed group: group of widget[%i] is wrong", i);
        }
    }
    
    group_length = g_slist_length (gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1)));
    if (group_length != ELEM_NUM - NEW_GRP_ELEM_NUM + 1)
    {
        TEST_FAIL ("changed group: old group_length = %d, should be %d", group_length, ELEM_NUM - NEW_GRP_ELEM_NUM + 1);
    } 
    
    /******* VISUALISATION *******/
    {
        gint i;
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        for (i = 0; i < ELEM_NUM; i++)
        {
            gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget[i]);
        }
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget[0]));
    
    #undef ELEM_NUM
    #undef NEW_GRP_ELEM_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_radio_menu_item_get_group
 * Params: GtkRadioMenuItem *radio_menu_item
 * Returns: GSList*
 * Assertion: Returns the group to which the radio menu item belongs, as a GList of GtkRadioMenuItem.
 * Params Values: a newly created GtkRadioMenuItem
 * Expected: GSList*
 * 
 * Name:   gtk_radio_menu_item_set_group
 * Params: GtkRadioMenuItem *radio_menu_item, GSList *group
 * Returns: void
 * Assertion: Sets the group of a radio menu item, or changes it.
 * Params Values: a newly created GtkRadioMenuItem, GSList*
 * Expected: void
 *   
 */
static void test_purpose_30()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define ELEM_NUM 100
    #define NEW_GRP_ELEM_NUM 49
    
    GtkWidget* widget[ELEM_NUM];
    GtkWidget* wdg1;
    GtkWidget* wdg2;
    GSList* grp1;
    GSList* grp2;
    GSList* group_value;
    gint i;
    gint group_length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    wdg1 = gtk_radio_menu_item_new (NULL);
    wdg2 = gtk_radio_menu_item_new (NULL);
    
    grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1));
    grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg2));
    
    for (i = 0; i < ELEM_NUM; i++)
    {
        widget[i] = gtk_radio_menu_item_new (grp1);
    
        if (!widget[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL); 
            return;
        } 
    
        if (!GTK_IS_RADIO_MENU_ITEM (widget[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL); 
            return;
        }
    
        grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    /* change group for a few elements */
    for (i = 0; i < NEW_GRP_ELEM_NUM; i++)
    {
        gtk_radio_menu_item_set_group (GTK_RADIO_MENU_ITEM (widget[i]), grp2);
        grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    for (i = 1; i < NEW_GRP_ELEM_NUM; i++)
    {
        group_value = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
        if (group_value != grp2)
        {
            TEST_FAIL ("changed group: group of widget[%i] is wrong", i);
        }
    }
    
    group_length = g_slist_length (gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1)));
    if (group_length != ELEM_NUM - NEW_GRP_ELEM_NUM + 1)
    {
        TEST_FAIL ("changed group: old group_length = %d, should be %d", group_length, ELEM_NUM - NEW_GRP_ELEM_NUM + 1);
    } 
    
    /******* VISUALISATION *******/
    {
        gint i;
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        for (i = 0; i < ELEM_NUM; i++)
        {
            gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget[i]);
        }
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget[0]));
    
    #undef ELEM_NUM
    #undef NEW_GRP_ELEM_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_radio_menu_item_get_group
 * Params: GtkRadioMenuItem *radio_menu_item
 * Returns: GSList*
 * Assertion: Returns the group to which the radio menu item belongs, as a GList of GtkRadioMenuItem.
 * Params Values: a newly created GtkRadioMenuItem
 * Expected: GSList*
 * 
 * Name:   gtk_radio_menu_item_set_group
 * Params: GtkRadioMenuItem *radio_menu_item, GSList *group
 * Returns: void
 * Assertion: Sets the group of a radio menu item, or changes it.
 * Params Values: a newly created GtkRadioMenuItem, GSList*
 * Expected: void
 *   
 */
static void test_purpose_31()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define ELEM_NUM 100
    #define NEW_GRP_ELEM_NUM 99
    
    GtkWidget* widget[ELEM_NUM];
    GtkWidget* wdg1;
    GtkWidget* wdg2;
    GSList* grp1;
    GSList* grp2;
    GSList* group_value;
    gint i;
    gint group_length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    wdg1 = gtk_radio_menu_item_new (NULL);
    wdg2 = gtk_radio_menu_item_new (NULL);
    
    grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1));
    grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg2));
    
    for (i = 0; i < ELEM_NUM; i++)
    {
        widget[i] = gtk_radio_menu_item_new (grp1);
    
        if (!widget[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL); 
            return;
        } 
    
        if (!GTK_IS_RADIO_MENU_ITEM (widget[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL); 
            return;
        }
    
        grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    /* change group for a few elements */
    for (i = 0; i < NEW_GRP_ELEM_NUM; i++)
    {
        gtk_radio_menu_item_set_group (GTK_RADIO_MENU_ITEM (widget[i]), grp2);
        grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    for (i = 1; i < NEW_GRP_ELEM_NUM; i++)
    {
        group_value = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
        if (group_value != grp2)
        {
            TEST_FAIL ("changed group: group of widget[%i] is wrong", i);
        }
    }
    
    group_length = g_slist_length (gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1)));
    if (group_length != ELEM_NUM - NEW_GRP_ELEM_NUM + 1)
    {
        TEST_FAIL ("changed group: old group_length = %d, should be %d", group_length, ELEM_NUM - NEW_GRP_ELEM_NUM + 1);
    } 
    
    /******* VISUALISATION *******/
    {
        gint i;
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        for (i = 0; i < ELEM_NUM; i++)
        {
            gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget[i]);
        }
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget[0]));
    
    #undef ELEM_NUM
    #undef NEW_GRP_ELEM_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_radio_menu_item_get_group
 * Params: GtkRadioMenuItem *radio_menu_item
 * Returns: GSList*
 * Assertion: Returns the group to which the radio menu item belongs, as a GList of GtkRadioMenuItem.
 * Params Values: a newly created GtkRadioMenuItem
 * Expected: GSList*
 * 
 * Name:   gtk_radio_menu_item_set_group
 * Params: GtkRadioMenuItem *radio_menu_item, GSList *group
 * Returns: void
 * Assertion: Sets the group of a radio menu item, or changes it.
 * Params Values: a newly created GtkRadioMenuItem, GSList*
 * Expected: void
 *   
 */
static void test_purpose_32()
{
    #define GROUP gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (gtk_radio_menu_item_new_with_label (NULL, "Item")))
    #define ELEM_NUM 100
    #define NEW_GRP_ELEM_NUM 100
    
    GtkWidget* widget[ELEM_NUM];
    GtkWidget* wdg1;
    GtkWidget* wdg2;
    GSList* grp1;
    GSList* grp2;
    GSList* group_value;
    gint i;
    gint group_length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    wdg1 = gtk_radio_menu_item_new (NULL);
    wdg2 = gtk_radio_menu_item_new (NULL);
    
    grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1));
    grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg2));
    
    for (i = 0; i < ELEM_NUM; i++)
    {
        widget[i] = gtk_radio_menu_item_new (grp1);
    
        if (!widget[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL); 
            return;
        } 
    
        if (!GTK_IS_RADIO_MENU_ITEM (widget[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL); 
            return;
        }
    
        grp1 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    /* change group for a few elements */
    for (i = 0; i < NEW_GRP_ELEM_NUM; i++)
    {
        gtk_radio_menu_item_set_group (GTK_RADIO_MENU_ITEM (widget[i]), grp2);
        grp2 = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
    }
    
    for (i = 1; i < NEW_GRP_ELEM_NUM; i++)
    {
        group_value = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (widget[i]));
        if (group_value != grp2)
        {
            TEST_FAIL ("changed group: group of widget[%i] is wrong", i);
        }
    }
    
    group_length = g_slist_length (gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (wdg1)));
    if (group_length != ELEM_NUM - NEW_GRP_ELEM_NUM + 1)
    {
        TEST_FAIL ("changed group: old group_length = %d, should be %d", group_length, ELEM_NUM - NEW_GRP_ELEM_NUM + 1);
    } 
    
    /******* VISUALISATION *******/
    {
        gint i;
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        for (i = 0; i < ELEM_NUM; i++)
        {
            gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget[i]);
        }
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget[0]));
    
    #undef ELEM_NUM
    #undef NEW_GRP_ELEM_NUM
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkRadioMenuItem ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {NULL,0}
};
