/*
 * GtkRange methods tests
 * Testing GtkRange methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include <float.h>
gboolean result;

void global_value_changed_signal (GtkRange *range, gpointer user_data)
{
    result = TRUE;
}

/*
 * Name: gtk_range_set_adjustment
 * Params: GtkRange *range, GtkAdjustment* adj
 * Returns: void
 * Assertion: Sets the adjustment to be used as the "model" object for this range widget
 * Params Values: GtkRange *range, GtkAdjustment* adj
 * Expected: void  
 */
static void test_purpose_1()
{
    #define RANGE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0))
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    GtkAdjustment* real_adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    adj = ADJ;
    if (!adj)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_adjustment (GTK_RANGE (widget), adj);
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adj, NULL);
    
    if (adj != real_adj)
    {
        TEST_FAIL ("adjustment = %p %p", real_adj, adj);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE
    #undef ADJ 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_adjustment
 * Params: GtkRange *range, GtkAdjustment* adj
 * Returns: void
 * Assertion: Sets the adjustment to be used as the "model" object for this range widget
 * Params Values: GtkRange *range, GtkAdjustment* adj
 * Expected: void  
 */
static void test_purpose_2()
{
    #define RANGE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 20.0, 5.0, 10.0, 20.0))
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    GtkAdjustment* real_adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    adj = ADJ;
    if (!adj)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_adjustment (GTK_RANGE (widget), adj);
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adj, NULL);
    
    if (adj != real_adj)
    {
        TEST_FAIL ("adjustment = %p %p", real_adj, adj);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE
    #undef ADJ 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_adjustment
 * Params: GtkRange *range, GtkAdjustment* adj
 * Returns: void
 * Assertion: Sets the adjustment to be used as the "model" object for this range widget
 * Params Values: GtkRange *range, GtkAdjustment* adj
 * Expected: void  
 */
static void test_purpose_3()
{
    #define RANGE gtk_vscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0))
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    GtkAdjustment* real_adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    adj = ADJ;
    if (!adj)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_adjustment (GTK_RANGE (widget), adj);
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adj, NULL);
    
    if (adj != real_adj)
    {
        TEST_FAIL ("adjustment = %p %p", real_adj, adj);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE
    #undef ADJ 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_adjustment
 * Params: GtkRange *range, GtkAdjustment* adj
 * Returns: void
 * Assertion: Sets the adjustment to be used as the "model" object for this range widget
 * Params Values: GtkRange *range, GtkAdjustment* adj
 * Expected: void  
 */
static void test_purpose_4()
{
    #define RANGE gtk_hscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 20.0, 5.0, 10.0, 20.0))
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    GtkAdjustment* real_adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    adj = ADJ;
    if (!adj)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_adjustment (GTK_RANGE (widget), adj);
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adj, NULL);
    
    if (adj != real_adj)
    {
        TEST_FAIL ("adjustment = %p %p", real_adj, adj);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE
    #undef ADJ 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_get_adjustment
 * Params: GtkRange *range
 * Returns: GtkAdjustment*
 * Assertion: Get the GtkAdjustment which is the "model" object for GtkRange
 * Params Values: GtkRange *range
 * Expected: GtkAdjustment*  
 */
static void test_purpose_5()
{
    #define RANGE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0))
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    adj = ADJ;
    if (!adj)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "adjustment", adj, NULL);
    if (adj != gtk_range_get_adjustment(GTK_RANGE (widget)))
    {
        TEST_FAIL ("adjustment = %p %p", gtk_range_get_adjustment(GTK_RANGE (widget)), adj);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE
    #undef ADJ 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_get_adjustment
 * Params: GtkRange *range
 * Returns: GtkAdjustment*
 * Assertion: Get the GtkAdjustment which is the "model" object for GtkRange
 * Params Values: GtkRange *range
 * Expected: GtkAdjustment*  
 */
static void test_purpose_6()
{
    #define RANGE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 20.0, 5.0, 10.0, 20.0))
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    adj = ADJ;
    if (!adj)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "adjustment", adj, NULL);
    if (adj != gtk_range_get_adjustment(GTK_RANGE (widget)))
    {
        TEST_FAIL ("adjustment = %p %p", gtk_range_get_adjustment(GTK_RANGE (widget)), adj);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE
    #undef ADJ 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_get_adjustment
 * Params: GtkRange *range
 * Returns: GtkAdjustment*
 * Assertion: Get the GtkAdjustment which is the "model" object for GtkRange
 * Params Values: GtkRange *range
 * Expected: GtkAdjustment*  
 */
static void test_purpose_7()
{
    #define RANGE gtk_vscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0))
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    adj = ADJ;
    if (!adj)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "adjustment", adj, NULL);
    if (adj != gtk_range_get_adjustment(GTK_RANGE (widget)))
    {
        TEST_FAIL ("adjustment = %p %p", gtk_range_get_adjustment(GTK_RANGE (widget)), adj);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE
    #undef ADJ 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_get_adjustment
 * Params: GtkRange *range
 * Returns: GtkAdjustment*
 * Assertion: Get the GtkAdjustment which is the "model" object for GtkRange
 * Params Values: GtkRange *range
 * Expected: GtkAdjustment*  
 */
static void test_purpose_8()
{
    #define RANGE gtk_hscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 20.0, 5.0, 10.0, 20.0))
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    adj = ADJ;
    if (!adj)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "adjustment", adj, NULL);
    if (adj != gtk_range_get_adjustment(GTK_RANGE (widget)))
    {
        TEST_FAIL ("adjustment = %p %p", gtk_range_get_adjustment(GTK_RANGE (widget)), adj);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE
    #undef ADJ 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_inverted
 * Params: GtkRange *range, gboolean inverted
 * Returns: void
 * Assertion: Ranges normally move from lower to higher values as the slider moves from top to bottom or left to right
 * Params Values: GtkRange *range, gboolean inverted
 * Expected: void
 * 
 * Name: gtk_range_set_inverted
 * Params: GtkRange *range, gboolean inverted
 * Returns: void
 * Assertion:  Inverted ranges have higher values at the top or on the right rather than on the bottom or left.
 * Params Values: GtkRange *range, gboolean inverted
 * Expected: void
 * 
 * Name: gtk_range_get_inverted
 * Params: GtkRange *range
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_range_set_inverted()
 * Params Values: GtkRange *range
 * Expected: TRUE  
 */
static void test_purpose_9()
{
    #define RANGE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define INVERTED TRUE
    
    GtkWidget *widget;
    gboolean inverted = INVERTED;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_inverted (GTK_RANGE (widget), inverted);
    if (inverted != gtk_range_get_inverted(GTK_RANGE (widget)))
    {
        TEST_FAIL ("inverted fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE 
    #undef INVERTED 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_inverted
 * Params: GtkRange *range, gboolean inverted
 * Returns: void
 * Assertion: Ranges normally move from lower to higher values as the slider moves from top to bottom or left to right
 * Params Values: GtkRange *range, gboolean inverted
 * Expected: void
 * 
 * Name: gtk_range_set_inverted
 * Params: GtkRange *range, gboolean inverted
 * Returns: void
 * Assertion:  Inverted ranges have higher values at the top or on the right rather than on the bottom or left.
 * Params Values: GtkRange *range, gboolean inverted
 * Expected: void
 * 
 * Name: gtk_range_get_inverted
 * Params: GtkRange *range
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_range_set_inverted()
 * Params Values: GtkRange *range
 * Expected: FALSE  
 */
static void test_purpose_10()
{
    #define RANGE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define INVERTED FALSE
    
    GtkWidget *widget;
    gboolean inverted = INVERTED;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_inverted (GTK_RANGE (widget), inverted);
    if (inverted != gtk_range_get_inverted(GTK_RANGE (widget)))
    {
        TEST_FAIL ("inverted fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE 
    #undef INVERTED 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_update_policy
 * Params: GtkRange *range, GtkUpdateType policy
 * Returns: void
 * Assertion: Sets the update policy for the range
 * Params Values: GtkRange *range, GTK_UPDATE_CONTINUOUS
 * Expected: void  
 */
static void test_purpose_11()
{
    #define RANGE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define POLICY GTK_UPDATE_CONTINUOUS
    
    GtkWidget *widget;
    GtkUpdateType policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_update_policy (GTK_RANGE (widget), POLICY);
    g_object_get (GTK_OBJECT (widget), "update-policy", &policy, NULL);
    
    if (policy != POLICY)
    {
        TEST_FAIL ("update policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE 
    #undef POLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_update_policy
 * Params: GtkRange *range, GtkUpdateType policy
 * Returns: void
 * Assertion: Sets the update policy for the range
 * Params Values: GtkRange *range, GTK_UPDATE_DISCONTINUOUS
 * Expected: void  
 */
static void test_purpose_12()
{
    #define RANGE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define POLICY GTK_UPDATE_DISCONTINUOUS
    
    GtkWidget *widget;
    GtkUpdateType policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_update_policy (GTK_RANGE (widget), POLICY);
    g_object_get (GTK_OBJECT (widget), "update-policy", &policy, NULL);
    
    if (policy != POLICY)
    {
        TEST_FAIL ("update policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE 
    #undef POLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_update_policy
 * Params: GtkRange *range, GtkUpdateType policy
 * Returns: void
 * Assertion: Sets the update policy for the range
 * Params Values: GtkRange *range, GTK_UPDATE_DELAYED
 * Expected: void  
 */
static void test_purpose_13()
{
    #define RANGE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define POLICY GTK_UPDATE_DELAYED
    
    GtkWidget *widget;
    GtkUpdateType policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_update_policy (GTK_RANGE (widget), POLICY);
    g_object_get (GTK_OBJECT (widget), "update-policy", &policy, NULL);
    
    if (policy != POLICY)
    {
        TEST_FAIL ("update policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE 
    #undef POLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_update_policy
 * Params: GtkRange *range, GtkUpdateType policy
 * Returns: void
 * Assertion: Sets the update policy for the range
 * Params Values: GtkRange *range, GTK_UPDATE_DISCONTINUOUS
 * Expected: void  
 */
static void test_purpose_14()
{
    #define RANGE gtk_vscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define POLICY GTK_UPDATE_DISCONTINUOUS
    
    GtkWidget *widget;
    GtkUpdateType policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_update_policy (GTK_RANGE (widget), POLICY);
    g_object_get (GTK_OBJECT (widget), "update-policy", &policy, NULL);
    
    if (policy != POLICY)
    {
        TEST_FAIL ("update policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE 
    #undef POLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_get_update_policy
 * Params: GtkRange *range 
 * Returns: GtkUpdateType
 * Assertion: Gets the update policy of range.
 * Params Values: GtkRange *range
 * Expected: GtkUpdateType  
 */
static void test_purpose_15()
{
    #define RANGE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define POLICY GTK_UPDATE_CONTINUOUS
    
    GtkWidget *widget;
    GtkUpdateType policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "update-policy", POLICY, NULL);
    policy = gtk_range_get_update_policy (GTK_RANGE (widget));
    
    if (policy != POLICY)
    {
        TEST_FAIL ("update policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE 
    #undef POLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_get_update_policy
 * Params: GtkRange *range 
 * Returns: GtkUpdateType
 * Assertion: Gets the update policy of range.
 * Params Values: GtkRange *range
 * Expected: GtkUpdateType  
 */
static void test_purpose_16()
{
    #define RANGE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define POLICY GTK_UPDATE_DISCONTINUOUS
    
    GtkWidget *widget;
    GtkUpdateType policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "update-policy", POLICY, NULL);
    policy = gtk_range_get_update_policy (GTK_RANGE (widget));
    
    if (policy != POLICY)
    {
        TEST_FAIL ("update policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE 
    #undef POLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_get_update_policy
 * Params: GtkRange *range 
 * Returns: GtkUpdateType
 * Assertion: Gets the update policy of range.
 * Params Values: GtkRange *range
 * Expected: GtkUpdateType  
 */
static void test_purpose_17()
{
    #define RANGE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define POLICY GTK_UPDATE_DELAYED
    
    GtkWidget *widget;
    GtkUpdateType policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "update-policy", POLICY, NULL);
    policy = gtk_range_get_update_policy (GTK_RANGE (widget));
    
    if (policy != POLICY)
    {
        TEST_FAIL ("update policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE 
    #undef POLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_get_update_policy
 * Params: GtkRange *range 
 * Returns: GtkUpdateType
 * Assertion: Gets the update policy of range.
 * Params Values: GtkRange *range
 * Expected: GtkUpdateType  
 */
static void test_purpose_18()
{
    #define RANGE gtk_vscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define POLICY GTK_UPDATE_DISCONTINUOUS
    
    GtkWidget *widget;
    GtkUpdateType policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "update-policy", POLICY, NULL);
    policy = gtk_range_get_update_policy (GTK_RANGE (widget));
    
    if (policy != POLICY)
    {
        TEST_FAIL ("update policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE 
    #undef POLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_value
 * Params: GtkRange *range, gdouble value
 * Returns: void
 * Assertion: Sets the current value of the range; if the value is outside the minimum or maximum range values, it will be clamped to fit inside them.
 * Params Values: GtkRange *range, 0.0
 * Expected: void
 * 
 * Name: gtk_range_set_value
 * Params: GtkRange *range, gdouble value
 * Returns: void
 * Assertion: The range emits the "value_changed" signal if the value changes.
 * Params Values: GtkRange *range, 0.0
 * Expected: void
 * 
 * Name: gtk_range_get_value
 * Params: GtkRange *range
 * Returns: gdouble
 * Assertion: Gets the current value of the range.
 * Params Values: GtkRange *range
 * Expected: gdouble  
 */
static void test_purpose_19()
{
    #define WIDGET gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new ((LOWER + UPPER) / 2.0, LOWER, UPPER, 0.0, 0.0, 0.0)))
    #define LOWER 0.0
    #define UPPER 10.0
    #define VALUE 5.1
    
    GtkWidget *widget;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "value-changed", GTK_SIGNAL_FUNC (global_value_changed_signal), NULL);
    
    gtk_range_set_value (GTK_RANGE (widget), VALUE);
    value = gtk_range_get_value (GTK_RANGE (widget));
    
    if (value != VALUE)
    {
        if ((VALUE < LOWER) && (value != LOWER))
            TEST_FAIL ("VALUE should be equal to LOWER", NULL);
        if ((UPPER < VALUE) && (value != UPPER))
            TEST_FAIL ("VALUE should be equal to UPPER", NULL);
        if ((UPPER <= VALUE) && (VALUE <= LOWER))
            TEST_FAIL ("VALUE is wrong", NULL);
    }
    
    if (!result)
    {
        TEST_FAIL ("'value-changed' signal not catched", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER
    #undef UPPER
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_value
 * Params: GtkRange *range, gdouble value
 * Returns: void
 * Assertion: Sets the current value of the range; if the value is outside the minimum or maximum range values, it will be clamped to fit inside them.
 * Params Values: GtkRange *range, 1.0
 * Expected: void
 * 
 * Name: gtk_range_set_value
 * Params: GtkRange *range, gdouble value
 * Returns: void
 * Assertion: The range emits the "value_changed" signal if the value changes.
 * Params Values: GtkRange *range, 1.0
 * Expected: void
 * 
 * Name: gtk_range_get_value
 * Params: GtkRange *range
 * Returns: gdouble
 * Assertion: Gets the current value of the range.
 * Params Values: GtkRange *range
 * Expected: gdouble  
 */
static void test_purpose_20()
{
    #define WIDGET gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new ((LOWER + UPPER) / 2.0, LOWER, UPPER, 0.0, 0.0, 00)))
    #define LOWER 1.0
    #define UPPER 10.0
    #define VALUE 0.5
    
    GtkWidget *widget;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "value-changed", GTK_SIGNAL_FUNC (global_value_changed_signal), NULL);
    
    gtk_range_set_value (GTK_RANGE (widget), VALUE);
    value = gtk_range_get_value (GTK_RANGE (widget));
    
    if (value != VALUE)
    {
        if ((VALUE < LOWER) && (value != LOWER))
            TEST_FAIL ("VALUE should be equal to LOWER", NULL);
        if ((UPPER < VALUE) && (value != UPPER))
            TEST_FAIL ("VALUE should be equal to UPPER", NULL);
        if ((UPPER <= VALUE) && (VALUE <= LOWER))
            TEST_FAIL ("VALUE is wrong", NULL);
    }
    
    if (!result)
    {
        TEST_FAIL ("'value-changed' signal not catched", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER
    #undef UPPER
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_value
 * Params: GtkRange *range, gdouble value
 * Returns: void
 * Assertion: Sets the current value of the range; if the value is outside the minimum or maximum range values, it will be clamped to fit inside them.
 * Params Values: GtkRange *range, 0.0
 * Expected: void
 * 
 * Name: gtk_range_set_value
 * Params: GtkRange *range, gdouble value
 * Returns: void
 * Assertion: The range emits the "value_changed" signal if the value changes.
 * Params Values: GtkRange *range, 0.0
 * Expected: void
 * 
 * Name: gtk_range_get_value
 * Params: GtkRange *range
 * Returns: gdouble
 * Assertion: Gets the current value of the range.
 * Params Values: GtkRange *range
 * Expected: gdouble  
 */
static void test_purpose_21()
{
    #define WIDGET gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new ((LOWER + UPPER) / 2.0, LOWER, UPPER, 0.0, 0.0, 0.0)))
    #define LOWER 0.0
    #define UPPER 10.0
    #define VALUE 5.1
    
    GtkWidget *widget;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "value-changed", GTK_SIGNAL_FUNC (global_value_changed_signal), NULL);
    
    gtk_range_set_value (GTK_RANGE (widget), VALUE);
    value = gtk_range_get_value (GTK_RANGE (widget));
    
    if (value != VALUE)
    {
        if ((VALUE < LOWER) && (value != LOWER))
            TEST_FAIL ("VALUE should be equal to LOWER", NULL);
        if ((UPPER < VALUE) && (value != UPPER))
            TEST_FAIL ("VALUE should be equal to UPPER", NULL);
        if ((UPPER <= VALUE) && (VALUE <= LOWER))
            TEST_FAIL ("VALUE is wrong", NULL);
    }
    
    if (!result)
    {
        TEST_FAIL ("'value-changed' signal not catched", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER
    #undef UPPER
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_value
 * Params: GtkRange *range, gdouble value
 * Returns: void
 * Assertion: Sets the current value of the range; if the value is outside the minimum or maximum range values, it will be clamped to fit inside them.
 * Params Values: GtkRange *range, 1.0
 * Expected: void
 * 
 * Name: gtk_range_set_value
 * Params: GtkRange *range, gdouble value
 * Returns: void
 * Assertion: The range emits the "value_changed" signal if the value changes.
 * Params Values: GtkRange *range, 1.0
 * Expected: void
 * 
 * Name: gtk_range_get_value
 * Params: GtkRange *range
 * Returns: gdouble
 * Assertion: Gets the current value of the range.
 * Params Values: GtkRange *range
 * Expected: gdouble  
 */
static void test_purpose_22()
{
    #define WIDGET gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new ((LOWER + UPPER) / 2.0, LOWER, UPPER, 0.0, 0.0, 00)))
    #define LOWER 1.0
    #define UPPER 10.0
    #define VALUE 0.5
    
    GtkWidget *widget;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "value-changed", GTK_SIGNAL_FUNC (global_value_changed_signal), NULL);
    
    gtk_range_set_value (GTK_RANGE (widget), VALUE);
    value = gtk_range_get_value (GTK_RANGE (widget));
    
    if (value != VALUE)
    {
        if ((VALUE < LOWER) && (value != LOWER))
            TEST_FAIL ("VALUE should be equal to LOWER", NULL);
        if ((UPPER < VALUE) && (value != UPPER))
            TEST_FAIL ("VALUE should be equal to UPPER", NULL);
        if ((UPPER <= VALUE) && (VALUE <= LOWER))
            TEST_FAIL ("VALUE is wrong", NULL);
    }
    
    if (!result)
    {
        TEST_FAIL ("'value-changed' signal not catched", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER
    #undef UPPER
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_value
 * Params: GtkRange *range, gdouble value
 * Returns: void
 * Assertion: Sets the current value of the range; if the value is outside the minimum or maximum range values, it will be clamped to fit inside them.
 * Params Values: GtkRange *range, 0.0
 * Expected: void
 * 
 * Name: gtk_range_set_value
 * Params: GtkRange *range, gdouble value
 * Returns: void
 * Assertion: The range emits the "value_changed" signal if the value changes.
 * Params Values: GtkRange *range, 0.0
 * Expected: void
 * 
 * Name: gtk_range_get_value
 * Params: GtkRange *range
 * Returns: gdouble
 * Assertion: Gets the current value of the range.
 * Params Values: GtkRange *range
 * Expected: gdouble  
 */
static void test_purpose_23()
{
    #define WIDGET gtk_hscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new ((LOWER + UPPER) / 2.0, LOWER, UPPER, 0.0, 0.0, 0.0)))
    #define LOWER 0.0
    #define UPPER 11.0
    #define VALUE 12.0
    
    GtkWidget *widget;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "value-changed", GTK_SIGNAL_FUNC (global_value_changed_signal), NULL);
    
    gtk_range_set_value (GTK_RANGE (widget), VALUE);
    value = gtk_range_get_value (GTK_RANGE (widget));
    
    if (value != VALUE)
    {
        if ((VALUE < LOWER) && (value != LOWER))
            TEST_FAIL ("VALUE should be equal to LOWER", NULL);
        if ((UPPER < VALUE) && (value != UPPER))
            TEST_FAIL ("VALUE should be equal to UPPER", NULL);
        if ((UPPER <= VALUE) && (VALUE <= LOWER))
            TEST_FAIL ("VALUE is wrong", NULL);
    }
    
    if (!result)
    {
        TEST_FAIL ("'value-changed' signal not catched", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER
    #undef UPPER
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_value
 * Params: GtkRange *range, gdouble value
 * Returns: void
 * Assertion: Sets the current value of the range; if the value is outside the minimum or maximum range values, it will be clamped to fit inside them.
 * Params Values: GtkRange *range, 0.0
 * Expected: void
 * 
 * Name: gtk_range_set_value
 * Params: GtkRange *range, gdouble value
 * Returns: void
 * Assertion: The range emits the "value_changed" signal if the value changes.
 * Params Values: GtkRange *range, 0.0
 * Expected: void
 * 
 * Name: gtk_range_get_value
 * Params: GtkRange *range
 * Returns: gdouble
 * Assertion: Gets the current value of the range.
 * Params Values: GtkRange *range
 * Expected: gdouble  
 */
static void test_purpose_24()
{
    #define WIDGET gtk_vscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new ((LOWER + UPPER) / 2.0, LOWER, UPPER, 0.0, 0.0, 0.0)))
    #define LOWER 0.0
    #define UPPER G_MAXDOUBLE
    #define VALUE G_MAXDOUBLE
    
    GtkWidget *widget;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "value-changed", GTK_SIGNAL_FUNC (global_value_changed_signal), NULL);
    
    gtk_range_set_value (GTK_RANGE (widget), VALUE);
    value = gtk_range_get_value (GTK_RANGE (widget));
    
    if (value != VALUE)
    {
        if ((VALUE < LOWER) && (value != LOWER))
            TEST_FAIL ("VALUE should be equal to LOWER", NULL);
        if ((UPPER < VALUE) && (value != UPPER))
            TEST_FAIL ("VALUE should be equal to UPPER", NULL);
        if ((UPPER <= VALUE) && (VALUE <= LOWER))
            TEST_FAIL ("VALUE is wrong", NULL);
    }
    
    if (!result)
    {
        TEST_FAIL ("'value-changed' signal not catched", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER
    #undef UPPER
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_range
 * Params: GtkRange *range, gdouble min, gdouble max
 * Returns: void
 * Assertion: Sets the allowable values in the GtkRange, and clamps the range value to be between min and max.
 * Params Values: GtkRange *range, 0, 10
 * Expected: void
 * 
 * Name: gtk_range_set_range
 * Params: GtkRange *range, gdouble min, gdouble max
 * Returns: void
 * Assertion: (If the range has a non-zero page size, it is clamped between min and max - page-size.)
 * Params Values: GtkRange *range, 0, 10
 * Expected: void  
 */
static void test_purpose_25()
{
    #define WIDGET gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (20.0, 0.0, 100.0, 0.0, 0.0, 0.0)))
    #define MIN_R 0
    #define MAX_R 10
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    gdouble value;
    gdouble page_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_range (GTK_RANGE (widget), MIN_R, MAX_R);
    
    adj = gtk_range_get_adjustment (GTK_RANGE (widget));
    page_size = adj->page_size;
    value = gtk_range_get_value (GTK_RANGE (widget));
    
    if ((adj->lower != MIN_R) || (adj->upper != MAX_R))
    {
        TEST_FAIL ("Bounds not equal", NULL);
    }
      
    if ((value < (gdouble) MIN_R) || ((gdouble)MAX_R - page_size < value))
    {
        TEST_FAIL ("value = %f should be in range [%f, %f]", value, (gdouble)MIN_R, (gdouble)MAX_R - page_size);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef MIN_R
    #undef MAX_R
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_range
 * Params: GtkRange *range, gdouble min, gdouble max
 * Returns: void
 * Assertion: Sets the allowable values in the GtkRange, and clamps the range value to be between min and max.
 * Params Values: GtkRange *range, 1, 10
 * Expected: void
 * 
 * Name: gtk_range_set_range
 * Params: GtkRange *range, gdouble min, gdouble max
 * Returns: void
 * Assertion: (If the range has a non-zero page size, it is clamped between min and max - page-size.)
 * Params Values: GtkRange *range, 1, 10
 * Expected: void  
 */
static void test_purpose_26()
{
    #define WIDGET gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (100.0, 5.0, 200.0, 0.0, 0.0, 0.0)))
    #define MIN_R 1
    #define MAX_R 10
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    gdouble value;
    gdouble page_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_range (GTK_RANGE (widget), MIN_R, MAX_R);
    
    adj = gtk_range_get_adjustment (GTK_RANGE (widget));
    page_size = adj->page_size;
    value = gtk_range_get_value (GTK_RANGE (widget));
    
    if ((adj->lower != MIN_R) || (adj->upper != MAX_R))
    {
        TEST_FAIL ("Bounds not equal", NULL);
    }
      
    if ((value < (gdouble) MIN_R) || ((gdouble)MAX_R - page_size < value))
    {
        TEST_FAIL ("value = %f should be in range [%f, %f]", value, (gdouble)MIN_R, (gdouble)MAX_R - page_size);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef MIN_R
    #undef MAX_R
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_range
 * Params: GtkRange *range, gdouble min, gdouble max
 * Returns: void
 * Assertion: Sets the allowable values in the GtkRange, and clamps the range value to be between min and max.
 * Params Values: GtkRange *range, 0, G_MAXDOUBLE
 * Expected: void
 * 
 * Name: gtk_range_set_range
 * Params: GtkRange *range, gdouble min, gdouble max
 * Returns: void
 * Assertion: (If the range has a non-zero page size, it is clamped between min and max - page-size.)
 * Params Values: GtkRange *range, 0, G_MAXDOUBLE
 * Expected: void  
 */
static void test_purpose_27()
{
    #define WIDGET gtk_vscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 1.0, 2.0, 0.0, 0.0, 0.0)))
    #define MIN_R 0
    #define MAX_R G_MAXDOUBLE
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    gdouble value;
    gdouble page_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_range (GTK_RANGE (widget), MIN_R, MAX_R);
    
    adj = gtk_range_get_adjustment (GTK_RANGE (widget));
    page_size = adj->page_size;
    value = gtk_range_get_value (GTK_RANGE (widget));
    
    if ((adj->lower != MIN_R) || (adj->upper != MAX_R))
    {
        TEST_FAIL ("Bounds not equal", NULL);
    }
      
    if ((value < (gdouble) MIN_R) || ((gdouble)MAX_R - page_size < value))
    {
        TEST_FAIL ("value = %f should be in range [%f, %f]", value, (gdouble)MIN_R, (gdouble)MAX_R - page_size);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef MIN_R
    #undef MAX_R
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_range
 * Params: GtkRange *range, gdouble min, gdouble max
 * Returns: void
 * Assertion: Sets the allowable values in the GtkRange, and clamps the range value to be between min and max.
 * Params Values: GtkRange *range, 0, 10
 * Expected: void
 * 
 * Name: gtk_range_set_range
 * Params: GtkRange *range, gdouble min, gdouble max
 * Returns: void
 * Assertion: (If the range has a non-zero page size, it is clamped between min and max - page-size.)
 * Params Values: GtkRange *range, 0, 10
 * Expected: void  
 */
static void test_purpose_28()
{
    #define WIDGET gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (20.0, 0.0, 100.0, 0.0, 1.0, 0.0)))
    #define MIN_R 0
    #define MAX_R 10
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    gdouble value;
    gdouble page_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_range (GTK_RANGE (widget), MIN_R, MAX_R);
    
    adj = gtk_range_get_adjustment (GTK_RANGE (widget));
    page_size = adj->page_size;
    value = gtk_range_get_value (GTK_RANGE (widget));
    
    if ((adj->lower != MIN_R) || (adj->upper != MAX_R))
    {
        TEST_FAIL ("Bounds not equal", NULL);
    }
      
    if ((value < (gdouble) MIN_R) || ((gdouble)MAX_R - page_size < value))
    {
        TEST_FAIL ("value = %f should be in range [%f, %f]", value, (gdouble)MIN_R, (gdouble)MAX_R - page_size);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef MIN_R
    #undef MAX_R
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_range
 * Params: GtkRange *range, gdouble min, gdouble max
 * Returns: void
 * Assertion: Sets the allowable values in the GtkRange, and clamps the range value to be between min and max.
 * Params Values: GtkRange *range, 1, 10
 * Expected: void
 * 
 * Name: gtk_range_set_range
 * Params: GtkRange *range, gdouble min, gdouble max
 * Returns: void
 * Assertion: (If the range has a non-zero page size, it is clamped between min and max - page-size.)
 * Params Values: GtkRange *range, 1, 10
 * Expected: void  
 */
static void test_purpose_29()
{
    #define WIDGET gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (100.0, 5.0, 200.0, 0.0, 5.0, 0.0)))
    #define MIN_R 1
    #define MAX_R 10
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    gdouble value;
    gdouble page_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_range (GTK_RANGE (widget), MIN_R, MAX_R);
    
    adj = gtk_range_get_adjustment (GTK_RANGE (widget));
    page_size = adj->page_size;
    value = gtk_range_get_value (GTK_RANGE (widget));
    
    if ((adj->lower != MIN_R) || (adj->upper != MAX_R))
    {
        TEST_FAIL ("Bounds not equal", NULL);
    }
      
    if ((value < (gdouble) MIN_R) || ((gdouble)MAX_R - page_size < value))
    {
        TEST_FAIL ("value = %f should be in range [%f, %f]", value, (gdouble)MIN_R, (gdouble)MAX_R - page_size);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef MIN_R
    #undef MAX_R
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_range
 * Params: GtkRange *range, gdouble min, gdouble max
 * Returns: void
 * Assertion: Sets the allowable values in the GtkRange, and clamps the range value to be between min and max.
 * Params Values: GtkRange *range, 0, G_MAXDOUBLE
 * Expected: void
 * 
 * Name: gtk_range_set_range
 * Params: GtkRange *range, gdouble min, gdouble max
 * Returns: void
 * Assertion: (If the range has a non-zero page size, it is clamped between min and max - page-size.)
 * Params Values: GtkRange *range, 0, G_MAXDOUBLE
 * Expected: void  
 */
static void test_purpose_30()
{
    #define WIDGET gtk_vscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 1.0, 2.0, 0.0, 6.0, 0.0)))
    #define MIN_R 0
    #define MAX_R G_MAXDOUBLE
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    gdouble value;
    gdouble page_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_range (GTK_RANGE (widget), MIN_R, MAX_R);
    
    adj = gtk_range_get_adjustment (GTK_RANGE (widget));
    page_size = adj->page_size;
    value = gtk_range_get_value (GTK_RANGE (widget));
    
    if ((adj->lower != MIN_R) || (adj->upper != MAX_R))
    {
        TEST_FAIL ("Bounds not equal", NULL);
    }
      
    if ((value < (gdouble) MIN_R) || ((gdouble)MAX_R - page_size < value))
    {
        TEST_FAIL ("value = %f should be in range [%f, %f]", value, (gdouble)MIN_R, (gdouble)MAX_R - page_size);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef MIN_R
    #undef MAX_R
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_increments
 * Params: GtkRange *range, gdouble step, gdouble page
 * Returns: void
 * Assertion: Sets the step and page sizes for the range.
 * Params Values: GtkRange *range, 1, 1
 * Expected: void  
 */
static void test_purpose_31()
{
    #define WIDGET gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (20.0, 0.0, 100.0, 0.0, 0.0, 0.0)))
    #define STEP 1
    #define PAGE 1
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_increments (GTK_RANGE (widget), STEP, PAGE);
    adj = gtk_range_get_adjustment (GTK_RANGE (widget));
    
    if ((adj->step_increment != STEP) || (adj->page_increment != PAGE))
    {
        TEST_FAIL ("increments not equal", NULL);
    }
      
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef STEP
    #undef PAGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_increments
 * Params: GtkRange *range, gdouble step, gdouble page
 * Returns: void
 * Assertion: Sets the step and page sizes for the range.
 * Params Values: GtkRange *range, 1, 10
 * Expected: void  
 */
static void test_purpose_32()
{
    #define WIDGET gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (100.0, 5.0, 200.0, 0.0, 0.0, 0.0)))
    #define STEP 1
    #define PAGE 10
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_increments (GTK_RANGE (widget), STEP, PAGE);
    adj = gtk_range_get_adjustment (GTK_RANGE (widget));
    
    if ((adj->step_increment != STEP) || (adj->page_increment != PAGE))
    {
        TEST_FAIL ("increments not equal", NULL);
    }
      
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef STEP
    #undef PAGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_set_increments
 * Params: GtkRange *range, gdouble step, gdouble page
 * Returns: void
 * Assertion: Sets the step and page sizes for the range.
 * Params Values: GtkRange *range, 100, G_MAXDOUBLE
 * Expected: void  
 */
static void test_purpose_33()
{
    #define WIDGET gtk_hscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, G_MAXDOUBLE, 0.0, 0.0, 0.0)))
    #define STEP 100
    #define PAGE G_MAXDOUBLE
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_range_set_increments (GTK_RANGE (widget), STEP, PAGE);
    adj = gtk_range_get_adjustment (GTK_RANGE (widget));
    
    if ((adj->step_increment != STEP) || (adj->page_increment != PAGE))
    {
        TEST_FAIL ("increments not equal", NULL);
    }
      
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef STEP
    #undef PAGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_get_adjustment
 * Params: GtkRange *range
 * Returns: GtkAdjustment*
 * Assertion: The return value does not have a reference added, so should not be unreferenced.
 * Params Values: GtkRange *range
 * Expected: GtkAdjustment*  
 */
static void test_purpose_34()
{
    #define RANGE gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0))
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    adj = ADJ;
    if (!adj)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "adjustment", adj, NULL);
    
    ref_c1 = G_OBJECT (widget)->ref_count;
    
    adj = gtk_range_get_adjustment(GTK_RANGE (widget));
    
    ref_c2 = G_OBJECT (adj)->ref_count;
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE
    #undef ADJ 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_get_adjustment
 * Params: GtkRange *range
 * Returns: GtkAdjustment*
 * Assertion: The return value does not have a reference added, so should not be unreferenced.
 * Params Values: GtkRange *range
 * Expected: GtkAdjustment*  
 */
static void test_purpose_35()
{
    #define RANGE gtk_vscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 20.0, 5.0, 10.0, 20.0))
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    adj = ADJ;
    if (!adj)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "adjustment", adj, NULL);
    
    ref_c1 = G_OBJECT (widget)->ref_count;
    
    adj = gtk_range_get_adjustment(GTK_RANGE (widget));
    
    ref_c2 = G_OBJECT (adj)->ref_count;
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE
    #undef ADJ 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_get_adjustment
 * Params: GtkRange *range
 * Returns: GtkAdjustment*
 * Assertion: The return value does not have a reference added, so should not be unreferenced.
 * Params Values: GtkRange *range
 * Expected: GtkAdjustment*  
 */
static void test_purpose_36()
{
    #define RANGE gtk_vscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0))
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    adj = ADJ;
    if (!adj)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "adjustment", adj, NULL);
    
    ref_c1 = G_OBJECT (widget)->ref_count;
    
    adj = gtk_range_get_adjustment(GTK_RANGE (widget));
    
    ref_c2 = G_OBJECT (adj)->ref_count;
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE
    #undef ADJ 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_range_get_adjustment
 * Params: GtkRange *range
 * Returns: GtkAdjustment*
 * Assertion: The return value does not have a reference added, so should not be unreferenced.
 * Params Values: GtkRange *range
 * Expected: GtkAdjustment*  
 */
static void test_purpose_37()
{
    #define RANGE gtk_hscrollbar_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)))  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 20.0, 5.0, 10.0, 20.0))
    
    GtkWidget *widget;
    GtkAdjustment* adj;
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = RANGE;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    adj = ADJ;
    if (!adj)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "adjustment", adj, NULL);
    
    ref_c1 = G_OBJECT (widget)->ref_count;
    
    adj = gtk_range_get_adjustment(GTK_RANGE (widget));
    
    ref_c2 = G_OBJECT (adj)->ref_count;
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RANGE
    #undef ADJ 
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkRange ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {NULL,0}
};
