/*
 * GtkTooltips methods tests
 * Testing GtkTooltips methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_tooltips_new
 * Params: void
 * Returns: GtkTooltips*
 * Assertion: Creates an empty group of tooltips.
 * Params Values: void
 * Expected: GtkTooltips*  
 */
static void test_purpose_1()
{
    GtkTooltips* widget;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_tooltips_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOOLTIPS (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    button = gtk_button_new_with_label ("Label");
    gtk_tooltips_set_tip (widget,button, "Tooltip 1", "Tooltip 2");
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (GTK_WIDGET (button));   
    /******* -------------  *******/ 
    
    gtk_object_destroy (GTK_OBJECT (widget));
    gtk_widget_destroy (GTK_WIDGET (gtk_widget_get_toplevel (button)));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tooltips_set_tip
 * Params: GtkTooltips *tooltips, GtkWidget *widget, const gchar *tip_text, const gchar *tip_private
 * Returns: void
 * Assertion: Adds a tooltip containing the message tip_text to the specified GtkWidget.
 * Params Values: GtkTooltips *tooltips, gtk_button_new_with_label("Button1"), "Load a new document into this window", "Requests the filename of a document." 
 * Expected: void
 * 
 * Name: gtk_tooltips_data_get
 * Params: GtkWidget*
 * Returns: GtkTooltipsData*
 * Assertion: Retrieves any GtkTooltipsData previously associated with the given widget.
 * Params Values: GtkWidget* set by gtk_tooltips_set_tip
 * Expected: GtkTooltips*  
 */
static void test_purpose_2()
{
    #define WIDGET gtk_button_new_with_label("Button1")
    #define TIP_TEXT "Load a new document into this window"
    #define TIP_PRIVATE "Requests the filename of a document."
    
    GtkTooltips* tooltips;
    GtkWidget* widget;
    GtkTooltipsData* tooltips_data;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tooltips =  gtk_tooltips_new ();
    
    if (!tooltips)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOOLTIPS (tooltips))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    widget = WIDGET;
    gtk_tooltips_set_tip (tooltips, widget, TIP_TEXT, TIP_PRIVATE);
    
    tooltips_data = gtk_tooltips_data_get (widget);
    if (tooltips_data == NULL)
    {
        TEST_FAIL ("tooltips_data = NULL", NULL);
        return;
    }
    
    if (tooltips_data->tooltips != tooltips)
    {
        TEST_FAIL ("tooltips_data->tooltips != tooltips", NULL);
    }
    
    if (tooltips_data->widget != widget)
    {
        TEST_FAIL ("tooltips_data->widget != widget", NULL);
    }
    
    if (strcmp (tooltips_data->tip_text, TIP_TEXT))
    {
        TEST_FAIL ("tooltips_data->tip_text = %s, should be %s", 
                   tooltips_data->tip_text, TIP_TEXT);
    }
    
    if (strcmp (tooltips_data->tip_private, TIP_PRIVATE))
    {
        TEST_FAIL ("tooltips_data->tip_private = %s, should be %s", 
                   tooltips_data->tip_private, TIP_PRIVATE);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (GTK_WIDGET (widget));   
    /******* -------------  *******/ 
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    gtk_object_destroy (GTK_OBJECT (tooltips));
    
    #undef WIDGET
    #undef TIP_TEXT
    #undef TIP_PRIVATE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tooltips_set_tip
 * Params: GtkTooltips *tooltips, GtkWidget *widget, const gchar *tip_text, const gchar *tip_private
 * Returns: void
 * Assertion: Adds a tooltip containing the message tip_text to the specified GtkWidget.
 * Params Values: GtkTooltips *tooltips, gtk_label_new("Label1"), "Load a new document into this window", "Requests the filename of a document." 
 * Expected: void
 * 
 * Name: gtk_tooltips_data_get
 * Params: GtkWidget*
 * Returns: GtkTooltipsData*
 * Assertion: Retrieves any GtkTooltipsData previously associated with the given widget.
 * Params Values: GtkWidget* set by gtk_tooltips_set_tip
 * Expected: GtkTooltips*  
 */
static void test_purpose_3()
{
    #define WIDGET gtk_label_new("Label1")
    #define TIP_TEXT "Load a new document into this window"
    #define TIP_PRIVATE "Requests the filename of a document."
    
    GtkTooltips* tooltips;
    GtkWidget* widget;
    GtkTooltipsData* tooltips_data;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tooltips =  gtk_tooltips_new ();
    
    if (!tooltips)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOOLTIPS (tooltips))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    widget = WIDGET;
    gtk_tooltips_set_tip (tooltips, widget, TIP_TEXT, TIP_PRIVATE);
    
    tooltips_data = gtk_tooltips_data_get (widget);
    if (tooltips_data == NULL)
    {
        TEST_FAIL ("tooltips_data = NULL", NULL);
        return;
    }
    
    if (tooltips_data->tooltips != tooltips)
    {
        TEST_FAIL ("tooltips_data->tooltips != tooltips", NULL);
    }
    
    if (tooltips_data->widget != widget)
    {
        TEST_FAIL ("tooltips_data->widget != widget", NULL);
    }
    
    if (strcmp (tooltips_data->tip_text, TIP_TEXT))
    {
        TEST_FAIL ("tooltips_data->tip_text = %s, should be %s", 
                   tooltips_data->tip_text, TIP_TEXT);
    }
    
    if (strcmp (tooltips_data->tip_private, TIP_PRIVATE))
    {
        TEST_FAIL ("tooltips_data->tip_private = %s, should be %s", 
                   tooltips_data->tip_private, TIP_PRIVATE);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (GTK_WIDGET (widget));   
    /******* -------------  *******/ 
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    gtk_object_destroy (GTK_OBJECT (tooltips));
    
    #undef WIDGET
    #undef TIP_TEXT
    #undef TIP_PRIVATE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tooltips_set_tip
 * Params: GtkTooltips *tooltips, GtkWidget *widget, const gchar *tip_text, const gchar *tip_private
 * Returns: void
 * Assertion: Adds a tooltip containing the message tip_text to the specified GtkWidget.
 * Params Values: GtkTooltips *tooltips, gtk_button_new_with_label("Button1"), "", "" 
 * Expected: void
 * 
 * Name: gtk_tooltips_data_get
 * Params: GtkWidget*
 * Returns: GtkTooltipsData*
 * Assertion: Retrieves any GtkTooltipsData previously associated with the given widget.
 * Params Values: GtkWidget* set by gtk_tooltips_set_tip
 * Expected: GtkTooltips*  
 */
static void test_purpose_4()
{
    #define WIDGET gtk_button_new_with_label("Button1")
    #define TIP_TEXT ""
    #define TIP_PRIVATE ""
    
    GtkTooltips* tooltips;
    GtkWidget* widget;
    GtkTooltipsData* tooltips_data;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tooltips =  gtk_tooltips_new ();
    
    if (!tooltips)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOOLTIPS (tooltips))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    widget = WIDGET;
    gtk_tooltips_set_tip (tooltips, widget, TIP_TEXT, TIP_PRIVATE);
    
    tooltips_data = gtk_tooltips_data_get (widget);
    if (tooltips_data == NULL)
    {
        TEST_FAIL ("tooltips_data = NULL", NULL);
        return;
    }
    
    if (tooltips_data->tooltips != tooltips)
    {
        TEST_FAIL ("tooltips_data->tooltips != tooltips", NULL);
    }
    
    if (tooltips_data->widget != widget)
    {
        TEST_FAIL ("tooltips_data->widget != widget", NULL);
    }
    
    if (strcmp (tooltips_data->tip_text, TIP_TEXT))
    {
        TEST_FAIL ("tooltips_data->tip_text = %s, should be %s", 
                   tooltips_data->tip_text, TIP_TEXT);
    }
    
    if (strcmp (tooltips_data->tip_private, TIP_PRIVATE))
    {
        TEST_FAIL ("tooltips_data->tip_private = %s, should be %s", 
                   tooltips_data->tip_private, TIP_PRIVATE);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (GTK_WIDGET (widget));   
    /******* -------------  *******/ 
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    gtk_object_destroy (GTK_OBJECT (tooltips));
    
    #undef WIDGET
    #undef TIP_TEXT
    #undef TIP_PRIVATE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tooltips_enable 
 * Params: GtkTooltips *tooltips
 * Returns: void
 * Assertion: Allows the user to see your tooltips as they navigate your application.
 * Params Values: GtkTooltips *tooltips
 * Expected: void  
 */
static void test_purpose_5()
{
    GtkTooltips* widget;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_tooltips_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOOLTIPS (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_tooltips_enable (widget);
    
    
    button = gtk_button_new_with_label ("Label");
    gtk_tooltips_set_tip (widget,button, "Tooltip 1", "Tooltip 2");
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (button);   
    /******* -------------  *******/ 
    
    gtk_object_destroy (GTK_OBJECT (widget));
    gtk_widget_destroy (gtk_widget_get_toplevel (button));
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tooltips_disable 
 * Params: GtkTooltips *tooltips
 * Returns: void
 * Assertion: Causes all tooltips in tooltips to become inactive. 
 * Params Values: GtkTooltips *tooltips
 * Expected: void  
 */
static void test_purpose_6()
{
    GtkTooltips* widget;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_tooltips_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOOLTIPS (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_tooltips_enable (widget);
    
    button = gtk_button_new_with_label ("Label");
    gtk_tooltips_set_tip (widget,button, "Tooltip 1", "Tooltip 2");
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (button);   
    /******* -------------  *******/ 
    
    gtk_object_destroy (GTK_OBJECT (widget));
    gtk_widget_destroy (gtk_widget_get_toplevel (button));
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkTooltips ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {NULL,0}
};
