/*
 * Selections methods tests
 * Testing Selections methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gint global_iter = 0;
static const char* gtk_selection_handler_key = "gtk-selection-handlers";
typedef struct _GtkSelectionTargetList GtkSelectionTargetList;

struct _GtkSelectionTargetList 
{
    GdkAtom selection;
    GtkTargetList *list;
};

GList *lists;
GtkSelectionTargetList *sellist;
GtkWidget* global_widget = NULL;
GdkAtom global_selection;
GdkAtom global_target;

void 
global_selection_received_handler (GtkWidget *widget, GtkSelectionData *data, guint time, gpointer user_data)
{
    global_iter++;
    gtk_main_quit ();
}

void 
global_selection_convert (GtkWidget *widget, gpointer user_data)
{
    GdkAtom  targets_atom = gdk_atom_intern ("TARGETS", FALSE);
    gboolean succeeded = gtk_selection_convert (global_widget, global_selection, global_target, GDK_CURRENT_TIME);

    if (!succeeded)
    {
        printf ("succeeded = FALSE\n", NULL);
    }
}


/*
 * Name: gtk_target_list_new
 * Params: const GtkTargetEntry *targets, guint ntargets
 * Returns: GtkTargetList*
 * Assertion: Creates a new GtkTargetList from an array of GtkTargetEntry.
 * Params Values: const GtkTargetEntry *targets, guint ntargets
 * Expected: GtkTargetList*  
 */
static void test_purpose_1()
{
    #define TARGETS {"ATOM", 0, 1}
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    gint i = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if ((pair->flags != targets[i].flags) || (pair->info != targets[i].info)||
            (pair->target != gdk_atom_intern (targets[i].target, FALSE)))
        {
            TEST_FAIL ("target[%i] has errors", NULL);
            return;
        }
        list = list->next;
        i++;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_new
 * Params: const GtkTargetEntry *targets, guint ntargets
 * Returns: GtkTargetList*
 * Assertion: Creates a new GtkTargetList from an array of GtkTargetEntry.
 * Params Values: const GtkTargetEntry *targets, guint ntargets
 * Expected: GtkTargetList*  
 */
static void test_purpose_2()
{
    #define TARGETS {"NEW_TARGET", 0, 1}
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    gint i = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if ((pair->flags != targets[i].flags) || (pair->info != targets[i].info)||
            (pair->target != gdk_atom_intern (targets[i].target, FALSE)))
        {
            TEST_FAIL ("target[%i] has errors", NULL);
            return;
        }
        list = list->next;
        i++;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_new
 * Params: const GtkTargetEntry *targets, guint ntargets
 * Returns: GtkTargetList*
 * Assertion: Creates a new GtkTargetList from an array of GtkTargetEntry.
 * Params Values: const GtkTargetEntry *targets, guint ntargets
 * Expected: GtkTargetList*  
 */
static void test_purpose_3()
{
    #define TARGETS {"STRING",0, 1}, {"TEXT", 0, 2}, {"COMPOUND_TEXT", 0, 3}, {"UTF8_STRING", 0, 4}
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    gint i = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if ((pair->flags != targets[i].flags) || (pair->info != targets[i].info)||
            (pair->target != gdk_atom_intern (targets[i].target, FALSE)))
        {
            TEST_FAIL ("target[%i] has errors", NULL);
            return;
        }
        list = list->next;
        i++;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_new
 * Params: const GtkTargetEntry *targets, guint ntargets
 * Returns: GtkTargetList*
 * Assertion: Creates a new GtkTargetList from an array of GtkTargetEntry.
 * Params Values: const GtkTargetEntry *targets, guint ntargets
 * Expected: GtkTargetList*  
 */
static void test_purpose_4()
{
    #define TARGETS {"STRING",0, 1}, {"MY_TEXT", 0, 2}, {"COMPOUND_TEXT", 0, 3}, {"UTF8_STRING", 0, 4}
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    gint i = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if ((pair->flags != targets[i].flags) || (pair->info != targets[i].info)||
            (pair->target != gdk_atom_intern (targets[i].target, FALSE)))
        {
            TEST_FAIL ("target[%i] has errors", NULL);
            return;
        }
        list = list->next;
        i++;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_ref
 * Params: GtkTargetList *list
 * Returns: void
 * Assertion: Increases the reference count of a GtkTargetList by one.
 * Params Values: GtkTargetList *list
 * Expected: void  
 */
static void test_purpose_5()
{
    static const GtkTargetEntry targets[] = {{"STRING",0, 1}, {"TEXT", 0, 2}, {"COMPOUND_TEXT", 0, 3}, {"UTF8_STRING", 0, 4}};
    GtkTargetList* tlist = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (tlist->ref_count != 1)
    {
        TEST_FAIL ("ref_count = %i", tlist->ref_count);
    }
    
    gtk_target_list_ref (tlist);
    
    if (tlist->ref_count != 2)
    {
        TEST_FAIL ("ref_count = %i", tlist->ref_count);
    }
    
    gtk_target_list_unref (tlist);
    gtk_target_list_unref (tlist);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_unref
 * Params: GtkTargetList *list
 * Returns: void
 * Assertion: Decreases the reference count of a GtkTargetList by one.
 * Params Values: GtkTargetList *list
 * Expected: void
 * 
 * Name: gtk_target_list_unref
 * Params: GtkTargetList *list
 * Returns: void
 * Assertion: If the resulting reference count is zero, frees the list.
 * Params Values: GtkTargetList *list
 * Expected: void  
 */
static void test_purpose_6()
{
    static const GtkTargetEntry targets[] = {{"STRING",0, 1}, {"TEXT", 0, 2}, {"COMPOUND_TEXT", 0, 3}, {"UTF8_STRING", 0, 4}};
    GtkTargetList* tlist = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_ref (tlist);
    
    gtk_target_list_unref (tlist);
    if (tlist->ref_count != 1)
    {
        TEST_FAIL ("ref_count = %i", tlist->ref_count);
    }
    
    gtk_target_list_unref (tlist);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_add 
 * Params: GtkTargetList *list, GdkAtom target, guint flags, guint info
 * Returns: void
 * Assertion: Adds another target to a GtkTargetList
 * Params Values: GtkTargetList *list, GdkAtom target, guint flags, guint info
 * Expected: void  
 */
static void test_purpose_7()
{
    #define TARGET "ATOM", 0, 1
    
    static const GtkTargetEntry target = {TARGET};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (NULL, 0);
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_add (tlist, gdk_atom_intern (target.target, FALSE), target.flags, target.info);
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if ((pair->flags != target.flags) || (pair->info != target.info)||
            (pair->target != gdk_atom_intern (target.target, FALSE)))
        {
            TEST_FAIL ("target[%i] has errors", NULL);
            return;
        }
        list = list->next;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_add 
 * Params: GtkTargetList *list, GdkAtom target, guint flags, guint info
 * Returns: void
 * Assertion: Adds another target to a GtkTargetList
 * Params Values: GtkTargetList *list, GdkAtom target, guint flags, guint info
 * Expected: void  
 */
static void test_purpose_8()
{
    #define TARGET "NEW_TARGET", 0, 1
    
    static const GtkTargetEntry target = {TARGET};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (NULL, 0);
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_add (tlist, gdk_atom_intern (target.target, FALSE), target.flags, target.info);
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if ((pair->flags != target.flags) || (pair->info != target.info)||
            (pair->target != gdk_atom_intern (target.target, FALSE)))
        {
            TEST_FAIL ("target[%i] has errors", NULL);
            return;
        }
        list = list->next;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_add 
 * Params: GtkTargetList *list, GdkAtom target, guint flags, guint info
 * Returns: void
 * Assertion: Adds another target to a GtkTargetList
 * Params Values: GtkTargetList *list, GdkAtom target, guint flags, guint info
 * Expected: void  
 */
static void test_purpose_9()
{
    #define TARGET "STRING",0, 11
    
    static const GtkTargetEntry target = {TARGET};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (NULL, 0);
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_add (tlist, gdk_atom_intern (target.target, FALSE), target.flags, target.info);
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if ((pair->flags != target.flags) || (pair->info != target.info)||
            (pair->target != gdk_atom_intern (target.target, FALSE)))
        {
            TEST_FAIL ("target[%i] has errors", NULL);
            return;
        }
        list = list->next;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_add 
 * Params: GtkTargetList *list, GdkAtom target, guint flags, guint info
 * Returns: void
 * Assertion: Adds another target to a GtkTargetList
 * Params Values: GtkTargetList *list, GdkAtom target, guint flags, guint info
 * Expected: void  
 */
static void test_purpose_10()
{
    #define TARGET "COMPOUND_TEXT", 0, 3
    
    static const GtkTargetEntry target = {TARGET};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (NULL, 0);
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_add (tlist, gdk_atom_intern (target.target, FALSE), target.flags, target.info);
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if ((pair->flags != target.flags) || (pair->info != target.info)||
            (pair->target != gdk_atom_intern (target.target, FALSE)))
        {
            TEST_FAIL ("target[%i] has errors", NULL);
            return;
        }
        list = list->next;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_add_table
 * Params: GtkTargetList *list, const GtkTargetEntry *targets, guint ntargets
 * Returns: void
 * Assertion: Adds a table of GtkTargetEntry into a target list
 * Params Values: GtkTargetList *list, const GtkTargetEntry *targets, guint ntargets
 * Expected: void  
 */
static void test_purpose_11()
{
    #define TARGETS {"ATOM", 0, 1}
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    gint i = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (NULL, 0);
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_add_table (tlist, targets, G_N_ELEMENTS (targets));
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if ((pair->flags != targets[i].flags) || (pair->info != targets[i].info)||
            (pair->target != gdk_atom_intern (targets[i].target, FALSE)))
        {
            TEST_FAIL ("target[%i] has errors", i);
            return;
        }
        list = list->next;
        i++;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_add_table
 * Params: GtkTargetList *list, const GtkTargetEntry *targets, guint ntargets
 * Returns: void
 * Assertion: Adds a table of GtkTargetEntry into a target list
 * Params Values: GtkTargetList *list, const GtkTargetEntry *targets, guint ntargets
 * Expected: void  
 */
static void test_purpose_12()
{
    #define TARGETS {"NEW_TARGET", 0, 1}
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    gint i = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (NULL, 0);
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_add_table (tlist, targets, G_N_ELEMENTS (targets));
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if ((pair->flags != targets[i].flags) || (pair->info != targets[i].info)||
            (pair->target != gdk_atom_intern (targets[i].target, FALSE)))
        {
            TEST_FAIL ("target[%i] has errors", i);
            return;
        }
        list = list->next;
        i++;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_add_table
 * Params: GtkTargetList *list, const GtkTargetEntry *targets, guint ntargets
 * Returns: void
 * Assertion: Adds a table of GtkTargetEntry into a target list
 * Params Values: GtkTargetList *list, const GtkTargetEntry *targets, guint ntargets
 * Expected: void  
 */
static void test_purpose_13()
{
    #define TARGETS {"STRING",0, 1}, {"MY_TEXT", 0, 2}, {"COMPOUND_TEXT", 0, 3}, {"UTF8_STRING", 0, 4}
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    gint i = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (NULL, 0);
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_add_table (tlist, targets, G_N_ELEMENTS (targets));
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if ((pair->flags != targets[i].flags) || (pair->info != targets[i].info)||
            (pair->target != gdk_atom_intern (targets[i].target, FALSE)))
        {
            TEST_FAIL ("target[%i] has errors", i);
            return;
        }
        list = list->next;
        i++;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_add_table
 * Params: GtkTargetList *list, const GtkTargetEntry *targets, guint ntargets
 * Returns: void
 * Assertion: Adds a table of GtkTargetEntry into a target list
 * Params Values: GtkTargetList *list, const GtkTargetEntry *targets, guint ntargets
 * Expected: void  
 */
static void test_purpose_14()
{
    #define TARGETS {"STRING",0, 1}, {"TEXT", 0, 2}, {"COMPOUND_TEXT", 0, 3}, {"UTF8_STRING", 0, 4}
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    gint i = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (NULL, 0);
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_add_table (tlist, targets, G_N_ELEMENTS (targets));
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if ((pair->flags != targets[i].flags) || (pair->info != targets[i].info)||
            (pair->target != gdk_atom_intern (targets[i].target, FALSE)))
        {
            TEST_FAIL ("target[%i] has errors", i);
            return;
        }
        list = list->next;
        i++;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_remove
 * Params: GtkTargetList *list, GdkAtom target
 * Returns: void
 * Assertion: Removes a target from a target list
 * Params Values: GtkTargetList *list, GdkAtom target
 * Expected: void  
 */
static void test_purpose_15()
{
    #define TARGETS {"ATOM", 0, 1}, {"STRING", 0, 1}
    #define ATOM "ATOM"
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    gint i = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_remove (tlist, gdk_atom_intern (ATOM, FALSE));
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if (pair->target == gdk_atom_intern (ATOM, FALSE))
        {
            TEST_FAIL ("atom '%s' not removed", ATOM);
            return;
        }
        list = list->next;
        i++;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    #undef ATOM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_remove
 * Params: GtkTargetList *list, GdkAtom target
 * Returns: void
 * Assertion: Removes a target from a target list
 * Params Values: GtkTargetList *list, GdkAtom target
 * Expected: void  
 */
static void test_purpose_16()
{
    #define TARGETS {"NEW_TARGET", 0, 1}, {"STRING", 0, 1}
    #define ATOM "STRING"
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    gint i = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_remove (tlist, gdk_atom_intern (ATOM, FALSE));
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if (pair->target == gdk_atom_intern (ATOM, FALSE))
        {
            TEST_FAIL ("atom '%s' not removed", ATOM);
            return;
        }
        list = list->next;
        i++;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    #undef ATOM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_remove
 * Params: GtkTargetList *list, GdkAtom target
 * Returns: void
 * Assertion: Removes a target from a target list
 * Params Values: GtkTargetList *list, GdkAtom target
 * Expected: void  
 */
static void test_purpose_17()
{
    #define TARGETS {"STRING",0, 1}, {"MY_TEXT", 0, 2}, {"COMPOUND_TEXT", 0, 3}, {"UTF8_STRING", 0, 4}
    #define ATOM "COMPOUND_TEXT"
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    gint i = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_remove (tlist, gdk_atom_intern (ATOM, FALSE));
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if (pair->target == gdk_atom_intern (ATOM, FALSE))
        {
            TEST_FAIL ("atom '%s' not removed", ATOM);
            return;
        }
        list = list->next;
        i++;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    #undef ATOM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_remove
 * Params: GtkTargetList *list, GdkAtom target
 * Returns: void
 * Assertion: Removes a target from a target list
 * Params Values: GtkTargetList *list, GdkAtom target
 * Expected: void  
 */
static void test_purpose_18()
{
    #define TARGETS {"STRING",0, 1}, {"TEXT", 0, 2}, {"COMPOUND_TEXT", 0, 3}, {"UTF8_STRING", 0, 4}
    #define ATOM "TEXT"
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    gint i = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_target_list_remove (tlist, gdk_atom_intern (ATOM, FALSE));
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if (pair->target == gdk_atom_intern (ATOM, FALSE))
        {
            TEST_FAIL ("atom '%s' not removed", ATOM);
            return;
        }
        list = list->next;
        i++;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    #undef ATOM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_find
 * Params: GtkTargetList *list, GdkAtom target, guint *info
 * Returns: gboolean
 * Assertion: Looks up a given target in a GtkTargetList
 * Params Values: GtkTargetList *list, GdkAtom target, guint *info
 * Expected: gboolean  
 */
static void test_purpose_19()
{
    #define TARGETS {"ATOM", 0, 1}, {"STRING", 0, 1}
    #define ATOM "ATOM"
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    guint info = 0;
    gint result = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    result = gtk_target_list_find (tlist, gdk_atom_intern (ATOM, FALSE), &info);
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if (pair->target == gdk_atom_intern (ATOM, FALSE))
        {
            if (!result)
            {
                TEST_FAIL ("'result' should be TRUE", NULL);
            }
            if (pair->info != info)
            {
                TEST_FAIL ("'info' should be %i", pair->info);
            }
            result = FALSE;
            break;
        }
        list = list->next;
    }
    
    if (result)
    {
        TEST_FAIL ("'result' should be FALSE", NULL);
        return;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    #undef ATOM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_find
 * Params: GtkTargetList *list, GdkAtom target, guint *info
 * Returns: gboolean
 * Assertion: Looks up a given target in a GtkTargetList
 * Params Values: GtkTargetList *list, GdkAtom target, guint *info
 * Expected: gboolean  
 */
static void test_purpose_20()
{
    #define TARGETS {"NEW_TARGET", 0, 1}, {"STRING", 0, 1}
    #define ATOM "NO_STRING"
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    guint info = 0;
    gint result = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    result = gtk_target_list_find (tlist, gdk_atom_intern (ATOM, FALSE), &info);
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if (pair->target == gdk_atom_intern (ATOM, FALSE))
        {
            if (!result)
            {
                TEST_FAIL ("'result' should be TRUE", NULL);
            }
            if (pair->info != info)
            {
                TEST_FAIL ("'info' should be %i", pair->info);
            }
            result = FALSE;
            break;
        }
        list = list->next;
    }
    
    if (result)
    {
        TEST_FAIL ("'result' should be FALSE", NULL);
        return;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    #undef ATOM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_find
 * Params: GtkTargetList *list, GdkAtom target, guint *info
 * Returns: gboolean
 * Assertion: Looks up a given target in a GtkTargetList
 * Params Values: GtkTargetList *list, GdkAtom target, guint *info
 * Expected: gboolean  
 */
static void test_purpose_21()
{
    #define TARGETS {"STRING",0, 1}, {"MY_TEXT", 0, 2}, {"COMPOUND_TEXT", 0, 3}, {"UTF8_STRING", 0, 4}
    #define ATOM "COMPOUND_TEXT"
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    guint info = 0;
    gint result = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    result = gtk_target_list_find (tlist, gdk_atom_intern (ATOM, FALSE), &info);
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if (pair->target == gdk_atom_intern (ATOM, FALSE))
        {
            if (!result)
            {
                TEST_FAIL ("'result' should be TRUE", NULL);
            }
            if (pair->info != info)
            {
                TEST_FAIL ("'info' should be %i", pair->info);
            }
            result = FALSE;
            break;
        }
        list = list->next;
    }
    
    if (result)
    {
        TEST_FAIL ("'result' should be FALSE", NULL);
        return;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    #undef ATOM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_target_list_find
 * Params: GtkTargetList *list, GdkAtom target, guint *info
 * Returns: gboolean
 * Assertion: Looks up a given target in a GtkTargetList
 * Params Values: GtkTargetList *list, GdkAtom target, guint *info
 * Expected: gboolean  
 */
static void test_purpose_22()
{
    #define TARGETS {"STRING",0, 1}, {"TEXT", 0, 2}, {"COMPOUND_TEXT", 0, 3}, {"UTF8_STRING", 0, 4}
    #define ATOM "TEXT"
    
    static const GtkTargetEntry targets[] = {TARGETS};
    GtkTargetList* tlist = NULL;
    GList* list = NULL;
    guint info = 0;
    gint result = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tlist = gtk_target_list_new (targets, G_N_ELEMENTS (targets));
    if (!tlist)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    result = gtk_target_list_find (tlist, gdk_atom_intern (ATOM, FALSE), &info);
    
    list = tlist->list;
    
    while (list)
    {
        GtkTargetPair* pair = (GtkTargetPair*)list->data;
        if (pair->target == gdk_atom_intern (ATOM, FALSE))
        {
            if (!result)
            {
                TEST_FAIL ("'result' should be TRUE", NULL);
            }
            if (pair->info != info)
            {
                TEST_FAIL ("'info' should be %i", pair->info);
            }
            result = FALSE;
            break;
        }
        list = list->next;
    }
    
    if (result)
    {
        TEST_FAIL ("'result' should be FALSE", NULL);
        return;
    }
    
    gtk_target_list_unref (tlist);
    
    #undef TARGETS
    #undef ATOM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_owner_set
 * Params: GtkWidget *widget, GdkAtom selection, guint32 time
 * Returns: gboolean
 * Assertion: Claims ownership of a given selection for a particular widget, or, if widget is NULL, release ownership of the selection.
 * Params Values: newly created GtkWidget*, gdk_atom_intern ("New_Selection", FALSE), GDK_CURRENT_TIME
 * Expected: TRUE  
 */
static void test_purpose_23()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define SELECTION gdk_atom_intern ("New_Selection", FALSE)
    #define TIME GDK_CURRENT_TIME
    #define RESULT TRUE
    
    GtkWidget* widget;
    gboolean succeeded;
    GdkAtom selection;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (widget != NULL)
    {
        gtk_widget_realize (widget);
    }
    
    selection = SELECTION;
    succeeded = gtk_selection_owner_set (widget, selection, TIME);
    
    if (succeeded != RESULT)
    {
        TEST_FAIL ("gtk_selection_owner_set () return %i instead of %i", succeeded, !succeeded);
    }
    #undef WIDGET
    #undef SELECTION
    #undef TIME 
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_owner_set
 * Params: GtkWidget *widget, GdkAtom selection, guint32 time
 * Returns: gboolean
 * Assertion: Claims ownership of a given selection for a particular widget, or, if widget is NULL, release ownership of the selection.
 * Params Values: newly created GtkWidget*, gdk_atom_intern ("New_Selection", FALSE), GDK_CURRENT_TIME
 * Expected: TRUE  
 */
static void test_purpose_24()
{
    #define WIDGET NULL
    #define SELECTION gdk_atom_intern ("New_Selection", FALSE)
    #define TIME GDK_CURRENT_TIME
    #define RESULT TRUE
    
    GtkWidget* widget;
    gboolean succeeded;
    GdkAtom selection;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (widget != NULL)
    {
        gtk_widget_realize (widget);
    }
    
    selection = SELECTION;
    succeeded = gtk_selection_owner_set (widget, selection, TIME);
    
    if (succeeded != RESULT)
    {
        TEST_FAIL ("gtk_selection_owner_set () return %i instead of %i", succeeded, !succeeded);
    }
    #undef WIDGET
    #undef SELECTION
    #undef TIME 
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_owner_set_for_display
 * Params: GdkDisplay* display, GtkWidget *widget, GdkAtom selection, guint32 time
 * Returns: gboolean
 * Assertion: Claim ownership of a given selection for a particular widget, or, if widget is NULL, release ownership of the selection.
 * Params Values: newly created GtkWidget*, gdk_atom_intern ("New_Selection", FALSE), GDK_CURRENT_TIME
 * Expected: TRUE  
 */
static void test_purpose_25()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define SELECTION gdk_atom_intern ("New_Selection", FALSE)
    #define TIME GDK_CURRENT_TIME
    #define RESULT TRUE
    
    GtkWidget* widget;
    gboolean succeeded;
    GdkAtom selection;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (widget != NULL)
    {
        gtk_widget_realize (widget);
    }
    
    selection = SELECTION;
    display = gdk_display_get_default ();
    succeeded = gtk_selection_owner_set_for_display (display, widget, selection, TIME);
    
    if (succeeded != RESULT)
    {
        TEST_FAIL ("gtk_selection_owner_set () return %i instead of %i", succeeded, !succeeded);
    }
    #undef WIDGET
    #undef SELECTION
    #undef TIME 
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_owner_set_for_display
 * Params: GdkDisplay* display, GtkWidget *widget, GdkAtom selection, guint32 time
 * Returns: gboolean
 * Assertion: Claim ownership of a given selection for a particular widget, or, if widget is NULL, release ownership of the selection.
 * Params Values: newly created GtkWidget*, gdk_atom_intern ("New_Selection", FALSE), GDK_CURRENT_TIME
 * Expected: TRUE  
 */
static void test_purpose_26()
{
    #define WIDGET NULL
    #define SELECTION gdk_atom_intern ("New_Selection", FALSE)
    #define TIME GDK_CURRENT_TIME
    #define RESULT TRUE
    
    GtkWidget* widget;
    gboolean succeeded;
    GdkAtom selection;
    GdkDisplay* display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (widget != NULL)
    {
        gtk_widget_realize (widget);
    }
    
    selection = SELECTION;
    display = gdk_display_get_default ();
    succeeded = gtk_selection_owner_set_for_display (display, widget, selection, TIME);
    
    if (succeeded != RESULT)
    {
        TEST_FAIL ("gtk_selection_owner_set () return %i instead of %i", succeeded, !succeeded);
    }
    #undef WIDGET
    #undef SELECTION
    #undef TIME 
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_add_target
 * Params: GtkWidget *widget, GdkAtom selection, GdkAtom target, guint info
 * Returns: void
 * Assertion: Adds specified target to the list of supported targets for a given widget and selection.
 * Params Values: newly created GtkWidget*, GDK_SELECTION_PRIMARY, gdk_atom_intern ("text", FALSE)
 * Expected: void  
 */
static void test_purpose_27()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define SELECTION GDK_SELECTION_PRIMARY
    #define TARGET gdk_atom_intern ("text", FALSE)
    #define INFO 0
    
    GtkWidget* widget;
    GdkAtom selection;
    GdkAtom target;
    gboolean target_found;
    gboolean succeeded;
    guint info;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (widget != NULL)
    {
        gtk_widget_realize (widget);
    }
    
    selection = SELECTION;
    target = TARGET;
    gtk_selection_add_target (widget, selection, target, INFO);
    
    target_found = FALSE;
    lists = g_object_get_data (GTK_OBJECT (widget), gtk_selection_handler_key);
    while (lists)
    {
        sellist = lists->data;
        if (sellist->selection == selection)
        {
            if (gtk_target_list_find (sellist->list, target, &info)) 
            {
                target_found = TRUE;
            }
        }
        lists = lists->next;
    }
    if (!target_found)
    {
            TEST_FAIL ("target was not added", NULL);             
    }
    #undef WIDGET
    #undef SELECTION
    #undef TARGET
    #undef INFO
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_add_target
 * Params: GtkWidget *widget, GdkAtom selection, GdkAtom target, guint info
 * Returns: void
 * Assertion: Adds specified target to the list of supported targets for a given widget and selection.
 * Params Values: newly created GtkWidget*, gdk_atom_intern ("New_Selection", FALSE), gdk_atom_intern ("", FALSE)
 * Expected: void  
 */
static void test_purpose_28()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define SELECTION gdk_atom_intern ("New_Selection", FALSE)
    #define TARGET gdk_atom_intern ("", FALSE)
    #define INFO 1
    
    GtkWidget* widget;
    GdkAtom selection;
    GdkAtom target;
    gboolean target_found;
    gboolean succeeded;
    guint info;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (widget != NULL)
    {
        gtk_widget_realize (widget);
    }
    
    selection = SELECTION;
    target = TARGET;
    gtk_selection_add_target (widget, selection, target, INFO);
    
    target_found = FALSE;
    lists = g_object_get_data (GTK_OBJECT (widget), gtk_selection_handler_key);
    while (lists)
    {
        sellist = lists->data;
        if (sellist->selection == selection)
        {
            if (gtk_target_list_find (sellist->list, target, &info)) 
            {
                target_found = TRUE;
            }
        }
        lists = lists->next;
    }
    if (!target_found)
    {
            TEST_FAIL ("target was not added", NULL);             
    }
    #undef WIDGET
    #undef SELECTION
    #undef TARGET
    #undef INFO
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_add_targets
 * Params: GtkWidget *widget, GdkAtom selection, const GdkTargetEntry *targets, guint ntargets
 * Returns: void
 * Assertion: Adds a table of targets to the list of supported targets for a given widget and selection. 
 * Params Values: newly created GtkWidget*, newly created GtkTargetEntry*, 1
 * Expected: void  
 */
static void test_purpose_29()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define SELECTION GDK_SELECTION_PRIMARY
    #define TARGETS {"NEW_TARGET", 0, 1}
    #define N_TARGETS 1
    
    const GtkTargetEntry targets[] = {TARGETS};
    GtkWidget* widget;
    GdkAtom selection;
    GdkAtom tmp_target;
    gint i;
    guint info;
    gboolean target_found;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (widget != NULL)
    {
        gtk_widget_realize (widget);
    }
    selection = SELECTION;
    gtk_selection_add_targets (widget, selection, targets, N_TARGETS);
    
    lists = g_object_get_data (GTK_OBJECT (widget), gtk_selection_handler_key);
    while (lists)
    {
        sellist = lists->data;
        if (sellist->selection == selection)
        {
            target_found = TRUE;
            for (i = 0; i++; i < N_TARGETS)
            {
                tmp_target = gdk_atom_intern (targets[i].target, FALSE);
                if (!gtk_target_list_find (sellist->list, tmp_target, &info)) 
                {
                    target_found = FALSE;
                    break;
                }
            }
            break;
        }
        lists = lists->next;
    }
    
    if (!target_found)
    {
        TEST_FAIL ("target '%s' was not added", targets[i].target);             
    }
    
    #undef WIDGET
    #undef SELECTION
    #undef TARGETS
    #undef N_TARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_add_targets
 * Params: GtkWidget *widget, GdkAtom selection, const GdkTargetEntry *targets, guint ntargets
 * Returns: void
 * Assertion: Adds a table of targets to the list of supported targets for a given widget and selection. 
 * Params Values: newly created GtkWidget*, newly created GtkTargetEntry*, 4
 * Expected: void  
 */
static void test_purpose_30()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define SELECTION gdk_atom_intern ("New_Selection", FALSE)
    #define TARGETS {"STRING",0, 1}, {"TEXT", 0, 2}, {"COMPOUND_TEXT", 0, 3}, {"UTF8_STRING", 0, 4}
    #define N_TARGETS 4
    
    const GtkTargetEntry targets[] = {TARGETS};
    GtkWidget* widget;
    GdkAtom selection;
    GdkAtom tmp_target;
    gint i;
    guint info;
    gboolean target_found;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (widget != NULL)
    {
        gtk_widget_realize (widget);
    }
    selection = SELECTION;
    gtk_selection_add_targets (widget, selection, targets, N_TARGETS);
    
    lists = g_object_get_data (GTK_OBJECT (widget), gtk_selection_handler_key);
    while (lists)
    {
        sellist = lists->data;
        if (sellist->selection == selection)
        {
            target_found = TRUE;
            for (i = 0; i++; i < N_TARGETS)
            {
                tmp_target = gdk_atom_intern (targets[i].target, FALSE);
                if (!gtk_target_list_find (sellist->list, tmp_target, &info)) 
                {
                    target_found = FALSE;
                    break;
                }
            }
            break;
        }
        lists = lists->next;
    }
    
    if (!target_found)
    {
        TEST_FAIL ("target '%s' was not added", targets[i].target);             
    }
    
    #undef WIDGET
    #undef SELECTION
    #undef TARGETS
    #undef N_TARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_clear_targets
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: void
 * Assertion: Remove all targets registered for the given selection for the widget.
 * Params Values: newly created GtkWidget*, GDK_SELECTION_PRIMARY
 * Expected: void  
 */
static void test_purpose_31()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define SELECTION GDK_SELECTION_PRIMARY
    #define TARGET gdk_atom_intern ("text", FALSE)
    #define INFO 0
    
    GtkWidget* widget;
    GdkAtom selection;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (widget != NULL)
    {
        gtk_widget_realize (widget);
    }
    selection = SELECTION;
    gtk_selection_add_target (widget, selection, TARGET, INFO);
    gtk_selection_clear_targets (widget, selection);
    
    lists = g_object_get_data (GTK_OBJECT (widget), gtk_selection_handler_key);
    while (lists)
    {
        sellist = lists->data;
        if (sellist->selection == selection)
        {
            TEST_FAIL ("gtk_selection_clear_targets () didn't remove all targets.", NULL);         
            break;
        }
        lists = lists->next;
    }
    
    #undef WIDGET
    #undef SELECTION
    #undef TARGET
    #undef INFO
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_clear_targets
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: void
 * Assertion: Remove all targets registered for the given selection for the widget.
 * Params Values: newly created GtkWidget*, gdk_atom_intern ("New_Selection", FALSE)
 * Expected: void  
 */
static void test_purpose_32()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define SELECTION gdk_atom_intern ("New_Selection", FALSE)
    #define TARGET gdk_atom_intern ("", FALSE)
    #define INFO 1
    
    GtkWidget* widget;
    GdkAtom selection;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (widget != NULL)
    {
        gtk_widget_realize (widget);
    }
    selection = SELECTION;
    gtk_selection_add_target (widget, selection, TARGET, INFO);
    gtk_selection_clear_targets (widget, selection);
    
    lists = g_object_get_data (GTK_OBJECT (widget), gtk_selection_handler_key);
    while (lists)
    {
        sellist = lists->data;
        if (sellist->selection == selection)
        {
            TEST_FAIL ("gtk_selection_clear_targets () didn't remove all targets.", NULL);         
            break;
        }
        lists = lists->next;
    }
    
    #undef WIDGET
    #undef SELECTION
    #undef TARGET
    #undef INFO
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_convert
 * Params: GtkWidget *widget, GdkAtom selection, GdkAtom target, guint32 time
 * Returns: gboolean
 * Assertion: Requests the contents of a selection.
 * Params Values: newly created GtkWidget*, GDK_SELECTION_PRIMARY, gdk_atom_intern ("STRING", FALSE), GDK_CURRENT_TIME
 * Expected: gboolean
 * 
 * Name: gtk_selection_convert
 * Params: GtkWidget *widget, GdkAtom selection, GdkAtom target, guint32 time
 * Returns: gboolean
 * Assertion: When received, a "selection_received" signal will be generated.
 * Params Values: newly created GtkWidget*, GDK_SELECTION_PRIMARY, gdk_atom_intern ("STRING", FALSE), GDK_CURRENT_TIME
 * Expected: gboolean  
 */
static void test_purpose_33()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define SELECTION GDK_SELECTION_PRIMARY
    #define TARGET gdk_atom_intern ("STRING", FALSE)
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_widget = WIDGET;
    global_selection = SELECTION;
    global_target = TARGET;
    
    if (global_widget != NULL)
    {
        gtk_widget_realize (global_widget);
    }
    
    global_iter = 0;
    
    g_signal_connect (G_OBJECT (global_widget), "selection_received", GTK_SIGNAL_FUNC (global_selection_received_handler), NULL);
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (global_widget, global_selection_convert);
    /*****************************/
    
    gtk_main();
    
    if (global_iter != 1)
    {
        TEST_FAIL ("global_iter = %d, should be 1", global_iter);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (global_widget));
    
    #undef WIDGET
    #undef SELECTION
    #undef TARGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_convert
 * Params: GtkWidget *widget, GdkAtom selection, GdkAtom target, guint32 time
 * Returns: gboolean
 * Assertion: Requests the contents of a selection.
 * Params Values: newly created GtkWidget*, gdk_atom_intern ("New_Selection", FALSE), gdk_atom_intern ("HTML/text", FALSE), GDK_CURRENT_TIME
 * Expected: gboolean
 * 
 * Name: gtk_selection_convert
 * Params: GtkWidget *widget, GdkAtom selection, GdkAtom target, guint32 time
 * Returns: gboolean
 * Assertion: When received, a "selection_received" signal will be generated.
 * Params Values: newly created GtkWidget*, gdk_atom_intern ("New_Selection", FALSE), gdk_atom_intern ("HTML/text", FALSE), GDK_CURRENT_TIME
 * Expected: gboolean  
 */
static void test_purpose_34()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define SELECTION gdk_atom_intern ("New_Selection", FALSE)
    #define TARGET gdk_atom_intern ("HTML/text", FALSE)
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_widget = WIDGET;
    global_selection = SELECTION;
    global_target = TARGET;
    
    if (global_widget != NULL)
    {
        gtk_widget_realize (global_widget);
    }
    
    global_iter = 0;
    
    g_signal_connect (G_OBJECT (global_widget), "selection_received", GTK_SIGNAL_FUNC (global_selection_received_handler), NULL);
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (global_widget, global_selection_convert);
    /*****************************/
    
    gtk_main();
    
    if (global_iter != 1)
    {
        TEST_FAIL ("global_iter = %d, should be 1", global_iter);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (global_widget));
    
    #undef WIDGET
    #undef SELECTION
    #undef TARGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_set
 * Params: GtkSelectionData *selection_data, GdkAtom type, gint format, const guchar *data, gint length
 * Returns: void
 * Assertion: Stores new data into a GtkSelectionData object. 
 * Params Values: newly created GtkSelectionData*, "STRING", 8, "Data", 4
 * Expected: void  
 */
static void test_purpose_35()
{
    #define TYPE "STRING"
    #define FORMAT 8
    #define DATA "Data"
    #define LENGTH 4
    
    GtkSelectionData selection_data;
    GdkAtom type;
    gchar* type_name;
    gchar* dup_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = gdk_atom_intern (TYPE, FALSE);
    
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    
    type_name = gdk_atom_name (selection_data.type);
    if (strcmp (TYPE, type_name))
    {
        TEST_FAIL ("selection_data.type = %s, instead of %s", type_name, TYPE);         
    }
    if (selection_data.format != FORMAT)
    {
        TEST_FAIL ("selection_data.format = %i, instead of %i", selection_data.format, FORMAT);         
    }
    if (selection_data.length != LENGTH)
    {
        TEST_FAIL ("selection_data.length = %i, instead of %i", selection_data.length, LENGTH);         
    }
    if ((LENGTH < 0) && (selection_data.data != NULL))
    {
        TEST_FAIL ("selection_data.data = %s, instead of NULL", selection_data.data);         
    } else 
    if ((LENGTH == 0) && strcmp ((const char*) selection_data.data, ""))
    {
        TEST_FAIL ("selection_data.data = %s, instead of \"\"", selection_data.data);         
    } else {
        dup_data = g_strndup (DATA, LENGTH); 
        if (strcmp ((const char*) selection_data.data, dup_data))
        {
            TEST_FAIL ("selection_data.data = %s, instead of %s", selection_data.data, dup_data);                 
        }
    }
    
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_set
 * Params: GtkSelectionData *selection_data, GdkAtom type, gint format, const guchar *data, gint length
 * Returns: void
 * Assertion: Stores new data into a GtkSelectionData object. 
 * Params Values: newly created GtkSelectionData*, "NONE", 111, "", 0
 * Expected: void  
 */
static void test_purpose_36()
{
    #define TYPE "NONE"
    #define FORMAT 111
    #define DATA ""
    #define LENGTH 0
    
    GtkSelectionData selection_data;
    GdkAtom type;
    gchar* type_name;
    gchar* dup_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = gdk_atom_intern (TYPE, FALSE);
    
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    
    type_name = gdk_atom_name (selection_data.type);
    if (strcmp (TYPE, type_name))
    {
        TEST_FAIL ("selection_data.type = %s, instead of %s", type_name, TYPE);         
    }
    if (selection_data.format != FORMAT)
    {
        TEST_FAIL ("selection_data.format = %i, instead of %i", selection_data.format, FORMAT);         
    }
    if (selection_data.length != LENGTH)
    {
        TEST_FAIL ("selection_data.length = %i, instead of %i", selection_data.length, LENGTH);         
    }
    if ((LENGTH < 0) && (selection_data.data != NULL))
    {
        TEST_FAIL ("selection_data.data = %s, instead of NULL", selection_data.data);         
    } else 
    if ((LENGTH == 0) && strcmp ((const char*) selection_data.data, ""))
    {
        TEST_FAIL ("selection_data.data = %s, instead of \"\"", selection_data.data);         
    } else {
        dup_data = g_strndup (DATA, LENGTH); 
        if (strcmp ((const char*) selection_data.data, dup_data))
        {
            TEST_FAIL ("selection_data.data = %s, instead of %s", selection_data.data, dup_data);                 
        }
    }
    
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_set
 * Params: GtkSelectionData *selection_data, GdkAtom type, gint format, const guchar *data, gint length
 * Returns: void
 * Assertion: Stores new data into a GtkSelectionData object. 
 * Params Values: newly created GtkSelectionData*, "PLAIN TEXT", 0, "Information", strlen ("Information")
 * Expected: void  
 */
static void test_purpose_37()
{
    #define TYPE "PLAIN TEXT"
    #define FORMAT 0
    #define DATA "Information"
    #define LENGTH strlen ("Information")
    
    GtkSelectionData selection_data;
    GdkAtom type;
    gchar* type_name;
    gchar* dup_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = gdk_atom_intern (TYPE, FALSE);
    
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    
    type_name = gdk_atom_name (selection_data.type);
    if (strcmp (TYPE, type_name))
    {
        TEST_FAIL ("selection_data.type = %s, instead of %s", type_name, TYPE);         
    }
    if (selection_data.format != FORMAT)
    {
        TEST_FAIL ("selection_data.format = %i, instead of %i", selection_data.format, FORMAT);         
    }
    if (selection_data.length != LENGTH)
    {
        TEST_FAIL ("selection_data.length = %i, instead of %i", selection_data.length, LENGTH);         
    }
    if ((LENGTH < 0) && (selection_data.data != NULL))
    {
        TEST_FAIL ("selection_data.data = %s, instead of NULL", selection_data.data);         
    } else 
    if ((LENGTH == 0) && strcmp ((const char*) selection_data.data, ""))
    {
        TEST_FAIL ("selection_data.data = %s, instead of \"\"", selection_data.data);         
    } else {
        dup_data = g_strndup (DATA, LENGTH); 
        if (strcmp ((const char*) selection_data.data, dup_data))
        {
            TEST_FAIL ("selection_data.data = %s, instead of %s", selection_data.data, dup_data);                 
        }
    }
    
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_set
 * Params: GtkSelectionData *selection_data, GdkAtom type, gint format, const guchar *data, gint length
 * Returns: void
 * Assertion: Stores new data into a GtkSelectionData object. 
 * Params Values: newly created GtkSelectionData*, "PLAIN TEXT", 0, "Information", 3
 * Expected: void  
 */
static void test_purpose_38()
{
    #define TYPE "PLAIN TEXT"
    #define FORMAT 0
    #define DATA "Information"
    #define LENGTH 3
    
    GtkSelectionData selection_data;
    GdkAtom type;
    gchar* type_name;
    gchar* dup_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = gdk_atom_intern (TYPE, FALSE);
    
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    
    type_name = gdk_atom_name (selection_data.type);
    if (strcmp (TYPE, type_name))
    {
        TEST_FAIL ("selection_data.type = %s, instead of %s", type_name, TYPE);         
    }
    if (selection_data.format != FORMAT)
    {
        TEST_FAIL ("selection_data.format = %i, instead of %i", selection_data.format, FORMAT);         
    }
    if (selection_data.length != LENGTH)
    {
        TEST_FAIL ("selection_data.length = %i, instead of %i", selection_data.length, LENGTH);         
    }
    if ((LENGTH < 0) && (selection_data.data != NULL))
    {
        TEST_FAIL ("selection_data.data = %s, instead of NULL", selection_data.data);         
    } else 
    if ((LENGTH == 0) && strcmp ((const char*) selection_data.data, ""))
    {
        TEST_FAIL ("selection_data.data = %s, instead of \"\"", selection_data.data);         
    } else {
        dup_data = g_strndup (DATA, LENGTH); 
        if (strcmp ((const char*) selection_data.data, dup_data))
        {
            TEST_FAIL ("selection_data.data = %s, instead of %s", selection_data.data, dup_data);                 
        }
    }
    
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_set
 * Params: GtkSelectionData *selection_data, GdkAtom type, gint format, const guchar *data, gint length
 * Returns: void
 * Assertion: Zero-terminates the stored data.
 * Params Values: newly created GtkSelectionData*, "STRING", 8, "Data", 4
 * Expected: void  
 */
static void test_purpose_39()
{
    #define TYPE "STRING"
    #define FORMAT 8
    #define DATA "Data"
    #define LENGTH 4
    
    GtkSelectionData selection_data;
    GdkAtom type;
    gchar* type_name;
    gchar* dup_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = gdk_atom_intern (TYPE, FALSE);
    
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    
    if (selection_data.length != LENGTH)
    {
        TEST_FAIL ("selection_data.length = %i, instead of %i", selection_data.length, LENGTH);         
    }
    if ((LENGTH < 0) && (selection_data.data != NULL))
    {
        TEST_FAIL ("selection_data.data = %s, instead of NULL", selection_data.data);         
    } else {
        if (selection_data.data[LENGTH] != 0)
        {
            TEST_FAIL ("The stored data is not zero-terminated", NULL);         
        } 
    }
    
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_set
 * Params: GtkSelectionData *selection_data, GdkAtom type, gint format, const guchar *data, gint length
 * Returns: void
 * Assertion: Zero-terminates the stored data.
 * Params Values: newly created GtkSelectionData*, "TEXT", 32, "", 0
 * Expected: void  
 */
static void test_purpose_40()
{
    #define TYPE "TEXT"
    #define FORMAT 32
    #define DATA ""
    #define LENGTH 0
    
    GtkSelectionData selection_data;
    GdkAtom type;
    gchar* type_name;
    gchar* dup_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = gdk_atom_intern (TYPE, FALSE);
    
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    
    if (selection_data.length != LENGTH)
    {
        TEST_FAIL ("selection_data.length = %i, instead of %i", selection_data.length, LENGTH);         
    }
    if ((LENGTH < 0) && (selection_data.data != NULL))
    {
        TEST_FAIL ("selection_data.data = %s, instead of NULL", selection_data.data);         
    } else {
        if (selection_data.data[LENGTH] != 0)
        {
            TEST_FAIL ("The stored data is not zero-terminated", NULL);         
        } 
    }
    
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_set_text
 * Params: GtkSelectionData *selection_data, const gchar *str, gint len
 * Returns: gboolean
 * Assertion: Sets the contents of the selection from a UTF-8 encoded string. 
 * Params Values: newly created GtkSelectionData*, "Selection data", 7
 * Expected: TRUE if the selection was successfully set, otherwise FALSE.
 * 
 * Name: gtk_selection_data_get_text
 * Params: GtkSelectionData *selection_data
 * Returns: guchar*
 * Assertion: Gets the contents of the selection data as a UTF-8 string.
 * Params Values: GtkSelectionData* with preseted data 
 * Expected: "Selection data"  
 */
static void test_purpose_41()
{
    #define STR "Selection data"
    #define LEN 7
    
    GtkSelectionData selection_data;
    gboolean succeeded;
    guchar* utf8_data = NULL;
    gchar* utf8_str = NULL;
    gchar* dup_data = NULL; 
    gchar* c_data = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    utf8_str = g_locale_to_utf8 (STR, -1, NULL, NULL, NULL);
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    succeeded = gtk_selection_data_set_text (&selection_data, utf8_str, LEN);
    utf8_data = gtk_selection_data_get_text(&selection_data);
    
    if (succeeded)
    {
        dup_data = g_strndup (STR, LEN);
        c_data = g_locale_from_utf8 ((const char*) utf8_data, -1, NULL, NULL, NULL);
        if (strcmp (dup_data, c_data))
        {
            TEST_FAIL ("gtk_selection_data_get_text () return %s, instead of %s", c_data, dup_data);         
        }
    
    }
    #undef STR
    #undef LEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_set_text
 * Params: GtkSelectionData *selection_data, const gchar *str, gint len
 * Returns: gboolean
 * Assertion: Sets the contents of the selection from a UTF-8 encoded string. 
 * Params Values: newly created GtkSelectionData*, " data ", 11
 * Expected: TRUE if the selection was successfully set, otherwise FALSE.
 * 
 * Name: gtk_selection_data_get_text
 * Params: GtkSelectionData *selection_data
 * Returns: guchar*
 * Assertion: Gets the contents of the selection data as a UTF-8 string.
 * Params Values: GtkSelectionData* with preseted data 
 * Expected: " data "  
 */
static void test_purpose_42()
{
    #define STR " data "
    #define LEN 11
    
    GtkSelectionData selection_data;
    gboolean succeeded;
    guchar* utf8_data = NULL;
    gchar* utf8_str = NULL;
    gchar* dup_data = NULL; 
    gchar* c_data = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    utf8_str = g_locale_to_utf8 (STR, -1, NULL, NULL, NULL);
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    succeeded = gtk_selection_data_set_text (&selection_data, utf8_str, LEN);
    utf8_data = gtk_selection_data_get_text(&selection_data);
    
    if (succeeded)
    {
        dup_data = g_strndup (STR, LEN);
        c_data = g_locale_from_utf8 ((const char*) utf8_data, -1, NULL, NULL, NULL);
        if (strcmp (dup_data, c_data))
        {
            TEST_FAIL ("gtk_selection_data_get_text () return %s, instead of %s", c_data, dup_data);         
        }
    
    }
    #undef STR
    #undef LEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_set_text
 * Params: GtkSelectionData *selection_data, const gchar *str, gint len
 * Returns: gboolean
 * Assertion: Sets the contents of the selection from a UTF-8 encoded string. 
 * Params Values: newly created GtkSelectionData*, "", -1
 * Expected: TRUE if the selection was successfully set, otherwise FALSE.
 * 
 * Name: gtk_selection_data_get_text
 * Params: GtkSelectionData *selection_data
 * Returns: guchar*
 * Assertion: Gets the contents of the selection data as a UTF-8 string.
 * Params Values: GtkSelectionData* with preseted data 
 * Expected: ""  
 */
static void test_purpose_43()
{
    #define STR ""
    #define LEN -1
    
    GtkSelectionData selection_data;
    gboolean succeeded;
    guchar* utf8_data = NULL;
    gchar* utf8_str = NULL;
    gchar* dup_data = NULL; 
    gchar* c_data = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    utf8_str = g_locale_to_utf8 (STR, -1, NULL, NULL, NULL);
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    succeeded = gtk_selection_data_set_text (&selection_data, utf8_str, LEN);
    utf8_data = gtk_selection_data_get_text(&selection_data);
    
    if (succeeded)
    {
        dup_data = g_strndup (STR, LEN);
        c_data = g_locale_from_utf8 ((const char*) utf8_data, -1, NULL, NULL, NULL);
        if (strcmp (dup_data, c_data))
        {
            TEST_FAIL ("gtk_selection_data_get_text () return %s, instead of %s", c_data, dup_data);         
        }
    
    }
    #undef STR
    #undef LEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_get_targets
 * Params: GtkSelectionData *selection_data, GdkAtom **targets, gint *n_atoms
 * Returns: gboolean
 * Assertion: Gets the contents of selection_data as an array of targets. 
 * Params Values: newly created GtkSelectionData*, location to store an array of targets, location to store number of items in targets
 * Expected: FALSE  
 */
static void test_purpose_44()
{
    #define TYPE gdk_atom_intern ("STRING", FALSE)
    #define FORMAT 8
    #define DATA "Data"
    #define LENGTH 4
    #define RESULT FALSE
    
    GtkSelectionData selection_data;
    GdkAtom type;
    gboolean succeeded;
    gint n_atoms;
    GdkAtom* targets;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = TYPE;
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    succeeded = gtk_selection_data_get_targets (&selection_data, &targets, &n_atoms);
    
    if (succeeded != RESULT)
    {
        TEST_FAIL ("gtk_selection_data_get_targets () return %i, instead of %i", succeeded, !succeeded);         
    }
    
    g_free (targets);
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_get_targets
 * Params: GtkSelectionData *selection_data, GdkAtom **targets, gint *n_atoms
 * Returns: gboolean
 * Assertion: Gets the contents of selection_data as an array of targets. 
 * Params Values: newly created GtkSelectionData*, location to store an array of targets, location to store number of items in targets
 * Expected: FALSE  
 */
static void test_purpose_45()
{
    #define TYPE gdk_atom_intern ("NONE", FALSE)
    #define FORMAT 111
    #define DATA ""
    #define LENGTH 7
    #define RESULT FALSE
    
    GtkSelectionData selection_data;
    GdkAtom type;
    gboolean succeeded;
    gint n_atoms;
    GdkAtom* targets;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = TYPE;
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    succeeded = gtk_selection_data_get_targets (&selection_data, &targets, &n_atoms);
    
    if (succeeded != RESULT)
    {
        TEST_FAIL ("gtk_selection_data_get_targets () return %i, instead of %i", succeeded, !succeeded);         
    }
    
    g_free (targets);
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_get_targets
 * Params: GtkSelectionData *selection_data, GdkAtom **targets, gint *n_atoms
 * Returns: gboolean
 * Assertion: Gets the contents of selection_data as an array of targets. 
 * Params Values: newly created GtkSelectionData*, location to store an array of targets, location to store number of items in targets
 * Expected: TRUE  
 */
static void test_purpose_46()
{
    #define TYPE GDK_SELECTION_TYPE_ATOM
    #define FORMAT 32
    #define DATA "Top secret"
    #define LENGTH 10
    #define RESULT TRUE
    
    GtkSelectionData selection_data;
    GdkAtom type;
    gboolean succeeded;
    gint n_atoms;
    GdkAtom* targets;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = TYPE;
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    succeeded = gtk_selection_data_get_targets (&selection_data, &targets, &n_atoms);
    
    if (succeeded != RESULT)
    {
        TEST_FAIL ("gtk_selection_data_get_targets () return %i, instead of %i", succeeded, !succeeded);         
    }
    
    g_free (targets);
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_get_targets
 * Params: GtkSelectionData *selection_data, GdkAtom **targets, gint *n_atoms
 * Returns: gboolean
 * Assertion: Gets the contents of selection_data as an array of targets. 
 * Params Values: newly created GtkSelectionData*, location to store an array of targets, location to store number of items in targets
 * Expected: TRUE  
 */
static void test_purpose_47()
{
    #define TYPE GDK_SELECTION_TYPE_ATOM
    #define FORMAT 32
    #define DATA ""
    #define LENGTH 0
    #define RESULT TRUE
    
    GtkSelectionData selection_data;
    GdkAtom type;
    gboolean succeeded;
    gint n_atoms;
    GdkAtom* targets;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = TYPE;
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    succeeded = gtk_selection_data_get_targets (&selection_data, &targets, &n_atoms);
    
    if (succeeded != RESULT)
    {
        TEST_FAIL ("gtk_selection_data_get_targets () return %i, instead of %i", succeeded, !succeeded);         
    }
    
    g_free (targets);
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_targets_include_text
 * Params: GtkSelectionData *selection_data, GdkAtom **targets, gint *n_atoms
 * Returns: gboolean
 * Assertion: Given a GtkSelectionData object holding a list of targets, determines if any of the targets in targets can be used to provide text.
 * Params Values: newly created GtkSelectionData*, location to store an array of targets, location to store number of items in targets
 * Expected: FALSE  
 */
static void test_purpose_48()
{
    #define TYPE gdk_atom_intern ("NOTYPE", FALSE)
    #define FORMAT 8
    #define DATA "STRING"
    #define LENGTH 6
    #define RESULT FALSE
    
    GtkSelectionData selection_data;
    gboolean succeeded;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, TYPE, FORMAT, (unsigned char*) DATA, LENGTH);
    succeeded = gtk_selection_data_targets_include_text (&selection_data);
    
    if (succeeded != RESULT)
    {
        TEST_FAIL ("gtk_selection_data_targets_include_text () return %i, instead of %i", succeeded, !succeeded);         
    }
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_targets_include_text
 * Params: GtkSelectionData *selection_data, GdkAtom **targets, gint *n_atoms
 * Returns: gboolean
 * Assertion: Given a GtkSelectionData object holding a list of targets, determines if any of the targets in targets can be used to provide text.
 * Params Values: newly created GtkSelectionData*, location to store an array of targets, location to store number of items in targets
 * Expected: FALSE  
 */
static void test_purpose_49()
{
    #define TYPE gdk_atom_intern ("NONE", FALSE)
    #define FORMAT 111
    #define DATA "UTF8_STRING"
    #define LENGTH 7
    #define RESULT FALSE
    
    GtkSelectionData selection_data;
    gboolean succeeded;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, TYPE, FORMAT, (unsigned char*) DATA, LENGTH);
    succeeded = gtk_selection_data_targets_include_text (&selection_data);
    
    if (succeeded != RESULT)
    {
        TEST_FAIL ("gtk_selection_data_targets_include_text () return %i, instead of %i", succeeded, !succeeded);         
    }
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_targets_include_text
 * Params: GtkSelectionData *selection_data, GdkAtom **targets, gint *n_atoms
 * Returns: gboolean
 * Assertion: Given a GtkSelectionData object holding a list of targets, determines if any of the targets in targets can be used to provide text.
 * Params Values: newly created GtkSelectionData*, location to store an array of targets, location to store number of items in targets
 * Expected: FALSE  
 */
static void test_purpose_50()
{
    #define TYPE GDK_SELECTION_TYPE_ATOM
    #define FORMAT 32
    #define DATA "TEXT"
    #define LENGTH 2
    #define RESULT FALSE
    
    GtkSelectionData selection_data;
    gboolean succeeded;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, TYPE, FORMAT, (unsigned char*) DATA, LENGTH);
    succeeded = gtk_selection_data_targets_include_text (&selection_data);
    
    if (succeeded != RESULT)
    {
        TEST_FAIL ("gtk_selection_data_targets_include_text () return %i, instead of %i", succeeded, !succeeded);         
    }
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_targets_include_text
 * Params: GtkSelectionData *selection_data, GdkAtom **targets, gint *n_atoms
 * Returns: gboolean
 * Assertion: Given a GtkSelectionData object holding a list of targets, determines if any of the targets in targets can be used to provide text.
 * Params Values: newly created GtkSelectionData*, location to store an array of targets, location to store number of items in targets
 * Expected: FALSE  
 */
static void test_purpose_51()
{
    #define TYPE GDK_SELECTION_TYPE_ATOM
    #define FORMAT 32
    #define DATA "COMPAUND_TEXT"
    #define LENGTH 8
    #define RESULT FALSE
    
    GtkSelectionData selection_data;
    gboolean succeeded;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, TYPE, FORMAT, (unsigned char*) DATA, LENGTH);
    succeeded = gtk_selection_data_targets_include_text (&selection_data);
    
    if (succeeded != RESULT)
    {
        TEST_FAIL ("gtk_selection_data_targets_include_text () return %i, instead of %i", succeeded, !succeeded);         
    }
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_remove_all
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Removes all handlers and unsets ownership of all selections for a widget. 
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_52()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define SELECTION gdk_atom_intern ("New_Selection", FALSE)
    #define TIME GDK_CURRENT_TIME
    #define RESULT TRUE
    
    GtkWidget* widget;
    gboolean succeeded;
    GdkAtom selection;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (widget != NULL)
    {
        gtk_widget_realize (widget);
    }
    
    selection = SELECTION;
    succeeded = gtk_selection_owner_set (widget, selection, TIME);
    gtk_selection_remove_all (widget);
    
    #undef WIDGET
    #undef SELECTION
    #undef TIME 
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_copy
 * Params: GtkSelectionData *selection_data
 * Returns: GtkSelectionData*
 * Assertion: Makes a copy of a GtkSelectionData structure and its data. 
 * Params Values: newly created GtkSelectionData*
 * Expected: GtkSelectionData* that is copy of selection_data  
 */
static void test_purpose_53()
{
    #define TYPE "STRING"
    #define FORMAT 8
    #define DATA "Data"
    #define LENGTH 4
    
    GtkSelectionData selection_data;
    GtkSelectionData* selection_data_copy;
    GdkAtom type;
    gchar* type_name;
    gchar* dup_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = gdk_atom_intern (TYPE, FALSE);
    
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    selection_data_copy = gtk_selection_data_copy (&selection_data);
    
    type_name = gdk_atom_name (selection_data_copy->type);
    if (strcmp ((const char*) TYPE, type_name))
    {
        TEST_FAIL ("selection_data_copy->type = %s, instead of %s", type_name, TYPE);         
    }
    if (selection_data_copy->format != FORMAT)
    {
        TEST_FAIL ("selection_data_copy->format = %i, instead of %i", selection_data_copy->format, FORMAT);         
    }
    if (selection_data_copy->length != LENGTH)
    {
        TEST_FAIL ("selection_data_copy->length = %i, instead of %i", selection_data_copy->length, LENGTH);         
    }
    if ((LENGTH < 0) && (selection_data_copy->data != NULL))
    {
        TEST_FAIL ("selection_data_copy->data = %s, instead of NULL", selection_data_copy->data);         
    } else 
    if ((LENGTH == 0) && strcmp ((const char*) selection_data_copy->data, ""))
    {
        TEST_FAIL ("selection_data_copy->data = %s, instead of \"\"", selection_data_copy->data);         
    } else {
        dup_data = g_strndup (DATA, LENGTH); 
        if (strcmp ((const char*) selection_data_copy->data, dup_data))
        {
            TEST_FAIL ("selection_data_copy->data = %s, instead of %s", selection_data_copy->data, dup_data);                 
        }
    }
    
    gtk_selection_data_free (selection_data_copy);
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_copy
 * Params: GtkSelectionData *selection_data
 * Returns: GtkSelectionData*
 * Assertion: Makes a copy of a GtkSelectionData structure and its data. 
 * Params Values: newly created GtkSelectionData*
 * Expected: GtkSelectionData* that is copy of selection_data  
 */
static void test_purpose_54()
{
    #define TYPE "NONE"
    #define FORMAT 111
    #define DATA ""
    #define LENGTH 7
    
    GtkSelectionData selection_data;
    GtkSelectionData* selection_data_copy;
    GdkAtom type;
    gchar* type_name;
    gchar* dup_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = gdk_atom_intern (TYPE, FALSE);
    
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    selection_data_copy = gtk_selection_data_copy (&selection_data);
    
    type_name = gdk_atom_name (selection_data_copy->type);
    if (strcmp ((const char*) TYPE, type_name))
    {
        TEST_FAIL ("selection_data_copy->type = %s, instead of %s", type_name, TYPE);         
    }
    if (selection_data_copy->format != FORMAT)
    {
        TEST_FAIL ("selection_data_copy->format = %i, instead of %i", selection_data_copy->format, FORMAT);         
    }
    if (selection_data_copy->length != LENGTH)
    {
        TEST_FAIL ("selection_data_copy->length = %i, instead of %i", selection_data_copy->length, LENGTH);         
    }
    if ((LENGTH < 0) && (selection_data_copy->data != NULL))
    {
        TEST_FAIL ("selection_data_copy->data = %s, instead of NULL", selection_data_copy->data);         
    } else 
    if ((LENGTH == 0) && strcmp ((const char*) selection_data_copy->data, ""))
    {
        TEST_FAIL ("selection_data_copy->data = %s, instead of \"\"", selection_data_copy->data);         
    } else {
        dup_data = g_strndup (DATA, LENGTH); 
        if (strcmp ((const char*) selection_data_copy->data, dup_data))
        {
            TEST_FAIL ("selection_data_copy->data = %s, instead of %s", selection_data_copy->data, dup_data);                 
        }
    }
    
    gtk_selection_data_free (selection_data_copy);
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_copy
 * Params: GtkSelectionData *selection_data
 * Returns: GtkSelectionData*
 * Assertion: Makes a copy of a GtkSelectionData structure and its data. 
 * Params Values: newly created GtkSelectionData*
 * Expected: GtkSelectionData* that is copy of selection_data  
 */
static void test_purpose_55()
{
    #define TYPE "PLAIN TEXT"
    #define FORMAT 0
    #define DATA "Information"
    #define LENGTH 3
    
    GtkSelectionData selection_data;
    GtkSelectionData* selection_data_copy;
    GdkAtom type;
    gchar* type_name;
    gchar* dup_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = gdk_atom_intern (TYPE, FALSE);
    
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    selection_data_copy = gtk_selection_data_copy (&selection_data);
    
    type_name = gdk_atom_name (selection_data_copy->type);
    if (strcmp ((const char*) TYPE, type_name))
    {
        TEST_FAIL ("selection_data_copy->type = %s, instead of %s", type_name, TYPE);         
    }
    if (selection_data_copy->format != FORMAT)
    {
        TEST_FAIL ("selection_data_copy->format = %i, instead of %i", selection_data_copy->format, FORMAT);         
    }
    if (selection_data_copy->length != LENGTH)
    {
        TEST_FAIL ("selection_data_copy->length = %i, instead of %i", selection_data_copy->length, LENGTH);         
    }
    if ((LENGTH < 0) && (selection_data_copy->data != NULL))
    {
        TEST_FAIL ("selection_data_copy->data = %s, instead of NULL", selection_data_copy->data);         
    } else 
    if ((LENGTH == 0) && strcmp ((const char*) selection_data_copy->data, ""))
    {
        TEST_FAIL ("selection_data_copy->data = %s, instead of \"\"", selection_data_copy->data);         
    } else {
        dup_data = g_strndup (DATA, LENGTH); 
        if (strcmp ((const char*) selection_data_copy->data, dup_data))
        {
            TEST_FAIL ("selection_data_copy->data = %s, instead of %s", selection_data_copy->data, dup_data);                 
        }
    }
    
    gtk_selection_data_free (selection_data_copy);
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_free
 * Params: GtkSelectionData *selection_data
 * Returns: void
 * Assertion: Frees a GtkSelectionData structure returned from gtk_selection_data_copy().
 * Params Values: GtkSelectionData* returned from gtk_selection_data_copy()
 * Expected: void  
 */
static void test_purpose_56()
{
    #define TYPE "STRING"
    #define FORMAT 8
    #define DATA "Data"
    #define LENGTH 4
    
    GtkSelectionData selection_data;
    GtkSelectionData* selection_data_copy;
    GdkAtom type;
    gchar* type_name;
    gchar* dup_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = gdk_atom_intern (TYPE, FALSE);
    
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    selection_data_copy = gtk_selection_data_copy (&selection_data);
    gtk_selection_data_free (selection_data_copy);
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_free
 * Params: GtkSelectionData *selection_data
 * Returns: void
 * Assertion: Frees a GtkSelectionData structure returned from gtk_selection_data_copy().
 * Params Values: GtkSelectionData* returned from gtk_selection_data_copy()
 * Expected: void  
 */
static void test_purpose_57()
{
    #define TYPE "NONE"
    #define FORMAT 111
    #define DATA ""
    #define LENGTH 7
    
    GtkSelectionData selection_data;
    GtkSelectionData* selection_data_copy;
    GdkAtom type;
    gchar* type_name;
    gchar* dup_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = gdk_atom_intern (TYPE, FALSE);
    
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    selection_data_copy = gtk_selection_data_copy (&selection_data);
    gtk_selection_data_free (selection_data_copy);
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_selection_data_free
 * Params: GtkSelectionData *selection_data
 * Returns: void
 * Assertion: Frees a GtkSelectionData structure returned from gtk_selection_data_copy().
 * Params Values: GtkSelectionData* returned from gtk_selection_data_copy()
 * Expected: void  
 */
static void test_purpose_58()
{
    #define TYPE "PLAIN TEXT"
    #define FORMAT 0
    #define DATA "Information"
    #define LENGTH 3
    
    GtkSelectionData selection_data;
    GtkSelectionData* selection_data_copy;
    GdkAtom type;
    gchar* type_name;
    gchar* dup_data;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    type = gdk_atom_intern (TYPE, FALSE);
    
    memset (&selection_data, 0, sizeof (GtkSelectionData));
    gtk_selection_data_set (&selection_data, type, FORMAT, (unsigned char*) DATA, LENGTH);
    selection_data_copy = gtk_selection_data_copy (&selection_data);
    gtk_selection_data_free (selection_data_copy);
    
    #undef TYPE
    #undef FORMAT
    #undef DATA
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for Selections ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {NULL,0}
};
