/*
 * pango_render methods tests
 * Testing pango_render methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: pango_context_get_metrics
 * Params: PangoContext *context,const PangoFontDescription *desc,PangoLanguage *language
 * Returns: a PangoFontMetrics object. The caller must call pango_font_metrics_unref() when finished using the object.
 * Assertion: Get overall metric information for a font particular font description. Since the metrics may be substantially different for different scripts, a language tag can be provided to indicate that the metrics should be retrieved that correspond to the script(s) used by that language.
 * Params Values: context_new,desc,NULL 
 * Expected: Metric information for the font with description desc
 *   
 */
static void test_purpose_1()
{
    #define CONTEXT context_new
    #define DESC    font_desc
    #define LANGUAGE NULL
    
    PangoFontDescription *font_desc;
    PangoContext *context_new;
    PangoFont *font_new;
    PangoFontMap* font_ft2_map;
    PangoFontMetrics *matrix = NULL;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create the context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    
    /*Get font description of the context.*/
    font_desc = pango_context_get_font_description(context_new);
    
    /*Load font from the context,with description desc.*/
    font_new = pango_font_map_load_font(font_ft2_map,context_new,font_desc);
    
    /*Get the metric information of the font with description desc.*/
    matrix = pango_context_get_metrics(CONTEXT,DESC,LANGUAGE);
    
    /*If no metric information is returned,test fails.*/
    if (matrix == NULL)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_font_description_free(font_desc);
    pango_font_metrics_unref(matrix);
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
    
    #undef CONTEXT
    #undef DESC
    #undef LANGUAGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_context_load_font
 * Params: PangoContext *context,const PangoFontDescription *desc
 * Returns: the font loaded, or NULL if no font matched.
 * Assertion: 
 * Loads the font in one of the fontmaps in the context that is the closest match for desc.
 * Params Values: context_new,desc
 * Expected: load font from context_new with description desc
 *   
 */
static void test_purpose_2()
{
    #define CONTEXT context_new
    #define DESC    font_desc
    
    PangoFontDescription *font_desc;
    PangoContext *context_new;
    PangoFont *font_new = NULL;
    PangoFontMap* font_ft2_map;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create the context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    font_desc = pango_context_get_font_description(context_new);
    
    /*Load font from the context,with description desc.*/
    font_new = pango_context_load_font(CONTEXT,DESC);
    
    /*If no font is loaded,test fails.*/
    if (font_new == NULL)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_font_description_free(font_desc);
    g_object_unref(font_ft2_map);
    
    #undef CONTEXT
    #undef DESC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_shape
 * Params: const gchar *text,gint length,PangoAnalysis *analysis,PangoGlyphString *glyphs
 * Returns: void
 * Assertion: Given a segment of text and the corresponding PangoAnalysis structure returned from pango_itemize(), convert the characters into glyphs. 
 * You may also pass in only a substring of the item from pango_itemize().
 * Params: "   ",3,&item->analysis,glyphs
 * Expected: convert characters into glyphs
 *   
 */
static void test_purpose_3()
{
    #define TEXT " Hello! "
    #define LENGTH 5
    #define ANALYSIS &item->analysis
    #define GLYPHS glyphs
    
    PangoAttrList *attr_list;
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoItem *item;
    GList *list;
    
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr_list = pango_attr_list_new();
    PangoGlyphString *glyphs = pango_glyph_string_new();
    
    /*g_printf("Number of glyphs is:%d.\n",glyphs->num_glyphs);*/
    
    /*To create the context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    
    /*Get the attr list structure of the string.*/
    list = pango_itemize(context_new," my string. ",0,10,attr_list,NULL);
    pango_attr_list_unref(attr_list);
    item = list->data;
    
    /*Do the convertion.*/
    pango_shape(TEXT,LENGTH,ANALYSIS,GLYPHS);
    /*g_printf("Number of glyphs is:%d.\n",glyphs->num_glyphs);*/
    
    /*Verify that the number of glyphs is correctly set.*/
    if (glyphs->num_glyphs != LENGTH)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_attr_list_unref(attr_list);
    g_object_unref(font_ft2_map);
    
    #undef TEXT
    #undef LENGTH 
    #undef ANALYSIS 
    #undef GLYPHS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_item_new
 * Params: void
 * Returns: the new PangoItem
 * Assertion: Creates a new PangoItem structure initialized to default values.
 * Params Values: void
 * Expected: new created item structure
 *   
 */
static void test_purpose_4()
{
    
    PangoItem *new_item = NULL;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new item structure.*/
    new_item = pango_item_new();
    
    /*If structure not created,test fails.*/
    if (new_item == NULL)
    {
    
        TEST_FAIL(get_not_created_msg(),NULL);
        return;
    }
    
    pango_item_free(new_item);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_context_set_matrix
 * Params: PangoContext *context, const PangoMatrix *matrix
 * Returns: void 
 * Assertion: Sets the transformation matrix that will be applied when rendering with this context. 
 * Note that reported metrics are in the user space coordinates before the application of the matrix, not device-space coordiantes after the application of the matrix. So, they don't scale with the matrix,though they may change slightly for different matrices, depending on how the text is fit to the pixel grid.
 * Params Values: context_new,&matrix_set
 * Expected: Set the transform matrix of context_new to matrix_set
 *   
 */
static void test_purpose_5()
{
    #define CONTEXT context_new
    #define MATRIX &matrix_set
    
    PangoFontDescription *font_desc;
    PangoContext *context_new;
    PangoFont *font_new;
    PangoFontMap* font_ft2_map;
    PangoMatrix matrix_set = {1,2,3,4,5,6.0};
    const PangoMatrix *matrix;
    
    double xx,xy,yx,yy,x0,y0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create the context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    font_desc = pango_context_get_font_description(context_new);
    font_new = pango_font_map_load_font(font_ft2_map,context_new,font_desc);
    
    /*Set the context matrix.*/
    pango_context_set_matrix(CONTEXT,MATRIX);
    
    /*Get the context matrix.*/
    matrix = pango_context_get_matrix(context_new);
    
    if (MATRIX == NULL)       
    {
        if (matrix != NULL)
        {
            TEST_FAIL(get_wrong_type_msg(),NULL);
        }
    }
    else
    {
        xx = matrix->xx;
        xy = matrix->xy;
        yx = matrix->yx;
        yy = matrix->yy;
        x0 = matrix->x0;
        y0 = matrix->y0;
    
    /*Compare the matrix set and gotten,if not equal,test fails.*/
        if (xx != matrix_set.xx || xy != matrix_set.xy || yx != matrix_set.yx || yy != matrix_set.yy || x0 != matrix_set.x0 || y0 != matrix_set.y0)
        {
            TEST_FAIL(get_wrong_type_msg(),NULL);
        }
    }
    pango_font_description_free(font_desc);
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
    
    #undef CONTEXT
    #undef MATRIX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_context_set_matrix
 * Params: PangoContext *context, const PangoMatrix *matrix
 * Returns: void 
 * Assertion: Sets the transformation matrix that will be applied when rendering with this context. 
 * Note that reported metrics are in the user space coordinates before the application of the matrix, not device-space coordiantes after the application of the matrix. So, they don't scale with the matrix,though they may change slightly for different matrices, depending on how the text is fit to the pixel grid.
 * Params Values: context_new,&matrix_set
 * Expected: Set the transform matrix of context_new to matrix_set
 *   
 */
static void test_purpose_6()
{
    #define CONTEXT context_new
    #define MATRIX NULL 
    
    PangoFontDescription *font_desc;
    PangoContext *context_new;
    PangoFont *font_new;
    PangoFontMap* font_ft2_map;
    PangoMatrix matrix_set = {1,2,3,4,5,6.0};
    const PangoMatrix *matrix;
    
    double xx,xy,yx,yy,x0,y0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create the context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    font_desc = pango_context_get_font_description(context_new);
    font_new = pango_font_map_load_font(font_ft2_map,context_new,font_desc);
    
    /*Set the context matrix.*/
    pango_context_set_matrix(CONTEXT,MATRIX);
    
    /*Get the context matrix.*/
    matrix = pango_context_get_matrix(context_new);
    
    if (MATRIX == NULL)       
    {
        if (matrix != NULL)
        {
            TEST_FAIL(get_wrong_type_msg(),NULL);
        }
    }
    else
    {
        xx = matrix->xx;
        xy = matrix->xy;
        yx = matrix->yx;
        yy = matrix->yy;
        x0 = matrix->x0;
        y0 = matrix->y0;
    
    /*Compare the matrix set and gotten,if not equal,test fails.*/
        if (xx != matrix_set.xx || xy != matrix_set.xy || yx != matrix_set.yx || yy != matrix_set.yy || x0 != matrix_set.x0 || y0 != matrix_set.y0)
        {
            TEST_FAIL(get_wrong_type_msg(),NULL);
        }
    }
    pango_font_description_free(font_desc);
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
    
    #undef CONTEXT
    #undef MATRIX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_context_get_matrix
 * Params: PangoContext *context
 * Returns: the matrix, or NULL if no matrix has been set (which is the same as the identity matrix). The returned matrix is owned by Pango and must not be modified or freed.
 * Assertion: Gets the transformation matrix that will be applied when rendering with this context. See pango_context_set_matrix().
 * Params Values: context_new 
 * Expected: the transform matrix of context context_new
 *   
 */
static void test_purpose_7()
{
    #define CONTEXT context_new
    
    PangoFontDescription *font_desc;
    PangoContext *context_new;
    PangoFont *font_new;
    PangoFontMap* font_ft2_map;
    PangoMatrix matrix_set = {1,2,3,4,5,6.0};
    const PangoMatrix *matrix = NULL;
    double xx,xy,yx,yy,x0,y0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create the context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    font_desc = pango_context_get_font_description(context_new);
    font_new = pango_font_map_load_font(font_ft2_map,context_new,font_desc);
    
    /*Set the context matrix.*/
    pango_context_set_matrix(context_new,&matrix_set);
    
    /*Get the context matrix.*/
    matrix = pango_context_get_matrix(CONTEXT);
           
    xx = matrix->xx;
    xy = matrix->xy;
    yx = matrix->yx;
    yy = matrix->yy;
    x0 = matrix->x0;
    y0 = matrix->y0;
    
    /*Compare the matrix set and gotten,if not equal,test fails.*/
    if (xx != matrix_set.xx || xy != matrix_set.xy || yx != matrix_set.yx || yy != matrix_set.yy || x0 != matrix_set.x0 || y0 != matrix_set.y0)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_font_description_free(font_desc);
    g_object_unref(font_new);
    g_object_unref(font_ft2_map);
    
    #undef CONTEXT
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for pango_render ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {NULL,0}
};
