/*
 * pango_tab methods tests
 * Testing pango_tab methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: pango_tab_array_set_tab
 * Params: PangoTabArray *tab_array,gint tab_index,PangoTabAlign alignment,gint location
 * Returns: void 
 * Assertion: Sets the alignment and location of a tab stop. alignment must always be PANGO_TAB_LEFT in the current implementation.
 * Params Values: tab_array_new,0,PANGO_TAB_LEFT,0
 * Expected: a tab stop with index 0 and location 0
 *   
 */
static void test_purpose_1()
{
    #define TABARRAY  tab_array_new 
    #define TABINDEX  0 
    #define TABALIGNMENT PANGO_TAB_LEFT
    #define LOCATION  0
    
    PangoTabArray *tab_array_new;
    gint *location;
        
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    location = g_new(gint,1);
    
    /*Create a new tab array with initial size of tab stops 3,and tab stops are in Pango units.*/
    tab_array_new = pango_tab_array_new(3,FALSE);
    
    /*Set tab stop in the tab array.*/
    pango_tab_array_set_tab(TABARRAY,TABINDEX,TABALIGNMENT,LOCATION);
    
    /*Get tab stop at the specified index TABINDEX.*/
    pango_tab_array_get_tab(tab_array_new,TABINDEX,NULL,location);
    
    /*Check whether the location of the tab set is correct.*/
    if (LOCATION != *location)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_tab_array_free(tab_array_new);
    g_free(location);
    
    #undef TABARRAY
    #undef TABINDEX
    #undef LOCATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_tab_array_set_tab
 * Params: PangoTabArray *tab_array,gint tab_index,PangoTabAlign alignment,gint location
 * Returns: void 
 * Assertion: Sets the alignment and location of a tab stop. alignment must always be PANGO_TAB_LEFT in the current implementation.
 * Params Values: tab_array_new,1,PANGO_TAB_LEFT,3
 * Expected: a tab stop with index 1 and location 3
 *   
 */
static void test_purpose_2()
{
    #define TABARRAY  tab_array_new 
    #define TABINDEX  1 
    #define TABALIGNMENT PANGO_TAB_LEFT
    #define LOCATION  3
    
    PangoTabArray *tab_array_new;
    gint *location;
        
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    location = g_new(gint,1);
    
    /*Create a new tab array with initial size of tab stops 3,and tab stops are in Pango units.*/
    tab_array_new = pango_tab_array_new(3,FALSE);
    
    /*Set tab stop in the tab array.*/
    pango_tab_array_set_tab(TABARRAY,TABINDEX,TABALIGNMENT,LOCATION);
    
    /*Get tab stop at the specified index TABINDEX.*/
    pango_tab_array_get_tab(tab_array_new,TABINDEX,NULL,location);
    
    /*Check whether the location of the tab set is correct.*/
    if (LOCATION != *location)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_tab_array_free(tab_array_new);
    g_free(location);
    
    #undef TABARRAY
    #undef TABINDEX
    #undef LOCATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_tab_array_set_tab
 * Params: PangoTabArray *tab_array,gint tab_index,PangoTabAlign alignment,gint location
 * Returns: void 
 * Assertion: Sets the alignment and location of a tab stop. alignment must always be PANGO_TAB_LEFT in the current implementation.
 * Params Values: tab_array_new,2,PANGO_TAB_LEFT,5
 * Expected: a tab stop with index 2 and location 5
 *   
 */
static void test_purpose_3()
{
    #define TABARRAY  tab_array_new 
    #define TABINDEX  2 
    #define TABALIGNMENT PANGO_TAB_LEFT
    #define LOCATION  5
    
    PangoTabArray *tab_array_new;
    gint *location;
        
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    location = g_new(gint,1);
    
    /*Create a new tab array with initial size of tab stops 3,and tab stops are in Pango units.*/
    tab_array_new = pango_tab_array_new(3,FALSE);
    
    /*Set tab stop in the tab array.*/
    pango_tab_array_set_tab(TABARRAY,TABINDEX,TABALIGNMENT,LOCATION);
    
    /*Get tab stop at the specified index TABINDEX.*/
    pango_tab_array_get_tab(tab_array_new,TABINDEX,NULL,location);
    
    /*Check whether the location of the tab set is correct.*/
    if (LOCATION != *location)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_tab_array_free(tab_array_new);
    g_free(location);
    
    #undef TABARRAY
    #undef TABINDEX
    #undef LOCATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_tab_array_new
 * Params: gint initial_size, positions_in_pixels
 * Returns: PangoTabArray *
 * Assertion: Creates an array of initial_size tab stops. Tab stops are specified in pixel units if positions_in_pixels is TRUE, otherwise in Pango units. All stops are initially at position 0.
 * Params Values: 0,TRUE
 * Expected: a new tab array with size of tab stops 0 and tab tab stops specified in <%3%> units
 *   
 */
static void test_purpose_4()
{
    #define TABSIZE 0
    #define POS_PIX TRUE
    
    PangoTabArray *tab_array_new;
    gint tab_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new tab array with size of tab stops TABSIZE.*/
    tab_array_new = pango_tab_array_new(TABSIZE,POS_PIX);
    
    /*Get the size of the tab array.*/
    tab_size = pango_tab_array_get_size(tab_array_new);
    
    /*Check whether the tab array is created.*/
    if (!tab_array_new)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        return;
    }
    
    /*Check the new created tab array's tab size is correct.*/
    if (tab_size != TABSIZE)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        pango_tab_array_free(tab_array_new);
        return;
    }
    
    /*Check whether the new created tab array's positions_in_pixels tag is correct.*/
    if (POS_PIX != pango_tab_array_get_positions_in_pixels(tab_array_new))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        pango_tab_array_free(tab_array_new);
        return;
    }
        
    pango_tab_array_free(tab_array_new);
    
    #undef TABSIZE
    #undef POS_PIX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_tab_array_new
 * Params: gint initial_size, positions_in_pixels
 * Returns: PangoTabArray *
 * Assertion: Creates an array of initial_size tab stops. Tab stops are specified in pixel units if positions_in_pixels is TRUE, otherwise in Pango units. All stops are initially at position 0.
 * Params Values: 1,FALSE
 * Expected: a new tab array with size of tab stops 1 and tab tab stops specified in <%3%> units
 *   
 */
static void test_purpose_5()
{
    #define TABSIZE 1
    #define POS_PIX FALSE
    
    PangoTabArray *tab_array_new;
    gint tab_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new tab array with size of tab stops TABSIZE.*/
    tab_array_new = pango_tab_array_new(TABSIZE,POS_PIX);
    
    /*Get the size of the tab array.*/
    tab_size = pango_tab_array_get_size(tab_array_new);
    
    /*Check whether the tab array is created.*/
    if (!tab_array_new)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        return;
    }
    
    /*Check the new created tab array's tab size is correct.*/
    if (tab_size != TABSIZE)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        pango_tab_array_free(tab_array_new);
        return;
    }
    
    /*Check whether the new created tab array's positions_in_pixels tag is correct.*/
    if (POS_PIX != pango_tab_array_get_positions_in_pixels(tab_array_new))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        pango_tab_array_free(tab_array_new);
        return;
    }
        
    pango_tab_array_free(tab_array_new);
    
    #undef TABSIZE
    #undef POS_PIX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_tab_array_new
 * Params: gint initial_size, positions_in_pixels
 * Returns: PangoTabArray *
 * Assertion: Creates an array of initial_size tab stops. Tab stops are specified in pixel units if positions_in_pixels is TRUE, otherwise in Pango units. All stops are initially at position 0.
 * Params Values: 2,FALSE
 * Expected: a new tab array with size of tab stops 2 and tab tab stops specified in <%3%> units
 *   
 */
static void test_purpose_6()
{
    #define TABSIZE 2
    #define POS_PIX FALSE
    
    PangoTabArray *tab_array_new;
    gint tab_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new tab array with size of tab stops TABSIZE.*/
    tab_array_new = pango_tab_array_new(TABSIZE,POS_PIX);
    
    /*Get the size of the tab array.*/
    tab_size = pango_tab_array_get_size(tab_array_new);
    
    /*Check whether the tab array is created.*/
    if (!tab_array_new)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        return;
    }
    
    /*Check the new created tab array's tab size is correct.*/
    if (tab_size != TABSIZE)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        pango_tab_array_free(tab_array_new);
        return;
    }
    
    /*Check whether the new created tab array's positions_in_pixels tag is correct.*/
    if (POS_PIX != pango_tab_array_get_positions_in_pixels(tab_array_new))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        pango_tab_array_free(tab_array_new);
        return;
    }
        
    pango_tab_array_free(tab_array_new);
    
    #undef TABSIZE
    #undef POS_PIX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_tab_array_free
 * Params: PangoTabArray *tab_array
 * Returns: void
 * Assertion: Frees a tab array and associated resources.
 * Params Values: tab_array_new 
 * Expected: size of tab array is 0
 *   
 */
static void test_purpose_7()
{
    #define TAB_ARRAY tab_array_new
    
    PangoTabArray *tab_array_new;
    gint size;  
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new tab array.*/
    tab_array_new = pango_tab_array_new(3,FALSE);
    
    /*Free the tab array.*/
    pango_tab_array_free(TAB_ARRAY);
    
    if (TAB_ARRAY != NULL)
    {
        size = pango_tab_array_get_size (TAB_ARRAY);
    /*   g_printf("Array size after free is %d.\n",size);*/
        /*Check whether the tab array is freed.*/
        if (size != 0)
        {
    /*      g_printf("Array size after free is %d.\n",size);*/
    /*      TEST_FAIL(get_wrong_type_msg(),NULL);*/
        }
    
    }
    
    #undef TAB_ARRAY
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for pango_tab ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {NULL,0}
};
