/*
 * GtkLabel methods tests
 * Testing GtkLabel methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: NULL
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: NULL
 * Expected: GtkLabel*  
 */
static void test_purpose_1()
{
    #define LABEL  NULL
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: ""
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: ""
 * Expected: GtkLabel*  
 */
static void test_purpose_2()
{
    #define LABEL  ""
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: " "
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: " "
 * Expected: GtkLabel*  
 */
static void test_purpose_3()
{
    #define LABEL  " "
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: "   "
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: "   "
 * Expected: GtkLabel*  
 */
static void test_purpose_4()
{
    #define LABEL  "   "
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: "Label String"
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: "Label String"
 * Expected: GtkLabel*  
 */
static void test_purpose_5()
{
    #define LABEL  "Label String"
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkLabel*  
 */
static void test_purpose_6()
{
    #define LABEL  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: "abcdefghijklmnopqrstuvwxyz \n ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: "abcdefghijklmnopqrstuvwxyz \n ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkLabel*  
 */
static void test_purpose_7()
{
    #define LABEL  "abcdefghijklmnopqrstuvwxyz \n ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkLabel*  
 */
static void test_purpose_8()
{
    #define LABEL  "!@#$%^&*()_+|~=\";:'?<>`/"
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: "_a_b"
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: "_a_b"
 * Expected: GtkLabel*  
 */
static void test_purpose_9()
{
    #define LABEL  "_a_b"
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: "\n\t\""
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: "\n\t\""
 * Expected: GtkLabel*  
 */
static void test_purpose_10()
{
    #define LABEL  "\n\t\""
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: "_\n\t\""
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: "_\n\t\""
 * Expected: GtkLabel*  
 */
static void test_purpose_11()
{
    #define LABEL  "_\n\t\""
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: "\b"
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: "\b"
 * Expected: GtkLabel*  
 */
static void test_purpose_12()
{
    #define LABEL  "\b"
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: Creates a new label with the given text inside it.
 * Params Values: "_\b"
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new
 * Params: const gchar *str
 * Returns: GtkWidget*
 * Assertion: You can pass NULL to get an empty label widget
 * Params Values: "_\b"
 * Expected: GtkLabel*  
 */
static void test_purpose_13()
{
    #define LABEL  "_\b"
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label = %s, should be %s", label, LABEL);
        }
    } else {
        if (strcmp ("", label))
        {
            TEST_FAIL ("label = '%s', should be '%s'", label, "");
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL);
    if (attributes != NULL) 
    {
        TEST_FAIL ("attributes is not NULL but should be", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (use_underline != FALSE) 
    {
        TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", justify, GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval != GDK_VoidSymbol) 
    {
        TEST_FAIL ("mnemonic_keyval is %d, should be %d", mnemonic_keyval, 
                   GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic widget is not NULL but should be", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkLabel, containing the text in str.
 * Params Values: "are_terb" 
 * Expected: GtkLabel*  
 */
static void test_purpose_14()
{
    #define LABEL  "are_terb"
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    /*  g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL); */
    /*  if (!LABEL || !strlen (LABEL)) */
    /*  { */
    /*      if (attributes != NULL) */
    /*      { */
    /*          TEST_FAIL ("attributes is not NULL but should be", NULL); */
    /*      } */
    /*  } else { */
    /*      if (attributes == NULL) */
    /*      { */
    /*          TEST_FAIL ("attributes is NULL but should be not", NULL); */
    /*      } */
    /*  } */
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
        
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval == GDK_VoidSymbol) 
    {
        TEST_FAIL ("selectable = %d, should be %d", selectable, GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic_widget is not NULL but should be", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkLabel, containing the text in str.
 * Params Values: "_areterb" 
 * Expected: GtkLabel*  
 */
static void test_purpose_15()
{
    #define LABEL  "_areterb"
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    /*  g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL); */
    /*  if (!LABEL || !strlen (LABEL)) */
    /*  { */
    /*      if (attributes != NULL) */
    /*      { */
    /*          TEST_FAIL ("attributes is not NULL but should be", NULL); */
    /*      } */
    /*  } else { */
    /*      if (attributes == NULL) */
    /*      { */
    /*          TEST_FAIL ("attributes is NULL but should be not", NULL); */
    /*      } */
    /*  } */
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
        
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval == GDK_VoidSymbol) 
    {
        TEST_FAIL ("selectable = %d, should be %d", selectable, GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic_widget is not NULL but should be", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkLabel, containing the text in str.
 * Params Values: "_\n\t\"" 
 * Expected: GtkLabel*  
 */
static void test_purpose_16()
{
    #define LABEL  "_\n\t\""
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    /*  g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL); */
    /*  if (!LABEL || !strlen (LABEL)) */
    /*  { */
    /*      if (attributes != NULL) */
    /*      { */
    /*          TEST_FAIL ("attributes is not NULL but should be", NULL); */
    /*      } */
    /*  } else { */
    /*      if (attributes == NULL) */
    /*      { */
    /*          TEST_FAIL ("attributes is NULL but should be not", NULL); */
    /*      } */
    /*  } */
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
        
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval == GDK_VoidSymbol) 
    {
        TEST_FAIL ("selectable = %d, should be %d", selectable, GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic_widget is not NULL but should be", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkLabel, containing the text in str.
 * Params Values: "_\b" 
 * Expected: GtkLabel*  
 */
static void test_purpose_17()
{
    #define LABEL  "_\b"
    
    PangoAttrList* attributes;
    gchararray label;
    gboolean use_markup;
    gboolean use_underline;
    GtkJustification justify;
    gboolean wrap;
    gboolean selectable;
    guint mnemonic_keyval;
    GtkWidget *mnemonic_widget;
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    /*  g_object_get(GTK_OBJECT(widget), "attributes", &attributes, NULL); */
    /*  if (!LABEL || !strlen (LABEL)) */
    /*  { */
    /*      if (attributes != NULL) */
    /*      { */
    /*          TEST_FAIL ("attributes is not NULL but should be", NULL); */
    /*      } */
    /*  } else { */
    /*      if (attributes == NULL) */
    /*      { */
    /*          TEST_FAIL ("attributes is NULL but should be not", NULL); */
    /*      } */
    /*  } */
    
    g_object_get(GTK_OBJECT(widget), "use-markup", &use_markup, NULL);
    if (use_markup != FALSE) 
    {
        TEST_FAIL ("use_markup = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
        
    g_object_get(GTK_OBJECT(widget), "justify", &justify, NULL);
    if (justify !=  GTK_JUSTIFY_LEFT) 
    {
        TEST_FAIL ("justify is %d, should be %d", GTK_JUSTIFY_LEFT);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL ("wrap = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "selectable", &selectable, NULL);
    if (selectable != FALSE) 
    {
        TEST_FAIL ("selectable = TRUE, should be FALSE", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-keyval", &mnemonic_keyval, NULL);
    if (mnemonic_keyval == GDK_VoidSymbol) 
    {
        TEST_FAIL ("selectable = %d, should be %d", selectable, GDK_VoidSymbol);
    }
    
    g_object_get(GTK_OBJECT(widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != NULL) 
    {
        TEST_FAIL ("mnemonic_widget is not NULL but should be", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: Sets the text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, ""
 * Expected: void
 * 
 * Name: gtk_label_get_text
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget, as displayed on the screen.
 * Params Values: newly created GtkLabel*
 * Expected: ""  
 */
static void test_purpose_18()
{
    #define TEXT ""
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (strcmp(gtk_label_get_text(GTK_LABEL (widget)), TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: Sets the text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, " "
 * Expected: void
 * 
 * Name: gtk_label_get_text
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget, as displayed on the screen.
 * Params Values: newly created GtkLabel*
 * Expected: " "  
 */
static void test_purpose_19()
{
    #define TEXT " "
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (strcmp(gtk_label_get_text(GTK_LABEL (widget)), TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: Sets the text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void
 * 
 * Name: gtk_label_get_text
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget, as displayed on the screen.
 * Params Values: newly created GtkLabel*
 * Expected: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"  
 */
static void test_purpose_20()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (strcmp(gtk_label_get_text(GTK_LABEL (widget)), TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: Sets the text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void
 * 
 * Name: gtk_label_get_text
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget, as displayed on the screen.
 * Params Values: newly created GtkLabel*
 * Expected: "!@#$%^&*()_+|~=\";:'?<>`/"  
 */
static void test_purpose_21()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (strcmp(gtk_label_get_text(GTK_LABEL (widget)), TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: Sets the text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "_a_b"
 * Expected: void
 * 
 * Name: gtk_label_get_text
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget, as displayed on the screen.
 * Params Values: newly created GtkLabel*
 * Expected: "_a_b"  
 */
static void test_purpose_22()
{
    #define TEXT "_a_b"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (strcmp(gtk_label_get_text(GTK_LABEL (widget)), TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: Sets the text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "\n\t\""
 * Expected: void
 * 
 * Name: gtk_label_get_text
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget, as displayed on the screen.
 * Params Values: newly created GtkLabel*
 * Expected: "\n\t\""  
 */
static void test_purpose_23()
{
    #define TEXT "\n\t\""
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (strcmp(gtk_label_get_text(GTK_LABEL (widget)), TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: Sets the text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "_\n\t\""
 * Expected: void
 * 
 * Name: gtk_label_get_text
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget, as displayed on the screen.
 * Params Values: newly created GtkLabel*
 * Expected: "_\n\t\""  
 */
static void test_purpose_24()
{
    #define TEXT "_\n\t\""
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (strcmp(gtk_label_get_text(GTK_LABEL (widget)), TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: Sets the text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "\b"
 * Expected: void
 * 
 * Name: gtk_label_get_text
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget, as displayed on the screen.
 * Params Values: newly created GtkLabel*
 * Expected: "\b"  
 */
static void test_purpose_25()
{
    #define TEXT "\b"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (strcmp(gtk_label_get_text(GTK_LABEL (widget)), TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: Sets the text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "_\b"
 * Expected: void
 * 
 * Name: gtk_label_get_text
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget, as displayed on the screen.
 * Params Values: newly created GtkLabel*
 * Expected: "_\b"  
 */
static void test_purpose_26()
{
    #define TEXT "_\b"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (strcmp(gtk_label_get_text(GTK_LABEL (widget)), TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_pattern
 * Params: GtkLabel *label, const gchar *pattern
 * Returns: void
 * Assertion: The pattern of underlines you want under the existing text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, ""
 * Expected: void  
 */
static void test_purpose_27()
{
    #define TEXT ""
    #define PATTERN ""
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_pattern (GTK_LABEL (widget), PATTERN);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef PATTERN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_pattern
 * Params: GtkLabel *label, const gchar *pattern
 * Returns: void
 * Assertion: The pattern of underlines you want under the existing text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, " "
 * Expected: void  
 */
static void test_purpose_28()
{
    #define TEXT " "
    #define PATTERN "_"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_pattern (GTK_LABEL (widget), PATTERN);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef PATTERN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_pattern
 * Params: GtkLabel *label, const gchar *pattern
 * Returns: void
 * Assertion: The pattern of underlines you want under the existing text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void  
 */
static void test_purpose_29()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define PATTERN "_   _   _"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_pattern (GTK_LABEL (widget), PATTERN);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef PATTERN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_pattern
 * Params: GtkLabel *label, const gchar *pattern
 * Returns: void
 * Assertion: The pattern of underlines you want under the existing text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void  
 */
static void test_purpose_30()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/"
    #define PATTERN "__"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_pattern (GTK_LABEL (widget), PATTERN);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef PATTERN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_pattern
 * Params: GtkLabel *label, const gchar *pattern
 * Returns: void
 * Assertion: The pattern of underlines you want under the existing text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "_a_b"
 * Expected: void  
 */
static void test_purpose_31()
{
    #define TEXT "_a_b"
    #define PATTERN " _ _"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_pattern (GTK_LABEL (widget), PATTERN);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef PATTERN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_pattern
 * Params: GtkLabel *label, const gchar *pattern
 * Returns: void
 * Assertion: The pattern of underlines you want under the existing text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "\n\t\""
 * Expected: void  
 */
static void test_purpose_32()
{
    #define TEXT "\n\t\""
    #define PATTERN "__"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_pattern (GTK_LABEL (widget), PATTERN);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef PATTERN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_pattern
 * Params: GtkLabel *label, const gchar *pattern
 * Returns: void
 * Assertion: The pattern of underlines you want under the existing text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "_\n\t\""
 * Expected: void  
 */
static void test_purpose_33()
{
    #define TEXT "_\n\t\""
    #define PATTERN "  __"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_pattern (GTK_LABEL (widget), PATTERN);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef PATTERN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_pattern
 * Params: GtkLabel *label, const gchar *pattern
 * Returns: void
 * Assertion: The pattern of underlines you want under the existing text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "\b"
 * Expected: void  
 */
static void test_purpose_34()
{
    #define TEXT "\b"
    #define PATTERN " "
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_pattern (GTK_LABEL (widget), PATTERN);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef PATTERN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_pattern
 * Params: GtkLabel *label, const gchar *pattern
 * Returns: void
 * Assertion: The pattern of underlines you want under the existing text within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, "_\b"
 * Expected: void  
 */
static void test_purpose_35()
{
    #define TEXT "_\b"
    #define PATTERN " _"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_pattern (GTK_LABEL (widget), PATTERN);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef PATTERN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_justify
 * Params: GtkLabel *label, GtkJustification jtype
 * Returns: void
 * Assertion: Sets the alignment of the lines in the text of the label relative to each other.
 * Params Values: newly created GtkLabel*, GTK_JUSTIFY_LEFT
 * Expected: void  
 */
static void test_purpose_36()
{
    #define JUSTIFY GTK_JUSTIFY_LEFT
    
    GtkWidget *widget;
    GtkJustification justify;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_justify (GTK_LABEL (widget), JUSTIFY);
    
    
    g_object_get (GTK_OBJECT (widget), "justify", &justify, NULL);
    if (JUSTIFY != justify)
    {
        TEST_FAIL("label justify = %i, should be %i", justify, JUSTIFY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef JUSTIFY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_justify
 * Params: GtkLabel *label, GtkJustification jtype
 * Returns: void
 * Assertion: Sets the alignment of the lines in the text of the label relative to each other.
 * Params Values: newly created GtkLabel*, GTK_JUSTIFY_RIGHT
 * Expected: void  
 */
static void test_purpose_37()
{
    #define JUSTIFY GTK_JUSTIFY_RIGHT
    
    GtkWidget *widget;
    GtkJustification justify;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_justify (GTK_LABEL (widget), JUSTIFY);
    
    
    g_object_get (GTK_OBJECT (widget), "justify", &justify, NULL);
    if (JUSTIFY != justify)
    {
        TEST_FAIL("label justify = %i, should be %i", justify, JUSTIFY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef JUSTIFY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_justify
 * Params: GtkLabel *label, GtkJustification jtype
 * Returns: void
 * Assertion: Sets the alignment of the lines in the text of the label relative to each other.
 * Params Values: newly created GtkLabel*, GTK_JUSTIFY_CENTER
 * Expected: void  
 */
static void test_purpose_38()
{
    #define JUSTIFY GTK_JUSTIFY_CENTER
    
    GtkWidget *widget;
    GtkJustification justify;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_justify (GTK_LABEL (widget), JUSTIFY);
    
    
    g_object_get (GTK_OBJECT (widget), "justify", &justify, NULL);
    if (JUSTIFY != justify)
    {
        TEST_FAIL("label justify = %i, should be %i", justify, JUSTIFY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef JUSTIFY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_justify
 * Params: GtkLabel *label, GtkJustification jtype
 * Returns: void
 * Assertion: Sets the alignment of the lines in the text of the label relative to each other.
 * Params Values: newly created GtkLabel*, GTK_JUSTIFY_FILL
 * Expected: void  
 */
static void test_purpose_39()
{
    #define JUSTIFY GTK_JUSTIFY_FILL
    
    GtkWidget *widget;
    GtkJustification justify;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_justify (GTK_LABEL (widget), JUSTIFY);
    
    
    g_object_get (GTK_OBJECT (widget), "justify", &justify, NULL);
    if (JUSTIFY != justify)
    {
        TEST_FAIL("label justify = %i, should be %i", justify, JUSTIFY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef JUSTIFY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_justify
 * Params: GtkLabel *label, GtkJustification jtype
 * Returns: void
 * Assertion: GTK_JUSTIFY_LEFT is the default value when the widget is first created with gtk_label_new().
 * Params Values: newly created GtkLabel*, <%0%>
 * Expected: void  
 */
static void test_purpose_40()
{
    GtkWidget *widget;
    GtkJustification justify;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "justify", &justify, NULL);
    if (justify != GTK_JUSTIFY_LEFT)
    {
        TEST_FAIL("label justify = %i, the default value is %d", 
                  justify, GTK_JUSTIFY_LEFT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_justify
 * Params: GtkLabel *label
 * Returns: GtkJustification
 * Assertion: Returns the justification of the label.
 * Params Values: GtkLabel* that justification set in GTK_JUSTIFY_LEFT
 * Expected: GTK_JUSTIFY_LEFT  
 */
static void test_purpose_41()
{
    #define JUSTIFY GTK_JUSTIFY_LEFT
    
    GtkWidget *widget;
    GtkJustification justify;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_justify (GTK_LABEL (widget), JUSTIFY);
    justify = gtk_label_get_justify (GTK_LABEL (widget));
    
    if (JUSTIFY != justify)
    {
        TEST_FAIL("gtk_label_get_justify() return %i instead of %i", justify, JUSTIFY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef JUSTIFY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_justify
 * Params: GtkLabel *label
 * Returns: GtkJustification
 * Assertion: Returns the justification of the label.
 * Params Values: GtkLabel* that justification set in GTK_JUSTIFY_RIGHT
 * Expected: GTK_JUSTIFY_RIGHT  
 */
static void test_purpose_42()
{
    #define JUSTIFY GTK_JUSTIFY_RIGHT
    
    GtkWidget *widget;
    GtkJustification justify;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_justify (GTK_LABEL (widget), JUSTIFY);
    justify = gtk_label_get_justify (GTK_LABEL (widget));
    
    if (JUSTIFY != justify)
    {
        TEST_FAIL("gtk_label_get_justify() return %i instead of %i", justify, JUSTIFY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef JUSTIFY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_justify
 * Params: GtkLabel *label
 * Returns: GtkJustification
 * Assertion: Returns the justification of the label.
 * Params Values: GtkLabel* that justification set in GTK_JUSTIFY_CENTER
 * Expected: GTK_JUSTIFY_CENTER  
 */
static void test_purpose_43()
{
    #define JUSTIFY GTK_JUSTIFY_CENTER
    
    GtkWidget *widget;
    GtkJustification justify;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_justify (GTK_LABEL (widget), JUSTIFY);
    justify = gtk_label_get_justify (GTK_LABEL (widget));
    
    if (JUSTIFY != justify)
    {
        TEST_FAIL("gtk_label_get_justify() return %i instead of %i", justify, JUSTIFY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef JUSTIFY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_justify
 * Params: GtkLabel *label
 * Returns: GtkJustification
 * Assertion: Returns the justification of the label.
 * Params Values: GtkLabel* that justification set in GTK_JUSTIFY_FILL
 * Expected: GTK_JUSTIFY_FILL  
 */
static void test_purpose_44()
{
    #define JUSTIFY GTK_JUSTIFY_FILL
    
    GtkWidget *widget;
    GtkJustification justify;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_justify (GTK_LABEL (widget), JUSTIFY);
    justify = gtk_label_get_justify (GTK_LABEL (widget));
    
    if (JUSTIFY != justify)
    {
        TEST_FAIL("gtk_label_get_justify() return %i instead of %i", justify, JUSTIFY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef JUSTIFY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_line_wrap
 * Params: GtkLabel *label, gboolean wrap
 * Returns: void
 * Assertion: Toggles line wrapping within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, TRUE
 * Expected: void  
 */
static void test_purpose_45()
{
    #define WRAP TRUE
    
    GtkWidget *widget;
    gboolean wrap;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_line_wrap (GTK_LABEL (widget), WRAP);
    
    
    g_object_get (GTK_OBJECT (widget), "wrap", &wrap, NULL);
    if (WRAP != wrap)
    {
        TEST_FAIL("label line wrap = %i, should be %i", wrap, WRAP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WRAP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_line_wrap
 * Params: GtkLabel *label, gboolean wrap
 * Returns: void
 * Assertion: Toggles line wrapping within the GtkLabel widget.
 * Params Values: newly created GtkLabel*, FALSE
 * Expected: void  
 */
static void test_purpose_46()
{
    #define WRAP FALSE
    
    GtkWidget *widget;
    gboolean wrap;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_line_wrap (GTK_LABEL (widget), WRAP);
    
    
    g_object_get (GTK_OBJECT (widget), "wrap", &wrap, NULL);
    if (WRAP != wrap)
    {
        TEST_FAIL("label line wrap = %i, should be %i", wrap, WRAP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WRAP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_line_wrap
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: Returns whether lines in the label are automatically wrapped. 
 * Params Values: GtkLabel* that wrap = TRUE
 * Expected: TRUE  
 */
static void test_purpose_47()
{
    #define WRAP TRUE
    
    GtkWidget *widget;
    gboolean wrap;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_line_wrap (GTK_LABEL (widget), WRAP);
    
    
    wrap = gtk_label_get_line_wrap (GTK_LABEL (widget));
    if (WRAP != wrap)
    {
        TEST_FAIL("label line wrap = %i, should be %i", wrap, WRAP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WRAP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_line_wrap
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: Returns whether lines in the label are automatically wrapped. 
 * Params Values: GtkLabel* that wrap = FALSE
 * Expected: FALSE  
 */
static void test_purpose_48()
{
    #define WRAP FALSE
    
    GtkWidget *widget;
    gboolean wrap;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_line_wrap (GTK_LABEL (widget), WRAP);
    
    
    wrap = gtk_label_get_line_wrap (GTK_LABEL (widget));
    if (WRAP != wrap)
    {
        TEST_FAIL("label line wrap = %i, should be %i", wrap, WRAP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WRAP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_selectable
 * Params: GtkLabel *label, gboolean selectable
 * Returns: void
 * Assertion: Selectable labels allow the user to select text from the label, for copy-and-paste.
 * Params Values: newly created GtkLabel*, TRUE
 * Expected: void
 * 
 * Name: gtk_label_get_selectable
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_label_set_selectable().
 * Params Values: newly created GtkLabel*
 * Expected: TRUE  
 */
static void test_purpose_49()
{
    #define SELECTABLE TRUE
    
    GtkWidget *widget;
    gboolean selectable;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable (GTK_LABEL (widget), SELECTABLE);
    
    if (gtk_label_get_selectable(GTK_LABEL (widget)) != SELECTABLE)
    {
        TEST_FAIL("Selectable =  %s, should be %s\n", gtk_label_get_selectable(GTK_LABEL (widget)), SELECTABLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SELECTABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_selectable
 * Params: GtkLabel *label, gboolean selectable
 * Returns: void
 * Assertion: Selectable labels allow the user to select text from the label, for copy-and-paste.
 * Params Values: newly created GtkLabel*, FALSE
 * Expected: void
 * 
 * Name: gtk_label_get_selectable
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_label_set_selectable().
 * Params Values: newly created GtkLabel*
 * Expected: FALSE  
 */
static void test_purpose_50()
{
    #define SELECTABLE FALSE
    
    GtkWidget *widget;
    gboolean selectable;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable (GTK_LABEL (widget), SELECTABLE);
    
    if (gtk_label_get_selectable(GTK_LABEL (widget)) != SELECTABLE)
    {
        TEST_FAIL("Selectable =  %s, should be %s\n", gtk_label_get_selectable(GTK_LABEL (widget)), SELECTABLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SELECTABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_mnemonic_widget
 * Params: GtkLabel *label, GtkWidget* mwidget
 * Returns: void
 * Assertion: If the label has been set so that it has an mnemonic key (using i.e. gtk_label_set_markup_with_mnemonic(), gtk_label_set_text_with_mnemonic(), gtk_label_new_with_mnemonic() or the "use_underline" property) the label can be associated with a widget that is the target of the mnemonic.
 * Params Values: newly created GtkLabel*, newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_51()
{
    
    GtkWidget *widget;
    GtkWidget *new_mwidget = NULL;
    GtkWidget *mnemonic_widget = NULL;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    new_mwidget = gtk_entry_new ();
    gtk_label_set_mnemonic_widget (GTK_LABEL (widget), new_mwidget);
    
    g_object_get (GTK_OBJECT (widget), "mnemonic-widget", &mnemonic_widget, NULL);
    if (mnemonic_widget != new_mwidget)
    {
        TEST_FAIL("Mnemonic widget is differ from that was set by gtk_label_set_mnemonic_widget ()", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_mnemonic_widget
 * Params: GtkLabel *label
 * Returns: GtkWidget*
 * Assertion: Retrieves the target of the mnemonic (keyboard shortcut) of this label.
 * Params Values: newly created GtkLabel*
 * Expected: newly created GtkWidget*  
 */
static void test_purpose_52()
{
    
    GtkWidget *widget;
    GtkWidget *new_mwidget = NULL;
    GtkWidget *mnemonic_widget = NULL;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    new_mwidget = gtk_entry_new ();
    
    g_object_set (GTK_OBJECT (widget), "mnemonic-widget", new_mwidget, NULL);
    mnemonic_widget = gtk_label_get_mnemonic_widget (GTK_LABEL (widget));
    
    if (mnemonic_widget != new_mwidget)
    {
        TEST_FAIL("Mnemonic widget is differ from that was set by gtk_label_set_mnemonic_widget ()", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_File"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_File"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_File"  
 */
static void test_purpose_53()
{
    #define STR "_File"
    #define CORRECT_KEYVAL 'f'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_file"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_file"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_file"  
 */
static void test_purpose_54()
{
    #define STR "_file"
    #define CORRECT_KEYVAL 'f'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_fil_e"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_fil_e"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_fil_e"  
 */
static void test_purpose_55()
{
    #define STR "_fil_e"
    #define CORRECT_KEYVAL 'f'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "__fil_e"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "__fil_e"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "__fil_e"  
 */
static void test_purpose_56()
{
    #define STR "__fil_e"
    #define CORRECT_KEYVAL 'e'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_fil_f"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_fil_f"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_fil_f"  
 */
static void test_purpose_57()
{
    #define STR "_fil_f"
    #define CORRECT_KEYVAL 'f'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "___fil_e"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "___fil_e"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "___fil_e"  
 */
static void test_purpose_58()
{
    #define STR "___fil_e"
    #define CORRECT_KEYVAL 'f'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_f__ile"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_f__ile"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_f__ile"  
 */
static void test_purpose_59()
{
    #define STR "_f__ile"
    #define CORRECT_KEYVAL 'f'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_@ile"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_@ile"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_@ile"  
 */
static void test_purpose_60()
{
    #define STR "_@ile"
    #define CORRECT_KEYVAL '@'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_#ile"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_#ile"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_#ile"  
 */
static void test_purpose_61()
{
    #define STR "_#ile"
    #define CORRECT_KEYVAL '#'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_/ile"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_/ile"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_/ile"  
 */
static void test_purpose_62()
{
    #define STR "_/ile"
    #define CORRECT_KEYVAL '/'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_\\le"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_\\le"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_\\le"  
 */
static void test_purpose_63()
{
    #define STR "_\\le"
    #define CORRECT_KEYVAL '\\'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_\nle"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_\nle"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_\nle"  
 */
static void test_purpose_64()
{
    #define STR "_\nle"
    #define CORRECT_KEYVAL 0x100000a
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_\rle"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_\rle"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_\rle"  
 */
static void test_purpose_65()
{
    #define STR "_\rle"
    #define CORRECT_KEYVAL 0x100000d
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_ le"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_ le"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_ le"  
 */
static void test_purpose_66()
{
    #define STR "_ le"
    #define CORRECT_KEYVAL ' '
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_fi_le"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_fi_le"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_fi_le"  
 */
static void test_purpose_67()
{
    #define STR "_fi_le"
    #define CORRECT_KEYVAL 'f'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "__le"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "__le"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "__le"  
 */
static void test_purpose_68()
{
    #define STR "__le"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "l__e"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "l__e"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "l__e"  
 */
static void test_purpose_69()
{
    #define STR "l__e"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "___le"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "___le"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "___le"  
 */
static void test_purpose_70()
{
    #define STR "___le"
    #define CORRECT_KEYVAL 'l'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "____le"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "____le"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "____le"  
 */
static void test_purpose_71()
{
    #define STR "____le"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "__"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "__"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "__"  
 */
static void test_purpose_72()
{
    #define STR "__"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "_\0"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "_\0"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "_\0"  
 */
static void test_purpose_73()
{
    #define STR "_\0"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: Sets the label's text from the string str.'
 * Params Values: newly created GtkLabel*, "Fil\0_e"
 * Expected: void
 * 
 * Name: gtk_label_set_text_with_mnemonic
 * Params: GtkLabel *label, const gchar *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: newly created GtkLabel*, "Fil\0_e"
 * Expected: void
 * 
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If the label has been set so that it has an mnemonic key this function returns the keyval used for the mnemonic accelerator.
 * Params Values: newly created GtkLabel*
 * Expected: "Fil\0_e"  
 */
static void test_purpose_74()
{
    #define STR "Fil\0_e"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_mnemonic_keyval
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: If there is no mnemonic set up it returns GDK_VoidSymbol.
 * Params Values: newly created GtkLabel*
 * Expected: "File"  
 */
static void test_purpose_75()
{
    #define STR "File"
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), STR);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != GDK_VoidSymbol)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'(GDK_VoidSymbol)\n", 
                  mnemonic_keyval, GDK_VoidSymbol);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: Selects a range of characters in the label, if the label is selectable. 
 * Params Values:
 * Expected: void  
 */
static void test_purpose_76()
{
    #define START_OFFSET 0
    #define END_OFFSET 0
    #define CORRECT_START_OFFSET 0
    #define CORRECT_END_OFFSET 0
    #define TEXT " "
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget),TRUE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i\n", start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i\n", 
                  end_offset, CORRECT_END_OFFSET);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: Selects a range of characters in the label, if the label is selectable. 
 * Params Values:
 * Expected: void  
 */
static void test_purpose_77()
{
    #define START_OFFSET 0
    #define END_OFFSET 1
    #define CORRECT_START_OFFSET 0
    #define CORRECT_END_OFFSET 1
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget),TRUE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i\n", start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i\n", 
                  end_offset, CORRECT_END_OFFSET);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: Selects a range of characters in the label, if the label is selectable. 
 * Params Values:
 * Expected: void  
 */
static void test_purpose_78()
{
    #define START_OFFSET 5
    #define END_OFFSET 20 
    #define CORRECT_START_OFFSET 5
    #define CORRECT_END_OFFSET 20 
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/"
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget),TRUE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i\n", start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i\n", 
                  end_offset, CORRECT_END_OFFSET);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: Selects a range of characters in the label, if the label is selectable. 
 * Params Values:
 * Expected: void  
 */
static void test_purpose_79()
{
    #define START_OFFSET 1
    #define END_OFFSET -1
    #define CORRECT_START_OFFSET 1
    #define CORRECT_END_OFFSET 4
    #define TEXT "_a_b"
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget),TRUE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i\n", start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i\n", 
                  end_offset, CORRECT_END_OFFSET);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: Selects a range of characters in the label, if the label is selectable. 
 * Params Values:
 * Expected: void  
 */
static void test_purpose_80()
{
    #define START_OFFSET -1
    #define END_OFFSET -1
    #define CORRECT_START_OFFSET 3
    #define CORRECT_END_OFFSET 3
    #define TEXT "\n\t\""
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget),TRUE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i\n", start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i\n", 
                  end_offset, CORRECT_END_OFFSET);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If the label is not selectable, this function has no effect.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_81()
{
    #define START_OFFSET 0
    #define END_OFFSET 0
    #define TEXT " "
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), FALSE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != 0) 
    {
        TEST_FAIL("start_offset =  %i, should be 0\n", start_offset);
    }
    
    if (end_offset != 0) 
    {
        TEST_FAIL("end_offset =  %i, should be 0\n", end_offset);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If the label is not selectable, this function has no effect.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_82()
{
    #define START_OFFSET 0
    #define END_OFFSET 1
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), FALSE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != 0) 
    {
        TEST_FAIL("start_offset =  %i, should be 0\n", start_offset);
    }
    
    if (end_offset != 0) 
    {
        TEST_FAIL("end_offset =  %i, should be 0\n", end_offset);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If the label is not selectable, this function has no effect.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_83()
{
    #define START_OFFSET 5
    #define END_OFFSET 20 
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/"
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), FALSE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != 0) 
    {
        TEST_FAIL("start_offset =  %i, should be 0\n", start_offset);
    }
    
    if (end_offset != 0) 
    {
        TEST_FAIL("end_offset =  %i, should be 0\n", end_offset);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If the label is not selectable, this function has no effect.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_84()
{
    #define START_OFFSET 1
    #define END_OFFSET -1
    #define TEXT "_a_b"
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), FALSE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != 0) 
    {
        TEST_FAIL("start_offset =  %i, should be 0\n", start_offset);
    }
    
    if (end_offset != 0) 
    {
        TEST_FAIL("end_offset =  %i, should be 0\n", end_offset);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If the label is not selectable, this function has no effect.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_85()
{
    #define START_OFFSET 5
    #define END_OFFSET -1
    #define TEXT "\n\t\""
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), FALSE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != 0) 
    {
        TEST_FAIL("start_offset =  %i, should be 0\n", start_offset);
    }
    
    if (end_offset != 0) 
    {
        TEST_FAIL("end_offset =  %i, should be 0\n", end_offset);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If the label is not selectable, this function has no effect.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_86()
{
    #define START_OFFSET -1
    #define END_OFFSET 0
    #define TEXT " "
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), FALSE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != 0) 
    {
        TEST_FAIL("start_offset =  %i, should be 0\n", start_offset);
    }
    
    if (end_offset != 0) 
    {
        TEST_FAIL("end_offset =  %i, should be 0\n", end_offset);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If the label is not selectable, this function has no effect.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_87()
{
    #define START_OFFSET 0
    #define END_OFFSET -1
    #define TEXT "abcdef"
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), FALSE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != 0) 
    {
        TEST_FAIL("start_offset =  %i, should be 0\n", start_offset);
    }
    
    if (end_offset != 0) 
    {
        TEST_FAIL("end_offset =  %i, should be 0\n", end_offset);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If the label is not selectable, this function has no effect.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_88()
{
    #define START_OFFSET -1
    #define END_OFFSET -1 
    #define TEXT "!@#$%^"
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), FALSE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != 0) 
    {
        TEST_FAIL("start_offset =  %i, should be 0\n", start_offset);
    }
    
    if (end_offset != 0) 
    {
        TEST_FAIL("end_offset =  %i, should be 0\n", end_offset);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If the label is not selectable, this function has no effect.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_89()
{
    #define START_OFFSET -1
    #define END_OFFSET -1
    #define TEXT "_a_b"
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), FALSE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != 0) 
    {
        TEST_FAIL("start_offset =  %i, should be 0\n", start_offset);
    }
    
    if (end_offset != 0) 
    {
        TEST_FAIL("end_offset =  %i, should be 0\n", end_offset);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If the label is not selectable, this function has no effect.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_90()
{
    #define START_OFFSET -1
    #define END_OFFSET -1
    #define TEXT "\n\t\""
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), FALSE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != 0) 
    {
        TEST_FAIL("start_offset =  %i, should be 0\n", start_offset);
    }
    
    if (end_offset != 0) 
    {
        TEST_FAIL("end_offset =  %i, should be 0\n", end_offset);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If start_offset or end_offset are -1, then the end of the label will be substituted.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_91()
{
    #define START_OFFSET -1
    #define END_OFFSET 0
    #define CORRECT_START_OFFSET 0
    #define CORRECT_END_OFFSET 1
    #define TEXT " "
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget),TRUE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i\n", start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i\n", 
                  end_offset, CORRECT_END_OFFSET);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If start_offset or end_offset are -1, then the end of the label will be substituted.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_92()
{
    #define START_OFFSET 0
    #define END_OFFSET -1
    #define CORRECT_START_OFFSET 0
    #define CORRECT_END_OFFSET 6
    #define TEXT "abcdef"
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget),TRUE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i\n", start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i\n", 
                  end_offset, CORRECT_END_OFFSET);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If start_offset or end_offset are -1, then the end of the label will be substituted.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_93()
{
    #define START_OFFSET -1
    #define END_OFFSET -1 
    #define CORRECT_START_OFFSET 6
    #define CORRECT_END_OFFSET 6 
    #define TEXT "!@#$%^"
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget),TRUE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i\n", start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i\n", 
                  end_offset, CORRECT_END_OFFSET);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If start_offset or end_offset are -1, then the end of the label will be substituted.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_94()
{
    #define START_OFFSET -1
    #define END_OFFSET -1
    #define CORRECT_START_OFFSET 4
    #define CORRECT_END_OFFSET 4
    #define TEXT "_a_b"
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget),TRUE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i\n", start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i\n", 
                  end_offset, CORRECT_END_OFFSET);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_select_region
 * Params: GtkLabel *label, gint start_offset, gint end_offset
 * Returns: void
 * Assertion: If start_offset or end_offset are -1, then the end of the label will be substituted.
 * Params Values:
 * Expected: void  
 */
static void test_purpose_95()
{
    #define START_OFFSET -1
    #define END_OFFSET -1
    #define CORRECT_START_OFFSET 3
    #define CORRECT_END_OFFSET 3
    #define TEXT "\n\t\""
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget),TRUE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i\n", start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i\n", 
                  end_offset, CORRECT_END_OFFSET);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_selection_bounds
 * Params: GtkLabel *label, gint *start, gint *end
 * Returns: gboolean
 * Assertion: Gets the selected range of characters in the label, returning TRUE if there's a selection.'
 * Params Values: GtkLabel *label, gint *start, gint *end
 * Expected: FALSE  
 */
static void test_purpose_96()
{
    #define START_OFFSET 0
    #define END_OFFSET 0
    #define SELECTABLE TRUE
    #define CORRECT_START_OFFSET 0
    #define CORRECT_END_OFFSET 0
    #define TEXT " "
    #define CORRECT_RESULT FALSE
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), SELECTABLE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i", 
                  start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i",  
                  end_offset, CORRECT_END_OFFSET);
    }
    
    if (non_empty != CORRECT_RESULT)
    {
        TEST_FAIL ("non_empty = %d, should be %d", non_empty, CORRECT_RESULT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    #undef SELECTABLE 
    #undef CORRECT_RESULT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_selection_bounds
 * Params: GtkLabel *label, gint *start, gint *end
 * Returns: gboolean
 * Assertion: Gets the selected range of characters in the label, returning TRUE if there's a selection.'
 * Params Values: GtkLabel *label, gint *start, gint *end
 * Expected: TRUE  
 */
static void test_purpose_97()
{
    #define START_OFFSET 0
    #define END_OFFSET 1
    #define SELECTABLE TRUE
    #define CORRECT_START_OFFSET 0
    #define CORRECT_END_OFFSET 1
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define CORRECT_RESULT TRUE
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), SELECTABLE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i", 
                  start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i",  
                  end_offset, CORRECT_END_OFFSET);
    }
    
    if (non_empty != CORRECT_RESULT)
    {
        TEST_FAIL ("non_empty = %d, should be %d", non_empty, CORRECT_RESULT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    #undef SELECTABLE 
    #undef CORRECT_RESULT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_selection_bounds
 * Params: GtkLabel *label, gint *start, gint *end
 * Returns: gboolean
 * Assertion: Gets the selected range of characters in the label, returning TRUE if there's a selection.'
 * Params Values: GtkLabel *label, gint *start, gint *end
 * Expected: TRUE  
 */
static void test_purpose_98()
{
    #define START_OFFSET 5
    #define END_OFFSET 20 
    #define SELECTABLE TRUE
    #define CORRECT_START_OFFSET 5
    #define CORRECT_END_OFFSET 20 
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/"
    #define CORRECT_RESULT TRUE
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), SELECTABLE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i", 
                  start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i",  
                  end_offset, CORRECT_END_OFFSET);
    }
    
    if (non_empty != CORRECT_RESULT)
    {
        TEST_FAIL ("non_empty = %d, should be %d", non_empty, CORRECT_RESULT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    #undef SELECTABLE 
    #undef CORRECT_RESULT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_selection_bounds
 * Params: GtkLabel *label, gint *start, gint *end
 * Returns: gboolean
 * Assertion: Gets the selected range of characters in the label, returning TRUE if there's a selection.'
 * Params Values: GtkLabel *label, gint *start, gint *end
 * Expected: FALSE  
 */
static void test_purpose_99()
{
    #define START_OFFSET 5
    #define END_OFFSET 20 
    #define SELECTABLE FALSE
    #define CORRECT_START_OFFSET 0
    #define CORRECT_END_OFFSET 0 
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/"
    #define CORRECT_RESULT FALSE
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), SELECTABLE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i", 
                  start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i",  
                  end_offset, CORRECT_END_OFFSET);
    }
    
    if (non_empty != CORRECT_RESULT)
    {
        TEST_FAIL ("non_empty = %d, should be %d", non_empty, CORRECT_RESULT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    #undef SELECTABLE 
    #undef CORRECT_RESULT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_selection_bounds
 * Params: GtkLabel *label, gint *start, gint *end
 * Returns: gboolean
 * Assertion: Gets the selected range of characters in the label, returning TRUE if there's a selection.'
 * Params Values: GtkLabel *label, gint *start, gint *end
 * Expected: TRUE  
 */
static void test_purpose_100()
{
    #define START_OFFSET 1
    #define END_OFFSET -1
    #define SELECTABLE TRUE
    #define CORRECT_START_OFFSET 1
    #define CORRECT_END_OFFSET 4
    #define TEXT "_a_b"
    #define CORRECT_RESULT TRUE
    
    gint start_offset;
    gint end_offset;
    gboolean non_empty = FALSE;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new (TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_selectable(GTK_LABEL (widget), SELECTABLE);
    gtk_label_select_region (GTK_LABEL (widget), START_OFFSET, END_OFFSET);
    non_empty = gtk_label_get_selection_bounds (GTK_LABEL (widget), &start_offset, &end_offset);
    
    if (start_offset != CORRECT_START_OFFSET) 
    {
        TEST_FAIL("start_offset =  %i, should be %i", 
                  start_offset, CORRECT_START_OFFSET);
    }
    
    if (end_offset != CORRECT_END_OFFSET) 
    {
        TEST_FAIL("end_offset =  %i, should be %i",  
                  end_offset, CORRECT_END_OFFSET);
    }
    
    if (non_empty != CORRECT_RESULT)
    {
        TEST_FAIL ("non_empty = %d, should be %d", non_empty, CORRECT_RESULT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CORRECT_START_OFFSET
    #undef CORRECT_END_OFFSET
    #undef START_OFFSET
    #undef END_OFFSET
    #undef TEXT
    #undef SELECTABLE 
    #undef CORRECT_RESULT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_use_markup
 * Params: GtkLabel *label, gboolean setting
 * Returns: void
 * Assertion: Sets whether the text of the label contains markup in Pango's text markup language.'
 * Params Values: newly created GtkLabel*, TRUE
 * Expected: void
 * 
 * Name: gtk_label_get_use_markup
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: Returns whether the label's text is interpreted as marked up with the Pango text markup language.'
 * Params Values: GtkLabel* that 'use-markup' = TRUE
 * Expected: TRUE  
 */
static void test_purpose_101()
{
    #define SETTING TRUE
    
    GtkWidget *widget;
    gboolean setting;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_use_markup (GTK_LABEL (widget), SETTING);
    setting = gtk_label_get_use_markup (GTK_LABEL (widget));
    if (SETTING != setting)
    {
        TEST_FAIL("label use-markup = %i, should be %i", setting, SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_use_markup
 * Params: GtkLabel *label, gboolean setting
 * Returns: void
 * Assertion: Sets whether the text of the label contains markup in Pango's text markup language.'
 * Params Values: newly created GtkLabel*, FALSE
 * Expected: void
 * 
 * Name: gtk_label_get_use_markup
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: Returns whether the label's text is interpreted as marked up with the Pango text markup language.'
 * Params Values: GtkLabel* that 'use-markup' = FALSE
 * Expected: FALSE  
 */
static void test_purpose_102()
{
    #define SETTING FALSE
    
    GtkWidget *widget;
    gboolean setting;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_use_markup (GTK_LABEL (widget), SETTING);
    setting = gtk_label_get_use_markup (GTK_LABEL (widget));
    if (SETTING != setting)
    {
        TEST_FAIL("label use-markup = %i, should be %i", setting, SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_use_underline
 * Params: GtkLabel *label, gboolean setting
 * Returns: void
 * Assertion: If true, an underline in the text indicates the next character should be used for the mnemonic accelerator key.
 * Params Values: newly created GtkLabel*, TRUE
 * Expected: void
 * 
 * Name: gtk_label_get_use_underline
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: Returns whether an embedded underline in the label indicates a mnemonic.
 * Params Values: GtkLabel* that 'use-underline' = TRUE
 * Expected: TRUE  
 */
static void test_purpose_103()
{
    #define SETTING TRUE
    
    GtkWidget *widget;
    gboolean setting;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_use_underline (GTK_LABEL (widget), SETTING);
    setting = gtk_label_get_use_underline (GTK_LABEL (widget));
    if (SETTING != setting)
    {
        TEST_FAIL("label use-underline = %i, should be %i", setting, SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_use_underline
 * Params: GtkLabel *label, gboolean setting
 * Returns: void
 * Assertion: If true, an underline in the text indicates the next character should be used for the mnemonic accelerator key.
 * Params Values: newly created GtkLabel*, FALSE
 * Expected: void
 * 
 * Name: gtk_label_get_use_underline
 * Params: GtkLabel *label
 * Returns: gboolean
 * Assertion: Returns whether an embedded underline in the label indicates a mnemonic.
 * Params Values: GtkLabel* that 'use-underline' = FALSE
 * Expected: FALSE  
 */
static void test_purpose_104()
{
    #define SETTING FALSE
    
    GtkWidget *widget;
    gboolean setting;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_use_underline (GTK_LABEL (widget), SETTING);
    setting = gtk_label_get_use_underline (GTK_LABEL (widget));
    if (SETTING != setting)
    {
        TEST_FAIL("label use-underline = %i, should be %i", setting, SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_label
 * Params: GtkLabel *label, const char *str
 * Returns: void
 * Assertion: Sets the text of the label.
 * Params Values: newly created GtkLabel*, ""
 * Expected: void  
 */
static void test_purpose_105()
{
    #define LABEL ""
    
    GtkWidget *widget;
    gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_label (GTK_LABEL (widget), LABEL);
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_label
 * Params: GtkLabel *label, const char *str
 * Returns: void
 * Assertion: Sets the text of the label.
 * Params Values: newly created GtkLabel*, " "
 * Expected: void  
 */
static void test_purpose_106()
{
    #define LABEL " "
    
    GtkWidget *widget;
    gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_label (GTK_LABEL (widget), LABEL);
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_label
 * Params: GtkLabel *label, const char *str
 * Returns: void
 * Assertion: Sets the text of the label.
 * Params Values: newly created GtkLabel*, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void  
 */
static void test_purpose_107()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_label (GTK_LABEL (widget), LABEL);
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_label
 * Params: GtkLabel *label, const char *str
 * Returns: void
 * Assertion: Sets the text of the label.
 * Params Values: newly created GtkLabel*, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void  
 */
static void test_purpose_108()
{
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget *widget;
    gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_label (GTK_LABEL (widget), LABEL);
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_label
 * Params: GtkLabel *label, const char *str
 * Returns: void
 * Assertion: Sets the text of the label.
 * Params Values: newly created GtkLabel*, "_a_b"
 * Expected: void  
 */
static void test_purpose_109()
{
    #define LABEL "_a_b"
    
    GtkWidget *widget;
    gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_label (GTK_LABEL (widget), LABEL);
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_label
 * Params: GtkLabel *label, const char *str
 * Returns: void
 * Assertion: Sets the text of the label.
 * Params Values: newly created GtkLabel*, "\n\t\""
 * Expected: void  
 */
static void test_purpose_110()
{
    #define LABEL "\n\t\""
    
    GtkWidget *widget;
    gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_label (GTK_LABEL (widget), LABEL);
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_label
 * Params: GtkLabel *label, const char *str
 * Returns: void
 * Assertion: Sets the text of the label.
 * Params Values: newly created GtkLabel*, "_\n\t\""
 * Expected: void  
 */
static void test_purpose_111()
{
    #define LABEL "_\n\t\""
    
    GtkWidget *widget;
    gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_label (GTK_LABEL (widget), LABEL);
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_label
 * Params: GtkLabel *label, const char *str
 * Returns: void
 * Assertion: Sets the text of the label.
 * Params Values: newly created GtkLabel*, "\b"
 * Expected: void  
 */
static void test_purpose_112()
{
    #define LABEL "\b"
    
    GtkWidget *widget;
    gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_label (GTK_LABEL (widget), LABEL);
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_label
 * Params: GtkLabel *label, const char *str
 * Returns: void
 * Assertion: Sets the text of the label.
 * Params Values: newly created GtkLabel*, "_\b"
 * Expected: void  
 */
static void test_purpose_113()
{
    #define LABEL "_\b"
    
    GtkWidget *widget;
    gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_label (GTK_LABEL (widget), LABEL);
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_label
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget including any embedded underlines indicating mnemonics and Pango markup.
 * Params Values: newly created GtkLabel*
 * Expected: ""  
 */
static void test_purpose_114()
{
    #define LABEL ""
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "label", LABEL, NULL);
    label = gtk_label_get_label (GTK_LABEL (widget));
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_label
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget including any embedded underlines indicating mnemonics and Pango markup.
 * Params Values: newly created GtkLabel*
 * Expected: " "  
 */
static void test_purpose_115()
{
    #define LABEL " "
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "label", LABEL, NULL);
    label = gtk_label_get_label (GTK_LABEL (widget));
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_label
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget including any embedded underlines indicating mnemonics and Pango markup.
 * Params Values: newly created GtkLabel*
 * Expected: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"  
 */
static void test_purpose_116()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "label", LABEL, NULL);
    label = gtk_label_get_label (GTK_LABEL (widget));
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_label
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget including any embedded underlines indicating mnemonics and Pango markup.
 * Params Values: newly created GtkLabel*
 * Expected: "!@#$%^&*()_+|~=\";:'?<>`/"  
 */
static void test_purpose_117()
{
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "label", LABEL, NULL);
    label = gtk_label_get_label (GTK_LABEL (widget));
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_label
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget including any embedded underlines indicating mnemonics and Pango markup.
 * Params Values: newly created GtkLabel*
 * Expected: "_a_b"  
 */
static void test_purpose_118()
{
    #define LABEL "_a_b"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "label", LABEL, NULL);
    label = gtk_label_get_label (GTK_LABEL (widget));
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_label
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget including any embedded underlines indicating mnemonics and Pango markup.
 * Params Values: newly created GtkLabel*
 * Expected: "\n\t\""  
 */
static void test_purpose_119()
{
    #define LABEL "\n\t\""
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "label", LABEL, NULL);
    label = gtk_label_get_label (GTK_LABEL (widget));
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_label
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget including any embedded underlines indicating mnemonics and Pango markup.
 * Params Values: newly created GtkLabel*
 * Expected: "_\n\t\""  
 */
static void test_purpose_120()
{
    #define LABEL "_\n\t\""
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "label", LABEL, NULL);
    label = gtk_label_get_label (GTK_LABEL (widget));
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_label
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget including any embedded underlines indicating mnemonics and Pango markup.
 * Params Values: newly created GtkLabel*
 * Expected: "\b"  
 */
static void test_purpose_121()
{
    #define LABEL "\b"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "label", LABEL, NULL);
    label = gtk_label_get_label (GTK_LABEL (widget));
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_label
 * Params: GtkLabel *label
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Fetches the text from a label widget including any embedded underlines indicating mnemonics and Pango markup.
 * Params Values: newly created GtkLabel*
 * Expected: "_\b"  
 */
static void test_purpose_122()
{
    #define LABEL "_\b"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* label;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "label", LABEL, NULL);
    label = gtk_label_get_label (GTK_LABEL (widget));
    
    if (strcmp (label, LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, LABEL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_attributes
 * Params: GtkLabel *label, PangoAttrList *attrs
 * Returns: void
 * Assertion: Sets a PangoAttrList; the attributes in the list are applied to the label text.
 * Params Values: newly created GtkLabel*,PangoAttrList*
 * Expected: void
 * 
 * Name: gtk_label_get_attributes
 * Params: GtkLabel *label
 * Returns: PangoAttrList*
 * Assertion: Gets the attribute list that was set on the label using gtk_label_set_attributes(), if any.
 * Params Values: newly created GtkLabel*
 * Expected: PangoAttrList*  
 */
static void test_purpose_123()
{
    GtkWidget *widget;
    PangoAttrList* attr;
    PangoAttrList* real_attr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    attr = pango_attr_list_new ();
    
    gtk_label_set_attributes (GTK_LABEL (widget), attr);
    
    real_attr = gtk_label_get_attributes (GTK_LABEL (widget));
    
    if (attr != real_attr)
    {
        TEST_FAIL ("PangoAttrList is not correct",NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_layout
 * Params: GtkLabel *label
 * Returns: PangoLayout*
 * Assertion: Gets the PangoLayout used to display the label. 
 * Params Values: newly created GtkLabel*
 * Expected: PangoLayout*  
 */
static void test_purpose_124()
{
    GtkWidget *widget;
    PangoLayout* layout;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    layout = gtk_label_get_layout (GTK_LABEL (widget));
    
    if (!layout)
    {
        TEST_FAIL ("PangoLayout is not returned",NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_layout_offsets
 * Params: GtkLabel *label, gint* x,gint* y
 * Returns: void
 * Assertion: Obtains the coordinates where the label will draw the PangoLayout representing the text in the label; useful to convert mouse events into coordinates inside the PangoLayout, e.g. to take some action if some part of the label is clicked.
 * Params Values: newly created GtkLabel*
 * Expected: void  
 */
static void test_purpose_125()
{
    #define X NULL
    #define Y NULL
    
    GtkWidget *widget;
    gint xx;
    gint yy;
    gint *x;
    gint *y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    x = X ? &xx : NULL;
    y = Y ? &yy : NULL;
    
    gtk_label_get_layout_offsets (GTK_LABEL (widget),x,y);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_get_layout_offsets
 * Params: GtkLabel *label, gint* x,gint* y
 * Returns: void
 * Assertion: Obtains the coordinates where the label will draw the PangoLayout representing the text in the label; useful to convert mouse events into coordinates inside the PangoLayout, e.g. to take some action if some part of the label is clicked.
 * Params Values: newly created GtkLabel*
 * Expected: void  
 */
static void test_purpose_126()
{
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint xx;
    gint yy;
    gint *x;
    gint *y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    x = X ? &xx : NULL;
    y = Y ? &yy : NULL;
    
    gtk_label_get_layout_offsets (GTK_LABEL (widget),x,y);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_File" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_File" 
 * Expected: GtkLabel*  
 */
static void test_purpose_127()
{
    #define LABEL  "_File"
    #define CORRECT_KEYVAL 'f'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_file" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_file" 
 * Expected: GtkLabel*  
 */
static void test_purpose_128()
{
    #define LABEL  "_file"
    #define CORRECT_KEYVAL 'f'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_fil_e" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_fil_e" 
 * Expected: GtkLabel*  
 */
static void test_purpose_129()
{
    #define LABEL  "_fil_e"
    #define CORRECT_KEYVAL 'f'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "__fil_e" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "__fil_e" 
 * Expected: GtkLabel*  
 */
static void test_purpose_130()
{
    #define LABEL  "__fil_e"
    #define CORRECT_KEYVAL 'e'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_fil_f" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_fil_f" 
 * Expected: GtkLabel*  
 */
static void test_purpose_131()
{
    #define LABEL  "_fil_f"
    #define CORRECT_KEYVAL 'f'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "___fil_e" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "___fil_e" 
 * Expected: GtkLabel*  
 */
static void test_purpose_132()
{
    #define LABEL  "___fil_e"
    #define CORRECT_KEYVAL 'f'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_f__ile" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_f__ile" 
 * Expected: GtkLabel*  
 */
static void test_purpose_133()
{
    #define LABEL  "_f__ile"
    #define CORRECT_KEYVAL 'f'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_@ile" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_@ile" 
 * Expected: GtkLabel*  
 */
static void test_purpose_134()
{
    #define LABEL  "_@ile"
    #define CORRECT_KEYVAL '@'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_#ile" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_#ile" 
 * Expected: GtkLabel*  
 */
static void test_purpose_135()
{
    #define LABEL  "_#ile"
    #define CORRECT_KEYVAL '#'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_/ile" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_/ile" 
 * Expected: GtkLabel*  
 */
static void test_purpose_136()
{
    #define LABEL  "_/ile"
    #define CORRECT_KEYVAL '/'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_\\le" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_\\le" 
 * Expected: GtkLabel*  
 */
static void test_purpose_137()
{
    #define LABEL  "_\\le"
    #define CORRECT_KEYVAL '\\'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_\nle" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_\nle" 
 * Expected: GtkLabel*  
 */
static void test_purpose_138()
{
    #define LABEL  "_\nle"
    #define CORRECT_KEYVAL 0x100000a
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_\rle" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_\rle" 
 * Expected: GtkLabel*  
 */
static void test_purpose_139()
{
    #define LABEL  "_\rle"
    #define CORRECT_KEYVAL 0x100000d
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_ le" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_ le" 
 * Expected: GtkLabel*  
 */
static void test_purpose_140()
{
    #define LABEL  "_ le"
    #define CORRECT_KEYVAL ' '
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_fi_le" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_fi_le" 
 * Expected: GtkLabel*  
 */
static void test_purpose_141()
{
    #define LABEL  "_fi_le"
    #define CORRECT_KEYVAL 'f'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "__le" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "__le" 
 * Expected: GtkLabel*  
 */
static void test_purpose_142()
{
    #define LABEL  "__le"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "l__e" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "l__e" 
 * Expected: GtkLabel*  
 */
static void test_purpose_143()
{
    #define LABEL  "l__e"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "___le" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "___le" 
 * Expected: GtkLabel*  
 */
static void test_purpose_144()
{
    #define LABEL  "___le"
    #define CORRECT_KEYVAL 'l'
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "____le" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "____le" 
 * Expected: GtkLabel*  
 */
static void test_purpose_145()
{
    #define LABEL  "____le"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "__" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "__" 
 * Expected: GtkLabel*  
 */
static void test_purpose_146()
{
    #define LABEL  "__"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "_\0" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_\0" 
 * Expected: GtkLabel*  
 */
static void test_purpose_147()
{
    #define LABEL  "_\0"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If characters in str are preceded by an underscore, they are underlined.
 * Params Values: "Fil\0_e" 
 * Expected: GtkLabel*
 * 
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "Fil\0_e" 
 * Expected: GtkLabel*  
 */
static void test_purpose_148()
{
    #define LABEL  "Fil\0_e"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If gtk_label_set_mnemonic_widget() is not called, then the first activatable ancestor of the GtkLabel will be chosen as the mnemonic widget. 
 * Params Values: <%0%> 
 * Expected: GtkLabel*  
 */
static void test_purpose_149()
{
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    GtkWidget *mnemonic_widget = NULL;
    GtkWidget* mwidget;
    GtkWidget *button;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    button = gtk_button_new ();
    widget = gtk_label_new_with_mnemonic ("Label");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_object_set (GTK_OBJECT (widget), "mnemonic_widget", button, NULL);
    
    mwidget = gtk_label_get_mnemonic_widget (GTK_LABEL (widget));
    if (mwidget != button)
    {
        TEST_FAIL("Mnemonic widget is differ from that was set", NULL);
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    gtk_widget_destroy (button);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores). 
 * Params Values: "__" 
 * Expected: GtkLabel*  
 */
static void test_purpose_150()
{
    #define LABEL  "__"
    #define CORRECT_LABEL "_"
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    
    real_label = gtk_label_get_text (GTK_LABEL (widget));
    if (strcmp (real_label, CORRECT_LABEL)) 
    {
        TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores). 
 * Params Values: " __" 
 * Expected: GtkLabel*  
 */
static void test_purpose_151()
{
    #define LABEL  " __"
    #define CORRECT_LABEL " _"
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    
    real_label = gtk_label_get_text (GTK_LABEL (widget));
    if (strcmp (real_label, CORRECT_LABEL)) 
    {
        TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores). 
 * Params Values: "  __" 
 * Expected: GtkLabel*  
 */
static void test_purpose_152()
{
    #define LABEL  "  __"
    #define CORRECT_LABEL "  _"
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    
    real_label = gtk_label_get_text (GTK_LABEL (widget));
    if (strcmp (real_label, CORRECT_LABEL)) 
    {
        TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores). 
 * Params Values: "__Label String" 
 * Expected: GtkLabel*  
 */
static void test_purpose_153()
{
    #define LABEL  "__Label String"
    #define CORRECT_LABEL "_Label String"
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    
    real_label = gtk_label_get_text (GTK_LABEL (widget));
    if (strcmp (real_label, CORRECT_LABEL)) 
    {
        TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores). 
 * Params Values: "__abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890" 
 * Expected: GtkLabel*  
 */
static void test_purpose_154()
{
    #define LABEL  "__abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define CORRECT_LABEL "_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    
    real_label = gtk_label_get_text (GTK_LABEL (widget));
    if (strcmp (real_label, CORRECT_LABEL)) 
    {
        TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores). 
 * Params Values: "__!@#$%^&*()_+|~=\";:'?<>`/" 
 * Expected: GtkLabel*  
 */
static void test_purpose_155()
{
    #define LABEL  "__!@#$%^&*()_+|~=\";:'?<>`/"
    #define CORRECT_LABEL "_!@#$%^&*()+|~=\";:'?<>`/"
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    
    real_label = gtk_label_get_text (GTK_LABEL (widget));
    if (strcmp (real_label, CORRECT_LABEL)) 
    {
        TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores). 
 * Params Values: "__a_b" 
 * Expected: GtkLabel*  
 */
static void test_purpose_156()
{
    #define LABEL  "__a_b"
    #define CORRECT_LABEL "_ab"
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    
    real_label = gtk_label_get_text (GTK_LABEL (widget));
    if (strcmp (real_label, CORRECT_LABEL)) 
    {
        TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores). 
 * Params Values: "\n\t\"" 
 * Expected: GtkLabel*  
 */
static void test_purpose_157()
{
    #define LABEL  "\n\t\""
    #define CORRECT_LABEL "\n\t\""
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    
    real_label = gtk_label_get_text (GTK_LABEL (widget));
    if (strcmp (real_label, CORRECT_LABEL)) 
    {
        TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores). 
 * Params Values: "__\n\t\"" 
 * Expected: GtkLabel*  
 */
static void test_purpose_158()
{
    #define LABEL  "__\n\t\""
    #define CORRECT_LABEL "_\n\t\""
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    
    real_label = gtk_label_get_text (GTK_LABEL (widget));
    if (strcmp (real_label, CORRECT_LABEL)) 
    {
        TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores). 
 * Params Values: "__\b" 
 * Expected: GtkLabel*  
 */
static void test_purpose_159()
{
    #define LABEL  "__\b"
    #define CORRECT_LABEL "_\b"
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    
    real_label = gtk_label_get_text (GTK_LABEL (widget));
    if (strcmp (real_label, CORRECT_LABEL)) 
    {
        TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_new_with_mnemonic
 * Params: const char *str
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores). 
 * Params Values: "_a" 
 * Expected: GtkLabel*  
 */
static void test_purpose_160()
{
    #define LABEL  "_a"
    #define CORRECT_LABEL "a"
    
    gchararray label;
    gboolean use_underline;
    guint mnemonic_keyval;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &label, NULL);
    if (LABEL)
    {
        if (strcmp (LABEL, label))
        {
            TEST_FAIL ("label is %s, should be %s", label, LABEL);
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "use-underline", &use_underline, NULL);
    if (!LABEL || !strlen (LABEL))
    {
        if (use_underline != FALSE)
        {
            TEST_FAIL ("use_underline = TRUE, should be FALSE", NULL);
        }
    } else {
        if (use_underline != TRUE)
        {
            TEST_FAIL ("use_underline = FALSE, should be TRUE", NULL);
        }
    }
    
    
    real_label = gtk_label_get_text (GTK_LABEL (widget));
    if (strcmp (real_label, CORRECT_LABEL)) 
    {
        TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_attributes
 * Params: GtkLabel *label, PangoAttrList *attrs
 * Returns: void
 * Assertion: The attributes set with this function will be ignored if the "use_underline" property or the "use_markup" property is TRUE.
 * Params Values: newly created GtkLabel*,PangoAttrList*
 * Expected: void  
 */
static void test_purpose_161()
{
    GtkWidget *widget;
    PangoAttrList *attr;
    PangoAttrList *attr_d;
    PangoAttrList *real_attr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "use-markup", TRUE, NULL);
    g_object_set(GTK_OBJECT(widget), "use-underline", TRUE, NULL);
    
    real_attr = gtk_label_get_attributes (GTK_LABEL (widget));
    
    attr = pango_attr_list_new ();
    
    gtk_label_set_attributes (GTK_LABEL (widget), attr);
    
    attr_d = gtk_label_get_attributes (GTK_LABEL (widget));
    
    if (attr != attr_d)
    {
        TEST_FAIL ("PangoAttrList is not correct",NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: It overwrites any text that was there before. 
 * Params Values: newly created GtkLabel*, ""
 * Expected: void  
 */
static void test_purpose_162()
{
    #define TEXT ""
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("TEXT");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (!strcmp(gtk_label_get_text(GTK_LABEL (widget)), "TEXT"))
    {
        TEST_FAIL("Text is not overwrited",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: It overwrites any text that was there before. 
 * Params Values: newly created GtkLabel*, " "
 * Expected: void  
 */
static void test_purpose_163()
{
    #define TEXT " "
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("TEXT");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (!strcmp(gtk_label_get_text(GTK_LABEL (widget)), "TEXT"))
    {
        TEST_FAIL("Text is not overwrited",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: It overwrites any text that was there before. 
 * Params Values: newly created GtkLabel*, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void  
 */
static void test_purpose_164()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("TEXT");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (!strcmp(gtk_label_get_text(GTK_LABEL (widget)), "TEXT"))
    {
        TEST_FAIL("Text is not overwrited",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: It overwrites any text that was there before. 
 * Params Values: newly created GtkLabel*, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void  
 */
static void test_purpose_165()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("TEXT");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (!strcmp(gtk_label_get_text(GTK_LABEL (widget)), "TEXT"))
    {
        TEST_FAIL("Text is not overwrited",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: It overwrites any text that was there before. 
 * Params Values: newly created GtkLabel*, "_a_b"
 * Expected: void  
 */
static void test_purpose_166()
{
    #define TEXT "_a_b"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("TEXT");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (!strcmp(gtk_label_get_text(GTK_LABEL (widget)), "TEXT"))
    {
        TEST_FAIL("Text is not overwrited",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: It overwrites any text that was there before. 
 * Params Values: newly created GtkLabel*, "\n\t\""
 * Expected: void  
 */
static void test_purpose_167()
{
    #define TEXT "\n\t\""
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("TEXT");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (!strcmp(gtk_label_get_text(GTK_LABEL (widget)), "TEXT"))
    {
        TEST_FAIL("Text is not overwrited",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: It overwrites any text that was there before. 
 * Params Values: newly created GtkLabel*, "_\n\t\""
 * Expected: void  
 */
static void test_purpose_168()
{
    #define TEXT "_\n\t\""
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("TEXT");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (!strcmp(gtk_label_get_text(GTK_LABEL (widget)), "TEXT"))
    {
        TEST_FAIL("Text is not overwrited",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: It overwrites any text that was there before. 
 * Params Values: newly created GtkLabel*, "\b"
 * Expected: void  
 */
static void test_purpose_169()
{
    #define TEXT "\b"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("TEXT");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (!strcmp(gtk_label_get_text(GTK_LABEL (widget)), "TEXT"))
    {
        TEST_FAIL("Text is not overwrited",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: It overwrites any text that was there before. 
 * Params Values: newly created GtkLabel*, "_\b"
 * Expected: void  
 */
static void test_purpose_170()
{
    #define TEXT "_\b"
    
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("TEXT");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), TEXT);
    
    if (!gtk_label_get_text(GTK_LABEL (widget)))
    {
        TEST_FAIL("Text =  %s, should be %s\n", gtk_label_get_text(GTK_LABEL (widget)), TEXT);
    } else 
    if (!strcmp(gtk_label_get_text(GTK_LABEL (widget)), "TEXT"))
    {
        TEST_FAIL("Text is not overwrited",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_text
 * Params: GtkLabel *label, const char *text
 * Returns: void
 * Assertion: This will also clear any previously set mnemonic accelerators.
 * Params Values: newly created GtkLabel*, <%0%>
 * Expected: void  
 */
static void test_purpose_171()
{
    
    GtkWidget *widget;
    GtkWidget *window;
    guint real_mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new_with_mnemonic ("_Text");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_label_set_text (GTK_LABEL (widget), "label");
    
    real_mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    
    if (real_mnemonic_keyval != GDK_VoidSymbol)
    {
        TEST_FAIL ("mnemonic accelerator is not cleared",NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup 
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: Parses str which is marked up with the Pango text markup language, setting the label's text and attribute list based on the parse results.
 * Params Values: GtkLabel*,"<span foreground=\"blue\" size=\"100\">Blue text</span> is <i>cool</i>!" 
 * Expected: void  
 */
static void test_purpose_172()
{
    #define MARKUP "<span foreground=\"blue\" size=\"100\">Blue text</span> is <i>cool</i>!"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    // dupe it, since it's a borrowed ref.
    text = g_strdup(gtk_label_get_text (GTK_LABEL (widget)));
    
    gtk_label_set_markup (GTK_LABEL (widget),MARKUP);
    
    if (!strcmp (text,gtk_label_get_text (GTK_LABEL (widget))))
    {
        free((void *)text);
        TEST_FAIL ("Label should be modified",NULL);
    }
    free((void *)text);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup 
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: Parses str which is marked up with the Pango text markup language, setting the label's text and attribute list based on the parse results.
 * Params Values: GtkLabel*,"AAAAAA\n" 
 * Expected: void  
 */
static void test_purpose_173()
{
    #define MARKUP "AAAAAA\n"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    // dupe it, since it's a borrowed ref.
    text = g_strdup(gtk_label_get_text (GTK_LABEL (widget)));
    
    gtk_label_set_markup (GTK_LABEL (widget),MARKUP);
    
    if (!strcmp (text,gtk_label_get_text (GTK_LABEL (widget))))
    {
        free((void *)text);
        TEST_FAIL ("Label should be modified",NULL);
    }
    free((void *)text);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup 
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: Parses str which is marked up with the Pango text markup language, setting the label's text and attribute list based on the parse results.
 * Params Values: GtkLabel*,"AAAAAAAAA\n BBBBBBBB\n" 
 * Expected: void  
 */
static void test_purpose_174()
{
    #define MARKUP "AAAAAAAAA\n BBBBBBBB\n"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    // dupe it, since it's a borrowed ref.
    text = g_strdup(gtk_label_get_text (GTK_LABEL (widget)));
    
    gtk_label_set_markup (GTK_LABEL (widget),MARKUP);
    
    if (!strcmp (text,gtk_label_get_text (GTK_LABEL (widget))))
    {
        free((void *)text);
        TEST_FAIL ("Label should be modified",NULL);
    }
    free((void *)text);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup 
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: Parses str which is marked up with the Pango text markup language, setting the label's text and attribute list based on the parse results.
 * Params Values: GtkLabel*,"<span> </span>" 
 * Expected: void  
 */
static void test_purpose_175()
{
    #define MARKUP "<span> </span>"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    // dupe it, since it's a borrowed ref.
    text = g_strdup(gtk_label_get_text (GTK_LABEL (widget)));
    
    gtk_label_set_markup (GTK_LABEL (widget),MARKUP);
    
    if (!strcmp (text,gtk_label_get_text (GTK_LABEL (widget))))
    {
        free((void *)text);
        TEST_FAIL ("Label should be modified",NULL);
    }
    free((void *)text);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup 
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: Parses str which is marked up with the Pango text markup language, setting the label's text and attribute list based on the parse results.
 * Params Values: GtkLabel*,"<span size=\"x-large\">BIG SIZE</span> <b>SIZE</b>" 
 * Expected: void  
 */
static void test_purpose_176()
{
    #define MARKUP "<span size=\"x-large\">BIG SIZE</span> <b>SIZE</b>"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    // dupe it, since it's a borrowed ref.
    text = g_strdup(gtk_label_get_text (GTK_LABEL (widget)));
    
    gtk_label_set_markup (GTK_LABEL (widget),MARKUP);
    
    if (!strcmp (text,gtk_label_get_text (GTK_LABEL (widget))))
    {
        free((void *)text);
        TEST_FAIL ("Label should be modified",NULL);
    }
    free((void *)text);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: Parses str which is marked up with the Pango text markup language, setting the label's text and attribute list based on the parse results.
 * Params Values: GtkLabel*,"<span foreground=\"blue\" size=\"100\">Blue text</span> is <i>cool</i>!" 
 * Expected: void  
 */
static void test_purpose_177()
{
    #define MARKUP "<span foreground=\"blue\" size=\"100\">Blue text</span> is <i>cool</i>!"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    // dupe it, since it's a borrowed ref.
    text = g_strdup(gtk_label_get_text (GTK_LABEL (widget)));
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    if (!strcmp (text,gtk_label_get_text (GTK_LABEL (widget))))
    {
        free((void *)text);
        TEST_FAIL ("Label should be modified",NULL);
    }
    free((void *)text);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: Parses str which is marked up with the Pango text markup language, setting the label's text and attribute list based on the parse results.
 * Params Values: GtkLabel*,"AAAAAA\n" 
 * Expected: void  
 */
static void test_purpose_178()
{
    #define MARKUP "AAAAAA\n"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    // dupe it, since it's a borrowed ref.
    text = g_strdup(gtk_label_get_text (GTK_LABEL (widget)));
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    if (!strcmp (text,gtk_label_get_text (GTK_LABEL (widget))))
    {
        free((void *)text);
        TEST_FAIL ("Label should be modified",NULL);
    }
    free((void *)text);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: Parses str which is marked up with the Pango text markup language, setting the label's text and attribute list based on the parse results.
 * Params Values: GtkLabel*,"_AAAAAA\n" 
 * Expected: void  
 */
static void test_purpose_179()
{
    #define MARKUP "_AAAAAA\n"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    // dupe it, since it's a borrowed ref.
    text = g_strdup(gtk_label_get_text (GTK_LABEL (widget)));
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    if (!strcmp (text,gtk_label_get_text (GTK_LABEL (widget))))
    {
        free((void *)text);
        TEST_FAIL ("Label should be modified",NULL);
    }
    free((void *)text);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: Parses str which is marked up with the Pango text markup language, setting the label's text and attribute list based on the parse results.
 * Params Values: GtkLabel*,"AAAAAAAAA\n BBBBBBBB\n CCCCCCCC \n\n DDDDDDDD" 
 * Expected: void  
 */
static void test_purpose_180()
{
    #define MARKUP "AAAAAAAAA\n BBBBBBBB\n CCCCCCCC \n\n DDDDDDDD"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    // dupe it, since it's a borrowed ref.
    text = g_strdup(gtk_label_get_text (GTK_LABEL (widget)));
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    if (!strcmp (text,gtk_label_get_text (GTK_LABEL (widget))))
    {
        free((void *)text);
        TEST_FAIL ("Label should be modified",NULL);
    }
    free((void *)text);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: Parses str which is marked up with the Pango text markup language, setting the label's text and attribute list based on the parse results.
 * Params Values: GtkLabel*,"<span> </span>" 
 * Expected: void  
 */
static void test_purpose_181()
{
    #define MARKUP "<span> </span>"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    // dupe it, since it's a borrowed ref.
    text = g_strdup(gtk_label_get_text (GTK_LABEL (widget)));
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    if (!strcmp (text,gtk_label_get_text (GTK_LABEL (widget))))
    {
        free((void *)text);
        TEST_FAIL ("Label should be modified",NULL);
    }
    free((void *)text);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: Parses str which is marked up with the Pango text markup language, setting the label's text and attribute list based on the parse results.
 * Params Values: GtkLabel*,"<span size=\"x-large\">BIG SIZE</span> <b>SIZE</b>" 
 * Expected: void  
 */
static void test_purpose_182()
{
    #define MARKUP "<span size=\"x-large\">BIG SIZE</span> <b>SIZE</b>"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    // dupe it, since it's a borrowed ref.
    text = g_strdup(gtk_label_get_text (GTK_LABEL (widget)));
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    if (!strcmp (text,gtk_label_get_text (GTK_LABEL (widget))))
    {
        free((void *)text);
        TEST_FAIL ("Label should be modified",NULL);
    }
    free((void *)text);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: Parses str which is marked up with the Pango text markup language, setting the label's text and attribute list based on the parse results.
 * Params Values: GtkLabel*,"<span size=\"xx-large\">BIG SIZE</span> <b>SIZE</b>" 
 * Expected: void  
 */
static void test_purpose_183()
{
    #define MARKUP "<span size=\"xx-large\">BIG SIZE</span> <b>SIZE</b>"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    // dupe it, since it's a borrowed ref.
    text = g_strdup(gtk_label_get_text (GTK_LABEL (widget)));
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    if (!strcmp (text,gtk_label_get_text (GTK_LABEL (widget))))
    {
        free((void *)text);
        TEST_FAIL ("Label should be modified",NULL);
    }
    free((void *)text);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: GtkLabel*,"_AAAAAA\n" 
 * Expected: void  
 */
static void test_purpose_184()
{
    #define MARKUP "_AAAAAA\n"
    #define CORRECT_KEYVAL 'a'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: GtkLabel*,"AAAAAAAAA\n BBBBBBBB\n _CCCCCCCC \n\n DDDDDDDD" 
 * Expected: void  
 */
static void test_purpose_185()
{
    #define MARKUP "AAAAAAAAA\n BBBBBBBB\n _CCCCCCCC \n\n DDDDDDDD"
    #define CORRECT_KEYVAL 'c'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: GtkLabel*,"_File" 
 * Expected: void  
 */
static void test_purpose_186()
{
    #define MARKUP "_File"
    #define CORRECT_KEYVAL 'f'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: GtkLabel*,"_file" 
 * Expected: void  
 */
static void test_purpose_187()
{
    #define MARKUP "_file"
    #define CORRECT_KEYVAL 'f'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: GtkLabel*,"_fil_e" 
 * Expected: void  
 */
static void test_purpose_188()
{
    #define MARKUP "_fil_e"
    #define CORRECT_KEYVAL 'f'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: GtkLabel*,"__fil_e" 
 * Expected: void  
 */
static void test_purpose_189()
{
    #define MARKUP "__fil_e"
    #define CORRECT_KEYVAL 'e'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_label_set_markup_with_mnemonic
 * Params: GtkLabel *label,const char *str
 * Returns: void
 * Assertion: If characters in str are preceded by an underscore, they are underlined indicating that they represent a keyboard accelerator called a mnemonic.
 * Params Values: GtkLabel*,"_fil_f" 
 * Expected: void  
 */
static void test_purpose_190()
{
    #define MARKUP "_fil_f"
    #define CORRECT_KEYVAL 'f'
    
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("LABEL");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_label_set_markup_with_mnemonic (GTK_LABEL (widget),MARKUP);
    
    mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (widget));
    if (mnemonic_keyval != CORRECT_KEYVAL)
    {
        TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                  mnemonic_keyval, CORRECT_KEYVAL);
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MARKUP 
    #undef CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkLabel ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {test_purpose_116, 1},
    {test_purpose_117, 1},
    {test_purpose_118, 1},
    {test_purpose_119, 1},
    {test_purpose_120, 1},
    {test_purpose_121, 1},
    {test_purpose_122, 1},
    {test_purpose_123, 1},
    {test_purpose_124, 1},
    {test_purpose_125, 1},
    {test_purpose_126, 1},
    {test_purpose_127, 1},
    {test_purpose_128, 1},
    {test_purpose_129, 1},
    {test_purpose_130, 1},
    {test_purpose_131, 1},
    {test_purpose_132, 1},
    {test_purpose_133, 1},
    {test_purpose_134, 1},
    {test_purpose_135, 1},
    {test_purpose_136, 1},
    {test_purpose_137, 1},
    {test_purpose_138, 1},
    {test_purpose_139, 1},
    {test_purpose_140, 1},
    {test_purpose_141, 1},
    {test_purpose_142, 1},
    {test_purpose_143, 1},
    {test_purpose_144, 1},
    {test_purpose_145, 1},
    {test_purpose_146, 1},
    {test_purpose_147, 1},
    {test_purpose_148, 1},
    {test_purpose_149, 1},
    {test_purpose_150, 1},
    {test_purpose_151, 1},
    {test_purpose_152, 1},
    {test_purpose_153, 1},
    {test_purpose_154, 1},
    {test_purpose_155, 1},
    {test_purpose_156, 1},
    {test_purpose_157, 1},
    {test_purpose_158, 1},
    {test_purpose_159, 1},
    {test_purpose_160, 1},
    {test_purpose_161, 1},
    {test_purpose_162, 1},
    {test_purpose_163, 1},
    {test_purpose_164, 1},
    {test_purpose_165, 1},
    {test_purpose_166, 1},
    {test_purpose_167, 1},
    {test_purpose_168, 1},
    {test_purpose_169, 1},
    {test_purpose_170, 1},
    {test_purpose_171, 1},
    {test_purpose_172, 1},
    {test_purpose_173, 1},
    {test_purpose_174, 1},
    {test_purpose_175, 1},
    {test_purpose_176, 1},
    {test_purpose_177, 1},
    {test_purpose_178, 1},
    {test_purpose_179, 1},
    {test_purpose_180, 1},
    {test_purpose_181, 1},
    {test_purpose_182, 1},
    {test_purpose_183, 1},
    {test_purpose_184, 1},
    {test_purpose_185, 1},
    {test_purpose_186, 1},
    {test_purpose_187, 1},
    {test_purpose_188, 1},
    {test_purpose_189, 1},
    {test_purpose_190, 1},
    {NULL,0}
};
