/*
 * GtkTreeViewColumn methods tests
 * Testing GtkTreeViewColumn methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
struct ListSort
{
  gint number1;
  gint number2;
};

struct ListSort data[] =
{
  { 3, 4 },
  { 2, 6 },
  { 0, 49 },
  { 856856, 965 },
  { 1, 34663 },
};

struct ListSort child_data[] =
{
  { 10, 149 },
  { 12, 13 },
  { 1856856, 1965 },
  { 11, 15 },
  { 14, 14 },
};

const gint NUM_TREE_ELEMS = 5;

gint global_counter = 0;

void 
global_tree_cell_data_func (GtkTreeViewColumn *tree_column,
                                 GtkCellRenderer *cell,
                                 GtkTreeModel *tree_model,
                                 GtkTreeIter *iter,
                                 gpointer data)
{
    return;
}

void 
global_clicked_handler (GtkTreeViewColumn *treeviewcolumn, 
                        gpointer user_data)
{
    global_counter++;
}

/*
 * Name:  gtk_tree_view_column_new
 * Params: void
 * Returns: GtkTreeViewColumn*
 * Assertion: Creates a new GtkTreeViewColumn.
 * Params Values: void
 * Expected: a newly created GtkTreeViewColumn*  
 */
static void test_purpose_1()
{
    GtkWidget* view;
    GtkTreeViewColumn* column;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_visible
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gboolean
 * Assertion: Sets the visibility of tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: TRUE
 * 
 * Name:  gtk_tree_view_column_get_visible
 * Params: GtkTreeViewColumn *tree_column, gboolean visible
 * Returns: void
 * Assertion: Returns TRUE if tree_column is visible.
 * Params Values: a newly created GtkTextViewColumn, TRUE
 * Expected: void  
 */
static void test_purpose_2()
{
    #define VISIBLE TRUE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_visible (column, VISIBLE);
    
    visible = gtk_tree_view_column_get_visible (column);
    if (visible != VISIBLE)
    {
        TEST_FAIL ("visible is %d, should be %d", visible, VISIBLE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_visible
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gboolean
 * Assertion: Sets the visibility of tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: FALSE
 * 
 * Name:  gtk_tree_view_column_get_visible
 * Params: GtkTreeViewColumn *tree_column, gboolean visible
 * Returns: void
 * Assertion: Returns TRUE if tree_column is visible.
 * Params Values: a newly created GtkTextViewColumn, FALSE
 * Expected: void  
 */
static void test_purpose_3()
{
    #define VISIBLE FALSE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_visible (column, VISIBLE);
    
    visible = gtk_tree_view_column_get_visible (column);
    if (visible != VISIBLE)
    {
        TEST_FAIL ("visible is %d, should be %d", visible, VISIBLE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_sizing
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GtkTreeViewColumnSizing
 * Assertion: Sets the growth behavior of tree_column to type.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: GTK_TREE_VIEW_COLUMN_GROW_ONLY
 * 
 * Name:  gtk_tree_view_column_get_sizing
 * Params: GtkTreeViewColumn *tree_column,  GtkTreeViewColumnSizing type 
 * Returns: void
 * Assertion: Returns the current type of tree_column.
 * Params Values: a newly created GtkTextViewColumn, GTK_TREE_VIEW_COLUMN_GROW_ONLY
 * Expected: void  
 */
static void test_purpose_4()
{
    #define SIZING GTK_TREE_VIEW_COLUMN_GROW_ONLY
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkTreeViewColumnSizing sizing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sizing (column, SIZING);
    
    sizing = gtk_tree_view_column_get_sizing (column);
    if (sizing != SIZING)
    {
        TEST_FAIL ("sizing is %d, should be %d", sizing, SIZING);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SIZING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_sizing
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GtkTreeViewColumnSizing
 * Assertion: Sets the growth behavior of tree_column to type.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: GTK_TREE_VIEW_COLUMN_AUTOSIZE
 * 
 * Name:  gtk_tree_view_column_get_sizing
 * Params: GtkTreeViewColumn *tree_column,  GtkTreeViewColumnSizing type 
 * Returns: void
 * Assertion: Returns the current type of tree_column.
 * Params Values: a newly created GtkTextViewColumn, GTK_TREE_VIEW_COLUMN_AUTOSIZE
 * Expected: void  
 */
static void test_purpose_5()
{
    #define SIZING GTK_TREE_VIEW_COLUMN_AUTOSIZE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkTreeViewColumnSizing sizing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sizing (column, SIZING);
    
    sizing = gtk_tree_view_column_get_sizing (column);
    if (sizing != SIZING)
    {
        TEST_FAIL ("sizing is %d, should be %d", sizing, SIZING);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SIZING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_sizing
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GtkTreeViewColumnSizing
 * Assertion: Sets the growth behavior of tree_column to type.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: GTK_TREE_VIEW_COLUMN_FIXED
 * 
 * Name:  gtk_tree_view_column_get_sizing
 * Params: GtkTreeViewColumn *tree_column,  GtkTreeViewColumnSizing type 
 * Returns: void
 * Assertion: Returns the current type of tree_column.
 * Params Values: a newly created GtkTextViewColumn, GTK_TREE_VIEW_COLUMN_FIXED
 * Expected: void  
 */
static void test_purpose_6()
{
    #define SIZING GTK_TREE_VIEW_COLUMN_FIXED
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkTreeViewColumnSizing sizing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sizing (column, SIZING);
    
    sizing = gtk_tree_view_column_get_sizing (column);
    if (sizing != SIZING)
    {
        TEST_FAIL ("sizing is %d, should be %d", sizing, SIZING);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SIZING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the current size of tree_column in pixels.
 * Params Values: a newly created GtkTextViewColumn with sizing GTK_TREE_VIEW_COLUMN_GROW_ONLY
 * Expected: <%1%>  
 */
static void test_purpose_7()
{
    #define SIZING GTK_TREE_VIEW_COLUMN_GROW_ONLY
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sizing (column, SIZING);
    gtk_tree_view_column_set_min_width (column, 0);
    gtk_tree_view_column_set_max_width (column, 20000);
    
    if (SIZING != GTK_TREE_VIEW_COLUMN_AUTOSIZE)
    {
        width = gtk_tree_view_column_get_width (column);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SIZING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the current size of tree_column in pixels.
 * Params Values: a newly created GtkTextViewColumn with sizing GTK_TREE_VIEW_COLUMN_AUTOSIZE
 * Expected: <%1%>  
 */
static void test_purpose_8()
{
    #define SIZING GTK_TREE_VIEW_COLUMN_AUTOSIZE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sizing (column, SIZING);
    gtk_tree_view_column_set_min_width (column, 0);
    gtk_tree_view_column_set_max_width (column, 20000);
    
    if (SIZING != GTK_TREE_VIEW_COLUMN_AUTOSIZE)
    {
        width = gtk_tree_view_column_get_width (column);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SIZING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the current size of tree_column in pixels.
 * Params Values: a newly created GtkTextViewColumn with sizing GTK_TREE_VIEW_COLUMN_FIXED
 * Expected: <%1%>  
 */
static void test_purpose_9()
{
    #define SIZING GTK_TREE_VIEW_COLUMN_FIXED
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sizing (column, SIZING);
    gtk_tree_view_column_set_min_width (column, 0);
    gtk_tree_view_column_set_max_width (column, 20000);
    
    if (SIZING != GTK_TREE_VIEW_COLUMN_AUTOSIZE)
    {
        width = gtk_tree_view_column_get_width (column);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SIZING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_min_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Sets the minimum width of the tree_column. 
 * Params Values: a newly created GtkTextViewColumn
 * Expected: -1
 * 
 * Name:  gtk_tree_view_column_get_min_width
 * Params: GtkTreeViewColumn *tree_column,  gint min_width
 * Returns: void
 * Assertion: Returns the minimum width in pixels of the tree_column, or -1 if no minimum width is set.
 * Params Values: a newly created GtkTextViewColumn, -1
 * Expected: void  
 */
static void test_purpose_10()
{
    #define MIN_WIDTH -1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint min_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    min_width = gtk_tree_view_column_get_min_width (column);
    if (min_width != MIN_WIDTH)
    {
        TEST_FAIL ("min_width is %f, should be %f", min_width, MIN_WIDTH);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef MIN_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_min_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Sets the minimum width of the tree_column. 
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 0
 * 
 * Name:  gtk_tree_view_column_get_min_width
 * Params: GtkTreeViewColumn *tree_column,  gint min_width
 * Returns: void
 * Assertion: Returns the minimum width in pixels of the tree_column, or -1 if no minimum width is set.
 * Params Values: a newly created GtkTextViewColumn, 0
 * Expected: void  
 */
static void test_purpose_11()
{
    #define MIN_WIDTH 0
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint min_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    min_width = gtk_tree_view_column_get_min_width (column);
    if (min_width != MIN_WIDTH)
    {
        TEST_FAIL ("min_width is %f, should be %f", min_width, MIN_WIDTH);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef MIN_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_min_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Sets the minimum width of the tree_column. 
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 1
 * 
 * Name:  gtk_tree_view_column_get_min_width
 * Params: GtkTreeViewColumn *tree_column,  gint min_width
 * Returns: void
 * Assertion: Returns the minimum width in pixels of the tree_column, or -1 if no minimum width is set.
 * Params Values: a newly created GtkTextViewColumn, 1
 * Expected: void  
 */
static void test_purpose_12()
{
    #define MIN_WIDTH 1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint min_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    min_width = gtk_tree_view_column_get_min_width (column);
    if (min_width != MIN_WIDTH)
    {
        TEST_FAIL ("min_width is %f, should be %f", min_width, MIN_WIDTH);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef MIN_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_min_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Sets the minimum width of the tree_column. 
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 10000
 * 
 * Name:  gtk_tree_view_column_get_min_width
 * Params: GtkTreeViewColumn *tree_column,  gint min_width
 * Returns: void
 * Assertion: Returns the minimum width in pixels of the tree_column, or -1 if no minimum width is set.
 * Params Values: a newly created GtkTextViewColumn, 10000
 * Expected: void  
 */
static void test_purpose_13()
{
    #define MIN_WIDTH 10000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint min_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    min_width = gtk_tree_view_column_get_min_width (column);
    if (min_width != MIN_WIDTH)
    {
        TEST_FAIL ("min_width is %f, should be %f", min_width, MIN_WIDTH);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef MIN_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_max_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the maximum width in pixels of the tree_column, or -1 if no maximum width is set.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: -1
 * 
 * Name:  gtk_tree_view_column_set_max_width
 * Params: GtkTreeViewColumn *tree_column,  gint max_width
 * Returns: void
 * Assertion: Sets the maximum width of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, -1
 * Expected: void  
 */
static void test_purpose_14()
{
    #define MAX_WIDTH -1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint max_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    max_width = gtk_tree_view_column_get_max_width (column);
    if (max_width != MAX_WIDTH)
    {
        TEST_FAIL ("max_width is %f, should be %f", max_width, MAX_WIDTH);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_max_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the maximum width in pixels of the tree_column, or -1 if no maximum width is set.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 0
 * 
 * Name:  gtk_tree_view_column_set_max_width
 * Params: GtkTreeViewColumn *tree_column,  gint max_width
 * Returns: void
 * Assertion: Sets the maximum width of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, 0
 * Expected: void  
 */
static void test_purpose_15()
{
    #define MAX_WIDTH 0
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint max_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    max_width = gtk_tree_view_column_get_max_width (column);
    if (max_width != MAX_WIDTH)
    {
        TEST_FAIL ("max_width is %f, should be %f", max_width, MAX_WIDTH);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_max_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the maximum width in pixels of the tree_column, or -1 if no maximum width is set.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 1
 * 
 * Name:  gtk_tree_view_column_set_max_width
 * Params: GtkTreeViewColumn *tree_column,  gint max_width
 * Returns: void
 * Assertion: Sets the maximum width of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, 1
 * Expected: void  
 */
static void test_purpose_16()
{
    #define MAX_WIDTH 1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint max_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    max_width = gtk_tree_view_column_get_max_width (column);
    if (max_width != MAX_WIDTH)
    {
        TEST_FAIL ("max_width is %f, should be %f", max_width, MAX_WIDTH);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_max_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the maximum width in pixels of the tree_column, or -1 if no maximum width is set.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 100000
 * 
 * Name:  gtk_tree_view_column_set_max_width
 * Params: GtkTreeViewColumn *tree_column,  gint max_width
 * Returns: void
 * Assertion: Sets the maximum width of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, 100000
 * Expected: void  
 */
static void test_purpose_17()
{
    #define MAX_WIDTH 100000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint max_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    max_width = gtk_tree_view_column_get_max_width (column);
    if (max_width != MAX_WIDTH)
    {
        TEST_FAIL ("max_width is %f, should be %f", max_width, MAX_WIDTH);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_max_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the maximum width in pixels of the tree_column, or -1 if no maximum width is set.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 20000
 * 
 * Name:  gtk_tree_view_column_set_max_width
 * Params: GtkTreeViewColumn *tree_column,  gint max_width
 * Returns: void
 * Assertion: Sets the maximum width of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, 20000
 * Expected: void  
 */
static void test_purpose_18()
{
    #define MAX_WIDTH 20000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint max_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    max_width = gtk_tree_view_column_get_max_width (column);
    if (max_width != MAX_WIDTH)
    {
        TEST_FAIL ("max_width is %f, should be %f", max_width, MAX_WIDTH);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_title
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the title of the widget.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: <%1%>
 * 
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, "Text"
 * Expected: void  
 */
static void test_purpose_19()
{
    #define TITLE "Text"
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_title
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the title of the widget.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: <%1%>
 * 
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void  
 */
static void test_purpose_20()
{
    #define TITLE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_title
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the title of the widget.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: <%1%>
 * 
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void  
 */
static void test_purpose_21()
{
    #define TITLE "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_title
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the title of the widget.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: <%1%>
 * 
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, "\b\n\t"
 * Expected: void  
 */
static void test_purpose_22()
{
    #define TITLE "\b\n\t"
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_title
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the title of the widget.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: <%1%>
 * 
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, ""
 * Expected: void  
 */
static void test_purpose_23()
{
    #define TITLE ""
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_title
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the title of the widget.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: <%1%>
 * 
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, " "
 * Expected: void  
 */
static void test_purpose_24()
{
    #define TITLE " "
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_title
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the title of the widget.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: <%1%>
 * 
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, NULL
 * Expected: void  
 */
static void test_purpose_25()
{
    #define TITLE NULL
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_title
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the title of the widget.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: <%1%>
 * 
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the tree_column.
 * Params Values: a newly created GtkTextViewColumn, "Text"
 * Expected: void  
 */
static void test_purpose_26()
{
    #define TITLE "Text"
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: If a custom widget has been set, then this value is ignored.
 * Params Values: a newly created GtkTextViewColumn, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void  
 */
static void test_purpose_27()
{
    #define TITLE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define CORRECT_TITLE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    button = gtk_button_new_with_label (CORRECT_TITLE);
    gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (column), button);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    #undef CORRECT_TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: If a custom widget has been set, then this value is ignored.
 * Params Values: a newly created GtkTextViewColumn, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void  
 */
static void test_purpose_28()
{
    #define TITLE "!@#$%^&*()_+|~=\";:'?<>`/"
    #define CORRECT_TITLE "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    button = gtk_button_new_with_label (CORRECT_TITLE);
    gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (column), button);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    #undef CORRECT_TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: If a custom widget has been set, then this value is ignored.
 * Params Values: a newly created GtkTextViewColumn, "\b\n\t"
 * Expected: void  
 */
static void test_purpose_29()
{
    #define TITLE "\b\n\t"
    #define CORRECT_TITLE "\b\n\t"
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    button = gtk_button_new_with_label (CORRECT_TITLE);
    gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (column), button);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    #undef CORRECT_TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: If a custom widget has been set, then this value is ignored.
 * Params Values: a newly created GtkTextViewColumn, NULL
 * Expected: void  
 */
static void test_purpose_30()
{
    #define TITLE NULL
    #define CORRECT_TITLE ""
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    button = gtk_button_new_with_label (CORRECT_TITLE);
    gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (column), button);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    #undef CORRECT_TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: If a custom widget has been set, then this value is ignored.
 * Params Values: a newly created GtkTextViewColumn, ""
 * Expected: void  
 */
static void test_purpose_31()
{
    #define TITLE ""
    #define CORRECT_TITLE NULL
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    button = gtk_button_new_with_label (CORRECT_TITLE);
    gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (column), button);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    #undef CORRECT_TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_title
 * Params: GtkTreeViewColumn *tree_column, const gchar *title
 * Returns: void
 * Assertion: If a custom widget has been set, then this value is ignored.
 * Params Values: a newly created GtkTextViewColumn, "Text"
 * Expected: void  
 */
static void test_purpose_32()
{
    #define TITLE "Text"
    #define CORRECT_TITLE "Another Text"
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    const gchar* title;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    button = gtk_button_new_with_label (CORRECT_TITLE);
    gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (column), button);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_title (GTK_TREE_VIEW_COLUMN (column), TITLE);
    title = gtk_tree_view_column_get_title (column);
    
    if (TITLE != NULL)
    {
        if (!title)
        {
            TEST_FAIL ("title is NULL but should be %s", TITLE);
        } else if (strcmp (title, (char*) TITLE)) {
            TEST_FAIL ("title is %s, should be %s", title, TITLE);
        }
    } else {
        if (title)
        {
            TEST_FAIL ("title is %s but should be NULL", title);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef TITLE
    #undef CORRECT_TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_clickable
 * Params: GtkTreeViewColumn *tree_column,  gboolean clickable
 * Returns: void
 * Assertion: Sets the header to be active if active is TRUE.
 * Params Values: a newly created GtkTextViewColumn,  TRUE
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_get_clickable
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gboolean 
 * Assertion: Returns TRUE if the user can click on the header for the column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: TRUE  
 */
static void test_purpose_33()
{
    #define CLICKABLE TRUE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gboolean clickable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_clickable (column, CLICKABLE);
    
    clickable = gtk_tree_view_column_get_clickable (column);
    if (clickable != CLICKABLE)
    {
        TEST_FAIL ("clickable = %d, should be %d", clickable, CLICKABLE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef CLICKABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_clickable
 * Params: GtkTreeViewColumn *tree_column,  gboolean clickable
 * Returns: void
 * Assertion: Sets the header to be active if active is TRUE.
 * Params Values: a newly created GtkTextViewColumn,  FALSE
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_get_clickable
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gboolean 
 * Assertion: Returns TRUE if the user can click on the header for the column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: FALSE  
 */
static void test_purpose_34()
{
    #define CLICKABLE FALSE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gboolean clickable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_clickable (column, CLICKABLE);
    
    clickable = gtk_tree_view_column_get_clickable (column);
    if (clickable != CLICKABLE)
    {
        TEST_FAIL ("clickable = %d, should be %d", clickable, CLICKABLE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef CLICKABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_widget
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GtkWidget*
 * Assertion: Sets the widget in the header to be widget.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: <%1%>
 * 
 * Name:  gtk_tree_view_column_get_widget
 * Params: GtkTreeViewColumn *tree_column, GtkWidget *widget
 * Returns: void
 * Assertion: Returns the GtkWidget in the button on the column header.
 * Params Values: a newly created GtkTextViewColumn, gtk_statusbar_new ()
 * Expected: void  
 */
static void test_purpose_35()
{
    #define CUSTOM_WIDGET gtk_statusbar_new ()
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkWidget* custom_widget;
    GtkWidget* real_custom_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    custom_widget = CUSTOM_WIDGET;
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (column), custom_widget);
    real_custom_widget = 
        gtk_tree_view_column_get_widget (GTK_TREE_VIEW_COLUMN (column));
    
    if (real_custom_widget != custom_widget)
    {
        TEST_FAIL ("custom widget differs from that the column was created with", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef CUSTOM_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_widget
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GtkWidget*
 * Assertion: Sets the widget in the header to be widget.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: <%1%>
 * 
 * Name:  gtk_tree_view_column_get_widget
 * Params: GtkTreeViewColumn *tree_column, GtkWidget *widget
 * Returns: void
 * Assertion: Returns the GtkWidget in the button on the column header.
 * Params Values: a newly created GtkTextViewColumn, gtk_table_new (65535, 5, FALSE)
 * Expected: void  
 */
static void test_purpose_36()
{
    #define CUSTOM_WIDGET gtk_table_new (65535, 5, FALSE)
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkWidget* custom_widget;
    GtkWidget* real_custom_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    custom_widget = CUSTOM_WIDGET;
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (column), custom_widget);
    real_custom_widget = 
        gtk_tree_view_column_get_widget (GTK_TREE_VIEW_COLUMN (column));
    
    if (real_custom_widget != custom_widget)
    {
        TEST_FAIL ("custom widget differs from that the column was created with", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef CUSTOM_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_widget
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GtkWidget*
 * Assertion: Sets the widget in the header to be widget.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: <%1%>
 * 
 * Name:  gtk_tree_view_column_get_widget
 * Params: GtkTreeViewColumn *tree_column, GtkWidget *widget
 * Returns: void
 * Assertion: Returns the GtkWidget in the button on the column header.
 * Params Values: a newly created GtkTextViewColumn, gtk_image_new_from_file ("sdg")
 * Expected: void  
 */
static void test_purpose_37()
{
    #define CUSTOM_WIDGET gtk_image_new_from_file ("sdg")
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkWidget* custom_widget;
    GtkWidget* real_custom_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    custom_widget = CUSTOM_WIDGET;
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (column), custom_widget);
    real_custom_widget = 
        gtk_tree_view_column_get_widget (GTK_TREE_VIEW_COLUMN (column));
    
    if (real_custom_widget != custom_widget)
    {
        TEST_FAIL ("custom widget differs from that the column was created with", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef CUSTOM_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_widget
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GtkWidget*
 * Assertion: Sets the widget in the header to be widget.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: <%1%>
 * 
 * Name:  gtk_tree_view_column_get_widget
 * Params: GtkTreeViewColumn *tree_column, GtkWidget *widget
 * Returns: void
 * Assertion: Returns the GtkWidget in the button on the column header.
 * Params Values: a newly created GtkTextViewColumn, NULL
 * Expected: void  
 */
static void test_purpose_38()
{
    #define CUSTOM_WIDGET NULL
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkWidget* custom_widget;
    GtkWidget* real_custom_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    custom_widget = CUSTOM_WIDGET;
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (column), custom_widget);
    real_custom_widget = 
        gtk_tree_view_column_get_widget (GTK_TREE_VIEW_COLUMN (column));
    
    if (real_custom_widget != custom_widget)
    {
        TEST_FAIL ("custom widget differs from that the column was created with", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef CUSTOM_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_widget
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GtkWidget *widget
 * Assertion:  If a custom widget has not been set then NULL is returned.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: NULL  
 */
static void test_purpose_39()
{
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkWidget* real_custom_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    real_custom_widget = 
        gtk_tree_view_column_get_widget (GTK_TREE_VIEW_COLUMN (column));
    
    if (real_custom_widget != NULL)
    {
        TEST_FAIL ("custom widget was not set; gtk_tree_view_column_get_widget () should return NULL but it doesn't", NULL);
        return;
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_alignment
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gfloat
 * Assertion: Returns the current x alignment of tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 0.0
 * 
 * Name:  gtk_tree_view_column_set_alignment
 * Params: GtkTreeViewColumn *tree_column,  gfloat xalign
 * Returns: void
 * Assertion: Sets the alignment of the title or custom widget inside the column header.
 * Params Values: a newly created GtkTextViewColumn, 0.0
 * Expected: void  
 */
static void test_purpose_40()
{
    #define XALIGN 0.0
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gfloat xalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_alignment (column, XALIGN);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    xalign = gtk_tree_view_column_get_alignment (column);
    if (xalign != XALIGN)
    {
        TEST_FAIL ("alignment is %f, should be %f", xalign, XALIGN);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef XALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_alignment
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gfloat
 * Assertion: Returns the current x alignment of tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 0.5
 * 
 * Name:  gtk_tree_view_column_set_alignment
 * Params: GtkTreeViewColumn *tree_column,  gfloat xalign
 * Returns: void
 * Assertion: Sets the alignment of the title or custom widget inside the column header.
 * Params Values: a newly created GtkTextViewColumn, 0.5
 * Expected: void  
 */
static void test_purpose_41()
{
    #define XALIGN 0.5
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gfloat xalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_alignment (column, XALIGN);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    xalign = gtk_tree_view_column_get_alignment (column);
    if (xalign != XALIGN)
    {
        TEST_FAIL ("alignment is %f, should be %f", xalign, XALIGN);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef XALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_alignment
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gfloat
 * Assertion: Returns the current x alignment of tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 1.0
 * 
 * Name:  gtk_tree_view_column_set_alignment
 * Params: GtkTreeViewColumn *tree_column,  gfloat xalign
 * Returns: void
 * Assertion: Sets the alignment of the title or custom widget inside the column header.
 * Params Values: a newly created GtkTextViewColumn, 1.0
 * Expected: void  
 */
static void test_purpose_42()
{
    #define XALIGN 1.0
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gfloat xalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_alignment (column, XALIGN);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    xalign = gtk_tree_view_column_get_alignment (column);
    if (xalign != XALIGN)
    {
        TEST_FAIL ("alignment is %f, should be %f", xalign, XALIGN);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef XALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_resizable
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gboolean
 * Assertion: If resizable is TRUE, then the user can explicitly resize the column by grabbing the outer edge of the column button.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: TRUE
 * 
 * Name:  gtk_tree_view_column_get_resizable
 * Params: GtkTreeViewColumn *tree_column, gboolean visible
 * Returns: void
 * Assertion: Returns TRUE if the tree_column can be resized by the end user.
 * Params Values: a newly created GtkTextViewColumn, TRUE
 * Expected: void  
 */
static void test_purpose_43()
{
    #define RESIZABLE TRUE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gboolean resizable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_resizable (column, RESIZABLE);
    
    resizable = gtk_tree_view_column_get_resizable (column);
    if (resizable != RESIZABLE)
    {
        TEST_FAIL ("resizable is %d, should be %d", resizable, RESIZABLE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RESIZABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_resizable
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gboolean
 * Assertion: If resizable is TRUE, then the user can explicitly resize the column by grabbing the outer edge of the column button.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: FALSE
 * 
 * Name:  gtk_tree_view_column_get_resizable
 * Params: GtkTreeViewColumn *tree_column, gboolean visible
 * Returns: void
 * Assertion: Returns TRUE if the tree_column can be resized by the end user.
 * Params Values: a newly created GtkTextViewColumn, FALSE
 * Expected: void  
 */
static void test_purpose_44()
{
    #define RESIZABLE FALSE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gboolean resizable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_resizable (column, RESIZABLE);
    
    resizable = gtk_tree_view_column_get_resizable (column);
    if (resizable != RESIZABLE)
    {
        TEST_FAIL ("resizable is %d, should be %d", resizable, RESIZABLE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RESIZABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_resizable
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gboolean
 * Assertion: If resizable is TRUE and sizing mode of the column is GTK_TREE_VIEW_COLUMN_AUTOSIZE, then the sizing mode is changed to GTK_TREE_VIEW_COLUMN_GROW_ONLY.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: TRUE  
 */
static void test_purpose_45()
{
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gboolean sizing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
    gtk_tree_view_column_set_resizable (column, TRUE);
    
    sizing = gtk_tree_view_column_get_sizing (column);
    if (sizing != GTK_TREE_VIEW_COLUMN_GROW_ONLY)
    {
        TEST_FAIL ("sizing is %d, should be %d", 
                   sizing, GTK_TREE_VIEW_COLUMN_GROW_ONLY);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RESIZABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_reorderable
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gboolean
 * Assertion: If reorderable is TRUE, then the column can be reordered by the end user dragging the header.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: TRUE
 * 
 * Name:  gtk_tree_view_column_get_reorderable
 * Params: GtkTreeViewColumn *tree_column, gboolean visible
 * Returns: void
 * Assertion: Returns TRUE if the tree_column can be reordered by the user.
 * Params Values: a newly created GtkTextViewColumn, TRUE
 * Expected: void  
 */
static void test_purpose_46()
{
    #define REORDERABLE TRUE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gboolean reorderable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_reorderable (column, REORDERABLE);
    
    reorderable = gtk_tree_view_column_get_reorderable (column);
    if (reorderable != REORDERABLE)
    {
        TEST_FAIL ("reorderable is %d, should be %d", reorderable, REORDERABLE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef REORDERABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_reorderable
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gboolean
 * Assertion: If reorderable is TRUE, then the column can be reordered by the end user dragging the header.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: FALSE
 * 
 * Name:  gtk_tree_view_column_get_reorderable
 * Params: GtkTreeViewColumn *tree_column, gboolean visible
 * Returns: void
 * Assertion: Returns TRUE if the tree_column can be reordered by the user.
 * Params Values: a newly created GtkTextViewColumn, FALSE
 * Expected: void  
 */
static void test_purpose_47()
{
    #define REORDERABLE FALSE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gboolean reorderable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_reorderable (column, REORDERABLE);
    
    reorderable = gtk_tree_view_column_get_reorderable (column);
    if (reorderable != REORDERABLE)
    {
        TEST_FAIL ("reorderable is %d, should be %d", reorderable, REORDERABLE);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef REORDERABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_fixed_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Gets the fixed width of the column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 1
 * 
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: Sets the size of the column in pixels.
 * Params Values: a newly created GtkTextViewColumn, 1
 * Expected: void  
 */
static void test_purpose_48()
{
    #define FIXED_WIDTH 1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_fixed_width (column);
    if (fixed_width != FIXED_WIDTH)
    {
        TEST_FAIL ("fixed_width is %f, should be %f", fixed_width, FIXED_WIDTH);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_fixed_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Gets the fixed width of the column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 10
 * 
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: Sets the size of the column in pixels.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_49()
{
    #define FIXED_WIDTH 10
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_fixed_width (column);
    if (fixed_width != FIXED_WIDTH)
    {
        TEST_FAIL ("fixed_width is %f, should be %f", fixed_width, FIXED_WIDTH);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_fixed_width
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Gets the fixed width of the column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 10000
 * 
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: Sets the size of the column in pixels.
 * Params Values: a newly created GtkTextViewColumn, 10000
 * Expected: void  
 */
static void test_purpose_50()
{
    #define FIXED_WIDTH 10000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_fixed_width (column);
    if (fixed_width != FIXED_WIDTH)
    {
        TEST_FAIL ("fixed_width is %f, should be %f", fixed_width, FIXED_WIDTH);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 1
 * Expected: void  
 */
static void test_purpose_51()
{
    #define FIXED_WIDTH 1
    #define MIN_WIDTH -1
    #define MAX_WIDTH -1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 1
 * Expected: void  
 */
static void test_purpose_52()
{
    #define FIXED_WIDTH 1
    #define MIN_WIDTH -1
    #define MAX_WIDTH 1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 1
 * Expected: void  
 */
static void test_purpose_53()
{
    #define FIXED_WIDTH 1
    #define MIN_WIDTH -1
    #define MAX_WIDTH 2
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 1
 * Expected: void  
 */
static void test_purpose_54()
{
    #define FIXED_WIDTH 1
    #define MIN_WIDTH 2
    #define MAX_WIDTH 2
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 1
 * Expected: void  
 */
static void test_purpose_55()
{
    #define FIXED_WIDTH 1
    #define MIN_WIDTH 2
    #define MAX_WIDTH -1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 1
 * Expected: void  
 */
static void test_purpose_56()
{
    #define FIXED_WIDTH 1
    #define MIN_WIDTH 2
    #define MAX_WIDTH 3
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_57()
{
    #define FIXED_WIDTH 10
    #define MIN_WIDTH -1
    #define MAX_WIDTH 5
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_58()
{
    #define FIXED_WIDTH 10
    #define MIN_WIDTH -1
    #define MAX_WIDTH -1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_59()
{
    #define FIXED_WIDTH 10
    #define MIN_WIDTH 5
    #define MAX_WIDTH 5
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_60()
{
    #define FIXED_WIDTH 10
    #define MIN_WIDTH 10
    #define MAX_WIDTH 10
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_61()
{
    #define FIXED_WIDTH 10
    #define MIN_WIDTH -1
    #define MAX_WIDTH 10
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_62()
{
    #define FIXED_WIDTH 10
    #define MIN_WIDTH 10
    #define MAX_WIDTH -1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_63()
{
    #define FIXED_WIDTH 10
    #define MIN_WIDTH 5
    #define MAX_WIDTH 10
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_64()
{
    #define FIXED_WIDTH 10
    #define MIN_WIDTH 5
    #define MAX_WIDTH 15
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_65()
{
    #define FIXED_WIDTH 10
    #define MIN_WIDTH -1
    #define MAX_WIDTH 15
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_66()
{
    #define FIXED_WIDTH 10
    #define MIN_WIDTH 10
    #define MAX_WIDTH 15
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_67()
{
    #define FIXED_WIDTH 10
    #define MIN_WIDTH 15
    #define MAX_WIDTH 1000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10000
 * Expected: void  
 */
static void test_purpose_68()
{
    #define FIXED_WIDTH 10000
    #define MIN_WIDTH 15000
    #define MAX_WIDTH 15000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 15000
 * Expected: void  
 */
static void test_purpose_69()
{
    #define FIXED_WIDTH 15000
    #define MIN_WIDTH -1
    #define MAX_WIDTH 15000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10000
 * Expected: void  
 */
static void test_purpose_70()
{
    #define FIXED_WIDTH 10000
    #define MIN_WIDTH 15000
    #define MAX_WIDTH -1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 10000
 * Expected: void  
 */
static void test_purpose_71()
{
    #define FIXED_WIDTH 10000
    #define MIN_WIDTH 5
    #define MAX_WIDTH 15000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 15000
 * Expected: void  
 */
static void test_purpose_72()
{
    #define FIXED_WIDTH 15000
    #define MIN_WIDTH -1
    #define MAX_WIDTH -1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_fixed_width
 * Params: GtkTreeViewColumn *tree_column,  gint fixed_width
 * Returns: void
 * Assertion: The size of the column is clamped to the min/max width for the column.
 * Params Values: a newly created GtkTextViewColumn, 15000
 * Expected: void  
 */
static void test_purpose_73()
{
    #define FIXED_WIDTH 15000
    #define MIN_WIDTH 15000
    #define MAX_WIDTH 15000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint fixed_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
    gtk_tree_view_column_set_min_width (column, MIN_WIDTH);
    gtk_tree_view_column_set_max_width (column, MAX_WIDTH);
    gtk_tree_view_column_set_fixed_width (column, FIXED_WIDTH);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    fixed_width = gtk_tree_view_column_get_width (column);
    
    if (MIN_WIDTH <= 0 && MAX_WIDTH == 0)
    {
        if (fixed_width != 1)
        {
            TEST_FAIL ("min_width = %d, max_width = %d; fixed_width is %d, should be 1", 
                       gtk_tree_view_column_get_min_width (column), 
                       gtk_tree_view_column_get_max_width (column),
                       fixed_width);
        }
    } else if (fixed_width < MIN_WIDTH || (MAX_WIDTH != -1 && fixed_width > MAX_WIDTH))
    {
        TEST_FAIL ("fixed_width is not clamped: fixed_width is %d, min_width = %d, max_width = %d", 
                   fixed_width, 
                   gtk_tree_view_column_get_min_width (column), 
                   gtk_tree_view_column_get_max_width (column));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef FIXED_WIDTH
    #undef MIN_WIDTH
    #undef MAX_WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_spacing
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the spacing of tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 0
 * 
 * Name:  gtk_tree_view_column_set_spacing
 * Params: GtkTreeViewColumn *tree_column,  gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of tree_column, which is the number of pixels to place between cell renderers packed into it.
 * Params Values: a newly created GtkTextViewColumn, 0
 * Expected: void  
 */
static void test_purpose_74()
{
    #define SPACING 0
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_spacing (column, SPACING);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    spacing = gtk_tree_view_column_get_spacing (column);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is %d, should be %d", spacing, SPACING);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_spacing
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the spacing of tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 1
 * 
 * Name:  gtk_tree_view_column_set_spacing
 * Params: GtkTreeViewColumn *tree_column,  gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of tree_column, which is the number of pixels to place between cell renderers packed into it.
 * Params Values: a newly created GtkTextViewColumn, 1
 * Expected: void  
 */
static void test_purpose_75()
{
    #define SPACING 1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_spacing (column, SPACING);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    spacing = gtk_tree_view_column_get_spacing (column);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is %d, should be %d", spacing, SPACING);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_spacing
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the spacing of tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 10
 * 
 * Name:  gtk_tree_view_column_set_spacing
 * Params: GtkTreeViewColumn *tree_column,  gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of tree_column, which is the number of pixels to place between cell renderers packed into it.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_76()
{
    #define SPACING 10
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_spacing (column, SPACING);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    spacing = gtk_tree_view_column_get_spacing (column);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is %d, should be %d", spacing, SPACING);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_spacing
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the spacing of tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 10000
 * 
 * Name:  gtk_tree_view_column_set_spacing
 * Params: GtkTreeViewColumn *tree_column,  gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of tree_column, which is the number of pixels to place between cell renderers packed into it.
 * Params Values: a newly created GtkTextViewColumn, 10000
 * Expected: void  
 */
static void test_purpose_77()
{
    #define SPACING 10000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_spacing (column, SPACING);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    spacing = gtk_tree_view_column_get_spacing (column);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is %d, should be %d", spacing, SPACING);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_spacing
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Returns the spacing of tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 20000
 * 
 * Name:  gtk_tree_view_column_set_spacing
 * Params: GtkTreeViewColumn *tree_column,  gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of tree_column, which is the number of pixels to place between cell renderers packed into it.
 * Params Values: a newly created GtkTextViewColumn, 20000
 * Expected: void  
 */
static void test_purpose_78()
{
    #define SPACING 20000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_view_column_set_spacing (column, SPACING);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    spacing = gtk_tree_view_column_get_spacing (column);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is %d, should be %d", spacing, SPACING);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_sort_order
 * Params: GtkTreeViewColumn *tree_column,  GtkSortType order
 * Returns: void
 * Assertion: Gets the value set by gtk_tree_view_column_set_sort_order().
 * Params Values: a newly created GtkTextViewColumn
 * Expected: GTK_SORT_ASCENDING
 * 
 * Name:  gtk_tree_view_column_set_sort_order
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GtkSortType
 * Assertion: Changes the appearance of the sort indicator.
 * Params Values: a newly created GtkTextViewColumn, GTK_SORT_ASCENDING
 * Expected: void  
 */
static void test_purpose_79()
{
    #define SORT_ORDER GTK_SORT_ASCENDING
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkSortType sort_order;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sort_order (column, SORT_ORDER);
    
    sort_order = gtk_tree_view_column_get_sort_order (column);
    if (sort_order != SORT_ORDER)
    {
        TEST_FAIL ("sort_order is %d, should be %d", sort_order, SORT_ORDER);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SORT_ORDER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_sort_order
 * Params: GtkTreeViewColumn *tree_column,  GtkSortType order
 * Returns: void
 * Assertion: Gets the value set by gtk_tree_view_column_set_sort_order().
 * Params Values: a newly created GtkTextViewColumn
 * Expected: GTK_SORT_DESCENDING
 * 
 * Name:  gtk_tree_view_column_set_sort_order
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GtkSortType
 * Assertion: Changes the appearance of the sort indicator.
 * Params Values: a newly created GtkTextViewColumn, GTK_SORT_DESCENDING
 * Expected: void  
 */
static void test_purpose_80()
{
    #define SORT_ORDER GTK_SORT_DESCENDING
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkSortType sort_order;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sort_order (column, SORT_ORDER);
    
    sort_order = gtk_tree_view_column_get_sort_order (column);
    if (sort_order != SORT_ORDER)
    {
        TEST_FAIL ("sort_order is %d, should be %d", sort_order, SORT_ORDER);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SORT_ORDER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_sort_indicator
 * Params: GtkTreeViewColumn *tree_column,  gboolean setting 
 * Returns: void
 * Assertion: Gets the value set by gtk_tree_view_column_set_sort_indicator().
 * Params Values: a newly created GtkTextViewColumn
 * Expected: TRUE
 * 
 * Name:  gtk_tree_view_column_set_sort_indicator
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gboolean
 * Assertion: Call this function with a setting of TRUE to display an arrow in the header button indicating the column is sorted.
 * Params Values: a newly created GtkTextViewColumn, TRUE
 * Expected: void  
 */
static void test_purpose_81()
{
    #define SHOW_SORT_INDICATOR TRUE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gboolean sort_indicator;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sort_indicator (column, SHOW_SORT_INDICATOR);
    
    sort_indicator = gtk_tree_view_column_get_sort_indicator (column);
    if (sort_indicator != SHOW_SORT_INDICATOR)
    {
        TEST_FAIL ("sort_indicator is %d, should be %d", sort_indicator, SHOW_SORT_INDICATOR);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SHOW_SORT_INDICATOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_sort_indicator
 * Params: GtkTreeViewColumn *tree_column,  gboolean setting 
 * Returns: void
 * Assertion: Gets the value set by gtk_tree_view_column_set_sort_indicator().
 * Params Values: a newly created GtkTextViewColumn
 * Expected: FALSE
 * 
 * Name:  gtk_tree_view_column_set_sort_indicator
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gboolean
 * Assertion: Call this function with a setting of TRUE to display an arrow in the header button indicating the column is sorted.
 * Params Values: a newly created GtkTextViewColumn, FALSE
 * Expected: void  
 */
static void test_purpose_82()
{
    #define SHOW_SORT_INDICATOR FALSE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gboolean sort_indicator;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sort_indicator (column, SHOW_SORT_INDICATOR);
    
    sort_indicator = gtk_tree_view_column_get_sort_indicator (column);
    if (sort_indicator != SHOW_SORT_INDICATOR)
    {
        TEST_FAIL ("sort_indicator is %d, should be %d", sort_indicator, SHOW_SORT_INDICATOR);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SHOW_SORT_INDICATOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_sort_column_id
 * Params: GtkTreeViewColumn *tree_column,  gint sort_column_id
 * Returns: void
 * Assertion: Gets the logical sort_column_id that the model sorts on when this column is selected for sorting.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 0
 * 
 * Name:  gtk_tree_view_column_set_sort_column_id
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Sets the logical sort_column_id that this column sorts on when this column is selected for sorting.
 * Params Values: a newly created GtkTextViewColumn, 0
 * Expected: void  
 */
static void test_purpose_83()
{
    #define SHOW_SORT_COLUMN_ID 0
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint sort_column_id;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sort_column_id (column, SHOW_SORT_COLUMN_ID);
    
    sort_column_id = gtk_tree_view_column_get_sort_column_id (column);
    if (sort_column_id != SHOW_SORT_COLUMN_ID)
    {
        TEST_FAIL ("sort_column_id is %d, should be %d", sort_column_id, SHOW_SORT_COLUMN_ID);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SHOW_SORT_COLUMN_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_sort_column_id
 * Params: GtkTreeViewColumn *tree_column,  gint sort_column_id
 * Returns: void
 * Assertion: Gets the logical sort_column_id that the model sorts on when this column is selected for sorting.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 1
 * 
 * Name:  gtk_tree_view_column_set_sort_column_id
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Sets the logical sort_column_id that this column sorts on when this column is selected for sorting.
 * Params Values: a newly created GtkTextViewColumn, 1
 * Expected: void  
 */
static void test_purpose_84()
{
    #define SHOW_SORT_COLUMN_ID 1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint sort_column_id;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sort_column_id (column, SHOW_SORT_COLUMN_ID);
    
    sort_column_id = gtk_tree_view_column_get_sort_column_id (column);
    if (sort_column_id != SHOW_SORT_COLUMN_ID)
    {
        TEST_FAIL ("sort_column_id is %d, should be %d", sort_column_id, SHOW_SORT_COLUMN_ID);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SHOW_SORT_COLUMN_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_sort_column_id
 * Params: GtkTreeViewColumn *tree_column,  gint sort_column_id
 * Returns: void
 * Assertion: Gets the logical sort_column_id that the model sorts on when this column is selected for sorting.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 10
 * 
 * Name:  gtk_tree_view_column_set_sort_column_id
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Sets the logical sort_column_id that this column sorts on when this column is selected for sorting.
 * Params Values: a newly created GtkTextViewColumn, 10
 * Expected: void  
 */
static void test_purpose_85()
{
    #define SHOW_SORT_COLUMN_ID 10
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint sort_column_id;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sort_column_id (column, SHOW_SORT_COLUMN_ID);
    
    sort_column_id = gtk_tree_view_column_get_sort_column_id (column);
    if (sort_column_id != SHOW_SORT_COLUMN_ID)
    {
        TEST_FAIL ("sort_column_id is %d, should be %d", sort_column_id, SHOW_SORT_COLUMN_ID);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SHOW_SORT_COLUMN_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_sort_column_id
 * Params: GtkTreeViewColumn *tree_column,  gint sort_column_id
 * Returns: void
 * Assertion: Gets the logical sort_column_id that the model sorts on when this column is selected for sorting.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: 10000
 * 
 * Name:  gtk_tree_view_column_set_sort_column_id
 * Params: GtkTreeViewColumn *tree_column
 * Returns: gint
 * Assertion: Sets the logical sort_column_id that this column sorts on when this column is selected for sorting.
 * Params Values: a newly created GtkTextViewColumn, 10000
 * Expected: void  
 */
static void test_purpose_86()
{
    #define SHOW_SORT_COLUMN_ID 10000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    gint sort_column_id;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_sort_column_id (column, SHOW_SORT_COLUMN_ID);
    
    sort_column_id = gtk_tree_view_column_get_sort_column_id (column);
    if (sort_column_id != SHOW_SORT_COLUMN_ID)
    {
        TEST_FAIL ("sort_column_id is %d, should be %d", sort_column_id, SHOW_SORT_COLUMN_ID);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef SHOW_SORT_COLUMN_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = -1, y = -1, width = -1, height = -1 (if any of these is -1 then rectangle is actually NULL)
 * Expected: -1  
 */
static void test_purpose_87()
{
    #define RECTANGLE_X -1
    #define RECTANGLE_Y -1
    #define RECTANGLE_WIDTH -1
    #define RECTANGLE_HEIGHT -1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 0, y = 1, width = 1, height = 1 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 0  
 */
static void test_purpose_88()
{
    #define RECTANGLE_X 0
    #define RECTANGLE_Y 1
    #define RECTANGLE_WIDTH 1
    #define RECTANGLE_HEIGHT 1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 0, y = 0, width = 0, height = 0 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 0  
 */
static void test_purpose_89()
{
    #define RECTANGLE_X 0
    #define RECTANGLE_Y 0
    #define RECTANGLE_WIDTH 0
    #define RECTANGLE_HEIGHT 0
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 1, y = 0, width = 1, height = 1 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 1  
 */
static void test_purpose_90()
{
    #define RECTANGLE_X 1
    #define RECTANGLE_Y 0
    #define RECTANGLE_WIDTH 1
    #define RECTANGLE_HEIGHT 1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 1, y = 1, width = 0, height = 1 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 1  
 */
static void test_purpose_91()
{
    #define RECTANGLE_X 1
    #define RECTANGLE_Y 1
    #define RECTANGLE_WIDTH 0
    #define RECTANGLE_HEIGHT 1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 1, y = 1, width = 1, height = 0 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 1  
 */
static void test_purpose_92()
{
    #define RECTANGLE_X 1
    #define RECTANGLE_Y 1
    #define RECTANGLE_WIDTH 1
    #define RECTANGLE_HEIGHT 0
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 1, y = 1, width = 1, height = 1 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 1  
 */
static void test_purpose_93()
{
    #define RECTANGLE_X 1
    #define RECTANGLE_Y 1
    #define RECTANGLE_WIDTH 1
    #define RECTANGLE_HEIGHT 1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 100, y = 100, width = 100, height = 100 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 100  
 */
static void test_purpose_94()
{
    #define RECTANGLE_X 100
    #define RECTANGLE_Y 100
    #define RECTANGLE_WIDTH 100
    #define RECTANGLE_HEIGHT 100
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 1, y = 100, width = 1, height = 100 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 1  
 */
static void test_purpose_95()
{
    #define RECTANGLE_X 1
    #define RECTANGLE_Y 100
    #define RECTANGLE_WIDTH 1
    #define RECTANGLE_HEIGHT 100
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 100, y = 1, width = 100, height = 1 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 100  
 */
static void test_purpose_96()
{
    #define RECTANGLE_X 100
    #define RECTANGLE_Y 1
    #define RECTANGLE_WIDTH 100
    #define RECTANGLE_HEIGHT 1
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 0, y = 20000, width = 20000, height = 20000 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 0  
 */
static void test_purpose_97()
{
    #define RECTANGLE_X 0
    #define RECTANGLE_Y 20000
    #define RECTANGLE_WIDTH 20000
    #define RECTANGLE_HEIGHT 20000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 20000, y = 0, width = 20000, height = 20000 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 20000  
 */
static void test_purpose_98()
{
    #define RECTANGLE_X 20000
    #define RECTANGLE_Y 0
    #define RECTANGLE_WIDTH 20000
    #define RECTANGLE_HEIGHT 20000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 20000, y = 20000, width = 0, height = 20000 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 20000  
 */
static void test_purpose_99()
{
    #define RECTANGLE_X 20000
    #define RECTANGLE_Y 20000
    #define RECTANGLE_WIDTH 0
    #define RECTANGLE_HEIGHT 20000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 20000, y = 20000, width = 20000, height = 0 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 20000  
 */
static void test_purpose_100()
{
    #define RECTANGLE_X 20000
    #define RECTANGLE_Y 20000
    #define RECTANGLE_WIDTH 20000
    #define RECTANGLE_HEIGHT 0
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 20000, y = 20000, width = 20000, height = 20000 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 20000  
 */
static void test_purpose_101()
{
    #define RECTANGLE_X 20000
    #define RECTANGLE_Y 20000
    #define RECTANGLE_WIDTH 20000
    #define RECTANGLE_HEIGHT 20000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 149, y = 20000, width = 20000, height = 20000 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 149  
 */
static void test_purpose_102()
{
    #define RECTANGLE_X 149
    #define RECTANGLE_Y 20000
    #define RECTANGLE_WIDTH 20000
    #define RECTANGLE_HEIGHT 20000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 20000, y = 149, width = 20000, height = 20000 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 20000  
 */
static void test_purpose_103()
{
    #define RECTANGLE_X 20000
    #define RECTANGLE_Y 149
    #define RECTANGLE_WIDTH 20000
    #define RECTANGLE_HEIGHT 20000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 20000, y = 20000, width = 149, height = 20000 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 20000  
 */
static void test_purpose_104()
{
    #define RECTANGLE_X 20000
    #define RECTANGLE_Y 20000
    #define RECTANGLE_WIDTH 149
    #define RECTANGLE_HEIGHT 20000
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_get_size
 * Params: GtkTreeViewColumn *tree_column,  GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the column.
 * Params Values: a newly created GtkTextViewColumn, GdkRectanlge with x = 20000, y = 20000, width = 20000, height = 149 (if any of these is -1 then rectangle is actually NULL)
 * Expected: 20000  
 */
static void test_purpose_105()
{
    #define RECTANGLE_X 20000
    #define RECTANGLE_Y 20000
    #define RECTANGLE_WIDTH 20000
    #define RECTANGLE_HEIGHT 149
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GdkRectangle rect;
    gint x_offset;
    gint y_offset;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    if (RECTANGLE_X == -1)
    {
        gtk_tree_view_column_cell_get_size (column, NULL, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, NULL, 
                                            &x_offset, &y_offset, &width, NULL);
    } else {
        rect.x = RECTANGLE_X;
        rect.y = RECTANGLE_Y;
        rect.width = RECTANGLE_WIDTH;
        rect.height = RECTANGLE_HEIGHT;
    
        gtk_tree_view_column_cell_get_size (column, &rect, NULL, NULL, NULL, NULL);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            NULL, &y_offset, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, NULL, &width, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, NULL, &height);
        gtk_tree_view_column_cell_get_size (column, &rect, 
                                            &x_offset, &y_offset, &width, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RECTANGLE_X
    #undef RECTANGLE_Y
    #undef RECTANGLE_WIDTH
    #undef RECTANGLE_HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_cell_data_func
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, GtkTreeCellDataFunc func, gpointer func_data, GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the GtkTreeViewColumnFunc to use for the column.
 * Params Values: a newly created GtkTextViewColumn, GtkCellRendererText*, gtk_tree_view_column_new_with_attributes ("title", renderer, "text", 0, NULL);            , NULL, NULL
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_set_cell_data_func
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, GtkTreeCellDataFunc func, gpointer func_data, GtkDestroyNotify destroy
 * Returns: void
 * Assertion: func may be NULL to remove an older one.
 * Params Values: a newly created GtkTextViewColumn, GtkCellRendererText*, gtk_tree_view_column_new_with_attributes ("title", renderer, "text", 0, NULL);            , NULL, NULL
 * Expected: void  
 */
static void test_purpose_106()
{
    #define COLUMN gtk_tree_view_column_new_with_attributes ("title", renderer, "text", 0, NULL);            
    #define CELL_DATA_FUNC &global_tree_cell_data_func
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkCellRenderer* renderer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    renderer = gtk_cell_renderer_text_new ();
    column = COLUMN;
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_cell_data_func (column, renderer,
                                             CELL_DATA_FUNC, NULL, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef COLUMN
    #undef CELL_DATA_FUNC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_cell_data_func
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, GtkTreeCellDataFunc func, gpointer func_data, GtkDestroyNotify destroy
 * Returns: void
 * Assertion: Sets the GtkTreeViewColumnFunc to use for the column.
 * Params Values: a newly created GtkTextViewColumn, GtkCellRendererText*, gtk_tree_view_column_new_with_attributes ("title", renderer, "text", 0, NULL);            , NULL, NULL
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_set_cell_data_func
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, GtkTreeCellDataFunc func, gpointer func_data, GtkDestroyNotify destroy
 * Returns: void
 * Assertion: func may be NULL to remove an older one.
 * Params Values: a newly created GtkTextViewColumn, GtkCellRendererText*, gtk_tree_view_column_new_with_attributes ("title", renderer, "text", 0, NULL);            , NULL, NULL
 * Expected: void  
 */
static void test_purpose_107()
{
    #define COLUMN gtk_tree_view_column_new_with_attributes ("title", renderer, "text", 0, NULL);            
    #define CELL_DATA_FUNC NULL
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkCellRenderer* renderer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    renderer = gtk_cell_renderer_text_new ();
    column = COLUMN;
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
    
        GtkCellRenderer* renderer;
        GtkListStore* model;
        int i;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_column_set_title (column, "column");
        gtk_tree_view_column_pack_start (column, renderer, TRUE);
        gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_tree_view_column_set_cell_data_func (column, renderer,
                                             CELL_DATA_FUNC, NULL, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef COLUMN
    #undef CELL_DATA_FUNC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_new_with_attributes
 * Params: const gchar *title, GtkCellRenderer *cell, ...
 * Returns: GtkTreeViewColumn*
 * Assertion: Creates a new GtkTreeViewColumn with a number of default values.
 * Params Values: "title", gtk_cell_renderer_text_new (), TRUE
 * Expected: GtkTextViewColumn*  
 */
static void test_purpose_108()
{
    #define EXPAND TRUE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkCellRenderer* renderer;
    G_CONST_RETURN gchar* real_title;
    GList* cell_renderers;
    gboolean has_rend = FALSE;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    renderer = gtk_cell_renderer_text_new ();
    column = gtk_tree_view_column_new_with_attributes ("title", renderer,  
                                                       "text", 0, NULL);
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        GtkCellRenderer* renderer;
    
        model  = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
    
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    real_title = gtk_tree_view_column_get_title (column);
    if (!real_title)
    {
        TEST_FAIL ("real_title = NULL, should be 'title'", NULL);
    } else if (strcmp (real_title, "title")) {
        TEST_FAIL ("real_title = '%s', should be 'title'", real_title);
    }
        
    cell_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < g_list_length (cell_renderers); i++)
    {
        GtkCellRenderer* rend;
    
        rend = (GtkCellRenderer*) g_list_nth_data (cell_renderers, i);
        if (rend == renderer)
        {
            has_rend = TRUE;
            break;
        }
    }
    
    if (has_rend == FALSE)
    {
        TEST_FAIL ("cell renderer added with gtk_tree_view_column_new_with_attributes () is not in the list of the column cell renderers", NULL);
    }
    
    g_list_free (cell_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_new_with_attributes
 * Params: const gchar *title, GtkCellRenderer *cell, ...
 * Returns: GtkTreeViewColumn*
 * Assertion: Creates a new GtkTreeViewColumn with a number of default values.
 * Params Values: "title", gtk_cell_renderer_text_new (), FALSE
 * Expected: GtkTextViewColumn*  
 */
static void test_purpose_109()
{
    #define EXPAND FALSE
    
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkCellRenderer* renderer;
    G_CONST_RETURN gchar* real_title;
    GList* cell_renderers;
    gboolean has_rend = FALSE;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    renderer = gtk_cell_renderer_text_new ();
    column = gtk_tree_view_column_new_with_attributes ("title", renderer,  
                                                       "text", 0, NULL);
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        GtkCellRenderer* renderer;
    
        model  = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
    
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    real_title = gtk_tree_view_column_get_title (column);
    if (!real_title)
    {
        TEST_FAIL ("real_title = NULL, should be 'title'", NULL);
    } else if (strcmp (real_title, "title")) {
        TEST_FAIL ("real_title = '%s', should be 'title'", real_title);
    }
        
    cell_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < g_list_length (cell_renderers); i++)
    {
        GtkCellRenderer* rend;
    
        rend = (GtkCellRenderer*) g_list_nth_data (cell_renderers, i);
        if (rend == renderer)
        {
            has_rend = TRUE;
            break;
        }
    }
    
    if (has_rend == FALSE)
    {
        TEST_FAIL ("cell renderer added with gtk_tree_view_column_new_with_attributes () is not in the list of the column cell renderers", NULL);
    }
    
    g_list_free (cell_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_attributes
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, ...
 * Returns: void
 * Assertion: Sets the attributes in the list as the attributes of tree_column.
 * Params Values: a newly created GtkTextViewColumn, ...
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_set_attributes
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, ...
 * Returns: void
 * Assertion: All existing attributes are removed, and replaced with the new attributes.
 * Params Values: a newly created GtkTextViewColumn, ...
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_add_attribute
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, const gchar *attribute, gint column
 * Returns: void
 * Assertion: Adds an attribute mapping to the list in tree_column.
 * Params Values: a newly created GtkTextViewColumn, GtkCellRenderer*, const gchar*, gint
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_clear_attributes
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer
 * Returns: void
 * Assertion: Clears all existing attributes previously set with gtk_tree_view_column_set_attributes().
 * Params Values: a newly created GtkTextViewColumn, GtkCellRenderer*
 * Expected: void  
 */
static void test_purpose_110()
{
    #define EXPAND TRUE
    #define IS_RADIO TRUE
    
    GtkTreeViewColumn* column;
    GtkCellRenderer* renderer;
    GtkCellRenderer* renderer1;
    GtkWidget* view;
    gchar* real_text;
    gboolean real_radio;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    renderer = gtk_cell_renderer_text_new ();
    gtk_tree_view_column_pack_start (column, renderer, EXPAND);
    gtk_tree_view_column_add_attribute (column, renderer, "background", 0);
    gtk_tree_view_column_add_attribute (column, renderer, "foreground", 1);
    
    renderer1 = gtk_cell_renderer_toggle_new ();
    gtk_tree_view_column_pack_start (column, renderer1, !EXPAND);
    gtk_tree_view_column_add_attribute (column, renderer1, "active", 0);
    
    gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
    g_object_set (G_OBJECT (renderer1), "radio", IS_RADIO, NULL);
    gtk_tree_view_column_set_attributes (column, renderer1, "radio", 0, NULL);
    gtk_tree_view_column_clear_attributes (column, renderer1);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_object_get (G_OBJECT (renderer1), "radio", &real_radio, NULL);
    if (real_radio != IS_RADIO)
    {
        TEST_FAIL ("real_radio = %d, should be %d", real_radio, IS_RADIO);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef EXPAND
    #undef IS_RADIO
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_attributes
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, ...
 * Returns: void
 * Assertion: Sets the attributes in the list as the attributes of tree_column.
 * Params Values: a newly created GtkTextViewColumn, ...
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_set_attributes
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, ...
 * Returns: void
 * Assertion: All existing attributes are removed, and replaced with the new attributes.
 * Params Values: a newly created GtkTextViewColumn, ...
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_add_attribute
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, const gchar *attribute, gint column
 * Returns: void
 * Assertion: Adds an attribute mapping to the list in tree_column.
 * Params Values: a newly created GtkTextViewColumn, GtkCellRenderer*, const gchar*, gint
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_clear_attributes
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer
 * Returns: void
 * Assertion: Clears all existing attributes previously set with gtk_tree_view_column_set_attributes().
 * Params Values: a newly created GtkTextViewColumn, GtkCellRenderer*
 * Expected: void  
 */
static void test_purpose_111()
{
    #define EXPAND FALSE
    #define IS_RADIO TRUE
    
    GtkTreeViewColumn* column;
    GtkCellRenderer* renderer;
    GtkCellRenderer* renderer1;
    GtkWidget* view;
    gchar* real_text;
    gboolean real_radio;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    renderer = gtk_cell_renderer_text_new ();
    gtk_tree_view_column_pack_start (column, renderer, EXPAND);
    gtk_tree_view_column_add_attribute (column, renderer, "background", 0);
    gtk_tree_view_column_add_attribute (column, renderer, "foreground", 1);
    
    renderer1 = gtk_cell_renderer_toggle_new ();
    gtk_tree_view_column_pack_start (column, renderer1, !EXPAND);
    gtk_tree_view_column_add_attribute (column, renderer1, "active", 0);
    
    gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
    g_object_set (G_OBJECT (renderer1), "radio", IS_RADIO, NULL);
    gtk_tree_view_column_set_attributes (column, renderer1, "radio", 0, NULL);
    gtk_tree_view_column_clear_attributes (column, renderer1);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_object_get (G_OBJECT (renderer1), "radio", &real_radio, NULL);
    if (real_radio != IS_RADIO)
    {
        TEST_FAIL ("real_radio = %d, should be %d", real_radio, IS_RADIO);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef EXPAND
    #undef IS_RADIO
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_attributes
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, ...
 * Returns: void
 * Assertion: Sets the attributes in the list as the attributes of tree_column.
 * Params Values: a newly created GtkTextViewColumn, ...
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_set_attributes
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, ...
 * Returns: void
 * Assertion: All existing attributes are removed, and replaced with the new attributes.
 * Params Values: a newly created GtkTextViewColumn, ...
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_add_attribute
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, const gchar *attribute, gint column
 * Returns: void
 * Assertion: Adds an attribute mapping to the list in tree_column.
 * Params Values: a newly created GtkTextViewColumn, GtkCellRenderer*, const gchar*, gint
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_clear_attributes
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer
 * Returns: void
 * Assertion: Clears all existing attributes previously set with gtk_tree_view_column_set_attributes().
 * Params Values: a newly created GtkTextViewColumn, GtkCellRenderer*
 * Expected: void  
 */
static void test_purpose_112()
{
    #define EXPAND TRUE
    #define IS_RADIO FALSE
    
    GtkTreeViewColumn* column;
    GtkCellRenderer* renderer;
    GtkCellRenderer* renderer1;
    GtkWidget* view;
    gchar* real_text;
    gboolean real_radio;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    renderer = gtk_cell_renderer_text_new ();
    gtk_tree_view_column_pack_start (column, renderer, EXPAND);
    gtk_tree_view_column_add_attribute (column, renderer, "background", 0);
    gtk_tree_view_column_add_attribute (column, renderer, "foreground", 1);
    
    renderer1 = gtk_cell_renderer_toggle_new ();
    gtk_tree_view_column_pack_start (column, renderer1, !EXPAND);
    gtk_tree_view_column_add_attribute (column, renderer1, "active", 0);
    
    gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
    g_object_set (G_OBJECT (renderer1), "radio", IS_RADIO, NULL);
    gtk_tree_view_column_set_attributes (column, renderer1, "radio", 0, NULL);
    gtk_tree_view_column_clear_attributes (column, renderer1);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_object_get (G_OBJECT (renderer1), "radio", &real_radio, NULL);
    if (real_radio != IS_RADIO)
    {
        TEST_FAIL ("real_radio = %d, should be %d", real_radio, IS_RADIO);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef EXPAND
    #undef IS_RADIO
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_set_attributes
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, ...
 * Returns: void
 * Assertion: Sets the attributes in the list as the attributes of tree_column.
 * Params Values: a newly created GtkTextViewColumn, ...
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_set_attributes
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, ...
 * Returns: void
 * Assertion: All existing attributes are removed, and replaced with the new attributes.
 * Params Values: a newly created GtkTextViewColumn, ...
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_add_attribute
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer, const gchar *attribute, gint column
 * Returns: void
 * Assertion: Adds an attribute mapping to the list in tree_column.
 * Params Values: a newly created GtkTextViewColumn, GtkCellRenderer*, const gchar*, gint
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_clear_attributes
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell_renderer
 * Returns: void
 * Assertion: Clears all existing attributes previously set with gtk_tree_view_column_set_attributes().
 * Params Values: a newly created GtkTextViewColumn, GtkCellRenderer*
 * Expected: void  
 */
static void test_purpose_113()
{
    #define EXPAND FALSE
    #define IS_RADIO FALSE
    
    GtkTreeViewColumn* column;
    GtkCellRenderer* renderer;
    GtkCellRenderer* renderer1;
    GtkWidget* view;
    gchar* real_text;
    gboolean real_radio;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    renderer = gtk_cell_renderer_text_new ();
    gtk_tree_view_column_pack_start (column, renderer, EXPAND);
    gtk_tree_view_column_add_attribute (column, renderer, "background", 0);
    gtk_tree_view_column_add_attribute (column, renderer, "foreground", 1);
    
    renderer1 = gtk_cell_renderer_toggle_new ();
    gtk_tree_view_column_pack_start (column, renderer1, !EXPAND);
    gtk_tree_view_column_add_attribute (column, renderer1, "active", 0);
    
    gtk_tree_view_column_set_attributes (column, renderer, "text", 0, NULL);
    g_object_set (G_OBJECT (renderer1), "radio", IS_RADIO, NULL);
    gtk_tree_view_column_set_attributes (column, renderer1, "radio", 0, NULL);
    gtk_tree_view_column_clear_attributes (column, renderer1);
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_object_get (G_OBJECT (renderer1), "radio", &real_radio, NULL);
    if (real_radio != IS_RADIO)
    {
        TEST_FAIL ("real_radio = %d, should be %d", real_radio, IS_RADIO);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef EXPAND
    #undef IS_RADIO
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_set_cell_data
 * Params: GtkTreeViewColumn *tree_column, GtkTreeModel *tree_model, GtkTreeIter *iter, gboolean is_expander, gboolean is_expanded
 * Returns: void
 * Assertion: Sets the cell renderer based on the tree_model and iter.
 * Params Values: a newly created GtkTextViewColumn, GtkTreeStore*, GtkTreeIter* got from path "0:0", TRUE, TRUE
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_cell_set_cell_data
 * Params: GtkTreeViewColumn *tree_column, GtkTreeModel *tree_model, GtkTreeIter *iter, gboolean is_expander, gboolean is_expanded
 * Returns: void
 * Assertion: That is, for every attribute mapping in tree_column, it will get a value from the set column on the iter, and use that value to set the attribute on the cell renderer.
 * Params Values: a newly created GtkTextViewColumn, GtkTreeStore*, GtkTreeIter* got from path "0:0", TRUE, TRUE
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_cell_is_visible
 * Params: GtkTreeViewColumn *tree_column
 * Returns: void
 * Assertion: Returns TRUE if any of the cells packed into the tree_column are visible.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: TRUE
 * 
 * Name:  gtk_tree_view_column_clear
 * Params: GtkTreeViewColumn *tree_column
 * Returns: void
 * Assertion: Unsets all the mappings on all renderers on the tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: void  
 */
static void test_purpose_114()
{
    #define PATH_STR "0:0"
    #define IS_EXPANDER TRUE
    #define IS_EXPANDED TRUE
    
    GtkTreeModel* model;
    GtkTreeViewColumn* column0;
    GtkTreeViewColumn* column1;
    GtkCellRenderer* renderer;
    GtkCellRenderer* renderer1;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkWidget* tree_view;
    gboolean is_visible;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = GTK_TREE_MODEL (gtk_tree_store_new (3, G_TYPE_UINT, 
                                                G_TYPE_UINT, G_TYPE_UINT));
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (GTK_TREE_STORE (model), &iter, NULL);
        gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (GTK_TREE_STORE (model), &child_iter, &iter);
            gtk_tree_store_set (GTK_TREE_STORE (model), &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    renderer = gtk_cell_renderer_text_new ();
    column0 = gtk_tree_view_column_new_with_attributes ("column0", renderer, 
                                                        "text", 0, 
                                                        "text", 1, 
                                                        NULL);
    if (!column0)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column0))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
    
    column1 = gtk_tree_view_column_new ();
    if (!column1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_model_get_iter_from_string (model, &iter, PATH_STR);
    gtk_tree_view_column_pack_start (column1, renderer, TRUE);
    gtk_tree_view_column_cell_set_cell_data (column1, model, &iter, IS_EXPANDER, IS_EXPANDED);
    gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    is_visible = gtk_tree_view_column_cell_is_visible (column1);
    if (is_visible != TRUE)
    {
        TEST_FAIL ("is_visible = %d, should be %d", is_visible, TRUE);
    }
    
    gtk_tree_view_column_clear (column1);
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef IS_EXPANDED
    #undef IS_EXPANDER
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_set_cell_data
 * Params: GtkTreeViewColumn *tree_column, GtkTreeModel *tree_model, GtkTreeIter *iter, gboolean is_expander, gboolean is_expanded
 * Returns: void
 * Assertion: Sets the cell renderer based on the tree_model and iter.
 * Params Values: a newly created GtkTextViewColumn, GtkTreeStore*, GtkTreeIter* got from path "4:3", FALSE, TRUE
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_cell_set_cell_data
 * Params: GtkTreeViewColumn *tree_column, GtkTreeModel *tree_model, GtkTreeIter *iter, gboolean is_expander, gboolean is_expanded
 * Returns: void
 * Assertion: That is, for every attribute mapping in tree_column, it will get a value from the set column on the iter, and use that value to set the attribute on the cell renderer.
 * Params Values: a newly created GtkTextViewColumn, GtkTreeStore*, GtkTreeIter* got from path "4:3", FALSE, TRUE
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_cell_is_visible
 * Params: GtkTreeViewColumn *tree_column
 * Returns: void
 * Assertion: Returns TRUE if any of the cells packed into the tree_column are visible.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: TRUE
 * 
 * Name:  gtk_tree_view_column_clear
 * Params: GtkTreeViewColumn *tree_column
 * Returns: void
 * Assertion: Unsets all the mappings on all renderers on the tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: void  
 */
static void test_purpose_115()
{
    #define PATH_STR "4:3"
    #define IS_EXPANDER FALSE
    #define IS_EXPANDED TRUE
    
    GtkTreeModel* model;
    GtkTreeViewColumn* column0;
    GtkTreeViewColumn* column1;
    GtkCellRenderer* renderer;
    GtkCellRenderer* renderer1;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkWidget* tree_view;
    gboolean is_visible;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = GTK_TREE_MODEL (gtk_tree_store_new (3, G_TYPE_UINT, 
                                                G_TYPE_UINT, G_TYPE_UINT));
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (GTK_TREE_STORE (model), &iter, NULL);
        gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (GTK_TREE_STORE (model), &child_iter, &iter);
            gtk_tree_store_set (GTK_TREE_STORE (model), &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    renderer = gtk_cell_renderer_text_new ();
    column0 = gtk_tree_view_column_new_with_attributes ("column0", renderer, 
                                                        "text", 0, 
                                                        "text", 1, 
                                                        NULL);
    if (!column0)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column0))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
    
    column1 = gtk_tree_view_column_new ();
    if (!column1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_model_get_iter_from_string (model, &iter, PATH_STR);
    gtk_tree_view_column_pack_start (column1, renderer, TRUE);
    gtk_tree_view_column_cell_set_cell_data (column1, model, &iter, IS_EXPANDER, IS_EXPANDED);
    gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    is_visible = gtk_tree_view_column_cell_is_visible (column1);
    if (is_visible != TRUE)
    {
        TEST_FAIL ("is_visible = %d, should be %d", is_visible, TRUE);
    }
    
    gtk_tree_view_column_clear (column1);
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef IS_EXPANDED
    #undef IS_EXPANDER
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_set_cell_data
 * Params: GtkTreeViewColumn *tree_column, GtkTreeModel *tree_model, GtkTreeIter *iter, gboolean is_expander, gboolean is_expanded
 * Returns: void
 * Assertion: Sets the cell renderer based on the tree_model and iter.
 * Params Values: a newly created GtkTextViewColumn, GtkTreeStore*, GtkTreeIter* got from path "2:1", TRUE, FALSE
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_cell_set_cell_data
 * Params: GtkTreeViewColumn *tree_column, GtkTreeModel *tree_model, GtkTreeIter *iter, gboolean is_expander, gboolean is_expanded
 * Returns: void
 * Assertion: That is, for every attribute mapping in tree_column, it will get a value from the set column on the iter, and use that value to set the attribute on the cell renderer.
 * Params Values: a newly created GtkTextViewColumn, GtkTreeStore*, GtkTreeIter* got from path "2:1", TRUE, FALSE
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_cell_is_visible
 * Params: GtkTreeViewColumn *tree_column
 * Returns: void
 * Assertion: Returns TRUE if any of the cells packed into the tree_column are visible.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: TRUE
 * 
 * Name:  gtk_tree_view_column_clear
 * Params: GtkTreeViewColumn *tree_column
 * Returns: void
 * Assertion: Unsets all the mappings on all renderers on the tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: void  
 */
static void test_purpose_116()
{
    #define PATH_STR "2:1"
    #define IS_EXPANDER TRUE
    #define IS_EXPANDED FALSE
    
    GtkTreeModel* model;
    GtkTreeViewColumn* column0;
    GtkTreeViewColumn* column1;
    GtkCellRenderer* renderer;
    GtkCellRenderer* renderer1;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkWidget* tree_view;
    gboolean is_visible;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = GTK_TREE_MODEL (gtk_tree_store_new (3, G_TYPE_UINT, 
                                                G_TYPE_UINT, G_TYPE_UINT));
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (GTK_TREE_STORE (model), &iter, NULL);
        gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (GTK_TREE_STORE (model), &child_iter, &iter);
            gtk_tree_store_set (GTK_TREE_STORE (model), &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    renderer = gtk_cell_renderer_text_new ();
    column0 = gtk_tree_view_column_new_with_attributes ("column0", renderer, 
                                                        "text", 0, 
                                                        "text", 1, 
                                                        NULL);
    if (!column0)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column0))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
    
    column1 = gtk_tree_view_column_new ();
    if (!column1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_model_get_iter_from_string (model, &iter, PATH_STR);
    gtk_tree_view_column_pack_start (column1, renderer, TRUE);
    gtk_tree_view_column_cell_set_cell_data (column1, model, &iter, IS_EXPANDER, IS_EXPANDED);
    gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    is_visible = gtk_tree_view_column_cell_is_visible (column1);
    if (is_visible != TRUE)
    {
        TEST_FAIL ("is_visible = %d, should be %d", is_visible, TRUE);
    }
    
    gtk_tree_view_column_clear (column1);
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef IS_EXPANDED
    #undef IS_EXPANDER
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_cell_set_cell_data
 * Params: GtkTreeViewColumn *tree_column, GtkTreeModel *tree_model, GtkTreeIter *iter, gboolean is_expander, gboolean is_expanded
 * Returns: void
 * Assertion: Sets the cell renderer based on the tree_model and iter.
 * Params Values: a newly created GtkTextViewColumn, GtkTreeStore*, GtkTreeIter* got from path "1:0", FALSE, FALSE
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_cell_set_cell_data
 * Params: GtkTreeViewColumn *tree_column, GtkTreeModel *tree_model, GtkTreeIter *iter, gboolean is_expander, gboolean is_expanded
 * Returns: void
 * Assertion: That is, for every attribute mapping in tree_column, it will get a value from the set column on the iter, and use that value to set the attribute on the cell renderer.
 * Params Values: a newly created GtkTextViewColumn, GtkTreeStore*, GtkTreeIter* got from path "1:0", FALSE, FALSE
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_cell_is_visible
 * Params: GtkTreeViewColumn *tree_column
 * Returns: void
 * Assertion: Returns TRUE if any of the cells packed into the tree_column are visible.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: TRUE
 * 
 * Name:  gtk_tree_view_column_clear
 * Params: GtkTreeViewColumn *tree_column
 * Returns: void
 * Assertion: Unsets all the mappings on all renderers on the tree_column.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: void  
 */
static void test_purpose_117()
{
    #define PATH_STR "1:0"
    #define IS_EXPANDER FALSE
    #define IS_EXPANDED FALSE
    
    GtkTreeModel* model;
    GtkTreeViewColumn* column0;
    GtkTreeViewColumn* column1;
    GtkCellRenderer* renderer;
    GtkCellRenderer* renderer1;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkWidget* tree_view;
    gboolean is_visible;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = GTK_TREE_MODEL (gtk_tree_store_new (3, G_TYPE_UINT, 
                                                G_TYPE_UINT, G_TYPE_UINT));
    tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
    for (i = 0; i < NUM_TREE_ELEMS; i++)
    {
        gint j;
        
        gtk_tree_store_append (GTK_TREE_STORE (model), &iter, NULL);
        gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
                            0, data[i].number1,
                            1, data[i].number2,
                            -1);
        for (j = 0; j < NUM_TREE_ELEMS; j++)
        {
            gtk_tree_store_append (GTK_TREE_STORE (model), &child_iter, &iter);
            gtk_tree_store_set (GTK_TREE_STORE (model), &child_iter,
                                0, child_data[j].number1,
                                1, child_data[j].number2,
                                -1);
        }
    }
    
    renderer = gtk_cell_renderer_text_new ();
    column0 = gtk_tree_view_column_new_with_attributes ("column0", renderer, 
                                                        "text", 0, 
                                                        "text", 1, 
                                                        NULL);
    if (!column0)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column0))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column0);
    
    column1 = gtk_tree_view_column_new ();
    if (!column1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_tree_model_get_iter_from_string (model, &iter, PATH_STR);
    gtk_tree_view_column_pack_start (column1, renderer, TRUE);
    gtk_tree_view_column_cell_set_cell_data (column1, model, &iter, IS_EXPANDER, IS_EXPANDED);
    gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (tree_view);
    /******* -------------  *******/  
    
    is_visible = gtk_tree_view_column_cell_is_visible (column1);
    if (is_visible != TRUE)
    {
        TEST_FAIL ("is_visible = %d, should be %d", is_visible, TRUE);
    }
    
    gtk_tree_view_column_clear (column1);
    gtk_widget_destroy (gtk_widget_get_toplevel (tree_view));
    
    #undef IS_EXPANDED
    #undef IS_EXPANDER
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_clicked
 * Params: GtkTreeViewColumn *tree_column
 * Returns: void
 * Assertion: Emits the "clicked" signal on the column.
 * Params Values: a newly created GtkTreeViewColumn*
 * Expected: void
 * 
 * Name:  gtk_tree_view_column_clicked
 * Params: GtkTreeViewColumn *tree_column
 * Returns: void
 * Assertion: This function will only work if tree_column is clickable.
 * Params Values: a newly created GtkTreeViewColumn*
 * Expected: void  
 */
static void test_purpose_118()
{
    GtkWidget* view;
    GtkTreeViewColumn* column;
    GtkCellRenderer* renderer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    renderer = gtk_cell_renderer_text_new ();
    column = gtk_tree_view_column_new_with_attributes ("title", renderer,  "text", 0, NULL);
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        GtkCellRenderer* renderer;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
    
        renderer = gtk_cell_renderer_text_new ();
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    global_counter = 0;
    g_signal_connect (G_OBJECT (column), "clicked", 
                      GTK_SIGNAL_FUNC (global_clicked_handler), NULL);
    
    gtk_tree_view_column_set_clickable (column, FALSE);
    gtk_tree_view_column_clicked (column);
    if (global_counter != 0)
    {
        TEST_FAIL ("column is not clickable but gtk_tree_view_column_clicked() works: global_counter = %d, should be 0", global_counter);
    }
    
    global_counter = 0;
    gtk_tree_view_column_set_clickable (column, TRUE);
    gtk_tree_view_column_clicked (column);
    if (global_counter != 1)
    {
        TEST_FAIL ("column is clickable but gtk_tree_view_column_clicked() doesn't work: global_counter = %d, should be 1", global_counter);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_cell_renderers
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GList*
 * Assertion: Returns a newly-allocated GList of all the cell renderers in the column, in no particular order.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: list of cell renderers  
 */
static void test_purpose_119()
{
    #define RENDERERS gtk_cell_renderer_text_new ()
    #define NUM_RENDERERS 1
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], TRUE);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_cell_renderers
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GList*
 * Assertion: Returns a newly-allocated GList of all the cell renderers in the column, in no particular order.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: list of cell renderers  
 */
static void test_purpose_120()
{
    #define RENDERERS gtk_cell_renderer_toggle_new()
    #define NUM_RENDERERS 1
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], TRUE);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_cell_renderers
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GList*
 * Assertion: Returns a newly-allocated GList of all the cell renderers in the column, in no particular order.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: list of cell renderers  
 */
static void test_purpose_121()
{
    #define RENDERERS gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 1
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], TRUE);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_cell_renderers
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GList*
 * Assertion: Returns a newly-allocated GList of all the cell renderers in the column, in no particular order.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: list of cell renderers  
 */
static void test_purpose_122()
{
    #define RENDERERS gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 2
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], TRUE);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_cell_renderers
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GList*
 * Assertion: Returns a newly-allocated GList of all the cell renderers in the column, in no particular order.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: list of cell renderers  
 */
static void test_purpose_123()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 3
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], TRUE);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_cell_renderers
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GList*
 * Assertion: Returns a newly-allocated GList of all the cell renderers in the column, in no particular order.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: list of cell renderers  
 */
static void test_purpose_124()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 6
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], TRUE);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_get_cell_renderers
 * Params: GtkTreeViewColumn *tree_column
 * Returns: GList*
 * Assertion: Returns a newly-allocated GList of all the cell renderers in the column, in no particular order.
 * Params Values: a newly created GtkTextViewColumn
 * Expected: list of cell renderers  
 */
static void test_purpose_125()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(), gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(), gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 18
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], TRUE);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_126()
{
    #define RENDERERS gtk_cell_renderer_text_new ()
    #define NUM_RENDERERS 1
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_127()
{
    #define RENDERERS gtk_cell_renderer_toggle_new()
    #define NUM_RENDERERS 1
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_128()
{
    #define RENDERERS gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 1
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_129()
{
    #define RENDERERS gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 2
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_130()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 3
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_131()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 6
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_132()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(), gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(), gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 18
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_133()
{
    #define RENDERERS gtk_cell_renderer_text_new ()
    #define NUM_RENDERERS 1
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_134()
{
    #define RENDERERS gtk_cell_renderer_toggle_new()
    #define NUM_RENDERERS 1
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_135()
{
    #define RENDERERS gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 1
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_136()
{
    #define RENDERERS gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 2
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_137()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 3
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_138()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 6
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_start
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Packs the cell into the beginning of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_139()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(), gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(), gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 18
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_start (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_140()
{
    #define RENDERERS gtk_cell_renderer_text_new ()
    #define NUM_RENDERERS 1
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_141()
{
    #define RENDERERS gtk_cell_renderer_toggle_new()
    #define NUM_RENDERERS 1
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_142()
{
    #define RENDERERS gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 1
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_143()
{
    #define RENDERERS gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 2
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_144()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 3
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_145()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 6
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, TRUE
 * Expected: void  
 */
static void test_purpose_146()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(), gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(), gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 18
    #define EXPAND TRUE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_147()
{
    #define RENDERERS gtk_cell_renderer_text_new ()
    #define NUM_RENDERERS 1
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_148()
{
    #define RENDERERS gtk_cell_renderer_toggle_new()
    #define NUM_RENDERERS 1
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_149()
{
    #define RENDERERS gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 1
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_150()
{
    #define RENDERERS gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 2
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_151()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 3
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_152()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 6
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, FALSE
 * Expected: void  
 */
static void test_purpose_153()
{
    #define RENDERERS gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(), gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(), gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new(),gtk_cell_renderer_text_new (), gtk_cell_renderer_toggle_new(), gtk_cell_renderer_pixbuf_new()
    #define NUM_RENDERERS 18
    #define EXPAND FALSE
    
    GList* real_renderers;
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[NUM_RENDERERS] = { RENDERERS };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], EXPAND);
    }
    
    real_renderers = gtk_tree_view_column_get_cell_renderers (column);
    for (i = 0; i < NUM_RENDERERS; i++)
    {
        if (!g_list_find (real_renderers, renderers[i]))
        {
            TEST_FAIL ("can't find renderer number %d in the list of renderers", 
                       i);
        }
    }
        
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    g_list_free (real_renderers);
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    #undef RENDERERS
    #undef NUM_RENDERERS
    #undef EXPAND
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_tree_view_column_pack_end
 * Params: GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, gboolean expand
 * Returns: void
 * Assertion: Adds the cell to end of the column.
 * Params Values: a newly created GtkTextViewColumn*, GtkCellRenderer*, <%2%>
 * Expected: void  
 */
static void test_purpose_154()
{
    GtkTreeViewColumn* column;
    gint i;
    GtkWidget* view;
    GtkCellRenderer *renderers[] = { gtk_cell_renderer_text_new (),
                                     gtk_cell_renderer_text_new () };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    column = gtk_tree_view_column_new ();
    
    if (!column)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TREE_VIEW_COLUMN (column))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < sizeof (renderers) / sizeof (renderers[0]); i++)
    {
        gtk_tree_view_column_pack_end (column, renderers[i], TRUE);
    }
    
    /******* VISUALISATION *******/
    {
        GtkTreeIter iter;
        int i;
        GtkListStore* model;
    
        model = gtk_list_store_new (1, G_TYPE_STRING);
        for (i = 0; i < 5; i++)
        {
            gtk_list_store_append (model, &iter);
        }
    
        view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
        gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
    
        TEST_VISUALIZE (view);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (view));
    
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkTreeViewColumn ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {test_purpose_116, 1},
    {test_purpose_117, 1},
    {test_purpose_118, 1},
    {test_purpose_119, 1},
    {test_purpose_120, 1},
    {test_purpose_121, 1},
    {test_purpose_122, 1},
    {test_purpose_123, 1},
    {test_purpose_124, 1},
    {test_purpose_125, 1},
    {test_purpose_126, 1},
    {test_purpose_127, 1},
    {test_purpose_128, 1},
    {test_purpose_129, 1},
    {test_purpose_130, 1},
    {test_purpose_131, 1},
    {test_purpose_132, 1},
    {test_purpose_133, 1},
    {test_purpose_134, 1},
    {test_purpose_135, 1},
    {test_purpose_136, 1},
    {test_purpose_137, 1},
    {test_purpose_138, 1},
    {test_purpose_139, 1},
    {test_purpose_140, 1},
    {test_purpose_141, 1},
    {test_purpose_142, 1},
    {test_purpose_143, 1},
    {test_purpose_144, 1},
    {test_purpose_145, 1},
    {test_purpose_146, 1},
    {test_purpose_147, 1},
    {test_purpose_148, 1},
    {test_purpose_149, 1},
    {test_purpose_150, 1},
    {test_purpose_151, 1},
    {test_purpose_152, 1},
    {test_purpose_153, 1},
    {test_purpose_154, 1},
    {NULL,0}
};
